-- (#) ./base/db/Oracle8i/client/create_ent_doc_schema.sql BL_core_schema_8.0.7_8.0.7.4.02_20100413  064938
-- (#) 
--
CREATE TABLE pm_document_type
(
  document_type_id   INTEGER           NOT NULL,
  document_type_name VARCHAR2(50)      NOT NULL,
  document_table     VARCHAR2(30)      NOT NULL,
  document_id_col    VARCHAR2(30)      NOT NULL,
  document_name_col  VARCHAR2(30),
  document_user_col  VARCHAR2(30),
  localhome          VARCHAR2(256),
  local              VARCHAR2(256),
  jndi               VARCHAR2(256),
  CONSTRAINT PK_pm_document_type PRIMARY KEY(document_type_id)
)
TABLESPACE WM_Client;

CREATE UNIQUE INDEX UNQ_pm_doc_typ_name
ON pm_document_type (UPPER(document_type_name))
TABLESPACE WM_Client;

CREATE SEQUENCE seq_document_type
    START WITH  1
    INCREMENT BY 1
    NOMAXVALUE
    NOCYCLE
;

INSERT INTO pm_document_type VALUES 
(seq_document_type.nextval, 'Folder', 'PM_Folder', 'ID', 'NAME', 'USERID', 
'com.watchmark.prospect.enterprise.FolderLocalHome',
'com.watchmark.prospect.enterprise.FolderLocal',NULL);

INSERT INTO pm_document_type VALUES 
(seq_document_type.nextval, 'Report', 'PM_Report', 'ID', 'NAME', 'USERID', 
'com.watchmark.prospect.enterprise.ReportLocalHome',
'com.watchmark.prospect.enterprise.ReportLocal',NULL);

INSERT INTO pm_document_type VALUES
(seq_document_type.nextval, 'Schedule', 'PM_Schedule', 'ID', 'NAME', 'USERID',
'com.watchmark.prospect.enterprise.ScheduleLocalHome',
'com.watchmark.prospect.enterprise.ScheduleLocal',NULL);

INSERT INTO pm_document_type VALUES
(seq_document_type.nextval, 'Report Group', 'PM_rptgrp', 'ID', 'NAME', 'USERID',
'com.watchmark.prospect.enterprise.ReportGroupLocalHome',
'com.watchmark.prospect.enterprise.ReportGroupLocal',NULL);

COMMIT;

---------------------------------------------------------------------------
-- the following section is to be moving to create_client_schema.sql
---------------------------------------------------------------------------
-- CREATE TABLE pm_group
-- (
--   group_id           INTEGER          NOT NULL,
--   group_name         VARCHAR2(256),
--  CONSTRAINT PK_pm_group PRIMARY KEY(group_id)
-- )
-- TABLESPACE WM_Client;

-- INSERT INTO pm_group(group_id,group_name)
-- VALUES(1,'PUBLIC');

-- INSERT INTO pm_group(group_id,group_name)
-- VALUES(2,'NOGROUP');

-- this will be put into pm_user table creation 
-- ALTER TABLE pm_user add 
-- ( group_id   INTEGER DEFAULT 1, -- NOGROUP group ID
--   CONSTRAINT fk_pm_user_grp_id FOREIGN KEY(group_id)
--       REFERENCES pm_group(group_id)
-- )
-- ;

-- CREATE UNIQUE INDEX UNQ_pm_grp_name on pm_group(UPPER(group_name))
-- TABLESPACE WM_Client;

-- CREATE SEQUENCE seq_pm_group_id
--     START WITH  1000
--     INCREMENT BY 1
--     NOMAXVALUE
--     NOCYCLE
-- ;

---------------------------------------------------------------------------
-- end of this section
---------------------------------------------------------------------------

CREATE TABLE pm_document
(
  document_id        INTEGER          NOT NULL, -- pk
  parent_doc_id      INTEGER,
  document_type_id   INTEGER          NOT NULL, -- fk to pm_document_type
  name               NVARCHAR2(256)    NOT NULL, -- name of the document
  document_fk        INTEGER          NOT NULL, -- generic fk to payload tbl
  user_id            INTEGER          NOT NULL, -- fk to pm_user
  group_id           INTEGER          NOT NULL, -- fk to pm_group
  user_read          CHAR(1)          NOT NULL,
  user_write         CHAR(1)          NOT NULL,
  group_read         CHAR(1)          NOT NULL,
  group_write        CHAR(1)          NOT NULL,
  created            DATE             DEFAULT SYSDATE,
  changed            DATE             DEFAULT SYSDATE,
  cleanup_time       DATE             ,  
  mime_type          VARCHAR2(64)     DEFAULT 'application/x-watchmark-doc',
  size_bytes         INTEGER          DEFAULT 0,
  description        VARCHAR2(255),
  CONSTRAINT pk_pm_document PRIMARY KEY (document_id),
  CONSTRAINT fk_parent_doc_id FOREIGN KEY(parent_doc_id)
     REFERENCES pm_document(document_id),
  CONSTRAINT fk_pm_doc_doc_type_id FOREIGN KEY(document_type_id)
     REFERENCES pm_document_type(document_type_id), 
  CONSTRAINT fk_pm_doc_user_id FOREIGN KEY(user_id)
     REFERENCES pm_user(id),
  CONSTRAINT fk_pm_doc_grp_id FOREIGN KEY(group_id)
     REFERENCES pm_group(group_id),
  CONSTRAINT UNQ_pm_doc_doctyp_fk UNIQUE(document_type_id, document_fk),
  CONSTRAINT ck_changed_after_create CHECK (changed >= created)
)
TABLESPACE WM_Client;

CREATE SEQUENCE seq_document_ID
    START WITH  1000
    INCREMENT BY 1
    NOMAXVALUE
    NOCYCLE
;

CREATE UNIQUE INDEX unq_pm_doc_fldid_name
 ON pm_document(parent_doc_id, UPPER(name));

CREATE INDEX idx_pm_document_name ON pm_document(name);

CREATE INDEX idx_pm_document_mime ON pm_document(UPPER(mime_type));

CREATE INDEX idx_pm_document_cleanup ON pm_document(cleanup_time);

CREATE INDEX idx_pm_document_parent_doc_id ON pm_document(parent_doc_id);

CREATE INDEX idx_pm_document_doctype ON pm_document(document_type_id);

CREATE TABLE pm_doc_properties
(
  document_id INTEGER      NOT NULL,   -- fk to pm_document
  name        VARCHAR2(64) NOT NULL,
  value       VARCHAR2(255),
  CONSTRAINT pk_pm_docprop PRIMARY KEY (document_id, name),
  CONSTRAINT fk_pm_docprop_did FOREIGN KEY(document_id) REFERENCES pm_document(document_id) ON DELETE CASCADE
) 
TABLESPACE WM_Client;
 
CREATE GLOBAL TEMPORARY TABLE pm_doc_properties_tmp
(
  document_id INTEGER NOT NULL,
  name        VARCHAR2(64) NOT NULL,
  value       VARCHAR2(255), 
  CONSTRAINT pk_pm_docprop_tmp PRIMARY KEY(document_id, name)
) 
ON COMMIT DELETE ROWS; 

CREATE GLOBAL TEMPORARY TABLE pm_doc_remove_tmp 
(
  id INTEGER NOT NULL,
  document_id INTEGER NULL,
  write_allowed VARCHAR2(10) NULL,
  name  VARCHAR2(256) NOT NULL, 
  path  VARCHAR2(2048) NOT NULL,
  CONSTRAINT pk_pm_docrem_tmp PRIMARY KEY(id)
)
ON COMMIT DELETE ROWS;

CREATE TABLE PM_User_Group
(
  User_id      INTEGER,
  Group_id     INTEGER,
 --
 -- primary key
 --
 CONSTRAINT PK_pm_User_Group PRIMARY KEY(User_id, Group_id),
 CONSTRAINT FK_pm_Usr_grp_gid 
             FOREIGN KEY(Group_id) REFERENCES PM_Group(Group_id) ON DELETE CASCADE,  
 CONSTRAINT FK_pm_Usr_Grp_uid 
             FOREIGN KEY(User_id) REFERENCES PM_User(id) ON DELETE CASCADE  
)
TABLESPACE WM_Client;

CREATE INDEX idx_pm_user_group_usrid ON pm_user_group(user_id);
CREATE INDEX idx_pm_user_group_grpid ON pm_user_group(group_id);

CREATE TABLE PM_User_acl_mask
(
  ACL_MASK_ID     INTEGER  NOT NULL,
  OwnerUser_ID    INTEGER  NOT NULL,
  User_ID         INTEGER,
  Group_ID        INTEGER,
  read            CHAR(1), 
  Write           CHAR(1), 
  --
  -- primary key
  --
 CONSTRAINT PK_PM_User_acl_mask PRIMARY KEY(ACL_MASK_ID),
 CONSTRAINT UNQ_PM_User_acl_mask UNIQUE (OwnerUser_ID, User_id, Group_id),
 CONSTRAINT FK_PM_Usr_acl_prof_ouid
             FOREIGN KEY(OwnerUser_id) REFERENCES PM_User(id) ON DELETE CASCADE,  
 CONSTRAINT FK_PM_Usr_acl_prof_uid 
             FOREIGN KEY(User_id) REFERENCES PM_User(id) ON DELETE CASCADE,  
 CONSTRAINT FK_PM_Usr_acl_prof_gid 
             FOREIGN KEY(group_id) REFERENCES PM_Group(group_id) ON DELETE CASCADE,  
 CONSTRAINT CHK_PM_User_acl_prof_read CHECK (read in ('Y','N')),
 CONSTRAINT CHK_PM_User_acl_prof_write CHECK (Write in ('Y','N'))
)
TABLESPACE WM_Client;  
  
CREATE SEQUENCE SQ_PM_User_acl_mask
    START WITH 1000
    INCREMENT BY 1
    NOMAXVALUE
    NOCYCLE
;

CREATE TABLE PM_Group_Acl
(
  Group_id       INTEGER,
  Doc_ID         INTEGER,
  read           CHAR(1),
  write          CHAR(1),
 --
 -- primary key
 --
 CONSTRAINT PK_PM_Group_Acl PRIMARY KEY(Group_id, Doc_ID),
 CONSTRAINT FK_PM_Grp_Acl_GrpID
                FOREIGN KEY(Group_ID) REFERENCES PM_Group(group_ID) ON DELETE CASCADE,
 CONSTRAINT FK_PM_Grp_Acl_Doc_id
                FOREIGN KEY(Doc_ID)   REFERENCES PM_Document(document_ID) ON DELETE CASCADE,
 CONSTRAINT CHK_PM_Grp_acl_read CHECK (read in ('Y','N')),
 CONSTRAINT CHK_PM_Grp_acl_write CHECK (Write in ('Y','N'))
)
TABLESPACE WM_Client;

CREATE INDEX idx_pm_group_acl_grpid ON pm_group_acl(group_id);
CREATE INDEX idx_pm_group_acl_docid ON pm_group_acl(doc_id);

CREATE TABLE PM_User_Acl
(
  User_ID          INTEGER,
  Doc_ID           INTEGER,
  read           CHAR(1),
  write          CHAR(1),
 --
 -- primary key
 --
 CONSTRAINT PK_PM_User_Acl PRIMARY KEY(User_id, Doc_ID),
 CONSTRAINT FK_PK_PM_Usr_Acl_UID
                FOREIGN KEY(User_id)   REFERENCES PM_User(ID) ON DELETE CASCADE,
 CONSTRAINT FK_PK_PM_Usr_Acl_DocID
                FOREIGN KEY(Doc_ID)    REFERENCES PM_Document(Document_ID) ON DELETE CASCADE,
 CONSTRAINT CHK_PM_Usr_acl_read CHECK(read in ('Y','N')),
 CONSTRAINT CHK_PM_Usr_acl_write CHECK(Write in ('Y','N'))
)
TABLESPACE WM_Client;

CREATE INDEX idx_pm_user_acl_usrid ON pm_user_acl(user_id);
CREATE INDEX idx_pm_user_acl_docid ON pm_user_acl(doc_id);

CREATE TABLE pm_url
(
  url_id             INTEGER          NOT NULL,
  url_type           CHAR(1)          NOT NULL,
  url                VARCHAR2(2000)   NOT NULL,
  CONSTRAINT PK_pm_url PRIMARY KEY(url_id)
)
TABLESPACE WM_Client;

-- following the Unix permission, the owner follows the owner permission bits
-- the group follows the group bits, since we have no other group, any other
-- user follows acl; The three views are for these three categories users.   
CREATE OR REPLACE VIEW pm_doc_owner_acl_v
AS
SELECT user_id, document_id doc_id, USER_READ read, USER_WRITE write
FROM pm_document;

CREATE OR REPLACE VIEW pm_doc_primarygroup_acl_v
AS
SELECT ug.user_id, doc.document_id doc_id,
       doc.GROUP_READ read, doc.GROUP_WRITE write
 FROM pm_document doc, pm_user_group ug
WHERE doc.group_id=ug.group_id;

CREATE OR REPLACE VIEW pm_doc_otheruser_acl_v
AS
SELECT user_id, doc_id, read, write
 FROM pm_user_acl
UNION
SELECT ug.user_id, gacl.doc_id, gacl.read,gacl.write
  FROM pm_user_group ug, pm_group_acl gacl
 WHERE ug.group_id=gacl.group_id;


-- Whenever something changes in a folder, an event gets posted
-- to this table so the folder cache can refresh. We include 
-- tstamp so we can purge
-- the table of events older than 1 day. This makes it possible
-- for multiple systems to read from the table, and keep it
-- clean at the same time.
CREATE TABLE pm_folder_event
(
  tstamp           DATE             NOT NULL,
  folder_event_id  INTEGER          NOT NULL,
  document_id      INTEGER          NOT NULL,
  CONSTRAINT pk_folder_event PRIMARY KEY (tstamp, folder_event_id),
  CONSTRAINT fk_folder_event_docid FOREIGN KEY(document_id) REFERENCES pm_document (document_id) ON DELETE CASCADE
) ORGANIZATION INDEX
TABLESPACE WM_Client;

--SEAde51509
CREATE INDEX pm_folder_event_doc_idx ON pm_folder_event(document_id);

CREATE SEQUENCE seq_folder_event
    START WITH  1
    INCREMENT BY 1
    NOMAXVALUE
    NOCYCLE
;

-- This table is used to hold files that need to be deleted when their
-- cleanup_time comes
--
CREATE TABLE pm_orphaned_files
(
  filename         VARCHAR2(256)    NOT NULL,
  cleanup_time     DATE,
  CONSTRAINT pk_orphaned_files PRIMARY KEY (filename)
)
TABLESPACE WM_Client;

-- --------------------------------------------------------
-- --------------------------------------------------------

CREATE TABLE pm_file (
  file_id   INTEGER,
  filename  VARCHAR2(256),
    CONSTRAINT pm_file_pk PRIMARY KEY ( file_id ),
    CONSTRAINT pm_file_filename_nn CHECK ( filename IS NOT NULL ),
    CONSTRAINT pm_file_filename_uq UNIQUE ( filename )
) TABLESPACE wm_client;

-- --------------------------------------------------------

CREATE SEQUENCE pm_file_seq;

-- --------------------------------------------------------

CREATE OR REPLACE TRIGGER pm_file_del_tr
   BEFORE DELETE ON pm_file FOR EACH ROW
BEGIN
 INSERT INTO pm_orphaned_files ( filename, cleanup_time )
   VALUES ( :old.filename, SYSDATE );
EXCEPTION
  WHEN DUP_VAL_ON_INDEX THEN
    NULL;
END;
/

-- --------------------------------------------------------
-- --------------------------------------------------------

EXIT

