
whenever sqlerror exit sql.sqlcode;

--
-- table of available functions. Static data
--
CREATE TABLE WM_Function(
    Id               INTEGER       PRIMARY KEY,
    RequiredArgCount INTEGER,
    OptionalArgCount INTEGER,
    Name             VARCHAR(64),
    ReturnType       CHAR(1)
);
--
-- sequence for WM_Function.Id
--
CREATE SEQUENCE WM_FunctionSQ
    START WITH 500
    INCREMENT BY 1
    NOMAXVALUE
    NOCYCLE
;

--
-- table of args required for each function defined above.
-- Static data.
--
CREATE TABLE WM_FunctionArgs(
    Id			INTEGER       PRIMARY KEY,
    FunctionId		INTEGER,
    Ordinal		INTEGER,
    Name		VARCHAR(64),
    Type		CHAR(1),
    Optional		CHAR(1) DEFAULT 'N',
    DefaultValueId	INTEGER -- FK to WM_Literal
);
--
-- sequence for WM_FunctionArgs.Id
--
CREATE SEQUENCE WM_FunctionArgsSQ
    START WITH 500
    INCREMENT BY 1
    NOMAXVALUE
    NOCYCLE
;


--
-- table identifying a particular use of a function in an expression
--
CREATE TABLE WM_FunctionInstance(
    Id			INTEGER PRIMARY KEY,
    FunctionId		INTEGER,
    ReferenceCount	INTEGER
);

--
-- sequence
--
CREATE SEQUENCE WM_FunctionInstanceSQ
    START WITH 500
    INCREMENT BY 1
    NOMAXVALUE
    NOCYCLE
;

--
-- table of function arguments. Expression
--
CREATE TABLE WM_FunctionAttributes(
    Id			INTEGER PRIMARY KEY,
    FunctionArgId	INTEGER, -- this is a value for this arg
    FunctionInstanceId  INTEGER NOT NULL, -- fk
    ExpressionId        INTEGER  -- FK into WM_Expression.Id
);

--
-- sequence
--
CREATE SEQUENCE WM_FunctionAttributesSQ
    START WITH 500
    INCREMENT BY 1
    NOMAXVALUE
    NOCYCLE
;

CREATE TABLE WM_Operator(
    Id			INTEGER PRIMARY KEY,
    Name		VARCHAR2(10)
);

--
-- sequence
--
CREATE SEQUENCE WM_OperatorSQ
    START WITH 500
    INCREMENT BY 1
    NOMAXVALUE
    NOCYCLE
;


--
-- Expressions can be defined in terms of other expressions,
-- functions or literals. Where the operatorId refers to a
-- literal operator, the LeftOperandId refers to a literal
-- id. When operatorId is a function type, LeftOperandId
-- refers to a WmFunctionInstance.Id. Otherwise, operands
-- refer internally to other WM_Expression.Ids
--
CREATE TABLE WM_Expression(
    Id			INTEGER PRIMARY KEY,
    OperatorId		INTEGER NOT NULL,
    LeftOperandId       INTEGER, -- unary, binary and ternary
    RightOperandId      INTEGER, -- binary and ternary
    TestOperandId	INTEGER, -- required for ternary
    ReferenceCount	INTEGER, -- support copy on write
    UserId		INTEGER  -- Support UDCs and System DCs
);

--
-- sequence
--
CREATE SEQUENCE WM_ExpressionSQ
    START WITH 500
    INCREMENT BY 1
    NOMAXVALUE
    NOCYCLE
;


--
-- Extensible list of literal types allow us to define
-- literals (such as constants, attributes etc) referring
-- to many sources.
CREATE TABLE WM_LiteralType(
    Id			INTEGER PRIMARY KEY,
    TypeName		VARCHAR2(64),
    LiteralSourceFK	INTEGER
);

--
-- sequence
--
CREATE SEQUENCE WM_LiteralTypeSQ
    START WITH 500
    INCREMENT BY 1
    NOMAXVALUE
    NOCYCLE
;

CREATE TABLE WM_Literal(
    Id			INTEGER PRIMARY KEY,
    LiteralTypeId	INTEGER,
    Value               VARCHAR2(64),
    AttributeFK		INTEGER -- generic
);

--
-- sequence
--
CREATE SEQUENCE WM_LiteralSQ
    START WITH 500
    INCREMENT BY 1
    NOMAXVALUE
    NOCYCLE
;

