# (#) ./base/db/Oracle8i/creation_scripts/global.Makefile BL_core_schema_8.0.7_8.0.7.4.02_20100413  064938
# (#) 
INSTALL	      = install

MAKEFILE      = Makefile

SHELL	      = /bin/sh

INSTALLDIR=..
################################################################
DBUSER=changeme
DBPASSWD=changeme
SID=changeme

SYSPASSWD=change_on_install
LOADERUSER=changeme
LOADERPASSWD=changeme
APPUSER=changeme
APPPASSWD=changeme
ORACLE_BASE=/u01/apps/oracle
ORACLE_HOME=/u01/apps/oracle/product/8.1.5
EXPORT_LOCATION=/export/home/oracle/exps
DAYS_TO_KEEP_ONLINE=3
DAYS_TO_KEEP_OFFLINE=4
DAYS_PARTITIONS_AHEAD=7

################################################################
TABLEDEFS_R14=tableDefFileR14
TABLEDEFS_R13=tableDefFileR13
TABLEDEFS_R12=tableDefFileR12

all:	build control dbtable dbfile

# makeAllTimeSeries.sh is one of the files created by the build script
# so we use that as our build target.
build:	makeAllTimeSeries.sql

control:	LoaderControl.txt

dbtable:	DatabaseTable.txt

dbfile:		DatabaseFile.txt

makeAllTimeSeries.sql:	buildTS.nawk $(TABLEDEFS_R14) $(MAKEFILE)
	nawk -f buildTS.nawk $(TABLEDEFS_R14)

LoaderControl.txt:	buildControl.nawk $(MAKEFILE) colDefsR14/* colDefsR13/* colDefsR12/* \
                        $(TABLEDEFS_R14) $(TABLEDEFS_R13) $(TABLEDEFS_R12)
	@banner "R12 run"
	@nawk -f buildControl.nawk $(TABLEDEFS_R12)
	@mv LoaderControl.txt LoaderControl.txt.R12
	@banner "R13 run"
	@nawk -f buildControl.nawk $(TABLEDEFS_R13)
	@mv LoaderControl.txt LoaderControl.txt.R13
	@echo "#R13 Above\n#### SOFTWARE BOUNDARY####\n#R12 Below\n" >> LoaderControl.txt.R13
	@banner "R14 run"
	@nawk -f buildControl.nawk $(TABLEDEFS_R14)
	@echo "#R14 Above\n#### SOFTWARE BOUNDARY####\n#R13 Below\n" >> LoaderControl.txt
	@cat LoaderControl.txt.R13 LoaderControl.txt.R12 >> LoaderControl.txt
	@rm -f LoaderControl.txt.R12 LoaderControl.txt.R13

DatabaseTable.txt:	buildDBTable.nawk $(TABLEDEFS_R14) $(MAKEFILE)
	@echo "nawk -f buildDBTable.nawk -v ora_sid=$(SID) -v ora_user=$(DBUSER) -v ora_passwd=***** $(TABLEDEFS_R14)"
	@nawk -f buildDBTable.nawk -v ora_sid=$(SID) -v ora_user=$(DBUSER) -v ora_passwd=$(DBPASSWD) $(TABLEDEFS_R14)

DatabaseFile.txt:	buildDBFile.nawk $(TABLEDEFS_R14) $(MAKEFILE)
	@echo "nawk -f buildDBTable.nawk -v writeDBfile=1 -v ora_sid=$(SID) -v ora_user=$(DBUSER) -v ora_passwd=****** $(TABLEDEFS_R14)"
	@nawk -f buildDBTable.nawk -v writeDBfile=1 -v ora_sid=$(SID) -v ora_user=$(DBUSER) -v ora_passwd=$(DBPASSWD) $(TABLEDEFS_R14)

ts:
	(cd schema; @sqlplus /NOLOG @pros_owner.sql $(SYSPASSWD) $(DBUSER) $(DBPASSWD) $(SID); cd ..)
	@echo "sqlplus $(DBUSER)/*****@$(SID)@makeAllTimeSeries.sql"
	@sqlplus $(DBUSER)/$(DBPASSWD)@$(SID) @makeAllTimeSeries.sql
	(cd schema; @sqlplus /NOLOG @pros_loader.sql $(SYSPASSWD) $(LOADERUSER) $(LOADERPASSWD) $(SID) $(DBUSER) $(DBPASSWD); cd ..)
	(cd schema; @sqlplus /NOLOG @pros_user.sql $(SYSPASSWD) $(APPUSER) $(APPPASSWD) $(SID) $(DBUSER) $(DBPASSWD); cd ..)
	#(mkdir $(ORACLE_BASE)/admin)
	#(mkdir $(ORACLE_BASE)/admin/$(SID))
	#(mkdir $(ORACLE_BASE)/admin/$(SID)/External) 
	#(cp schema/wmexport.so $(ORACLE_BASE)/admin/$(SID)/External ) 
	(cd schema;  @sqlplus /NOLOG @pros_control.sql $(DBUSER) $(DBPASSWD) $(SID) $(LOADERUSER) $(ORACLE_BASE) $(DAYS_TO_KEEP_ONLINE) $(DAYS_TO_KEEP_OFFLINE) $(EXPORT_LOCATION) $(ORACLE_HOME) $(DAYS_PARTITIONS_AHEAD) $(SYSPASSWD) $(LOADERPASSWD); cd ..)


drop:
	@echo "$(DBUSER)/*****@$(SID) @dropAllTimeSeries.sql"
	@sqlplus $(DBUSER)/$(DBPASSWD)@$(SID) @dropAllTimeSeries.sql

empty:
	nawk -f buildTruncate.nawk $(TABLEDEFS_R14)
	@echo "$(DBUSER)/******@$(SID) @truncateAllTables.sql"
	@sqlplus $(DBUSER)/$(DBPASSWD)@$(SID) @truncateAllTables.sql

install:	$(INSTALLDIR)/data/LoaderControl.txt $(INSTALLDIR)/data/DatabaseTable.txt \
		$(INSTALLDIR)/data/DatabaseFile.txt

$(INSTALLDIR)/data/LoaderControl.txt:	LoaderControl.txt
	(cd $(INSTALLDIR)/data; sccs edit LoaderControl.txt)
	rm -f $(INSTALLDIR)/data/LoaderControl.txt
	cp LoaderControl.txt $(INSTALLDIR)/data/LoaderControl.txt
	(cd $(INSTALLDIR)/data; \
	sccs delget -y"installing new LoaderControl.txt" LoaderControl.txt)

$(INSTALLDIR)/data/DatabaseTable.txt:	DatabaseTable.txt
	(cd $(INSTALLDIR)/data; sccs edit DatabaseTable.txt)
	rm -f $(INSTALLDIR)/data/DatabaseTable.txt
	cp DatabaseTable.txt $(INSTALLDIR)/data/DatabaseTable.txt
	(cd $(INSTALLDIR)/data; \
	sccs delget -y"installing new DatabaseTable.txt" DatabaseTable.txt)

$(INSTALLDIR)/data/DatabaseFile.txt:	DatabaseFile.txt
	(cd $(INSTALLDIR)/data; sccs edit DatabaseFile.txt)
	rm -f $(INSTALLDIR)/data/DatabaseFile.txt
	cp DatabaseFile.txt $(INSTALLDIR)/data/DatabaseFile.txt
	(cd $(INSTALLDIR)/data; \
	sccs delget -y"installing new DatabaseFile.txt" DatabaseFile.txt)

.C.o:
	$(CC) -c $(CXXFLAGS) $<

.c.o:
	$(CC) -c -w $(CFLAGS) $<

clean:
	@rm -fr BUILD DROP LOAD_CONTROL
	@rm -f LoaderControl.txt DatabaseTable.txt DatabaseFile.txt
	@rm -f makeAllTimeSeries.sql dropAllTimeSeries.sql
	@rm -f loaderHistoryDrop.lst truncateAllTables.sql

###
