-- -------------------------------------
-- (#) ./base/db/Oracle8i/ea/Export/create_ea_imp_schema.sql BL_core_schema_8.0.7_8.0.7.4.02_20100413  064938
-- (#) 
-- -------------------------------------
--

SET SERVEROUTPUT ON SIZE 1000000

DECLARE
  NO_TABLE EXCEPTION;
  PRAGMA EXCEPTION_INIT( NO_TABLE, -00942 );
BEGIN
  EXECUTE IMMEDIATE 'DROP TABLE EXP_DELETE';
EXCEPTION
  WHEN NO_TABLE THEN NULL;
END;
/

CREATE TABLE exp_delete (
  tstamp      DATE, 
  table_name  VARCHAR2(30), 
  row_id      ROWID,
  p_row_id    ROWID,
  msg         LONG,
    CONSTRAINT exp_delete_pk PRIMARY KEY ( table_name, row_id )
);

PROMPT Creating index pm_calendar_unq...

DECLARE
  NAME_IN_USE EXCEPTION;
  PRAGMA EXCEPTION_INIT( NAME_IN_USE, -955 );
BEGIN
  EXECUTE IMMEDIATE
    'CREATE UNIQUE INDEX pm_calendar_unq ON pm_calendar  ' ||
    '  ( DTSCOPEID, CALENDARDATE, FIRSTHOUR, LASTHOUR, ' ||
    '    FIRSTSECONDS, LASTSECONDS ) ';
EXCEPTION
  WHEN NAME_IN_USE THEN
    DBMS_OUTPUT.PUT_LINE( 'OK. Index pm_calendar_unq already exists...' );
END;
/

PROMPT Creating index pm_hourrange_uq...

DECLARE
  NAME_IN_USE EXCEPTION;
  PRAGMA EXCEPTION_INIT( NAME_IN_USE, -955 );
BEGIN
  EXECUTE IMMEDIATE
    'CREATE UNIQUE INDEX pm_hourrange_uq ' ||
    '  ON pm_hourrange ( busyhourid, firsthour, lasthour ) ' ||
    '  TABLESPACE wm_client ';
EXCEPTION
  WHEN NAME_IN_USE THEN
    DBMS_OUTPUT.PUT_LINE( 'OK. Index pm_hourrange_uq already exists...' );
END;
/
 
CREATE OR REPLACE VIEW EXP_JOB_GROUP_VIEW AS
  SELECT * FROM JOB_GROUP WHERE GROUP_TYPE = 1004;

CREATE OR REPLACE VIEW EXP_PM_FOLDER_DEL_VIEW AS
  SELECT * FROM PM_FOLDER;

CREATE OR REPLACE VIEW EXP_HOURRANGE_VIEW AS
 SELECT a.userid,
        b.id,
        b.busyhourid,
        b.firsthour,
        b.lasthour,
        b.firstseconds,
        b.lastseconds
    FROM pm_busyhour a, pm_hourrange b
   WHERE a.id = b.busyhourid;

CREATE OR REPLACE TRIGGER EXP_HOURRANGE_VIEW_TR
  instead of insert or update or delete 
    on EXP_HOURRANGE_VIEW for each row
DECLARE
  lv_userid NUMBER;
BEGIN

  IF ( INSERTING ) THEN
    SELECT userid INTO lv_userid FROM pm_busyhour WHERE id = :new.busyhourid;
    IF ( lv_userid = :new.userid ) THEN

      INSERT INTO PM_HOURRANGE ( ID, BUSYHOURID, FIRSTHOUR, LASTHOUR, FIRSTSECONDS, LASTSECONDS )
        VALUES ( :new.ID, :new.BUSYHOURID, :new.FIRSTHOUR, :new.LASTHOUR, :new.FIRSTSECONDS, :new.LASTSECONDS );

    END IF;

  ELSIF ( UPDATING ) THEN
    SELECT userid INTO lv_userid FROM pm_busyhour WHERE id = :new.busyhourid;
    IF ( lv_userid = :new.userid ) THEN
 
     UPDATE PM_HOURRANGE
        SET BUSYHOURID = :new.BUSYHOURID, FIRSTHOUR = :new.FIRSTHOUR, LASTHOUR = :new.LASTHOUR,
            FIRSTSECONDS = :new.FIRSTSECONDS, LASTSECONDS = :new.LASTSECONDS
      WHERE ID = :old.id;

    END IF;

  ELSIF ( DELETING ) THEN 
    SELECT userid INTO lv_userid FROM pm_busyhour WHERE id = :old.busyhourid;
    IF ( lv_userid = :old.userid ) THEN

      DELETE FROM PM_HOURRANGE WHERE id = :old.id;

    END IF;

  END IF;

END;
/
SHOW ERRORS

CREATE OR REPLACE VIEW exp_field_name_view AS
  SELECT d.namespace_id, d.name, d.report_header, d.report_header2, d.edit_label, d.name_desc,
         f.field_id, f.entity_id, f.datatype, f.field_type, f.field_group_id, f.field_access, f.field_owner, f.field_desc, f.field_aggregator, f.field_emits_aggregator, f.datasource_id
    FROM wmd_dict_name d, wmd_field_def f
   WHERE d.field_id = f.field_id
     AND d.entity_id = f.entity_id;

CREATE OR REPLACE TRIGGER exp_field_name_view_ins_tr
  INSTEAD OF INSERT ON exp_field_name_view FOR EACH ROW
BEGIN
  INSERT INTO wmd_field_def ( field_id, entity_id, datatype, field_type, field_group_id, field_access, field_owner, field_desc, field_aggregator, field_emits_aggregator, datasource_id )
    VALUES ( :new.field_id, :new.entity_id, :new.datatype, :new.field_type, :new.field_group_id, :new.field_access, :new.field_owner, :new.field_desc, :new.field_aggregator, :new.field_emits_aggregator, :new.datasource_id );
  INSERT INTO wmd_dict_name ( namespace_id, field_id, entity_id, name, report_header, report_header2, edit_label, name_desc )
    VALUES ( :new.namespace_id, :new.field_id, :new.entity_id, :new.name, :new.report_header, :new.report_header2, :new.edit_label, :new.name_desc );
END;
/
SHOW ERRORS

CREATE OR REPLACE TRIGGER exp_field_name_view_upd_tr
  INSTEAD OF UPDATE ON exp_field_name_view FOR EACH ROW
BEGIN
  UPDATE wmd_field_def 
     SET entity_id = :new.entity_id,
         datatype = :new.datatype,
         field_type = :new.field_type,
         field_group_id = :new.field_group_id,
         field_access = :new.field_access,
         field_owner = :new.field_owner,
         field_desc = :new.field_desc,
         field_aggregator = :new.field_aggregator,
         field_emits_aggregator = :new.field_emits_aggregator,
         datasource_id = :new.datasource_id
   WHERE field_id = :old.field_id;

  UPDATE wmd_dict_name
     SET entity_id = :new.entity_id,
         name = :new.name,
         report_header = :new.report_header,
         report_header2 = :new.report_header2,
         edit_label = :new.edit_label,
         name_desc = :new.name_desc
   WHERE field_id = :old.field_id
     AND namespace_id = :old.namespace_id; 

END;
/
SHOW ERRORS

CREATE OR REPLACE VIEW exp_pm_cfgtpl_view AS
  SELECT (id * -1) id, folderid, userid, name, description, changed, category, type, entity_id, needsinput
    FROM pm_cfgtpl;

CREATE OR REPLACE TRIGGER exp_pm_cfgtpl_view_ins_tr
  INSTEAD OF INSERT ON exp_pm_cfgtpl_view FOR EACH ROW
BEGIN
  INSERT INTO pm_cfgtpl ( id, folderid, userid, name, description, changed, category, type, entity_id, needsinput )
    VALUES ( ABS( :new.id ), :new.folderid, :new.userid, :new.name, :new.description, :new.changed, 
             :new.category, :new.type, :new.entity_id, :new.needsinput );
END;
/
SHOW ERRORS

CREATE OR REPLACE VIEW exp_pm_report_view AS
    SELECT id, folderid, userid, name, 
           description, changed, category, type, entity_id, scenarioid, 
           DECODE( SUBSTR( category, 1, 6), 'Config', templateid * -1, templateid ) templateid, 
           chansetplanid, destinationid, pagesetupid, dtscopeid, reportspecid, channelnumber, 
           domainscenarioid, mapradiusscale, testchannels, equippedonly, filename
      FROM PM_REPORT;

CREATE OR REPLACE TRIGGER exp_pm_report_view_ins_tr
  INSTEAD OF INSERT OR UPDATE ON exp_pm_report_view FOR EACH ROW
BEGIN

  IF INSERTING THEN

  INSERT INTO pm_report ( id, folderid, userid, name, 
           description, changed, category, type, entity_id, scenarioid, 
           templateid, 
           chansetplanid, destinationid, pagesetupid, dtscopeid, reportspecid, channelnumber, 
           domainscenarioid, mapradiusscale, testchannels, equippedonly, filename )
  VALUES ( :new.id, :new.folderid, :new.userid, :new.name, 
           :new.description, :new.changed, :new.category, :new.type, :new.entity_id, :new.scenarioid, 
           ABS( :new.templateid ), 
           :new.chansetplanid, :new.destinationid, :new.pagesetupid, :new.dtscopeid, :new.reportspecid, :new.channelnumber, 
           :new.domainscenarioid, :new.mapradiusscale, :new.testchannels, :new.equippedonly, :new.filename );

  ELSIF UPDATING THEN
    -- UNQ_REPORT unique key violation
    UPDATE pm_report SET
           folderid = :new.folderid, 
           userid = :new.userid,  
           name = :new.name, 
           description = :new.description,  
           changed = SYSDATE,  
           category = :new.category,  
           type = :new.type,  
           entity_id = :new.entity_id,  
           scenarioid = :new.scenarioid, 
           templateid = :new.templateid, 
           chansetplanid = :new.chansetplanid,  
           destinationid = :new.destinationid,  
           pagesetupid = :new.pagesetupid,  
           dtscopeid = :new.dtscopeid,  
           reportspecid = :new.reportspecid,  
           channelnumber = :new.channelnumber, 
           domainscenarioid = :new.domainscenarioid,  
           mapradiusscale = :new.mapradiusscale,  
           testchannels = :new.testchannels,  
           equippedonly = :new.equippedonly,  
           filename = :new.filename
     WHERE FOLDERID = :old.folderid
       AND UPPER( name ) = UPPER( :old.name )
       AND CATEGORY = :old.category
       AND ENTITY_ID = :old.entity_id;
  END IF;

END;
/
SHOW ERRORS

