--
-- (#) ./base/db/Oracle8i/eds/create_eds_schema.sql BL_core_schema_8.0.7_8.0.7.4.02_20100413  064938
-- (#) 
--

PROMPT Creating table EDS_DOCUMENT...

CREATE TABLE EDS_DOCUMENT(
      Id              NUMBER,
      UserId          NUMBER        ,
      FolderId        NUMBER        ,
      Name            VARCHAR2(64)  ,
      Description     VARCHAR2(255) ,
      Changed         Date          Default Trunc(Sysdate,'MI') NOT NULL,
      Category        VARCHAR2(64)  NOT NULL,
      Type            VARCHAR2(64)  NOT NULL,
      Entity_Id       NUMBER        NOT NULL,
      Is_Time_Series  VARCHAR2(1)   NOT NULL,
        CONSTRAINT EDS_DOCUMENT_is_time_series_ck CHECK (is_time_series IN ('Y','N')),
      Frequency_Id    NUMBER,
      EDS_Type        VARCHAR2(1)   NOT NULL,
        CONSTRAINT EDS_DOCUMENT_eds_type_ck CHECK (eds_type IN ('A','O')),
-- A for Ascii, O for ODBC
--Primary Key
CONSTRAINT PK_EDS_Doc PRIMARY KEY (ID) USING INDEX TABLESPACE wm_client,
-- Foreign Keys
CONSTRAINT FK_EDS_Doc_FldrId FOREIGN KEY (folderid) REFERENCES pm_folder(id),
CONSTRAINT FK_EDS_Doc_UsrId  FOREIGN KEY (userid)   REFERENCES pm_user(id),
CONSTRAINT FK_EDS_Doc_EntId  FOREIGN KEY (entity_id) REFERENCES wmn_entity(entity_id),
CONSTRAINT FK_EDS_Doc_FreqId FOREIGN KEY (frequency_id) REFERENCES wm_frequency(frequency_id)
)TABLESPACE WM_CLIENT;

CREATE SEQUENCE SQ_EDS_DOCUMENT
  START WITH 1000
  INCREMENT BY 1
  NOMAXVALUE
  NOCYCLE
;


CREATE UNIQUE INDEX uni_EDS_name ON EDS_DOCUMENT
  ( folderid      ASC,
    UPPER("NAME") ASC,
    category      ASC
   );


PROMPT Creating table EDS_ASCII_FILE...

CREATE TABLE EDS_Ascii_File(
   EDS_Id      NUMBER,
   FileName    VARCHAR2(256)   NOT NULL,
   Separator   CHAR(1) DEFAULT chr(09)  NOT NULL,
--Primary Key
CONSTRAINT PK_EDS_AscFile PRIMARY KEY (EDS_Id) USING INDEX TABLESPACE wm_client,
-- Foreign Keys
CONSTRAINT FK_EDS_AscFile_Id FOREIGN KEY (EDS_Id) REFERENCES EDS_DOCUMENT(Id) ON DELETE
CASCADE)TABLESPACE WM_CLIENT;


PROMPT Creating view EDS_Ascii_Doc_V

CREATE OR REPLACE VIEW EDS_Ascii_Doc_V
AS SELECT d.Id,d.UserId,d.FolderId,d.Name,
          d.Description,d.Changed,d.type,d.Category,
          d.Entity_id, d.Is_Time_Series, d.Frequency_Id,
          f.filename,f.separator
FROM   EDS_DOCUMENT d,EDS_ASCII_FILE f
WHERE  d.Id = f.EDS_Id
AND    d.EDS_TYPE = 'A';


PROMPT Creating table EDS_ODBC_FILE...

CREATE TABLE EDS_ODBC_File(
    EDS_Id      NUMBER,
    Table_Name  VARCHAR2(256) NOT NULL,
    DB_Server   VARCHAR2(256) NOT NULL,
    DB_UserId   VARCHAR2(64),
    DB_Password VARCHAR2(64),
    DB_Database VARCHAR2(256),
--Primary Key
CONSTRAINT PK_EDS_OdbcFile PRIMARY KEY (EDS_Id) USING INDEX TABLESPACE wm_client,
-- Foreign Keys
CONSTRAINT FK_EDS_OdbcFile_Id FOREIGN KEY (EDS_Id) REFERENCES EDS_DOCUMENT(Id) ON DELETE
CASCADE)TABLESPACE WM_CLIENT;


PROMPT Creating view EDS_Odbc_Doc_V...

CREATE OR REPLACE VIEW EDS_Odbc_Doc_V
AS SELECT d.Id,d.UserId,d.FolderId,d.Name,
          d.Description,d.Changed,d.type,d.Category,
          d.Entity_id, d.Is_Time_Series, d.Frequency_Id,
          f.table_name,f.db_server, f.db_userId,
          f.db_password,f.db_database
FROM    EDS_DOCUMENT d, EDS_ODBC_FILE f
WHERE   d.Id = f.EDS_Id
AND     d.EDS_TYPE = 'O';

PROMPT Creating table EDS_COLUMN...

CREATE TABLE EDS_Column(COL_ID         NUMBER,
			EDS_ID         NUMBER         NOT NULL,
			COL_NAME       VARCHAR2(40)   NOT NULL,
			COL_TYPE       VARCHAR(1)     NOT NULL
 CONSTRAINT eds_coltyp_chk CHECK ( COL_TYPE IN ( 'I', 'F', 'S', 'E', 'D' ) ),
  -- (I)nteger, (F)loat, (S)tring, (E)numeration, (D)ate
			COL_POSITION   NUMBER         NOT NULL,
			IS_TIMESTAMP   VARCHAR(1)     DEFAULT 'N' NOT NULL,
 CONSTRAINT EDS_Column_IS_TIMESTAMP_ck CHECK (IS_TIMESTAMP IN ('Y','N')),
                        EDITOR_POSITION NUMBER         NOT NULL,
--Primary Key
CONSTRAINT PK_EDS_ColId PRIMARY KEY (COL_ID) USING INDEX TABLESPACE WM_CLIENT,
-- Foreign Keys
CONSTRAINT FK_EDS_ColId FOREIGN KEY (EDS_ID) REFERENCES EDS_DOCUMENT(Id) ON DELETE CASCADE,
CONSTRAINT UQ_EDS_ColId_EdsId UNIQUE(EDS_ID, COL_NAME),
CONSTRAINT UQ_EDS_ColId_EdsIdColPos UNIQUE(EDS_ID, COL_POSITION),
CONSTRAINT UQ_EDS_Col_Editor_Pos UNIQUE(EDS_ID, EDITOR_POSITION)
)TABLESPACE WM_CLIENT;

CREATE SEQUENCE SQ_EDS_Column
  START WITH 1000
  INCREMENT BY 1
  NOMAXVALUE
  NOCYCLE
;

PROMPT Creating table EDS_PRIMARYKEY...

CREATE TABLE EDS_PRIMARYKEY(
     PK_ID      NUMBER   ,
     EDS_ID     NUMBER    NOT NULL,
     COL_ID     NUMBER    NOT NULL,
     FIELD_ID   NUMBER    NOT NULL,
     ORDINAL    NUMBER    NOT NULL,
--Primary Key
CONSTRAINT PK_EDS_PMRYKEYID PRIMARY KEY (PK_ID) USING INDEX TABLESPACE WM_CLIENT,
-- Foreign Keys
CONSTRAINT FK_EDS_PMRYKEYEDS_ID FOREIGN KEY (EDS_ID) REFERENCES EDS_DOCUMENT(Id) ON
DELETE CASCADE,
CONSTRAINT FK_EDS_PMRYKEYCOL_ID FOREIGN KEY (COL_ID) REFERENCES EDS_Column(COL_ID) ON DELETE CASCADE,
CONSTRAINT FK_EDS_PMRYKEYField_ID FOREIGN KEY (FIELD_ID) REFERENCES WMD_FIELD_DEF(FIELD_ID) ON DELETE CASCADE,
CONSTRAINT UQ_EDS_PMRYKEY_EDSCOLID UNIQUE(EDS_ID,COL_ID),
CONSTRAINT UQ_EDS_PMRYKEY_EDSORDID UNIQUE(EDS_ID,ORDINAL)
)TABLESPACE WM_CLIENT;

CREATE SEQUENCE SQ_EDS_PRIMARYKEY
  START WITH 1000
  INCREMENT BY 1
  NOMAXVALUE
  NOCYCLE
;

PROMPT Creating table WMD_EDS_DEF...

CREATE TABLE WMD_EDS_DEF(FIELD_ID    NUMBER    NOT NULL,
		         EDS_ID      NUMBER    NOT NULL,
                         COL_ID      NUMBER    NOT NULL,
-- Foreign Keys
CONSTRAINT FK_EDSDEF_EDSID FOREIGN KEY (EDS_ID) REFERENCES   EDS_DOCUMENT(Id) ,
CONSTRAINT FK_EDSDEF_COLID FOREIGN KEY (COL_ID) REFERENCES   EDS_Column(COL_ID) ,
CONSTRAINT FK_EDSDEF_FLDID FOREIGN KEY (FIELD_ID) REFERENCES WMD_FIELD_DEF(FIELD_ID) ON DELETE CASCADE
)TABLESPACE WM_CLIENT;

 


   

