CREATE OR REPLACE TRIGGER
  -- ------------------------------------------------------------------------
  --     eds_docv_trigger.sql 1.1.0
  -- ------------------------------------------------------------------------
  --     Ascii trigger
  -- ------------------------------------------------------------------------
  EDS_Ascii_Docv_TRIGGER
  INSTEAD OF INSERT OR DELETE OR UPDATE ON EDS_Ascii_Doc_V
  FOR EACH ROW
  DECLARE

  v_eds_id NUMBER;

  BEGIN

  IF (inserting) THEN 
     --
     -- Split the insert into the two component tables.
     --
    INSERT INTO EDS_DOCUMENT(Id,Name,Description,FolderId,
                         UserId,Category,Type,entity_id,
                         is_time_series, frequency_id, EDS_TYPE)
    VALUES(:NEW.Id,:NEW.NAME,:NEW.description,:NEW.folderid,
         :NEW.userid,:NEW.category,:NEW.type,:NEW.entity_id,
         :NEW.is_time_series,:NEW.frequency_id,'A')
    returning Id into v_eds_id ;

   INSERT INTO EDS_ASCII_FILE(EDS_Id,FileName,Separator)
     VALUES (:NEW.Id,:NEW.filename,:NEW.separator);
      

  ELSIF (deleting) THEN
     
    DELETE FROM EDS_DOCUMENT WHERE Id = :OLD.Id;

 
  ELSIF (updating) THEN

   UPDATE EDS_DOCUMENT
   SET     FolderId       = NVL(:NEW.FolderId,FolderId),
           UserId         = NVL(:NEW.UserId,UserId),
           Name           = NVL(:NEW.Name,Name),
           Description    = NVL(:NEW.Description,Description),
           Is_Time_Series = NVL(:NEW.Is_Time_Series,Is_Time_Series),
           Frequency_Id   = NVL(:NEW.Frequency_Id,Frequency_Id),
           Changed        = Trunc(Sysdate,'MI')
   WHERE    Id            = :NEW.Id;

   UPDATE EDS_ASCII_FILE
   SET   filename  = NVL(:NEW.filename,filename),
         separator = NVL(:NEW.separator,separator)
   WHERE EDS_Id    = :NEW.Id;


  END IF;
       

  END EDS_Ascii_Docv_TRIGGER;
/
show errors trigger EDS_Ascii_Docv_TRIGGER;


CREATE OR REPLACE TRIGGER
  -- ------------------------------------------------------------------------
  --     eds_docv_trigger.sql 1.1.0
  -- ------------------------------------------------------------------------
  --     ODBC trigger
  -- ------------------------------------------------------------------------
  EDS_Odbc_Docv_TRIGGER
  INSTEAD OF INSERT OR DELETE OR UPDATE ON EDS_Odbc_Doc_V
  FOR EACH ROW
  DECLARE

  v_eds_id NUMBER;

  BEGIN

  IF (inserting) THEN 
     --
     -- Split the insert into the two component tables.
     --
    INSERT INTO EDS_DOCUMENT(Id,Name,Description,FolderId,
                         UserId,Category,Type,entity_id,
                         is_time_series, frequency_id, EDS_TYPE)
    VALUES(:NEW.Id,:NEW.NAME,:NEW.description,:NEW.folderid,
         :NEW.userid,:NEW.category,:NEW.type,:NEW.entity_id,
         :NEW.is_time_series,:NEW.frequency_id,'O')
    returning Id into v_eds_id ;

   INSERT INTO EDS_ODBC_FILE(EDS_Id,Table_Name, DB_Server,
                             DB_UserId, DB_Password, 
                             DB_Database)
     VALUES (:NEW.Id,:NEW.table_name,:NEW.db_server,
             :NEW.db_userid,:NEW.db_password,
             :NEW.db_database);
      

  ELSIF (deleting) THEN
     
    DELETE FROM EDS_DOCUMENT WHERE Id = :OLD.Id;

 
  ELSIF (updating) THEN

   UPDATE EDS_DOCUMENT
   SET     FolderId       = NVL(:NEW.FolderId,FolderId),
           UserId         = NVL(:NEW.UserId,UserId),
           Name           = NVL(:NEW.Name,Name),
           Description    = NVL(:NEW.Description,Description),
           Is_Time_Series = NVL(:NEW.Is_Time_Series,Is_Time_Series),
           Frequency_Id   = NVL(:NEW.Frequency_Id,Frequency_Id),
           Changed        = Trunc(Sysdate,'MI')
   WHERE    Id            = :NEW.Id;

   UPDATE EDS_ODBC_FILE
   SET   table_name  = NVL(:NEW.table_name,table_name),
         db_server   = NVL(:NEW.db_server,db_server),
         db_userid   = NVL(:NEW.db_userid,db_userid),
         db_password = NVL(:NEW.db_password,db_password),
         db_database = NVL(:NEW.db_database,db_database)
   WHERE EDS_Id    = :NEW.Id;


  END IF;
       

  END EDS_Odbc_Docv_TRIGGER;
/
show errors trigger EDS_Odbc_Docv_TRIGGER;


CREATE OR REPLACE TRIGGER
  -- ------------------------------------------------------------------------
  --     eds_docv_trigger.sql 1.1.0
  -- ------------------------------------------------------------------------
  --     EDS data dictionary refresh trigger
  -- ------------------------------------------------------------------------
  WMD_EDS_DEF_DDREF_TRIGGER
  AFTER INSERT OR DELETE OR UPDATE ON WMD_EDS_DEF
BEGIN
   SYS.DBMS_ALERT.signal(user ||'_WMD_DICT_UPDATE', '');
END WMD_EDS_DEF_DDREF_TRIGGER;
/
show errors trigger WMD_EDS_DEF_DDREF_TRIGGER;

EXIT;
-- --------------------------------------------------------------------------
-- Local Variables:
-- mode: pls
