CREATE OR REPLACE PACKAGE BODY exp_custom AS
  -- ----------------------------------------------------------------------
  -- (#) ./base/db/Oracle8i/export2/export2_custom_data_pkgb.sql BL_core_schema_8.0.7_8.0.7.4.02_20100413  064938
  -- (#) 
  -- Copyright 2003 WatchMark Corp.
  -- ----------------------------------------------------------------------
  --
  --  Known meta-date versions:
  --    1    - Generic
  --    2    - Enterprise Generic
  --    1000 - Enterprise Export
  --    1001 - Enterprise Import

  /**********************************************************/

  gv_scenario_id    NUMBER DEFAULT NULL;
  gv_user_id        NUMBER DEFAULT NULL;
  gv_depend_id      NUMBER DEFAULT NULL;
  gv_root_folder_id NUMBER DEFAULT NULL;
  gv_first_folder   BOOLEAN DEFAULT TRUE;
  gv_system_id      NUMBER DEFAULT NULL;

  -- SEAde64782
  -- Store PM_BUSYHOUR.RETENTION_DAYS for later calculation of PM_BUSYHOUR.FIRSTNEEDED
  gv_bh_retention_days pm_busyhour.daily_retention%TYPE DEFAULT 0;

  -- SEAde64782
  -- Each time we process a BH, reset the exists flag
  -- Used to see whether we should insewrt a PM_HOURRANGE record for
  -- the busy hour. Remember we usually insert multiple houranges for one BH
  gv_exists_busyhour BOOLEAN DEFAULT FALSE;
  --SA Import SEAde66940
  -- Each time we process a SA_SCHEDULE, reset the exists flag
  -- Used to see whether we should insert a SCHED_HOUR_EX record for
  -- the parent record.
  gv_exists_schedule BOOLEAN DEFAULT FALSE;

  -- Each time we process a GROUP, reset the exists flag
  -- Used to see whether we should insert a JOB_GROUP_ITEM record for
  -- the parent record.
  gv_exists_group NUMBER DEFAULT 0; --SK

  -- Each time we process a Soft Alarm, reset the exists flag
  -- Used to see whether we should insert a PM_THRESHOLD record for
  -- the parent record.
  gv_exists_sa          NUMBER DEFAULT 0;
  gv_exists_sa_template NUMBER DEFAULT 0;

  --each time we process a UDC field we need ot see if it exists, to determine
  gv_exists_udc NUMBER DEFAULT 0;

  gv_existing_udcs t_ExportImport_ids := t_ExportImport_ids();

  -- SEAde64782 local procs to translate busyhour id and userid
  PROCEDURE translate_bh_ids;

  -- SA Import SEAde66940
  -- additional translations
  PROCEDURE translate_sa_sched_ids;

  PROCEDURE translate_group_ids;
  PROCEDURE translate_softalarm_ids;
  PROCEDURE translate_user_ids;
  PROCEDURE translate_udc_ids;
  PROCEDURE translate_sa_template_ids;
  -- THESE ARE FOR THE SPECIAL ROW BASED TRANSLATIONS THAT DO NOT USE THE EXP_TRN TABLE
  PROCEDURE do_sa_translations;
  FUNCTION get_sa_translations(pv_row_number  IN NUMBER,
                               pv_table_name  IN VARCHAR2,
                               pv_column_name IN VARCHAR2,
                               pv_old_value   IN VARCHAR2) RETURN VARCHAR2;
  PROCEDURE add_sa_translation(pv_row_number  IN NUMBER,
                               pv_table_name  IN VARCHAR2,
                               pv_column_name IN VARCHAR2,
                               pv_new_value   IN VARCHAR2);

  -- SEAde65006 [David Scott] Adding this to resolve scenario to a specific scenario where multiple scenarios exist with the same name
  FUNCTION getscenarioid(pv_scenario_name IN VARCHAR2) RETURN NUMBER;


  -- Took out as part of the SA/BH import export core merge.
  -- This needs to be uncommented when the SA_Range Feature is merged in.
  -- SA Import SEAde66940
  FUNCTION get_soft_alarm_id(pv_alarm_id   IN VARCHAR2,
                             pv_row_number IN NUMBER) RETURN VARCHAR2;

  FUNCTION getschedulestarttime(pv_time IN VARCHAR2) RETURN VARCHAR2;
  
  /*
    --Get_first_needed
    --Return first needed date
    --core merge from motorola         
  */
  FUNCTION Getfirstneeded RETURN VARCHAR2;
  
  FUNCTION Getfirstneeded RETURN VARCHAR2 IS
     lv_oldneeded           DATE;
     lv_currneeded          DATE;  
     lv_return              VARCHAR2(25);
  BEGIN
  
      -- SEAde64782
      -- note that DAILY_RETENTION column must be retrieved before FIRSTNEEDED
      lv_oldneeded := trunc(SYSDATE) - nvl(gv_bh_retention_days, 0);

      -- SEAde24229
      -- SELECT NVL( TO_CHAR( TRUNC( MIN( timestamp ) ), export2.gv_date_format ),
      --          TO_CHAR( TRUNC( SYSDATE ), export2.gv_date_format ) )
      -- INTO lv_return_value
      -- FROM wm_available_data;

      SELECT nvl(trunc(MIN(TIMESTAMP)), trunc(SYSDATE))
         INTO lv_currneeded
         FROM wm_available_data;

      IF (lv_oldneeded > lv_currneeded) THEN
         lv_return := to_char(lv_oldneeded, export2.gv_date_format);
      ELSE
         lv_return := to_char(lv_currneeded, export2.gv_date_format);
      END IF;

      RETURN lv_return;
  
  END Getfirstneeded;

  PROCEDURE addinstance(instance_id IN NUMBER,
                        inst_list   IN OUT NOCOPY t_ExportImport_ids) IS
  BEGIN
    exp_log('PROCEDURE addInstance, instance_id = ' || instance_id,
            export2.const_proc_calls);
    --check to make sure we do not have this in list already
    IF (instance_id NOT MEMBER OF inst_list) THEN
      inst_list.EXTEND(1);
      inst_list(inst_list.LAST) := instance_id;
    END IF;
  END addinstance;

  PROCEDURE printlist(list_name IN VARCHAR2, my_list IN t_ExportImport_ids) IS

    output VARCHAR2(32000);

  BEGIN
    exp_log('PROCEDURE printList, list_name = ' || list_name,
            export2.const_proc_calls);
    output := list_name || ' = { ';

    IF my_list.COUNT > 0 THEN
      FOR i IN my_list.FIRST .. my_list.LAST LOOP
        output := output || my_list(i);
        IF (i != my_list.LAST) THEN
          output := output || ',';
        END IF;
      END LOOP;
    END IF;

    output := output || ' }';

    exp_log(output, export2.const_debug);
  END printlist;

  /**********************************************************/

  FUNCTION do_scenarios RETURN INTEGER AS
  BEGIN
    exp_log('Function do_scenarios', export2.const_proc_calls);

    RETURN g_do_scenarios;
  END do_scenarios;

  /**********************************************************/

  FUNCTION version RETURN VARCHAR2 AS
  BEGIN
    exp_log('Function version ', export2.const_proc_calls);
    RETURN '@(#) export2_custom_data_pkgb.sql 1.11.0 04/11/17 09:15:59';
  END;

  /**********************************************************/

  FUNCTION get_system_id RETURN NUMBER AS
  BEGIN
    exp_log('Function get_system_id', export2.const_proc_calls);

    IF gv_system_id IS NULL THEN
      SELECT id
        INTO gv_system_id
        FROM pm_user
       WHERE lower(NAME) = const_system_name;
    END IF;

    RETURN gv_system_id;

  EXCEPTION
    WHEN no_data_found THEN
      raise_application_error(-20116, 'Cannot retrieve id of system user.');

  END;

  /**********************************************************/
  -- SEAde64782
  -- Returns TRUE if user exists
  FUNCTION exists_user(pv_userid VARCHAR2) RETURN BOOLEAN AS
    lv_return_value BOOLEAN DEFAULT TRUE;
    lv_dummy        pm_user.id%TYPE;
  BEGIN
    exp_log('Function exists_user: pv_userid = ' || pv_userid,
            export2.const_proc_calls);
    BEGIN
      SELECT id INTO lv_dummy FROM pm_user WHERE id = pv_userid;
    EXCEPTION
      WHEN no_data_found THEN
        lv_return_value := FALSE;
    END;
    RETURN lv_return_value;
  END;

  -- Returns TRUE if the object named exists in the given table
  FUNCTION exists_by_name(pv_name VARCHAR2, pv_table_name VARCHAR2)
    RETURN BOOLEAN AS
    lv_return_value BOOLEAN DEFAULT FALSE;
    lv_dummy        NUMBER DEFAULT 0;
    lv_sql          VARCHAR2(1000);
  BEGIN
    exp_log('Function exists_by_name: pv_name = ' || pv_name ||
            ' pv_table_name = ' || pv_table_name,
            export2.const_proc_calls);
    BEGIN

      lv_sql := 'SELECT count(*) FROM ' || pv_table_name ||
                ' WHERE name = :name';
      exp_log(lv_sql, export2.const_dynamic_sql);
      EXECUTE IMMEDIATE lv_sql
        INTO lv_dummy
        USING pv_name;
    END;
    IF (lv_dummy > 0) THEN
      lv_return_value := TRUE;
    END IF;
    RETURN lv_return_value;
  END;

  -- Returns field id if the udc exists already
  FUNCTION exists_udc(pv_name VARCHAR2, pv_entity_id VARCHAR2) RETURN NUMBER AS

    lv_return_value NUMBER DEFAULT 0;
    lv_sql          VARCHAR2(1000);
    lv_type         VARCHAR2(1) := 'U';

  BEGIN
    exp_log('Function exists_udc: pv_name  = ' || pv_name ||
            ', pv_entity_id  = ' || pv_entity_id,
            export2.const_proc_calls);

    lv_sql := 'SELECT f.field_id ';
    lv_sql := lv_sql || ' FROM exp_field_name_view f ';
    lv_sql := lv_sql || ' WHERE f.NAME = :name ';
    lv_sql := lv_sql || ' AND f.field_type = :type ';
    lv_sql := lv_sql || ' AND f.entity_id = :entity_id ';
    exp_log(lv_sql, export2.const_dynamic_sql);

    BEGIN
      EXECUTE IMMEDIATE lv_sql
        INTO lv_return_value
        USING pv_name, lv_type, pv_entity_id;

    EXCEPTION
      WHEN no_data_found THEN
        lv_return_value := 0;
      WHEN OTHERS THEN
        exp_log(SQLERRM, export2.const_errors);
    END;

    RETURN lv_return_value;
  END exists_udc;

  -- Returns field id if the udc exists already
  FUNCTION exists_udc(pv_row_id NUMBER) RETURN NUMBER AS
    CURSOR import(cv_row_id NUMBER) IS
      SELECT table_name, data FROM exp_des WHERE id = cv_row_id;

    lv_name      VARCHAR2(100);
    lv_entity_id VARCHAR2(15);
    lv_udc_id    NUMBER;
  BEGIN
    exp_log('Function exists_udc: pv_row_id = ' || pv_row_id,
            export2.const_proc_calls);
    FOR imp_row IN import(pv_row_id) LOOP
      lv_name      := export2.parse_column_value(imp_row.data,
                                                 export2.get_column_ordinal(imp_row.table_name,
                                                                            'NAME'));
      lv_entity_id := export2.parse_column_value(imp_row.data,
                                                 export2.get_column_ordinal(imp_row.table_name,
                                                                            'ENTITY_ID'));
    END LOOP;

    lv_udc_id := exists_udc(lv_name, lv_entity_id);

    IF (lv_udc_id != 0) THEN
      addinstance(lv_udc_id, gv_existing_udcs);
    END IF;

    printlist('gv_existing_udcs', gv_existing_udcs);

    RETURN lv_udc_id;

  END exists_udc;

  -- Returns field id if the udc exists already
  FUNCTION exists_udc(pv_old_field_id VARCHAR2) RETURN NUMBER AS

    lv_old_field_id NUMBER;
    lv_return_val   NUMBER := 0;
  BEGIN
    exp_log('Function exists_udc: pv_old_field_id = ' || pv_old_field_id,
            export2.const_proc_calls);

    lv_old_field_id := to_number(pv_old_field_id);

    printlist('gv_existing_udcs', gv_existing_udcs);

    IF (lv_old_field_id MEMBER OF gv_existing_udcs) THEN
      lv_return_val := lv_old_field_id;
    END IF;

    RETURN lv_return_val;
  END exists_udc;

  --gets the id of the entity based on its name and tyhe folder it is in
  FUNCTION get_id_by_name_and_folder(pv_table_name VARCHAR2,
                                     pv_old_value  VARCHAR2,
                                     pv_name       VARCHAR2) RETURN NUMBER AS

    lv_sql          VARCHAR2(1000);
    lv_new_folderid NUMBER;
    lv_new_id       NUMBER;

  BEGIN
    exp_log('Function get_id_by_name_and_folder: pv_table_name = ' ||
            pv_table_name || ' pv_old_value = ' || pv_old_value ||
            ' pv_name = ' || pv_name,
            export2.const_proc_calls);

    -- try to get the current folder id from the trn table
    BEGIN
      SELECT to_number(new_value)
        INTO lv_new_folderid
        FROM exp_trn
       WHERE table_name = pv_table_name
         AND column_name = 'FOLDERID'
         AND old_value = pv_old_value;
    EXCEPTION
      WHEN no_data_found THEN
        RETURN 0;
    END;

    -- now see if the entity exists by the folder and name

    BEGIN
      lv_sql := 'SELECT id FROM ' || pv_table_name ||
                ' WHERE NAME = :name AND FOLDERID = :new_folderid ';
      exp_log(lv_sql, export2.const_dynamic_sql);
      EXECUTE IMMEDIATE lv_sql
        INTO lv_new_id
        USING pv_name, lv_new_folderid;

    EXCEPTION
      WHEN no_data_found THEN
        RETURN 0;
    END;

    RETURN lv_new_id;

  END;

  -- Returns the ID of the object in the target system if the object named exists in the given table, or 0 if it does not
  FUNCTION exists_by_name_and_folder(pv_row_id NUMBER) RETURN NUMBER AS

    CURSOR import(cv_row_id NUMBER) IS
      SELECT table_name, data FROM exp_des WHERE id = cv_row_id;

    lv_name         VARCHAR2(100);
    lv_old_folderid VARCHAR2(15);
    lv_new_id       NUMBER;

  BEGIN
    exp_log('Function exists_by_name_and_folder: pv_row_id = ' ||
            pv_row_id,
            export2.const_proc_calls);

    FOR imp_row IN import(pv_row_id) LOOP
      lv_name         := export2.parse_column_value(imp_row.data,
                                                    export2.get_column_ordinal(imp_row.table_name,
                                                                               'NAME'));
      lv_old_folderid := export2.parse_column_value(imp_row.data,
                                                    export2.get_column_ordinal(imp_row.table_name,
                                                                               'FOLDERID'));
      lv_new_id       := get_id_by_name_and_folder(imp_row.table_name,
                                                   lv_old_folderid,
                                                   lv_name);

    END LOOP;

    RETURN lv_new_id;
  END;

  /**********************************************************/

  PROCEDURE decode_document(pv_path       IN VARCHAR2,
                            pv_table_name OUT VARCHAR2,
                            pv_criteria   OUT VARCHAR2) IS
    fullname   VARCHAR2(512);
    docname    VARCHAR2(512);
    dirname    VARCHAR2(512);
    dir_id     NUMBER;
    doc_id     NUMBER;
    last_slash PLS_INTEGER;
  BEGIN
    exp_log('Procedure decode_document: pv_path = ' || pv_path,
            export2.const_proc_calls);
    fullname   := REPLACE(pv_path, '\', '/');
    last_slash := instr(fullname, '/', -1);

    IF last_slash = 0 THEN
      docname := fullname;
      dirname := '';
    ELSE
      dirname := substr(fullname, 1, last_slash - 1);
      docname := substr(fullname, last_slash + 1);
    END IF;

    dir_id := get_folder_id_by_path(dirname);

    BEGIN

      SELECT id
        INTO doc_id
        FROM pm_report
       WHERE folderid = dir_id
         AND NAME = docname
         AND rownum = 1;

      pv_table_name := 'EXP_PM_REPORT_VIEW';

    EXCEPTION
      WHEN no_data_found THEN

        BEGIN

          SELECT id
            INTO doc_id
            FROM pm_template
           WHERE folderid = dir_id
             AND NAME = docname
             AND rownum = 1;

          pv_table_name := 'PM_TEMPLATE';

        EXCEPTION
          WHEN no_data_found THEN
            raise_application_error(-20115,
                                    'Report/Template ' || fullname ||
                                    ' not found.');
        END;

    END;

    pv_criteria := 'ID=' || to_char(doc_id) || ' AND FOLDERID=' ||
                   to_char(dir_id);

  END;

  /**********************************************************/

  FUNCTION get_root_folderid RETURN pm_folder.id%TYPE AS
  BEGIN
    exp_log('Function get_root_folderid', export2.const_proc_calls);

    IF gv_root_folder_id IS NULL THEN

      BEGIN
        SELECT id
          INTO gv_root_folder_id
          FROM pm_folder
         WHERE NAME = const_root_folder_name
           AND folderid IS NULL;
      EXCEPTION
        WHEN no_data_found THEN
          raise_application_error(-20115,
                                  const_root_folder_name || ' not found.');
      END;

    END IF;

    RETURN gv_root_folder_id;

  END;

  /**********************************************************/

  FUNCTION get_users_folderid RETURN pm_folder.id%TYPE AS
    lv_usrfldid pm_folder.id%TYPE;
    lv_rtfldid  pm_folder.id%TYPE;
  BEGIN
    exp_log('Function get_users_folderid', export2.const_proc_calls);

    lv_rtfldid := get_root_folderid();

    SELECT id
      INTO lv_usrfldid
      FROM pm_folder f
     WHERE NAME = const_users_folder_name
       AND folderid = lv_rtfldid
       AND rownum = 1;

    RETURN lv_usrfldid;
  EXCEPTION
    WHEN no_data_found THEN
      raise_application_error(-20114,
                              const_root_folder_name || '/' ||
                              const_users_folder_name || ' not found.');
  END;

  /**********************************************************/

  PROCEDURE repair_user_homes AS

    lv_folder_id       NUMBER;
    lv_users_folder_id pm_folder.id%TYPE;

    CURSOR vc_1 IS
      SELECT id, NAME
        FROM pm_user
       WHERE folderid IS NULL
         AND NAME != 'system'
         FOR UPDATE OF folderid;
  BEGIN
    exp_log('Procedure repair_user_homes', export2.const_proc_calls);

    -- SEAde37551: retrieve Folder ID of /Users from the database
    --             instead of hard-coding it to 9.
    lv_users_folder_id := get_users_folderid();

    FOR lv_c1 IN vc_1 LOOP
      SELECT sq_folder.NEXTVAL INTO lv_folder_id FROM dual;
      BEGIN
        INSERT INTO pm_folder
          (id,
           folderid,
           userid,
           NAME,
           description,
           changed,
           TYPE,
           category)
        VALUES
          (lv_folder_id,
           lv_users_folder_id,
           lv_c1.id,
           lv_c1.NAME,
           'Home Folder for ' || lv_c1.NAME,
           trunc(SYSDATE, 'MI'),
           'N',
           'Explorer Documents');
      EXCEPTION
        WHEN dup_val_on_index THEN
          SELECT id
            INTO lv_folder_id
            FROM pm_folder
           WHERE upper(NAME) = upper(lv_c1.NAME)
             AND folderid = lv_users_folder_id;
      END;
      UPDATE pm_user SET folderid = lv_folder_id WHERE CURRENT OF vc_1;
    END LOOP;
  END;

  /**********************************************************/

  FUNCTION exp_data(pv_table_name  VARCHAR2,
                    pv_column_name VARCHAR2,
                    pv_value       VARCHAR2) RETURN VARCHAR2 AS

    lv_return_value VARCHAR2(32767) DEFAULT pv_value;
    lv_version      NUMBER DEFAULT export2.gv_version;

    --Schedule id cursor
    CURSOR c_sched_id(p_group_id IN VARCHAR2) IS
      SELECT s.schedule_id
        FROM sa_schedule sas, schedule s
       WHERE sas.sa_schedule_id = s.sched_fk
         AND sas.folderid != 0 -- ensures we only take schedule definitions here
         AND sas.group_id = p_group_id;

  BEGIN
    exp_log('Function exp_data: pv_table_name = ' || pv_table_name ||
            ' pv_column_name = ' || pv_column_name || ' pv_value = ' ||
            pv_value,
            export2.const_proc_calls);

    ----------------------------------------------------------
    -- Generic exceptions.
    ----------------------------------------------------------

    IF (do_scenarios = 1) AND (pv_table_name IN ('EXP_QUERY_NAME_VIEW')) AND
       (pv_column_name IN ('QUERY_ID')) THEN

      BEGIN
        --exp_log( pv_table_name || ' ' || pv_column_name || ' ' || pv_value, 2047);
        -- Make a copy of the query text for mangling...
        INSERT INTO exp_query_text
          (query_id, query_row, query_text)
          SELECT query_id, query_row, query_text
            FROM wmq_query_text
           WHERE query_id = to_number(pv_value);

        exp_scenario.read_exp_query(to_number(pv_value));
        exp_scenario.translate;
        exp_scenario.write_exp_query(to_number(pv_value));

      EXCEPTION
        WHEN dup_val_on_index THEN
          NULL; -- Nothing to do;
      END;
      -- Soft Alarms Export
    ELSIF pv_table_name IN ('EXP_SA_JOB_GROUP_VIEW','EXP_JOB_GROUP_VIEW') AND pv_column_name = 'ID' THEN
      -- Whenever a Group is found, save the related schedule ids
      -- so that the schedules can be exported after the rest of the data
      -- dbms_output.put_line('group id = '||pv_value);
      --Get the schedule id for this group_id if there is one, and save to the table
      FOR r_sched_id IN c_sched_id(pv_value) LOOP
        gv_schedule_id_tab(gv_schedule_id_tab.COUNT) := r_sched_id.schedule_id;
        exp_log('schedule_id is ' ||
                gv_schedule_id_tab(gv_schedule_id_tab.LAST),
                export2.const_debug);
      END LOOP;
    END IF;

    RETURN lv_return_value;
  END;

  /**********************************************************/

  FUNCTION imp_data(pv_table_name  VARCHAR2,
                    pv_column_name VARCHAR2,
                    pv_value       VARCHAR2,
                    pv_no_parent   BOOLEAN,
                    pv_row_number  NUMBER) RETURN VARCHAR2 AS

    lv_return_value        VARCHAR2(32767) DEFAULT pv_value;
    lv_version             NUMBER DEFAULT export2.gv_version;
    lv_scenarios_folder_id pm_folder.ID%TYPE;
    lv_user_id             NUMBER DEFAULT NULL;
    lv_dummy               INTEGER;  
    lv_min_softalarm_id    INTEGER := 0;   
    lv_max_softalarm_id    INTEGER := 0;
  BEGIN
    exp_log('Function imp_data: pv_table_name = ' || pv_table_name ||
            ' pv_column_name = ' || pv_column_name || ' pv_value = ' ||
            pv_value || ' pv_row_number = ' || pv_row_number,
            export2.const_proc_calls);

    ----------------------------------------------------------
    -- Generic exceptions. Executed for all versions.
    ----------------------------------------------------------

    IF (pv_no_parent AND pv_column_name = 'FOLDERID' AND
       pv_table_name NOT IN
       ('SA_SCHEDULE', 'PM_USER', 'EXP_QUERY_NAME_VIEW')) THEN
      IF (gv_depend_id IS NULL) THEN

        gv_depend_id := create_depend_folder(export2.gv_folder_id);

      END IF;
      lv_return_value := to_char(gv_depend_id);

    ELSIF (pv_column_name = 'SUMMARY' AND pv_table_name = 'SA_TEMPLATE') THEN

      SELECT sq_sa_template.NEXTVAL + 1 INTO lv_dummy FROM dual;
      lv_return_value := substr(pv_value, 1, 100) || ' (ID#' ||
                         to_char(lv_dummy) || ')';
      -- SA Import SEAde66940
      -- Took out as part of the SA/BH import export core merge.
      -- This needs to be uncommented when the SA_Range Feature is merged in.
    ELSIF (pv_column_name = 'ALARM_ID' AND pv_table_name = 'SA_SOFTALARM') THEN

      -- SA Import: checks to see if ID exists on system as this must be unique
      -- if it does then gets a new max + 1 value that does not
      -- only if this is a new soft alarm, if it is an existing one then take what is in file
      
      --
      -- Add a check to see if alarm range of outside of min or max.
      --
      
      lv_return_value := get_soft_alarm_id(pv_value, pv_row_number);
      
      BEGIN
      
      
      
         SELECT  VALUE INTO  lv_min_softalarm_id from wm_system_values_v
           where NAME = 'MIN_SOFTALARM_ID';
        
          SELECT  VALUE INTO  lv_max_softalarm_id from wm_system_values_v
            where NAME = 'MAX_SOFTALARM_ID';
            
           IF  lv_min_softalarm_id IS NOT NULL AND lv_max_softalarm_id IS NOT NULL THEN
               --check if alarm id with in range
               IF pv_value NOT BETWEEN lv_min_softalarm_id AND lv_max_softalarm_id THEN
                  --raise Error out of range.
                   raise_application_error(-20113,
                       lv_return_value || ' Importing a SoftAlarm with an Alarm ID of ' || pv_value || ' is outside of Range: ' || lv_min_softalarm_id || ' ' || lv_max_softalarm_id);                  
               END IF;
           END IF;
            
      EXCEPTION 
      WHEN NO_DATA_FOUND THEN
        NULL; 
      END;
            
     
      -- SA Import SEAde66940
      -- determine if sa schedule exists in system, set flag
    ELSIF (pv_column_name = 'NAME' AND pv_table_name = 'SA_SCHEDULE') THEN
      gv_exists_schedule := exists_by_name(pv_value, pv_table_name);
    ELSIF (pv_column_name = 'CHANGED' AND pv_table_name = 'SA_SCHEDULE') THEN

      lv_return_value := to_char(trunc(SYSDATE, 'MI'),
                                 export2.gv_date_format);

      -- determine if GROUP already exists in system, set flag
    ELSIF (pv_column_name = 'NAME' AND pv_table_name IN ('EXP_SA_JOB_GROUP_VIEW','EXP_JOB_GROUP_VIEW')) THEN
      gv_exists_group := exists_by_name_and_folder(pv_row_number);

      -- determine if GROUP already exists in system, set flag
    ELSIF (pv_column_name = 'NAME' AND pv_table_name = 'SA_SOFTALARM') THEN
      gv_exists_sa := exists_by_name_and_folder(pv_row_number);

      -- determine if GROUP already exists in system, set flag
    ELSIF (pv_column_name = 'NAME' AND pv_table_name = 'SA_TEMPLATE') THEN
      gv_exists_sa_template := exists_by_name_and_folder(pv_row_number);

      -- determine if FIELD already exists in system (and is a UDC), set flag  (at field level)
    ELSIF (pv_column_name = 'FIELD_ID' AND
          pv_table_name = 'EXP_FIELD_NAME_VIEW') THEN
      gv_exists_udc := exists_udc(pv_row_number);
      exp_log('gv_exists_udc = ' || gv_exists_udc, export2.const_debug);
      -- determine if FIELD already exists in system (and is a UDC), set flag  (at udc level)
    ELSIF (pv_column_name = 'FIELD_ID' AND pv_table_name = 'WMD_UDC_DEF') THEN
      gv_exists_udc := exists_udc(pv_value);
      exp_log('gv_exists_udc = ' || gv_exists_udc, export2.const_debug);
      -- SA Import SEAde66940
    ELSIF (pv_column_name = 'FOLDERID' AND pv_table_name = 'SA_SCHEDULE') THEN

      -- SA Import: always put the schedules in the schedule folder
      lv_return_value := to_char(get_folder_id_by_path('/Schedule'));
      exp_log('The schedules folder id is: ' || lv_return_value,
              export2.const_debug);

      -- SA Import SEAde67225
      -- must null the overwrite scenario id on imported sa schedules
    ELSIF (pv_column_name = 'OVRSCENARIOID' AND
          pv_table_name = 'SA_SCHEDULE') THEN
      lv_return_value := 'NULL';

      -- SA Import SEAde67225
      -- must null the data time on imported sa schedules
    ELSIF (pv_column_name = 'DATA_TIME' AND pv_table_name = 'SA_SCHEDULE') THEN
      lv_return_value := 'NULL';

      -- SA Import SEAde67225
      -- must set the start and sched times accordingly on imported schedules
    ELSIF ((pv_column_name = 'START_TIME' OR pv_column_name = 'SCHED_TIME') AND
          pv_table_name = 'SCHEDULE') THEN
      lv_return_value := getschedulestarttime(pv_value);

      -- SA Import SEAde66940
    ELSIF (gv_scenario_name IS NOT NULL AND (pv_column_name = 'SCENARIOID' AND
          pv_table_name = 'SA_SOFTALARM')) THEN

      lv_return_value := getscenarioid(gv_scenario_name);

    ELSIF (pv_column_name = 'STATUS' AND pv_table_name = 'WMD_UDC_DEF') THEN
      -- SEAde23934
      lv_return_value := 'N';

    ELSIF (pv_column_name IN ('FIRSTAVAIL', 'LASTAVAIL') AND
          pv_table_name = 'PM_BUSYHOUR') THEN
      -- SEAde23936
      -- SEAde24324
      lv_return_value := 'NULL';

      -- SEAde64782
      -- Critical that DAILY_RETENTION is retrieved before FIRSTNEEDED
      -- as it is used to re-set FIRSTNEEDED.
    ELSIF (pv_column_name = 'DAILY_RETENTION' AND
          pv_table_name = 'PM_BUSYHOUR') THEN
      -- store val for later use
      IF (pv_value = 'NULL') THEN
        gv_bh_retention_days := 0;
      ELSE
        --exp_log('gv_bh_retention_days: ' || pv_value, export2.CONST_PROC_CALLS);
        gv_bh_retention_days := nvl(to_number(pv_value), 0);
      END IF;

    ELSIF (pv_column_name = 'FIRSTNEEDED' AND pv_table_name = 'PM_BUSYHOUR') THEN
    
      -- Added as part of the core merge
      IF gv_set_FirstNeeded = 'S' THEN
         lv_return_value  := to_char(SYSDATE, export2.gv_date_format);
      ELSE
         lv_return_value := Getfirstneeded;                  
      END IF;
      -- SEAde64782
      -- if user does not exist then set to 'system' id
    ELSIF (pv_column_name = 'USERID' AND pv_table_name = 'PM_BUSYHOUR') THEN
      IF (NOT exists_user(pv_value)) THEN
        lv_return_value := get_system_id();
      END IF;

      -- SEAde64782
      -- determine if BH already existed in system, set flag
    ELSIF (pv_column_name = 'NAME' AND pv_table_name = 'PM_BUSYHOUR') THEN
      gv_exists_busyhour := exists_by_name(pv_value, pv_table_name);

    ELSIF (gv_scenario_name IS NOT NULL AND (pv_column_name = 'SCENARIO_ID' AND
          pv_table_name = 'PM_BUSYHOUR')) THEN

      lv_return_value := getscenarioid(gv_scenario_name);

    ELSIF (gv_user_id IS NOT NULL AND
          pv_column_name IN ('USER_ID', 'FIELD_OWNER', 'USERID')) THEN
      -- SEAde25114
      -- SEAde24787
      -- SEAde28625
      -- SEAde27578
      lv_return_value := to_char(gv_user_id);

    ELSIF (pv_column_name IN
          ('SCENARIOID', 'SCENARIO_ID', 'DOMAINSCENARIOID', 'BHSCENARIO_ID')) THEN

      IF (pv_value = 'NULL') THEN
        -- SEAde35973
        lv_return_value := pv_value;

      ELSIF (do_scenarios = 0) THEN
        IF (gv_scenario_id IS NULL) THEN
          IF (gv_depend_id IS NULL) THEN
            gv_depend_id := create_depend_folder(export2.gv_folder_id);
          END IF;
          SELECT userid
            INTO lv_user_id
            FROM pm_folder
           WHERE id = gv_depend_id;
           
           BEGIN
           SELECT ID INTO lv_scenarios_folder_id 
           FROM pm_folder 
           WHERE upper(NAME) = upper(gv_default_scenarios_path);
           
           EXCEPTION
           WHEN OTHERS THEN
               exp_log('Error finding folder ' || gv_default_scenarios_path ||
            ' in pm_folder table = ' || SQLCODE || ' ' || SQLERRM);           
           END;
          --gv_scenario_id := create_depend_scenario(lv_user_id, gv_depend_id);
          gv_scenario_id := create_depend_scenario(lv_user_id, lv_scenarios_folder_id);
        END IF;

        lv_return_value := to_char(gv_scenario_id);

      END IF;

    ELSIF (pv_table_name IN
          ('EXP_PM_SCENARIO_VIEW', 'EXP_PM_SCENARIO2_VIEW') AND
          pv_column_name IN ('TYPE')) THEN

      -- SEAde50899: All scenarios should be imported as user defined scenarios.
      lv_return_value := 'U';

    END IF;

    -- special handling for sa_export (folder and user ids)
    IF (gv_sa_import = 1) THEN
      IF ((pv_table_name = 'PM_FOLDER' AND
         pv_column_name IN ('FOLDERID', 'USERID')) OR
         (pv_table_name IN ('SA_SCHEDULE', 'SA_SOFTALARM', 'SA_TEMPLATE',
          'EXP_SA_JOB_GROUP_VIEW','EXP_JOB_GROUP_VIEW') AND pv_column_name = 'USERID')) THEN
        lv_return_value := get_sa_translations(pv_row_number,
                                               pv_table_name,
                                               pv_column_name,
                                               pv_value);
      END IF;

    END IF;

    RETURN lv_return_value;
  END;

  /**********************************************************/

  FUNCTION override_action(pv_table_name   VARCHAR2,
                           pv_column_name  VARCHAR2,
                           pv_column_value VARCHAR2,
                           pv_action       VARCHAR2) RETURN VARCHAR2 IS
    return_val exp_tab.action%TYPE;
    lv_action  VARCHAR2(30);
  BEGIN

    exp_log('Function override_action: pv_table_name = ' || pv_table_name ||
            ' pv_column_name = ' || pv_column_name ||
            ' pv_column_value = ' || pv_column_value || ' pv_action = ' ||
            pv_action,
            export2.const_proc_calls);

    lv_action := upper(gv_action);

    return_val := pv_action;

    -- SEAde64782
    -- Here we override the action depending on
    -- user specified action, gv_action
    IF (gv_action IS NOT NULL) THEN
      IF pv_table_name IN ('PM_BUSYHOUR', 'PM_HOURRANGE') THEN
        IF (lv_action = 'IGNORE') THEN
          IF (pv_table_name = 'PM_HOURRANGE' AND gv_exists_busyhour) THEN
            return_val                   := 'REUSE_FIRST_RO';
            export2.gv_fk_error_is_fatal := FALSE;
          ELSE
            return_val := 'REUSE';
          END IF;
        ELSIF (lv_action = 'OVERWRITE') THEN
          return_val := 'REPLACE';
        ELSIF (lv_action = 'FAIL') THEN
          return_val := 'ABORT';
        END IF;

      ELSIF pv_table_name IN
            ('SCHEDULE', 'SA_SCHEDULE', 'SCHEDULE_HOUR_EX') THEN
        IF (lv_action = 'IGNORE') THEN
          IF (pv_table_name = 'SCHEDULE_HOUR_EX' AND gv_exists_schedule) THEN
            return_val                   := 'REUSE_FIRST_RO';
            export2.gv_fk_error_is_fatal := FALSE;
          ELSE
            return_val := 'REUSE';
          END IF;
        ELSIF (lv_action = 'OVERWRITE') THEN
          return_val := 'REPLACE';
        ELSIF (lv_action = 'FAIL') THEN
          return_val := 'ABORT';
        END IF;

      ELSIF pv_table_name IN ('EXP_JOB_GROUP_VIEW','EXP_SA_JOB_GROUP_VIEW', 'JOB_GROUP_ITEM') THEN
        lv_action := upper(gv_action);
        IF (lv_action = 'IGNORE') THEN
          IF (pv_table_name = 'JOB_GROUP_ITEM' AND gv_exists_group != 0) THEN
            return_val                   := 'REUSE_FIRST_RO';
            export2.gv_fk_error_is_fatal := FALSE;
          ELSE
            return_val := 'REUSE';
          END IF;
        ELSIF (lv_action = 'OVERWRITE') THEN
          return_val := 'REPLACE';
        ELSIF (lv_action = 'FAIL') THEN
          return_val := 'ABORT';
        END IF;

      ELSIF pv_table_name IN ('SA_SOFTALARM', 'SA_THRESHOLD') THEN
        lv_action := upper(gv_action);
        IF (lv_action = 'IGNORE') THEN
          IF (pv_table_name = 'SA_THRESHOLD' AND gv_exists_sa != 0) THEN
            return_val                   := 'REUSE_FIRST_RO';
            export2.gv_fk_error_is_fatal := FALSE;
          ELSE
            return_val := 'REUSE';
          END IF;
        ELSIF (lv_action = 'OVERWRITE') THEN
          return_val := 'REPLACE';
        ELSIF (lv_action = 'FAIL') THEN
          return_val := 'ABORT';
        END IF;

      ELSIF pv_table_name IN ('SA_TEMPLATE') THEN
        IF (lv_action = 'IGNORE') THEN
          return_val := 'REUSE';
        ELSIF (lv_action = 'OVERWRITE') THEN
          return_val := 'REPLACE';
        ELSIF (lv_action = 'FAIL') THEN
          return_val := 'ABORT';
        END IF;
        -- note how we need to use the gv_exists_udc for OVERWRITE and FAIL
        -- also as we only want to do this for UDCs
      ELSIF pv_table_name IN
            ('EXP_FIELD_NAME_VIEW', 'WMD_UDC_DEF', 'WMD_FIELD_TECH') THEN
        IF (lv_action = 'IGNORE') THEN
          exp_log('Table is: ' || pv_table_name || ', gv_exists_udc = ' ||
                  gv_exists_udc,
                  export2.const_debug);
          IF (pv_table_name IN ('WMD_UDC_DEF', 'WMD_FIELD_TECH') AND
             gv_exists_udc != 0) THEN
            export2.gv_fk_error_is_fatal := FALSE;
            return_val                   := 'REUSE_FIRST_RO';
          ELSE
            return_val := 'REUSE';
          END IF;
        ELSIF (lv_action = 'OVERWRITE') THEN
          IF ((pv_table_name = 'EXP_FIELD_NAME_VIEW' AND gv_exists_udc != 0) OR
             (pv_table_name = 'WMD_UDC_DEF')) THEN
            return_val := 'REPLACE';
          END IF;
        ELSIF (lv_action = 'FAIL' AND gv_exists_udc != 0) THEN
          return_val := 'ABORT';
        END IF;

        -- if this is import_busyhour.sh or import_soft_alarm.sh tool, then do not create users
      ELSIF (pv_table_name = 'PM_USER') THEN
        -- we do not want to insert a new user - motorola security requirement
        return_val := 'REJECT';
      END IF;

    END IF;

    -- SA Import: SEAde66940
    -- excluding this check when doing SA Import specifically as there is additional requirement on system users here
    IF pv_column_name = 'USERID' AND
       pv_column_value = to_char(get_system_id()) AND gv_sa_import = 0 THEN
      IF pv_table_name IN
         ('PM_TEMPLATE', 'PM_MAP', 'PM_GRAPH', 'PM_BUSYHOUR',
          'PM_CHANSETPLAN', 'EXP_PM_REPORT_VIEW', 'PM_NOTIFICATION',
          'SA_TEMPLATE', 'SA_SOFTALARM', 'EDS_DOCUMENT', 'JOB_GROUP',
           'EXP_JOB_GROUP_VIEW','EXP_SA_JOB_GROUP_VIEW', 'SA_SCHEDULE') THEN
        return_val := 'REUSE_FIRST_RO';
      END IF;
    END IF;

    exp_log('Function override_action: new action = ' || return_val,
            export2.const_debug);

    RETURN return_val;

  END;

  /* This allows us to determine whether we should get the new translated value form a sequence or not */
  FUNCTION do_sequence(pv_table_name VARCHAR2, pv_column_name VARCHAR2)
    RETURN BOOLEAN IS
    return_val BOOLEAN DEFAULT FALSE;
    lv_action  VARCHAR2(100);
  BEGIN

    exp_log('Function do_sequence: pv_table_name = ' || pv_table_name ||
            ' pv_column_name = ' || pv_column_name,
            export2.const_proc_calls);

    lv_action := upper(gv_action);

    IF ((lv_action = 'OVERWRITE') AND
       (pv_column_name = 'ID' AND
       pv_table_name IN
       ('SA_TEMPLATE', 'SA_SOFTALARM', 'EXP_JOB_GROUP_VIEW','EXP_SA_JOB_GROUP_VIEW', 'PM_BUSYHOUR'))) THEN
      return_val := FALSE;
    ELSIF ((lv_action = 'OVERWRITE') AND
          (pv_column_name = 'FIELD_ID' AND
          pv_table_name = 'EXP_FIELD_NAME_VIEW')) THEN
      return_val := FALSE;
    ELSIF ((lv_action = 'OVERWRITE') AND (pv_table_name = 'PM_USER')) THEN
      return_val := FALSE;
    ELSIF ((lv_action = 'OVERWRITE') AND (pv_table_name = 'SCHEDULE')) THEN
      return_val := TRUE;
    ELSIF (lv_action IS NULL OR
          (lv_action IS NOT NULL AND pv_table_name != 'PM_USER')) THEN
      return_val := TRUE;
    END IF;

    IF (return_val) THEN
      exp_log('Function do_sequence returning: true', export2.const_debug);
    ELSE
      exp_log('Function do_sequence returning: false', export2.const_debug);
    END IF;

    RETURN return_val;

  END do_sequence;

  /**********************************************************/

  -- SEAde64782
  -- Busyhour ID's must be translated from import to existing.
  -- If the User does not exist, then default it to 'system'
  PROCEDURE translate_ids IS
  BEGIN
    exp_log('procedure translate_ids', export2.const_proc_calls);
    translate_bh_ids;
    translate_user_ids;

    --SA Import SEAde66940
    -- only need to do this for the SA import
    IF (gv_sa_import = 1) THEN
      -- SA Import: To get relationships and translations for folders and user ids specifically
      do_sa_translations;
      -- translations for each of the components
      translate_sa_sched_ids;
    END IF;

    translate_udc_ids;

  END;

  /**********************************************************/
  --SA Import SEAde66940
  PROCEDURE translate_sa_config_ids IS
  BEGIN
    -- translations for each of the components that are identified by folder also
    IF (gv_sa_import = 1) THEN
      translate_group_ids;
      translate_softalarm_ids;
      translate_sa_template_ids;
    END IF;
  END;

  /**********************************************************/

  -- SEAde64782
  -- Create translations that map imported Busyhour ID's to Existing id's

  PROCEDURE translate_bh_ids IS
    -- imported busyhour id
    bh_id_value LONG;
    -- imported busyhour name
    bh_name_value LONG;
    -- existing Busyhour ID's
    -- we must translate the imported ID's to the existing one's
    curr_bh_id pm_busyhour.id%TYPE;

  BEGIN
    exp_log('procedure translate_bh_ids', export2.const_proc_calls);

    IF (exp_custom.gv_action = 'OVERWRITE') THEN

      -- Loop over the busy hour import records
      FOR import IN (SELECT table_name, data
                       FROM exp_des
                      WHERE table_name = 'PM_BUSYHOUR') LOOP
        -- get the imported PM_BUSYHOUR.ID value
        bh_id_value := export2.parse_column_value(import.data,
                                                  export2.get_column_ordinal('PM_BUSYHOUR',
                                                                             'ID'));
        exp_log(' BH id value is ' || bh_id_value, export2.const_debug);
        -- get the imported PM_BUSYHOUR.NAME value
        bh_name_value := export2.parse_column_value(import.data,
                                                    export2.get_column_ordinal('PM_BUSYHOUR',
                                                                               'NAME'));
        exp_log(' BH name value is ' || bh_name_value, export2.const_debug);

        -- If the BH exists, then translate ID, otherwise get new ID
        BEGIN
          SELECT id
            INTO curr_bh_id
            FROM pm_busyhour
           WHERE upper(NAME) = upper(bh_name_value);
        EXCEPTION
          WHEN no_data_found THEN
            SELECT sq_busyhour.NEXTVAL INTO curr_bh_id FROM dual;
        END;
        exp_log('Current BH id is ' || curr_bh_id, export2.const_debug);

        -- insert the translation ( imported Busyhour IDs to existing Busyhour Ids)
        -- when the busyhour_import action is REPLACE, we must however reuse existing Id's
        export2.add_trn('PM_BUSYHOUR', 'ID', bh_id_value, curr_bh_id);

        -- we must also delete the hour ranges associated with the busyhours that we are replacing.
        DELETE FROM pm_hourrange
         WHERE pm_hourrange.busyhourid = curr_bh_id;
      END LOOP;
    END IF;
  END;

  /**********************************************************/
  -- START SK100707
  --SA Import SEAde66940
  -- Create translations that map SA SCHEDULE ID's to Existing id's

  PROCEDURE translate_sa_sched_ids IS
    -- imported Schedule IDs
    sa_schedule_id_value LONG;

    -- imported Schedule name
    sa_schedule_name_value LONG;

    -- existing SA_SCHEDULE ID's
    -- we must translate the imported SCHEDULE ID's to the existing one's
    curr_sa_schedule_id sa_schedule.sa_schedule_id%TYPE;

  BEGIN
    exp_log('procedure translate_sa_sched_ids', export2.const_proc_calls);

    IF (exp_custom.gv_action = 'OVERWRITE') THEN

      -- Loop over import records
      FOR import IN (SELECT table_name, data
                       FROM exp_des
                      WHERE table_name = 'SA_SCHEDULE') LOOP

        -- get the imported SA_SCHEDULE.SCHEDULE_ID value
        sa_schedule_id_value := export2.parse_column_value(import.data,
                                                           export2.get_column_ordinal('SA_SCHEDULE',
                                                                                      'SA_SCHEDULE_ID'));
        exp_log(' SA_SCHEDULE id value is ' || sa_schedule_id_value,
                export2.const_debug);

        -- get the imported SA_SCHEDULE.NAME value
        sa_schedule_name_value := export2.parse_column_value(import.data,
                                                             export2.get_column_ordinal('SA_SCHEDULE',
                                                                                        'NAME'));
        exp_log(' SA_SCHEDULE name value is ' || sa_schedule_name_value,
                export2.const_debug);

        -- If the SA_SCHEDULE exists, then translate ID, otherwise get new ID
        BEGIN
          SELECT sa_schedule_id
            INTO curr_sa_schedule_id
            FROM sa_schedule
           WHERE NAME = sa_schedule_name_value;
        EXCEPTION
          WHEN no_data_found THEN
            SELECT sq_schedule.NEXTVAL INTO curr_sa_schedule_id FROM dual;
        END;

        exp_log('Current SA_SCHEDULE id is ' || curr_sa_schedule_id,
                export2.const_debug);

        -- insert the translation ( imported SA_SCHEDULE IDs to existing SA_SCHEDULE Ids)
        -- when the schedule import action is REPLACE, we must however reuse existing Id's
        export2.add_trn('SA_SCHEDULE',
                        'SA_SCHEDULE_ID',
                        sa_schedule_id_value,
                        curr_sa_schedule_id);
        export2.add_trn('SCHEDULE',
                        'SCHED_FK',
                        sa_schedule_id_value,
                        curr_sa_schedule_id);

        -- we must also delete the hour ex associated with the schedule that we are replacing.
        DELETE FROM schedule_hour_ex
         WHERE schedule_hour_ex.schedule_id IN
               (SELECT schedule_id
                  FROM schedule
                 WHERE sched_fk = curr_sa_schedule_id);
        -- must also delete associated schedule_event record
        DELETE FROM schedule_event
         WHERE schedule_event.schedule_id IN
               (SELECT schedule_id
                  FROM schedule
                 WHERE sched_fk = curr_sa_schedule_id);
        -- finally delete associated schedule record
        DELETE FROM schedule WHERE sched_fk = curr_sa_schedule_id;
      END LOOP;

    END IF;
  END;

  -- END SK100707
  /**********************************************************/

  -- SEAde64782
  -- Create translations that map imported User ID's to Existing id's

  PROCEDURE translate_user_ids IS
    -- imported user IDs
    user_id_value LONG;
    -- imported username
    user_name_value LONG;
    -- existing USER ID's
    -- we must translate the imported ID's to the existing one's
    curr_user_id   pm_user.id%TYPE;
    curr_user_name pm_user.NAME%TYPE;

  BEGIN
    exp_log('procedure translate_user_ids', export2.const_debug);

    -- Loop over import records that have no parent.
    FOR import IN (SELECT table_name, data
                     FROM exp_des
                    WHERE table_name = 'PM_USER') LOOP
      -- get the imported PM_USER.ID value
      user_id_value := export2.parse_column_value(import.data,
                                                  export2.get_column_ordinal('PM_USER',
                                                                             'ID'));
      exp_log(' USER id value is ' || user_id_value, export2.const_debug);
      -- get the imported PM_BUSER.NAME value
      user_name_value := export2.parse_column_value(import.data,
                                                    export2.get_column_ordinal('PM_USER',
                                                                               'NAME'));
      exp_log(' USER name value is ' || user_name_value,
              export2.const_debug);

      -- If the USER does not exist, then translate ID to 'system', otherwise do nothing
      BEGIN
        SELECT NAME
          INTO curr_user_name
          FROM pm_user
         WHERE NAME = user_name_value;
      EXCEPTION
        WHEN no_data_found THEN
          curr_user_id := get_system_id();
          -- insert the translation ( imported USER IDs to existing USER Ids)
          -- when the busyhour_import action is REPLACE, we must however reuse existing Id's
          export2.add_trn('PM_USER', 'NAME', user_name_value, 'system');
      END;
      exp_log('Current USER id is ' || curr_user_id, export2.const_debug);

    END LOOP;
  END;

  /**********************************************************/

  --SA Import SEAde66940
  -- To insert translations for folder id (parent folder) and user ids based on whether user exists in target system or not.
  -- Cannot use existing transaltions table here as we may have the same parent folder id having to be translated differently
  -- depending on whether the user is in the target system or not

  PROCEDURE do_sa_translations IS

    folder_id      LONG; -- imported Folder IDs
    folder_p_id    LONG; -- imported Parent Folder IDs
    folder_name    LONG; --imported folder name
    folder_user_id LONG; -- imported Folder user IDs
    user_id        LONG; -- imported User IDs
    user_name      LONG; -- imported User names
    row_number     NUMBER; -- for the row number

    sa_user_id LONG; -- for soft alarm user id

    -- existing USER ID's
    -- we must translate the imported ID's to the existing one's
    curr_user_id        pm_user.id%TYPE;
    curr_user_folder_id pm_folder.id%TYPE;

  BEGIN
    exp_log('procedure do_sa_translations', export2.const_proc_calls);

    -- only do this for sa import
    IF (gv_sa_import = 1) THEN

      -- Loop over PM_FOLDER import records
      FOR folders IN (SELECT id, table_name, data
                        FROM exp_des
                       WHERE table_name = 'PM_FOLDER') LOOP

        row_number := folders.id;
        -- get the folder id value from the folder
        folder_id := export2.parse_column_value(folders.data,
                                                export2.get_column_ordinal('PM_FOLDER',
                                                                           'ID'));
        -- get the parent id
        folder_p_id := export2.parse_column_value(folders.data,
                                                  export2.get_column_ordinal('PM_FOLDER',
                                                                             'FOLDERID'));
        -- get the name
        folder_name := export2.parse_column_value(folders.data,
                                                  export2.get_column_ordinal('PM_FOLDER',
                                                                             'NAME'));
        -- get the imported user id value from the folder
        folder_user_id := export2.parse_column_value(folders.data,
                                                     export2.get_column_ordinal('PM_FOLDER',
                                                                                'USERID'));
        exp_log(' Folder USER id value is ' || folder_user_id,
                export2.const_debug);

        -- if the path is passed in then reconcile it to a folder and user and use these for mapping
        IF (gv_default_path IS NOT NULL) THEN
          curr_user_folder_id := export2.gv_folder_id;
          curr_user_id        := export2.gv_user_id;

        ELSE
          -- go through data to get these

          --loop through any PM_USER records in the import and get user id
          FOR users IN (SELECT table_name, data
                          FROM exp_des
                         WHERE table_name = 'PM_USER') LOOP
            user_id := export2.parse_column_value(users.data,
                                                  export2.get_column_ordinal('PM_USER',
                                                                             'ID'));

            -- check for user id matching the folder user id
            IF (folder_user_id = user_id) THEN
              exp_log(' Folder USER id matches user id value',
                      export2.const_debug);
              --get the user name if we get a match
              user_name := export2.parse_column_value(users.data,
                                                      export2.get_column_ordinal('PM_USER',
                                                                                 'NAME'));
              exp_log(' user name is ' || user_name, export2.const_debug);

              -- check to see if user exists on target system
              BEGIN
                SELECT id
                  INTO curr_user_id
                  FROM pm_user
                 WHERE NAME = user_name;

                -- if the folder name matches the user name then need to set the current folder to the /users folder
                IF (folder_name = user_name) THEN
                  curr_user_folder_id := get_users_folderid();
                ELSIF (user_name = const_system_name) THEN
                  -- system owned objects will be uput into dependncies folder
                  curr_user_id := gv_default_user_id;
                  -- if the folder name matches the user name then this goes striaght into the dependencies folder
                  export2.gv_folder_id := get_root_folderid();
                  curr_user_folder_id  := create_folder(create_depend_folder(export2.gv_folder_id),
                                                        user_name);
                ELSE
                  --otherwise go to the users home folder
                  curr_user_folder_id := get_folder_id_by_path('users/' ||
                                                               user_name);
                END IF;
                exp_log(' user id on target ' || curr_user_id ||
                        ' user folder id on target ' ||
                        curr_user_folder_id,
                        export2.const_debug);

              EXCEPTION
                WHEN no_data_found THEN
                  -- if we cannot find the user in the target system then it is set to system user and dependencies folder
                  curr_user_id := gv_default_user_id;
                  -- if the folder name matches the user name then this goes striaght into the dependencies folder
                  export2.gv_folder_id := get_root_folderid();
                  IF (folder_name = user_name) THEN
                    curr_user_folder_id := create_depend_folder(export2.gv_folder_id);
                  ELSE
                    curr_user_folder_id := create_folder(create_depend_folder(export2.gv_folder_id),
                                                         user_name);
                  END IF;
              END;

              EXIT; -- can exit inner loop here as we have the match on user in data
            END IF;

          END LOOP; --users loop

          -- if we did not get a match in data this will be moved to the Dependencies folder as a system user
          IF (user_name IS NULL) THEN
            user_name            := 'system';
            curr_user_id         := gv_default_user_id;
            export2.gv_folder_id := get_root_folderid();
            curr_user_folder_id  := create_folder(create_depend_folder(export2.gv_folder_id),
                                                  user_name);
          END IF;

        END IF;

        --populate sa translations table with values  can be used later for tranlsating user ids

        add_sa_translation(row_number,
                           'PM_FOLDER',
                           'USERID',
                           to_char(curr_user_id));
        add_sa_translation(row_number,
                           'PM_FOLDER',
                           'FOLDERID',
                           to_char(curr_user_folder_id));

        -- at this point we have the user ID for all the SA config associated with that user
        -- therefore we can assign it to all of this related config
        FOR sa_config IN (SELECT id, table_name, data
                            FROM exp_des
                           WHERE table_name IN
                                 ('SA_SOFTALARM', 'SA_TEMPLATE',
                                  'EXP_JOB_GROUP_VIEW','EXP_SA_JOB_GROUP_VIEW', 'SA_SCHEDULE')) LOOP
          sa_user_id := export2.parse_column_value(sa_config.data,
                                                   export2.get_column_ordinal(sa_config.table_name,
                                                                              'USERID'));
          IF ((sa_user_id = user_id) OR (gv_default_path IS NOT NULL)) THEN
            add_sa_translation(sa_config.id,
                               sa_config.table_name,
                               'USERID',
                               to_char(curr_user_id));
          END IF;

        END LOOP; -- sa_config loop

      END LOOP; --folder loop

    END IF;
  END;

  /*********************************************************************/
  -- Soft Alarms Export
  -- May be required here
  PROCEDURE translate_group_ids IS

    -- imported Group ID
    group_id_value LONG;
    -- imported group name
    group_name_value LONG;
    -- imported folderid
    group_folderid_value LONG;

    -- existing GROUP IDs
    -- we must translate the imported IDs to the existing ones
    curr_group_id exp_sa_job_group_view.id%TYPE;

  BEGIN
    exp_log('procedure translate_group_ids', export2.const_proc_calls);

    IF (exp_custom.gv_action = 'OVERWRITE') THEN

      -- Loop over import records in EXP_SA_JOB_GROUP_VIEW
      FOR import IN (SELECT table_name, data
                       FROM exp_des
                      WHERE table_name = 'EXP_SA_JOB_GROUP_VIEW') LOOP
                      
        -- get the imported EXP_SA_JOB_GROUP_VIEW.ID value
        group_id_value := export2.parse_column_value(import.data,
                                                     export2.get_column_ordinal('EXP_SA_JOB_GROUP_VIEW',
                                                                                'ID'));
        exp_log(' GROUP id value is ' || group_id_value,
                export2.const_debug);
        -- get the imported EXP_SA_JOB_GROUP_VIEW.NAME value
        group_name_value := export2.parse_column_value(import.data,
                                                       export2.get_column_ordinal('EXP_SA_JOB_GROUP_VIEW',
                                                                                  'NAME'));
        exp_log(' GROUP name value is ' || group_name_value,
                export2.const_debug);
        -- get the imported EXP_SA_JOB_GROUP_VIEW.NAME value
        group_folderid_value := export2.parse_column_value(import.data,
                                                           export2.get_column_ordinal('EXP_SA_JOB_GROUP_VIEW',
                                                                                      'FOLDERID'));
        exp_log(' GROUP folder id value is ' || group_folderid_value,
                export2.const_debug);

        curr_group_id := get_id_by_name_and_folder('EXP_SA_JOB_GROUP_VIEW',
                                                   group_folderid_value,
                                                   group_name_value);
        IF (curr_group_id = 0) THEN
          SELECT job_group_seq.NEXTVAL INTO curr_group_id FROM dual;
        END IF;

        exp_log('Current GROUP id is ' || curr_group_id,
                export2.const_debug);

        -- insert the translation ( imported Group IDs to existing Group Ids)
        export2.add_trn('EXP_SA_JOB_GROUP_VIEW',
                        'ID',
                        group_id_value,
                        curr_group_id);

        -- we must also delete the the child group item records associated with the groups that we are replacing.
        DELETE FROM job_group_item
         WHERE job_group_item.group_id = curr_group_id;

      END LOOP;
      
      -- Loop over import records in EXP_SA_JOB_GROUP_VIEW
      FOR import IN (SELECT table_name, data
                       FROM exp_des
                      WHERE table_name = 'EXP_JOB_GROUP_VIEW') LOOP
                      
        -- get the imported EXP_SA_JOB_GROUP_VIEW.ID value
        group_id_value := export2.parse_column_value(import.data,
                                                     export2.get_column_ordinal('EXP_JOB_GROUP_VIEW',
                                                                                'ID'));
        exp_log(' GROUP id value is ' || group_id_value,
                export2.const_debug);
        -- get the imported EXP_SA_JOB_GROUP_VIEW.NAME value
        group_name_value := export2.parse_column_value(import.data,
                                                       export2.get_column_ordinal('EXP_JOB_GROUP_VIEW',
                                                                                  'NAME'));
        exp_log(' GROUP name value is ' || group_name_value,
                export2.const_debug);
        -- get the imported EXP_SA_JOB_GROUP_VIEW.NAME value
        group_folderid_value := export2.parse_column_value(import.data,
                                                           export2.get_column_ordinal('EXP_JOB_GROUP_VIEW',
                                                                                      'FOLDERID'));
        exp_log(' GROUP folder id value is ' || group_folderid_value,
                export2.const_debug);

        curr_group_id := get_id_by_name_and_folder('EXP_JOB_GROUP_VIEW',
                                                   group_folderid_value,
                                                   group_name_value);
        IF (curr_group_id = 0) THEN
          SELECT job_group_seq.NEXTVAL INTO curr_group_id FROM dual;
        END IF;

        exp_log('Current GROUP id is ' || curr_group_id,
                export2.const_debug);

        -- insert the translation ( imported Group IDs to existing Group Ids)
        export2.add_trn('EXP_JOB_GROUP_VIEW',
                        'ID',
                        group_id_value,
                        curr_group_id);

        -- we must also delete the the child group item records associated with the groups that we are replacing.
        DELETE FROM job_group_item
         WHERE job_group_item.group_id = curr_group_id;

      END LOOP;
      
      
    END IF;
  END;

  /*********************************************************************/
  -- Soft Alarms Export
  -- May be required here
  PROCEDURE translate_softalarm_ids IS

    --imported soft alarm IDs
    softalarm_id_value LONG;
    -- imported softalarm name
    softalarm_name_value LONG;
    -- imported softalarm folder
    softalarm_folderid_value LONG;

    -- existing SOFTALARM ID's
    -- we must translate the imported ID's to the existing one's
    curr_softalarm_id sa_softalarm.id%TYPE;

  BEGIN
    exp_log('procedure translate_softalarm_ids', export2.const_proc_calls);

    IF (exp_custom.gv_action = 'OVERWRITE') THEN

      -- Loop over import records in SA_SOFTALARM
      FOR import IN (SELECT table_name, data
                       FROM exp_des
                      WHERE table_name = 'SA_SOFTALARM') LOOP
        -- get the imported SA_SOFTALARM.ID value
        softalarm_id_value := export2.parse_column_value(import.data,
                                                         export2.get_column_ordinal('SA_SOFTALARM',
                                                                                    'ID'));
        exp_log(' SoftAlarm id value is ' || softalarm_id_value,
                export2.const_debug);
        -- get the imported SA_SOFTALARM.NAME value
        softalarm_name_value := export2.parse_column_value(import.data,
                                                           export2.get_column_ordinal('SA_SOFTALARM',
                                                                                      'NAME'));
        exp_log(' SOFTALARM name value is ' || softalarm_name_value,
                export2.const_debug);
        -- get the imported SA_SOFTALARM.FOLDERID value
        softalarm_folderid_value := export2.parse_column_value(import.data,
                                                               export2.get_column_ordinal('SA_SOFTALARM',
                                                                                          'FOLDERID'));
        exp_log(' SOFTALARM folder id value is ' ||
                softalarm_folderid_value,
                export2.const_debug);

        -- If the SOFTALARM exists, then translate ID, otherwise get new ID
        curr_softalarm_id := get_id_by_name_and_folder('SA_SOFTALARM',
                                                       softalarm_folderid_value,
                                                       softalarm_name_value);
        IF (curr_softalarm_id = 0) THEN
          SELECT sq_softalarm.NEXTVAL INTO curr_softalarm_id FROM dual;
        END IF;

        exp_log('Current SOFTALARM id is ' || curr_softalarm_id,
                export2.const_debug);

        -- insert the translation ( imported SA IDs to existing SA Ids)
        export2.add_trn('SA_SOFTALARM',
                        'ID',
                        softalarm_id_value,
                        curr_softalarm_id);

        -- we must also delete the the child threshold records associated with the SA that we are replacing.
        DELETE FROM sa_threshold
         WHERE sa_threshold.softalarm_id = curr_softalarm_id;

        -- we must also delete from this table to stop overwrites causing issues when SAs execute
        -- due to this table ending up in an inconsistent state
        DELETE FROM sa_logical_operator
         WHERE sa_logical_operator.sa_id = curr_softalarm_id;

      END LOOP;
    END IF;
  END;

  /*********************************************************************/
  --SA Import SEAde66940
  PROCEDURE translate_sa_template_ids IS

    --imported soft alarm IDs
    sa_template_id_value LONG;
    -- imported softalarm name
    sa_template_name_value LONG;
    -- imported softalarm folder
    sa_template_folderid_value LONG;
    -- existing SOFTALARM ID's
    -- we must translate the imported ID's to the existing one's
    curr_sa_template_id sa_template.id%TYPE;

  BEGIN
    exp_log('procedure translate_sa_template_ids',
            export2.const_proc_calls);

    IF (exp_custom.gv_action = 'OVERWRITE') THEN

      -- Loop over import records in SA_SOFTALARM
      FOR import IN (SELECT table_name, data
                       FROM exp_des
                      WHERE table_name = 'SA_TEMPLATE') LOOP
        -- get the imported SA_TEMPLATE.ID value
        sa_template_id_value := export2.parse_column_value(import.data,
                                                           export2.get_column_ordinal('SA_TEMPLATE',
                                                                                      'ID'));
        exp_log(' SA_TEMPLATE id value is ' || sa_template_id_value,
                export2.const_debug);
        -- get the imported SA_SOFTALARM.NAME value
        sa_template_name_value := export2.parse_column_value(import.data,
                                                             export2.get_column_ordinal('SA_TEMPLATE',
                                                                                        'NAME'));
        exp_log(' SA_TEMPLATE name value is ' || sa_template_name_value,
                export2.const_debug);
        -- get the imported EXP_SA_JOB_GROUP_VIEW.NAME value
        sa_template_folderid_value := export2.parse_column_value(import.data,
                                                                 export2.get_column_ordinal('SA_TEMPLATE',
                                                                                            'FOLDERID'));
        exp_log(' SA Template folder id value is ' ||
                sa_template_folderid_value,
                export2.const_debug);

        -- If the SA_TEMPLATE exists, then translate ID, otherwise get new ID
        curr_sa_template_id := get_id_by_name_and_folder('SA_TEMPLATE',
                                                         sa_template_folderid_value,
                                                         sa_template_name_value);
        IF (curr_sa_template_id = 0) THEN
          SELECT sq_sa_template.NEXTVAL INTO curr_sa_template_id FROM dual;
        END IF;

        exp_log('Current SA_TEMPLATE id is ' || curr_sa_template_id,
                export2.const_debug);

        -- insert the translation ( imported SA IDs to existing SA Ids)
        export2.add_trn('SA_TEMPLATE',
                        'ID',
                        sa_template_id_value,
                        curr_sa_template_id);

      END LOOP;
    END IF;
  END;
  /* SA Import allows for UDCs to be updated */

  PROCEDURE translate_udc_ids IS

    -- imported field ID
    field_id_value LONG;
    -- imported field name
    field_name_value LONG;
    -- imported field ID
    field_entity_id_value LONG;

    -- we must translate the imported IDs to the existing ones
    curr_field_id exp_field_name_view.field_id%TYPE;

  BEGIN
    exp_log('procedure translate_udc_ids', export2.const_proc_calls);

    IF (exp_custom.gv_action = 'OVERWRITE') THEN

      -- Loop over import records in EXP_FIELD_NAME_VIEW
      FOR import IN (SELECT table_name, data
                       FROM exp_des
                      WHERE table_name = 'EXP_FIELD_NAME_VIEW') LOOP
        -- get the imported EXP_FIELD_NAME_VIEW.FIELD_ID value
        field_id_value := export2.parse_column_value(import.data,
                                                     export2.get_column_ordinal('EXP_FIELD_NAME_VIEW',
                                                                                'FIELD_ID'));
        exp_log(' Field id value is ' || field_id_value,
                export2.const_debug);
        -- get the imported EXP_FIELD_NAME_VIEW.NAME value
        field_name_value := export2.parse_column_value(import.data,
                                                       export2.get_column_ordinal('EXP_FIELD_NAME_VIEW',
                                                                                  'NAME'));
        exp_log(' Field name value is ' || field_name_value,
                export2.const_debug);
        -- get the imported EXP_FIELD_NAME_VIEW.entity_id value
        field_entity_id_value := export2.parse_column_value(import.data,
                                                            export2.get_column_ordinal('EXP_FIELD_NAME_VIEW',
                                                                                       'ENTITY_ID'));
        exp_log(' Field entity id value is ' || field_entity_id_value,
                export2.const_debug);

        curr_field_id := exists_udc(field_name_value, field_entity_id_value);
        IF (curr_field_id = 0) THEN
          exp_log('Field not found for ' || field_name_value ||
                  ' getting id from sequence',
                  export2.const_debug);

          SELECT wmd_field_def_seq.NEXTVAL INTO curr_field_id FROM dual;
        END IF;

        exp_log('Current Fields id is ' || curr_field_id,
                export2.const_debug);

        -- insert the translation ( imported field IDs to existing field Ids)
        export2.add_trn('EXP_FIELD_NAME_VIEW',
                        'FIELD_ID',
                        field_id_value,
                        curr_field_id);
        --export2.add_trn ('WMN_UDC_DEF', 'FIELD_ID', field_id_value, curr_field_id);

        -- we must also delete the the child field tech records associated with the groups that we are replacing.
        DELETE FROM wmd_field_tech t WHERE t.field_id = curr_field_id;

      END LOOP;
    END IF;
  END;

  --SA Import SEAde66940
  -- TO DO: Figure out a way to imlement this fully
  PROCEDURE translate_config_ids(pv_table_name VARCHAR2) IS

    --imported IDs, NAME and FOLDER ID
    id_val       LONG;
    name_val     LONG;
    folderid_val LONG;

    -- we must translate the imported ID's to the current one's
    curr_id NUMBER;

    lv_sql      VARCHAR2(1000);
    lv_seq_name VARCHAR2(100);

  BEGIN
    exp_log('procedure translate_config_ids pv_table_name =' ||
            pv_table_name,
            export2.const_proc_calls);

    -- Loop over import records in the table
    FOR import IN (SELECT table_name, data
                     FROM exp_des
                    WHERE table_name = pv_table_name) LOOP
      -- get the imported ID value
      id_val := export2.parse_column_value(import.data,
                                           export2.get_column_ordinal(pv_table_name,
                                                                      'ID'));
      exp_log(pv_table_name || '.id value is ' || id_val,
              export2.const_debug);
      -- get the imported NAME value
      name_val := export2.parse_column_value(import.data,
                                             export2.get_column_ordinal(pv_table_name,
                                                                        'NAME'));
      exp_log(pv_table_name || '.name value is ' || name_val,
              export2.const_debug);
      -- get the imported FOLDERID value
      folderid_val := export2.parse_column_value(import.data,
                                                 export2.get_column_ordinal(pv_table_name,
                                                                            'FOLDERID'));
      exp_log(pv_table_name || '.folderid value is ' || folderid_val,
              export2.const_debug);

      -- If the entity exists, then translate ID,
      curr_id := get_id_by_name_and_folder(pv_table_name,
                                           folderid_val,
                                           name_val);
      -- otherwise get new ID from table's sequence
      IF (curr_id = 0) THEN

        SELECT sequence_name
          INTO lv_seq_name
          FROM exp_seq
         WHERE table_name = pv_table_name;

        lv_sql := ' SELECT TO_CHAR( ' || lv_seq_name ||
                  '.NEXTVAL ) FROM dual ';
        exp_log(lv_sql, export2.const_dynamic_sql);
        EXECUTE IMMEDIATE lv_sql
          INTO curr_id;
      END IF;

      exp_log('Current ' || pv_table_name || '.id is ' || curr_id,
              export2.const_debug);

      -- insert the translation ( imported SA IDs to existing SA Ids)
      export2.add_trn(pv_table_name, 'ID', id_val, curr_id);

    END LOOP;
  END;

  /**********************************************************/

  FUNCTION create_depend_scenario(pv_dep_userid   NUMBER,
                                  pv_dep_folderid NUMBER) RETURN NUMBER AS
    lv_id NUMBER;

    vactive    BOOLEAN;
    vqueryid   INTEGER;
    vroot      BOOLEAN := FALSE;
    vgroup     BOOLEAN := FALSE;
    vfilter    VARCHAR2(200) := NULL;
    vquerytext VARCHAR2(4000);
    vclasstext VARCHAR2(4000);

    CURSOR entitydata IS
      SELECT ent.entity_id,
             ent.entity_name,
             ent.defaultnameexpr,
             ent.labelexpr,
             ent.entityorderexpr,
             ent.isgroup
        FROM wmn_entity ent, wmn_entity_context ec
       WHERE ec.context_id = wm_scenario.get_context
         AND ent.entity_id = ec.entity_id
       ORDER BY ent.entityordernum;
  BEGIN
    exp_log('Function create_depend_scenario: pv_dep_userid =' ||
            to_char(pv_dep_userid) || ' pv_dep_folderid =' ||
            to_char(pv_dep_folderid),
            export2.const_proc_calls);

    vqueryid := wm_query.new_query('Undefined Query');
    wm_query.add_query_text(vqueryid, '<QUERY Type = "GATEWAY">');
    wm_query.add_query_text(vqueryid,
                            '<SET_VALUE Name="GATEWAY.SpecialMembers" Value="1"/>');
    FOR entity IN entitydata LOOP
      vgroup := (entity.isgroup = 'y');
      IF (entity.entity_name = 'System') THEN
        vroot   := TRUE;
        vfilter := 'inGroup(Id,"0")';
      ELSE
        vroot   := FALSE;
        vfilter := NULL;
      END IF;

      vclasstext := '<CLASS Name=''' || entity.entity_name || '''>';
      IF (vfilter IS NOT NULL) THEN
        vclasstext := vclasstext || '<FILTER><![CDATA[' || vfilter ||
                      ']]></FILTER>';
      END IF;
      vclasstext := vclasstext || '<ID/>';
      IF (NOT vroot) THEN
        vclasstext := vclasstext || '<PARENT/>';
      END IF;
      vclasstext := vclasstext || '<SORT Order=''Ascending''><![CDATA[' ||
                    entity.entityorderexpr || ']]></SORT>';
      vclasstext := vclasstext ||
                    '<DATAMEMBER Name=''DefaultName''><![CDATA[' ||
                    entity.defaultnameexpr || ']]></DATAMEMBER>';
      IF (NOT vgroup) THEN
        vclasstext := vclasstext || '<DATAMEMBER Name=''Name''/>';
        vclasstext := vclasstext || '<DATAMEMBER Name=''Label''><![CDATA[' ||
                      entity.labelexpr || ']]></DATAMEMBER>';
      END IF;
      vclasstext := vclasstext || '<DATAMEMBER Name=''Order''><![CDATA[' ||
                    entity.entityorderexpr || ']]></DATAMEMBER>';
      vclasstext := vclasstext || '<DATAMEMBER Name=''Active''/>';
      vclasstext := vclasstext || '<DATAMEMBER Name=''Placeholder''/>';

      IF (vactive) THEN
        vclasstext := vclasstext ||
                      '<DATAMEMBER Name=''Unlinked''><![CDATA[0]]></DATAMEMBER>';
      ELSE
        vclasstext := vclasstext ||
                      '<DATAMEMBER Name=''Unlinked''><![CDATA[1]]></DATAMEMBER>';
      END IF;
      vclasstext := vclasstext ||
                    '<DATAMEMBER Name=''Excluded''><![CDATA[0]]></DATAMEMBER>';
      vclasstext := vclasstext || '</CLASS>';

      vquerytext := vclasstext;

      wm_query.add_query_text(vqueryid, vquerytext);
    END LOOP;

    wm_query.add_query_text(vqueryid, '</QUERY>');

    SELECT sq_scenario.NEXTVAL INTO lv_id FROM dual;

    BEGIN
            

      INSERT INTO pm_scenario
        (id,
         folderid,
         userid,
         NAME,
         description,
         changed,
         TYPE,
         systemid,
         query_id)
      VALUES
        (lv_id,
         pv_dep_folderid,
         pv_dep_userid,
         'Undefined Scenario',
         'Undefined Scenario for Imported Objects',
         SYSDATE,
         'U',
         NULL,
         vqueryid);
      exp_log('Inserted undefined scenario');
    EXCEPTION
      WHEN dup_val_on_index THEN
        exp_log('Selecting existing undefined scenario');

        SELECT id
          INTO lv_id
          FROM pm_scenario
         WHERE folderid = pv_dep_folderid
           AND upper(NAME) = upper('Undefined Scenario');
    END;

    RETURN lv_id;

  END; -- create_depend_scenario

  /*********************************************************************/

  FUNCTION create_depend_folder(pv_folder_id NUMBER) RETURN NUMBER AS
    lv_id      NUMBER;
    lv_user_id NUMBER;
  BEGIN

    exp_log('Function create_depend_folder: pv_folder_id =' ||
            to_char(pv_folder_id),
            export2.const_proc_calls);

    IF pv_folder_id IS NULL THEN
      -- Use the root's folder id
      RETURN get_root_folderid();
    END IF;

    IF export2.process_mode = export2.const_mode_full THEN
      -- This is a full prospect import. No Dependencies needed.
      -- Use the root's folder id
      RETURN get_root_folderid();
    END IF;

    IF (gv_sa_import = 0) THEN
      SELECT userid INTO lv_user_id FROM pm_folder WHERE id = pv_folder_id;
    ELSE
      lv_user_id := gv_default_user_id;
    END IF;

    BEGIN

      SELECT id
        INTO lv_id
        FROM pm_folder
       WHERE folderid = pv_folder_id
         AND upper(NAME) = upper('Dependencies');

    EXCEPTION
      WHEN no_data_found THEN
        SELECT sq_folder.NEXTVAL INTO lv_id FROM dual;

        INSERT INTO pm_folder
          (id,
           folderid,
           userid,
           NAME,
           description,
           changed,
           TYPE,
           category)
        VALUES
          (lv_id,
           pv_folder_id,
           lv_user_id,
           'Dependencies',
           'Import/Export Dependencies',
           SYSDATE,
           'N',
           'Explorer Documents');
        exp_log('New Dependencies Folder Created: ID=' || to_char(lv_id) ||
                ' FOLDERID=' || to_char(pv_folder_id),
                export2.const_warnings);

    END;


    RETURN lv_id;

  END; -- create_depend_folder

  /*********************************************************************/


FUNCTION create_folder(pv_folder_id NUMBER, pv_folder_name VARCHAR2)

    RETURN NUMBER AS
    lv_id      NUMBER;
    lv_user_id NUMBER;
  BEGIN

    exp_log('Function create_folder: pv_folder_id =' ||
            to_char(pv_folder_id),
            export2.const_proc_calls);

    IF pv_folder_id IS NULL THEN
      -- Use the root's folder id
      RETURN get_root_folderid();
    END IF;

    IF export2.process_mode = export2.const_mode_full THEN
      -- This is a full prospect import. No Dependencies needed.
      -- Use the root's folder id
      RETURN get_root_folderid();
    END IF;

    SELECT userid INTO lv_user_id FROM pm_folder WHERE id = pv_folder_id;

    BEGIN

      SELECT id
        INTO lv_id
        FROM pm_folder
       WHERE folderid = pv_folder_id
         AND upper(NAME) = upper(pv_folder_name);

    EXCEPTION
      WHEN no_data_found THEN
        SELECT sq_folder.NEXTVAL INTO lv_id FROM dual;

        INSERT INTO pm_folder
          (id,
           folderid,
           userid,
           NAME,
           description,
           changed,
           TYPE,
           category)
        VALUES
          (lv_id,
           pv_folder_id,
           lv_user_id,
           pv_folder_name,
           'Import/Export Created Folder',
           SYSDATE,
           'N',
           'Explorer Documents');
        exp_log('New Folder Created : NAME = ' || pv_folder_name ||
                ' ID = ' || to_char(lv_id) || ' FOLDERID = ' ||
                to_char(pv_folder_id),
                export2.const_debug);

    END;

    RETURN lv_id;

  END; -- create_folder

  /*********************************************************************/

  FUNCTION create_udc_template(pv_folder_id NUMBER) RETURN NUMBER AS
    lv_templateid  NUMBER;
    lv_rowcount    NUMBER DEFAULT 1;
    lv_entity_id   wmn_entity.entity_id%TYPE;
    lv_entity_name wmn_entity.entity_name%TYPE;
    lv_userid      pm_user.id%TYPE;
  BEGIN
    exp_log('Function create_udc_template: pv_folder_id =' ||
            to_char(pv_folder_id),
            export2.const_proc_calls);

    SELECT sq_template.NEXTVAL INTO lv_templateid FROM dual;

    SELECT entity_id, entity_name
      INTO lv_entity_id, lv_entity_name
      FROM wmn_entity
     WHERE upper(entity_name) = 'SYSTEM';

    SELECT id INTO lv_userid FROM pm_user WHERE upper(NAME) = 'PROSPECT';

    BEGIN

      INSERT INTO pm_template
        (id,
         folderid,
         userid,
         NAME,
         description,
         changed,
         category,
         TYPE,
         entity_id,
         criteriafieldid)
      VALUES
        (lv_templateid,
         pv_folder_id,
         lv_userid,
         'UDC_Temp',
         'Temporary UDC Export Template',
         SYSDATE,
         'Traffic',
         lv_entity_name,
         lv_entity_id,
         NULL);

      FOR v_c1 IN (SELECT field_id FROM wmd_udc_def) LOOP

        INSERT INTO pm_templatefield
          (templateid, ordinal, field_id, sortorder, isshown)
        VALUES
          (lv_templateid, lv_rowcount, v_c1.field_id, 'N', 'Y');

        lv_rowcount := lv_rowcount + 1;
      END LOOP;

    EXCEPTION
      WHEN dup_val_on_index THEN
        NULL;
    END;

    RETURN lv_templateid;

  END; -- create_udc_template

  /*********************************************************************/

  FUNCTION get_folder_id_by_path(pv_path VARCHAR2) RETURN NUMBER AS
    lv_name      pm_folder.NAME%TYPE := 'ROOT';
    lv_path      VARCHAR2(4000) := rtrim(ltrim(REPLACE(pv_path, '\', '/'),
                                               '/'),
                                         '/') || '/';
    lv_id        pm_folder.id%TYPE;
    lv_parent_id pm_folder.folderid%TYPE := NULL;
  BEGIN
    exp_log('Function get_folder_id_by_path: pv_path =' || pv_path,
            export2.const_proc_calls);

    LOOP
      EXIT WHEN lv_name IS NULL;
      SELECT id
        INTO lv_id
        FROM pm_folder
       WHERE upper(NAME) = upper(lv_name)
         AND decode(folderid, NULL, -1, folderid) = nvl(lv_parent_id, -1);
      lv_parent_id := lv_id;
      lv_name      := substr(lv_path, 1, instr(lv_path, '/') - 1);
      lv_path      := substr(lv_path,
                             instr(lv_path, '/') + 1,
                             length(lv_path));
    END LOOP;

    RETURN lv_id;

  EXCEPTION
    WHEN no_data_found THEN
      raise_application_error(-20113,
                              'Target Prospect document path not found: ' ||
                              pv_path);
  END;

  /*********************************************************************/

  FUNCTION get_user_id_by_path(pv_path VARCHAR2) RETURN NUMBER AS
    lv_folder_id pm_folder.id%TYPE;
    lv_user_id   pm_user.id%TYPE;

  BEGIN
    exp_log('Function get_user_id_by_path: pv_path =' || pv_path,
            export2.const_proc_calls);

    lv_folder_id := get_folder_id_by_path(pv_path);

    SELECT userid INTO lv_user_id FROM pm_folder WHERE id = lv_folder_id;

    RETURN lv_user_id;

  EXCEPTION
    WHEN no_data_found THEN
      raise_application_error(-20118,
                              'Target Prospect user not found from path: ' ||
                              pv_path);
  END;

  /*********************************************************************/

  FUNCTION get_folder_path_by_id(pv_folder_id NUMBER) RETURN VARCHAR2 AS

    lv_name      pm_folder.NAME%TYPE;
    lv_path      VARCHAR2(4000);
    lv_id        pm_folder.id%TYPE;
    lv_parent_id pm_folder.folderid%TYPE := NULL;
  BEGIN
    exp_log('Function get_folder_path_by_id: pv_folder_id =' ||
            to_char(pv_folder_id),
            export2.const_proc_calls);

    lv_id := pv_folder_id;

    LOOP
      SELECT NAME, folderid
        INTO lv_name, lv_parent_id
        FROM pm_folder
       WHERE id = lv_id;

      -- if we hit the root get out of loop
      EXIT WHEN lv_parent_id IS NULL;

      --build up path
      lv_path := '/' || lv_name || lv_path;

      lv_id := lv_parent_id;

    END LOOP;

    RETURN lv_path;

  EXCEPTION
    WHEN no_data_found THEN
      raise_application_error(-20119,
                              'Target Prospect document path not found from id: ' ||
                              pv_folder_id);
  END;

  /*********************************************************************/

  PROCEDURE exp_field_name_fix IS
    CURSOR c_expdes(p_tabname IN VARCHAR2) IS
      SELECT ROWID xid, data
        FROM exp_des ex
       WHERE ex.table_name = p_tabname;

    lv_compatible BOOLEAN := FALSE;
    lv_updated    BOOLEAN := FALSE;
    lv_namespace  VARCHAR2(10);
    lv_ordinal    PLS_INTEGER;

  BEGIN
    exp_log('Procedure exp_field_name_fix', export2.const_proc_calls);

    OPEN c_expdes('EXP_FIELD_NAME_VIEW');
    IF c_expdes%NOTFOUND THEN
      lv_compatible := TRUE;
    END IF;
    CLOSE c_expdes;

    IF NOT lv_compatible THEN

      OPEN c_expdes('EXP_FIELD_NAME2_VIEW');
      IF c_expdes%FOUND THEN
        lv_compatible := TRUE;
      END IF;
      CLOSE c_expdes;

    END IF;

    IF NOT lv_compatible THEN

      lv_ordinal := export2.get_column_ordinal('EXP_FIELD_NAME_VIEW',
                                               'NAMESPACE_ID');

      FOR r_expdes IN c_expdes('EXP_FIELD_NAME_VIEW') LOOP

        lv_namespace := export2.parse_column_value(r_expdes.data,
                                                   lv_ordinal);
        IF (to_number(lv_namespace) <> 0) THEN

          UPDATE exp_des
             SET table_name = 'EXP_FIELD_NAME2_VIEW'
           WHERE ROWID = r_expdes.xid;

          lv_updated := TRUE;

        END IF;

      END LOOP;

      IF lv_updated THEN

        INSERT INTO exp_met
          (table_name, column_name, ordinal)
          SELECT 'EXP_FIELD_NAME2_VIEW', column_name, ordinal
            FROM exp_met a
           WHERE table_name = 'EXP_FIELD_NAME_VIEW'
             AND NOT EXISTS
           (SELECT 1
                    FROM exp_met b
                   WHERE b.table_name = 'EXP_FIELD_NAME2_VIEW'
                     AND b.column_name = a.column_name);

      END IF;

    END IF;

  END;

  /*********************************************************************/

  PROCEDURE compatibility_fixes IS
  BEGIN
    exp_log('Procedure compatibility_fixes', export2.const_proc_calls);

    exp_field_name_fix;

  END;

  /*********************************************************************/

  PROCEDURE fix_imported_system_scenarios AS
    --
    -- Procedure 're-links' objects associated with imported non-user
    -- scenarios by translating the ids of non-user scenarios in
    -- 'Dependencies' folders with like names scenarios is the system
    -- owned scenario folder.
    --
    -- No action is taken for imported non-user scenarios that do
    -- not have like names system owned scenarios.
    --
    -- This script is re-runable.
    --
    -- There is no 'UNDO'.
    --
    i_folderid pm_folder.id%TYPE;
  BEGIN
    exp_log('Procedure fix_imported_system_scenarios',
            export2.const_proc_calls);

    -- Get the root folder id for this schema.
    SELECT id INTO i_folderid FROM pm_folder WHERE upper(NAME) = 'ROOT';

    -- Get the system scenario folder id for this schema.
    SELECT id
      INTO i_folderid
      FROM pm_folder
     WHERE upper(NAME) = 'SCENARIOS'
       AND folderid = i_folderid;

    -- For each imported non-user scenario, find
    -- a matching system non-user scenario.
    FOR cv IN (SELECT a.id system_scenario_id, b.id user_scenario_id
                 FROM (SELECT id, NAME -- Finds all the non-user scenarios
                         FROM pm_scenario -- in the system scenarios folder.
                        WHERE TYPE != 'U'
                          AND folderid = i_folderid) a,
                      (SELECT c.id   id, -- Finds all the scenarios
                              c.NAME NAME -- located in 'Dependencies' folders...
                         FROM pm_scenario c, pm_folder d
                        WHERE c.folderid = d.id
                          AND upper(d.NAME) = 'DEPENDENCIES') b
                WHERE upper(a.NAME) = upper(b.NAME) -- Where they have the same name as system scenarios ...
               ) LOOP

      -- Update scenario ids effected by import.
      UPDATE bh_reportspec
         SET scenarioid = cv.system_scenario_id
       WHERE scenarioid = cv.user_scenario_id;
      UPDATE pm_busyhour
         SET scenario_id = cv.system_scenario_id
       WHERE scenario_id = cv.user_scenario_id;
      UPDATE pm_report
         SET scenarioid = cv.system_scenario_id
       WHERE scenarioid = cv.user_scenario_id;
      UPDATE pm_report
         SET domainscenarioid = cv.system_scenario_id
       WHERE domainscenarioid = cv.user_scenario_id;
      UPDATE pm_reportspec
         SET bhscenario_id = cv.system_scenario_id
       WHERE bhscenario_id = cv.user_scenario_id;
      UPDATE sa_softalarm
         SET scenarioid = cv.system_scenario_id
       WHERE scenarioid = cv.user_scenario_id;
    END LOOP;

    -- Any scenario outside the scenarios folder should be a user scenario...
    UPDATE pm_scenario
       SET TYPE = 'U'
     WHERE TYPE != 'U'
       AND folderid != i_folderid;

  END;

  /*********************************************************************/

  -- SEAde65006 [David Scott] Adding this to resolve scenario to a specific scenario where multiple scenarios exist with the same name
  FUNCTION getscenarioid(pv_scenario_name IN VARCHAR2) RETURN NUMBER AS
    lv_fullname      VARCHAR2(512);
    lv_scenario_name VARCHAR2(512);
    lv_dirname       VARCHAR2(512);
    lv_folder_id     NUMBER;
    lv_scenario_id   NUMBER;
    lv_last_slash    PLS_INTEGER;
  BEGIN
    exp_log('Function getScenarioID: pv_scenario_name =' ||
            pv_scenario_name,
            export2.const_proc_calls);

    lv_fullname   := REPLACE(pv_scenario_name, '\', '/');
    lv_last_slash := instr(lv_fullname, '/', -1);

    -- basically if it does not contain a path (slash) assume it is in the scenarios directory
    IF lv_last_slash = 0 THEN
      lv_scenario_name := lv_fullname;
      lv_dirname       := '/Scenarios';
    ELSE
      lv_scenario_name := substr(lv_fullname, lv_last_slash + 1);
      lv_dirname       := substr(lv_fullname, 1, lv_last_slash - 1);

    END IF;

    lv_folder_id := get_folder_id_by_path(lv_dirname);

    BEGIN
      SELECT id
        INTO lv_scenario_id
        FROM pm_scenario
       WHERE NAME = lv_scenario_name
         AND folderid = lv_folder_id;
    EXCEPTION
      WHEN no_data_found THEN
        raise_application_error(-20117,
                                'Cannot retrieve scenario ' ||
                                gv_scenario_name);
    END;

    RETURN lv_scenario_id;

  END; -- getScenarioID

  /*********************************************************************/
  -- Soft Alarm Export
  PROCEDURE export_sa_schedules
  -- For the SCHEDULE table, build the criteria string now from the id's saved in a previous
    -- call to procedure for the documents
   IS
    lv_criteria VARCHAR2(4000);
  BEGIN
    exp_log('Procedure export_sa_schedules', export2.const_proc_calls);

    -- only do this if we have to
    IF (gv_schedule_id_tab.COUNT > 0) THEN

      lv_criteria := 'schedule_id in (';
      FOR lv_i IN gv_schedule_id_tab.FIRST .. gv_schedule_id_tab.LAST LOOP
        lv_criteria := lv_criteria || gv_schedule_id_tab(lv_i) || ',';
      END LOOP;
      -- chop off last comma
      lv_criteria := substr(lv_criteria, 1, length(lv_criteria) - 1) || ')';
      -- now make a call to export these schedules only
      export2.export('SCHEDULE', lv_criteria);

    END IF;

  END;

  /*********************************************************************/

  -- SA Export SEAde66940
  PROCEDURE export_sa_folders AS

    CURSOR sa_folder_ids IS
      SELECT id
        FROM pm_folder pmf
       WHERE pmf.id IN (SELECT folderid
                          FROM sa_softalarm
                        UNION
                        SELECT DISTINCT folderid
                          FROM sa_template
                        UNION
                         SELECT DISTINCT exp_folderid.folderid
                          FROM ( SELECT folderid,group_type FROM exp_sa_job_group_view 
                                 UNION 
                                 SELECT folderid,group_type FROM exp_job_group_view) exp_folderid,
                               group_type_job_type gtjt,
                               job_type            jt
                         WHERE exp_folderid.group_type = gtjt.group_id
                           AND gtjt.job_type = jt.id
                           AND jt.description = 'Soft Alarm')
         AND TYPE != 'S' -- exclude system folders
         AND folderid IS NOT NULL; -- exclude root

    lv_criteria     VARCHAR2(4000);
    lv_folder_count NUMBER := 0;

  BEGIN
    exp_log('Procedure export_sa_folders', export2.const_proc_calls);

    lv_criteria := 'ID in (';

    FOR folder_id IN sa_folder_ids LOOP
      lv_criteria     := lv_criteria || folder_id.id || ',';
      lv_folder_count := lv_folder_count + 1;
    END LOOP;
    -- chop off last comma
    lv_criteria := substr(lv_criteria, 1, length(lv_criteria) - 1) || ')';
    -- now make a call to export these folders only
    IF (lv_folder_count > 0) THEN
      export2.export(const_folder_table, lv_criteria);
    ELSE
      raise_application_error(-20120,
                              'No Folders containing Soft Alarms found in source system.');
    END IF;
  END;

  /*********************************************************************/
  -- SA Import SEAde66940

  PROCEDURE import_sa AS

  BEGIN
    exp_log('Procedure import_sa', export2.const_proc_calls);

    gv_sa_import := 1;
    IF (gv_default_path IS NOT NULL) THEN
      export2.gv_folder_id := get_folder_id_by_path(gv_default_path);
      export2.gv_user_id   := get_user_id_by_path(gv_default_path);
    END IF;
    export2.import(const_folder_table,
                   'ID=' || to_char(get_root_folderid()));
  END;

  /*********************************************************************/
  -- Took out as part of the SA/BH import export core merge.
  -- This needs to be uncommented when the SA_Range Feature is merged in.
  -- A new column in the sa_softalarm table will need to be created.
  -- SA Import SEAde66940


  FUNCTION get_soft_alarm_id(pv_alarm_id   IN VARCHAR2,
                             pv_row_number IN NUMBER) RETURN VARCHAR2 AS
    lv_return_value NUMBER;

    lv_id              sa_softalarm.id%TYPE;
    lv_alarm_id        sa_softalarm.alarm_id%TYPE;
    lv_alarm_name      sa_softalarm.NAME%TYPE;
    lv_folder_name     VARCHAR2(2048);
    lv_check           BOOLEAN DEFAULT FALSE;
    lv_check_overwrite BOOLEAN DEFAULT FALSE;

  BEGIN
    exp_log('Function get_soft_alarm_id: pv_alarm_id =' || pv_alarm_id,
            export2.const_proc_calls);

    -- now check to see if current row's soft alarm already exists
    lv_id := exists_by_name_and_folder(pv_row_number);

    -- if so then get the alarm id from this row
    IF (lv_id != 0) THEN
      exp_log('Soft alarm already exists with id: ' || to_char(lv_id),
              export2.const_debug);
      SELECT alarm_id INTO lv_alarm_id FROM sa_softalarm WHERE id = lv_id;

      exp_log('Existing alarm id: ' || to_char(lv_alarm_id), export2.const_debug);

      -- if old value is different to new then we need to check if new value is already in use
      IF (to_number(pv_alarm_id) != lv_alarm_id) THEN
        exp_log('New alarm id: ' || pv_alarm_id ||
                ' does not match existing id, flag check alarm id value for overwrite',
                export2.const_debug);
        lv_check_overwrite := TRUE;
      END IF;
    ELSE
      exp_log('Soft alarm does not already exist in system, flag check alarm id value',
              export2.const_debug);
      lv_check := TRUE;
    END IF;

    IF (lv_check = TRUE OR lv_check_overwrite = TRUE) THEN
      exp_log('Checking alarm id value', export2.const_debug);
      -- does it exist already in the system
      BEGIN
        SELECT sa.NAME, get_folder_path_by_id(sa.folderid)
          INTO lv_alarm_name, lv_folder_name
          FROM sa_softalarm sa
         WHERE alarm_id = to_number(pv_alarm_id);
      EXCEPTION
        WHEN no_data_found THEN
          exp_log('Checking did not find alarm id in system, returning passed value: ' ||
                  pv_alarm_id,
                  export2.const_debug);
          -- in this case just return the original value
          lv_return_value := pv_alarm_id;

      END;
      -- if so and we are in OVERWRITE mode then we must raise an error and stop the import
      IF (lv_alarm_name IS NOT NULL) THEN
        IF ((lv_check_overwrite = TRUE AND gv_action = 'OVERWRITE') OR
           lv_check = TRUE) THEN
          exp_log('Alarm id value aready exists in target system, cannot complete import.',
                  export2.const_errors);
          raise_application_error(-20122,
                                  'Alarm id: ' || pv_alarm_id ||
                                  ' aready exists in target system for alarm: ' ||
                                  lv_alarm_name || ' in folder: ' ||
                                  lv_folder_name ||
                                  ', import row number is: ' ||
                                  pv_row_number ||
                                  ', cannot complete import. ');
        END IF;
      ELSE
        exp_log('Checking did not find alarm id in system, returning passed value: ' ||
                pv_alarm_id,
                export2.const_debug);
        -- in this case just return the original value
        lv_return_value := pv_alarm_id;
      END IF;
    ELSE
      exp_log('Not Checking alarm id value, returning passed value: ' ||
              pv_alarm_id,
              export2.const_debug);
      lv_return_value := pv_alarm_id;
    END IF;

    RETURN lv_return_value;
  END;

  --SA Import SEAde66940
  --Function for user and folder translations as defined by special SA import rules

  FUNCTION get_sa_translations(pv_row_number  IN NUMBER,
                               pv_table_name  IN VARCHAR2,
                               pv_column_name IN VARCHAR2,
                               pv_old_value   IN VARCHAR2) RETURN VARCHAR2 AS

  BEGIN
    exp_log('Function get_sa_translations: pv_row_number = ' ||
            pv_row_number || ' pv_table_name = ' || pv_table_name ||
            ' pv_column_name = ' || pv_column_name || ' pv_old_value = ' ||
            pv_old_value,
            export2.const_proc_calls);

    -- Look through the translations table to see if the records are here
    IF (gv_sa_transalation_tab.COUNT > 0) THEN
      FOR lv_i IN gv_sa_transalation_tab.FIRST .. gv_sa_transalation_tab.LAST LOOP

        IF (gv_sa_transalation_tab.EXISTS(lv_i)) THEN
          IF (gv_sa_transalation_tab(lv_i)
             .row_number = pv_row_number AND gv_sa_transalation_tab(lv_i)
             .table_name = pv_table_name AND gv_sa_transalation_tab(lv_i)
             .column_name = pv_column_name) THEN
            RETURN gv_sa_transalation_tab(lv_i) .new_value;
          END IF;
        END IF;
      END LOOP;
    END IF;

    RETURN pv_old_value;

  END;

  PROCEDURE add_sa_translation(pv_row_number  IN NUMBER,
                               pv_table_name  IN VARCHAR2,
                               pv_column_name IN VARCHAR2,
                               pv_new_value   IN VARCHAR2) IS
    lv_idx NUMBER;
  BEGIN
    exp_log('Procedure add_sa_translation: pv_row_number = ' ||
            pv_row_number || ' pv_table_name = ' || pv_table_name ||
            ' pv_column_name = ' || pv_column_name || ' pv_new_value = ' ||
            pv_new_value,
            export2.const_proc_calls);

    lv_idx := gv_sa_transalation_tab.COUNT;

    --populate table with new value
    gv_sa_transalation_tab(lv_idx).row_number := pv_row_number;
    gv_sa_transalation_tab(lv_idx).table_name := pv_table_name;
    gv_sa_transalation_tab(lv_idx).column_name := pv_column_name;
    gv_sa_transalation_tab(lv_idx).new_value := pv_new_value;

  END;

  FUNCTION get_user_id_from_name(pv_username IN VARCHAR2) RETURN NUMBER AS

    lv_user_id NUMBER;

  BEGIN
    exp_log('Function get_user_id_from_name: pv_username = ' ||
            pv_username,
            export2.const_proc_calls);

    SELECT id INTO lv_user_id FROM pm_user WHERE NAME = pv_username;

    RETURN lv_user_id;

  EXCEPTION
    WHEN no_data_found THEN
      raise_application_error(-20121,
                              'Target Prospect user not found from name: ' ||
                              pv_username);
  END;

  FUNCTION getschedulestarttime(pv_time IN VARCHAR2) RETURN VARCHAR2 AS
    lv_return_value VARCHAR2(100);
  BEGIN
    exp_log('Function getScheduleStartTime: pv_time =' || pv_time,
            export2.const_proc_calls);

    IF (trunc(to_date(pv_time, export2.gv_date_format), 'DD') <
       trunc(SYSDATE, 'DD')) THEN
      lv_return_value := to_char(trunc(SYSDATE, 'DD'),
                                 export2.gv_date_format);
    ELSE
      lv_return_value := pv_time;
    END IF;

    RETURN lv_return_value;

  END;

END;
/
show errors PACKAGE BODY exp_custom;
