--
-- (#) ./base/db/Oracle8i/map/create_map_schema.sql BL_core_schema_8.0.7_8.0.7.4.02_20100413  064938
-- (#) 
--

CREATE TABLE PM_Map(
    Id               INTEGER       NOT NULL,
    FolderId         INTEGER       NOT NULL,
    UserId           INTEGER       NOT NULL,
    Name             VARCHAR2(64)  NOT NULL,
    Description      VARCHAR2(255),
    Changed          DATE          DEFAULT TRUNC(SYSDATE,'MI') NOT NULL,
    Type             CHAR(1),
    Query_Id         INTEGER,     
    -- constraints required to prevent removing folder or user
    --
    CONSTRAINT FK_Map_FolderId
		FOREIGN KEY(FolderId)          REFERENCES PM_Folder(Id),
    CONSTRAINT FK_Map_UserId
		FOREIGN KEY(UserId)            REFERENCES PM_User(Id),
    CONSTRAINT PK_PM_Map PRIMARY KEY(Id)
)
TABLESPACE WM_Client;

--
-- index required to prevent duplicate documents in folder
--
CREATE UNIQUE INDEX UNQ_Map ON PM_Map(FolderId, UPPER(Name))
TABLESPACE WM_Client;


CREATE OR REPLACE TRIGGER PM_Map_TR_AD
    AFTER DELETE ON PM_Map
    FOR EACH ROW
    BEGIN
        SP_DeleteStringTable(:OLD.Query_Id);
    END;
/
SHOW ERRORS


--
-- sequence for PM_Map.Id
--
CREATE SEQUENCE SQ_Map
    START WITH 1000
    INCREMENT BY 1
    NOMAXVALUE
    NOCYCLE
;

CREATE TABLE wm_map_config (
  entity_id     NUMBER,
  loc_type_id   NUMBER,
  loc_type	VARCHAR2(30),
  table_name	VARCHAR2(30),
  column_name   VARCHAR2(30),
    CONSTRAINT wmn_map_config_pk PRIMARY KEY ( entity_id, loc_type ) USING INDEX TABLESPACE config,
    CONSTRAINT wmn_map_config_entity_id_fk FOREIGN KEY ( entity_id ) REFERENCES wmn_entity( entity_id ),
    CONSTRAINT wmn_map_config_loc_type_cc CHECK ( loc_type IN ( 'LATITUDE', 'LONGITUDE', 'ELEVATION', 'TILT', 'HEIGHT', 'AZIMUTH', 'SECTOR_WIDTH', 'RADIUS' ) )
) TABLESPACE WM_Client;

CREATE GLOBAL TEMPORARY TABLE wm_map_info_tmp (
  instance_id   NUMBER,
  latitude      FLOAT,
  longitude     FLOAT,
  elevation     FLOAT,
  height	FLOAT,
  tilt          NUMBER,
  azimuth       NUMBER,
  sector_width  NUMBER,
  radius	FLOAT,
    CONSTRAINT wm_map_info_tmp_pk PRIMARY KEY (instance_id)
) ON COMMIT DELETE ROWS;

EXIT
-- Done.

