-- ---------------------------------------------------------------------------
-- (#) ./base/db/Oracle8i/metadata/timezone/timezone.sql BL_core_schema_8.0.7_8.0.7.4.02_20100413  064938
-- (#) 
-- COPYRIGHT 2004 WatchMark Corp.
-- ---------------------------------------------------------------------------

--    DESCRIPTION
--      Daylight Saving Time and Locale table definitions
--
--    This was originally designed by
--    07/31/2000   JKallman - Created

--
-- Table: wm_dst_rules
--
--  id               : Unique identifier for this specific rule (referenced by wm_locales)
--  start_month      : DST starting month.  Month is 1-based, e.g., 1 for January
--  start_day        : DST starting day-of-week-in-month.
--  start_dayofweek  : DST Starting day-of-week (1=Sunday, 2=Monday, etc.)
--  start_time       : DST starting time, in minutes from 00:00 in local time
--  end_month        : DST ending month.  Month is 1-based, e.g., 1 for January
--  end_day          : DST ending day-of-week-in-month
--  end_dayofweek    : DST ending day-of-week
--  end_time         : DST ending time, in minutes from 00:00 in local time
--  dst_savings      : DST amount of time saved, in minutes
--
--  Note:  DST ends is given in standard time, not DST time, so 120 means the clocks
--         are switched back from @3 DST to @2 standard time
--
--
--  Typically, this table will follow the day-of-week-in-month rules.
--  To specify an exacty day of the month, such as March 1, set start_dayofweek to 0
--  To specify the first day of the week occurring on or after an exact dy of the month,
--    the day of the week will be negative.
--  To specify the last day of the week occurring on or before an exact day of the month,
--    make the day of the week and the day of the month negative.
--
--  Examples:   First Sunday in the start month, start_day=1, start_dayofweek=1
--              Last Sunday in the start month, start_day=-1, start_dayofweek=1
--              7th day in the start month, start_day=7, start_dayofweek=0
--              First Monday on or after 5th day of start month, start_day=5, start_dayofweek=-1
--              Last Wednesday on or before 21st of start month, start_day=-21, start_dayofweek=-4
--



-- Rule #1
--
--    Start:  Second Sunday in March at 2:00A local time
--    End:    First Sunday in November at 2:00A local time
--
-- Used for most of the United States, Mexico
--
INSERT INTO wm_dst_rules( id, start_month, start_day, start_dayofweek, start_time, 
                           end_month, end_day, end_dayofweek, end_time, dst_savings ) 
               VALUES( 1, 3, 8, -1, 120, 11, 1, 1, 120, 60);



-- Rule #2
--
-- Start:  Last Sunday in March at 2:00A
-- End:    Last Sunday in October at 2:00A
--
-- Used for most of Europe (Berlin, Brussels, Venice, Vienna, Warsaw, Zurich)
--
INSERT INTO wm_dst_rules( id, start_month, start_day, start_dayofweek, start_time, 
                           end_month, end_day, end_dayofweek, end_time, dst_savings ) 
               VALUES( 2, 3, -1, 1, 120, 10, -1, 1, 120, 60 );


-- Rule #3
--
-- Start:  Last Sunday in March at 1:00A
-- End:    Last Sunday in October at 1:00A
--
-- Used for London, Dublin
--
INSERT INTO wm_dst_rules( id, start_month, start_day, start_dayofweek, start_time, 
                           end_month, end_day, end_dayofweek, end_time, dst_savings ) 
               VALUES( 3, 3, -1, 1, 60, 10, -1, 1, 60, 60 );


-- Rule #4
--
-- Start:  Last Sunday in October at 2:00A
-- End:    Last Sunday in March at 2:00A
--
-- Used for Sydney, Australia
--
INSERT INTO wm_dst_rules( id, start_month, start_day, start_dayofweek, start_time, 
                           end_month, end_day, end_dayofweek, end_time, dst_savings ) 
               VALUES( 4, 10, -1, 1, 120, 3, -1, 1, 120, 60 );


-- Rule #5
--
-- Start:  First Sunday on or after October 1 at 0:00
-- End:    First Sunday on or after February 11 at 0:00
--
-- Used for Sao Paulo, Brazil, Rio de Janeiro, Brazil
--
INSERT INTO wm_dst_rules( id, start_month, start_day, start_dayofweek, start_time, 
                           end_month, end_day, end_dayofweek, end_time, dst_savings ) 
               VALUES( 5, 10, 1, -1, 0, 2, 11, -1, 0, 60 );


-- Rule #6
--
-- Start:  April 1 at 0:00
-- End:    October 1 at 0:00
--
-- Used for Paraguay
--
INSERT INTO wm_dst_rules( id, start_month, start_day, start_dayofweek, start_time, 
                           end_month, end_day, end_dayofweek, end_time, dst_savings ) 
               VALUES( 6, 4, 1, 0, 0, 10, 1, 0, 0, 60 );


-- Rule #7
--
-- Start:  Last Sunday in September at 2:00
-- End:    First Sunday in April at 2:00
--
-- Used for Auckland, New Zealand
--
INSERT INTO wm_dst_rules( id, start_month, start_day, start_dayofweek, start_time, 
                           end_month, end_day, end_dayofweek, end_time, dst_savings ) 
               VALUES( 7, 9, -1, 1, 120, 4, 1, 1, 120, 60 );


-- Rule #8
--
-- Start:  Last Sunday in March at 3:00A
-- End:    Last Sunday in October at 3:00A
--
-- Used for Athens, Greece
-- NOTE:  Java TimeZone rules say that Athens follows normal
--        EU DST rules and not the above.
--
INSERT INTO wm_dst_rules( id, start_month, start_day, start_dayofweek, start_time, 
                           end_month, end_day, end_dayofweek, end_time, dst_savings ) 
               VALUES( 8, 3, -1, 1, 180, 10, -1, 1, 180, 60 );

-- Rule #9
--
-- Start:  April 1 at 3:00A
-- End:    October 1 at 3:00A
--
-- Used for Baghdad, Iraq
--
INSERT INTO wm_dst_rules( id, start_month, start_day, start_dayofweek, start_time, 
                           end_month, end_day, end_dayofweek, end_time, dst_savings ) 
               VALUES( 9, 4, 1, 0, 180, 10, 1, 0, 180, 60 );

-- Rule #10
--
-- Start:  Last Sunday in March at 0:00A
-- End:    Last Sunday in September at 0:00A
--
-- Used for Beirut, Lebanon
--
INSERT INTO wm_dst_rules( id, start_month, start_day, start_dayofweek, start_time, 
                           end_month, end_day, end_dayofweek, end_time, dst_savings ) 
               VALUES( 10, 3, -1, 1, 0, 9, -1, 1, 0, 60 );


-- Rule #11
--
-- Start:  Last Sunday in March at 0:00A
-- End:    Last Sunday in October at 0:00A
--
-- Used for Bucharest, Romania
--
INSERT INTO wm_dst_rules( id, start_month, start_day, start_dayofweek, start_time, 
                           end_month, end_day, end_dayofweek, end_time, dst_savings ) 
               VALUES( 11, 3, -1, 1, 0, 10, -1, 1, 0, 60 );

-- Rule #12
--
-- Start:  Last Friday in April at 1:00A
-- End:    Last Friday in September at 3:00A
--
-- Used for Cairo, Egypt
--
INSERT INTO wm_dst_rules( id, start_month, start_day, start_dayofweek, start_time, 
                           end_month, end_day, end_dayofweek, end_time, dst_savings ) 
               VALUES( 12, 4, -1, 6, 60, 10, -1, 6, 180, 60 );

-- Rule #13
--
-- Start:  First Sunday in April at 0:00A
-- End:    First Sunday on/after October 8 at 0:00A
--
-- Used for Havana, Cuba
--
INSERT INTO wm_dst_rules( id, start_month, start_day, start_dayofweek, start_time, 
                           end_month, end_day, end_dayofweek, end_time, dst_savings ) 
               VALUES( 13, 4, 1, -1, 0, 10, 8, -1, 0, 60 );

--new
-- Rule #14
--
-- Start:  First Sunday on or after March 15 at 2:00
-- End:    First Sunday on or after September 1 at 2:00
--
-- Used for Jerusalem, Israel
--
INSERT INTO wm_dst_rules( id, start_month, start_day, start_dayofweek, start_time, 
                           end_month, end_day, end_dayofweek, end_time, dst_savings ) 
               VALUES( 14, 3, 15, -1, 120, 10, 1, -1, 120, 60 );


-- Rule #15
--
-- Start:  First Sunday on or after October 9 at 0:00
-- End:    First Sunday on or after March 9 at 0:00
--
-- Used for Santiago, Chile
--
INSERT INTO wm_dst_rules( id, start_month, start_day, start_dayofweek, start_time, 
                           end_month, end_day, end_dayofweek, end_time, dst_savings ) 
               VALUES( 15, 10, 9, -1, 0, 3, 9, -1, 0, 60 );




--
-- Table: wm_locales
--
--  id               : Unique identifier for this locale
--  dst_id           : Daylight Saving Time Rule ID  (Value of zero means no DST observed)
--  locale_name      : Long name of locale
--  gmt_offset       : Offset from GMT in minutes
--

INSERT INTO wm_locales( id, dst_id, locale_name, gmt_offset )
    VALUES(1, 1, 'America/New York',-300);

INSERT INTO wm_locales( id, dst_id, locale_name, gmt_offset )
    VALUES(2, NULL, 'America/Indianapolis',-300);

INSERT INTO wm_locales( id, dst_id, locale_name, gmt_offset )
    VALUES(3, 1, 'America/Chicago', -360);

INSERT INTO wm_locales( id, dst_id, locale_name, gmt_offset )
    VALUES(4, 5, 'America/Sao Paulo', -180 );

INSERT INTO wm_locales( id, dst_id, locale_name, gmt_offset )
    VALUES(5, 1, 'America/Denver', -420);

INSERT INTO wm_locales( id, dst_id, locale_name, gmt_offset )
    VALUES(6, NULL, 'America/Phoenix', -420);

INSERT INTO wm_locales( id, dst_id, locale_name, gmt_offset )
    VALUES(7, 1, 'America/San Francisco', -480);

INSERT INTO wm_locales( id, dst_id, locale_name, gmt_offset )
    VALUES(8, 1, 'America/Mexico City', -480);

INSERT INTO wm_locales( id, dst_id, locale_name, gmt_offset )
    VALUES(9, NULL, 'America/Honolulu', -600);

INSERT INTO wm_locales( id, dst_id, locale_name, gmt_offset )
    VALUES(10, 3, 'Europe/London', 0 );

INSERT INTO wm_locales( id, dst_id, locale_name, gmt_offset )
    VALUES(11, 2, 'Europe/Berlin', 60 );

INSERT INTO wm_locales( id, dst_id, locale_name, gmt_offset )
    VALUES(12, 2, 'Europe/Rome', 60);

INSERT INTO wm_locales( id, dst_id, locale_name, gmt_offset )
    VALUES(13, 2, 'Europe/Warsaw', 60);

INSERT INTO wm_locales( id, dst_id, locale_name, gmt_offset )
    VALUES(14, NULL, 'Asia/Hong Kong', 480);

INSERT INTO wm_locales( id, dst_id, locale_name, gmt_offset )
    VALUES(15, NULL, 'Asia/Tokyo', 540);
	
INSERT INTO wm_locales( id, dst_id, locale_name, gmt_offset )
    VALUES(16, NULL, 'Australia/Perth', 480 );

INSERT INTO wm_locales( id, dst_id, locale_name, gmt_offset )
    VALUES(17, 4, 'Australia/Sydney', 600 );

INSERT INTO wm_locales( id, dst_id, locale_name, gmt_offset )
    VALUES(18, NULL, 'America/Buenos Aires', -180 );

INSERT INTO wm_locales( id, dst_id, locale_name, gmt_offset )
    VALUES(19, 3, 'Europe/Vienna', 60 );

INSERT INTO wm_locales( id, dst_id, locale_name, gmt_offset )
    VALUES(20, 3, 'Europe/Brussels', 60 );

INSERT INTO wm_locales( id, dst_id, locale_name, gmt_offset )
    VALUES(21, 3, 'Europe/Zurich', 60 );

INSERT INTO wm_locales( id, dst_id, locale_name, gmt_offset )
    VALUES(22, 1, 'America/Anchorage', -540);

INSERT INTO wm_locales( id, dst_id, locale_name, gmt_offset )
    VALUES(23, NULL, 'America/Puerto Rico', -240);

INSERT INTO wm_locales( id, dst_id, locale_name, gmt_offset )
    VALUES(24, 14, 'Asia/Jerusalem', 120 );

INSERT INTO wm_locales( id, dst_id, locale_name, gmt_offset )
    VALUES(25, 2, 'Europe/Moscow', 180 );

INSERT INTO wm_locales( id, dst_id, locale_name, gmt_offset )
    VALUES(26, NULL, 'Asia/Calcutta', 330 );

INSERT INTO wm_locales( id, dst_id, locale_name, gmt_offset )
    VALUES(27, NULL, 'Asia/Bangkok', 420 );

INSERT INTO wm_locales( id, dst_id, locale_name, gmt_offset )
    VALUES(28, 7, 'Pacific/Auckland', 720 );

INSERT INTO wm_locales( id, dst_id, locale_name, gmt_offset )
    VALUES(29, 2, 'Europe/Paris', 60 );

INSERT INTO wm_locales( id, dst_id, locale_name, gmt_offset )
    VALUES(30, NULL, 'America/Lima Peru',-300);

INSERT INTO wm_locales( id, dst_id, locale_name, gmt_offset )
    VALUES(31, NULL, 'Greenwich Mean Time',0);

INSERT INTO wm_locales( id, dst_id, locale_name, gmt_offset )
    VALUES(32, 3, 'Europe/Athens',120);

INSERT INTO wm_locales( id, dst_id, locale_name, gmt_offset )
    VALUES(33, 15, 'America/Santiago', -240);

INSERT INTO wm_locales( id, dst_id, locale_name, gmt_offset )
    VALUES(34, NULL, 'America/Caracas', -270);

INSERT INTO wm_locales( id, dst_id, locale_name, gmt_offset )
    VALUES(35, NULL, 'America/Noronha', -120);

INSERT INTO wm_locales( id, dst_id, locale_name, gmt_offset )
    VALUES(36, 3, 'Europe/Madrid', 60 );

INSERT INTO wm_locales( id, dst_id, locale_name, gmt_offset )
    VALUES(37, 2, 'Europe/Helsinki', 120 );

INSERT INTO wm_locales( id, dst_id, locale_name, gmt_offset )
    VALUES(38, NULL, 'Asia/Riyadh', 180);

INSERT INTO wm_locales( id, dst_id, locale_name, gmt_offset )
    VALUES(39, NULL, 'Australia/Brisbane', 600);

INSERT INTO wm_locales( id, dst_id, locale_name, gmt_offset )
    VALUES(40, NULL, 'Asia/Dubai', 240);

INSERT INTO wm_locales( id, dst_id, locale_name, gmt_offset )
    VALUES(41, 4, 'Australia/Adelaide', 570);

INSERT INTO wm_locales( id, dst_id, locale_name, gmt_offset )
    VALUES(42, 1, 'America/Seattle', -480);

INSERT INTO wm_locales( id, dst_id, locale_name, gmt_offset )
    VALUES(43, NULL, 'GMT', 0 );

commit;
--EXIT;


