---------------------------------------------------------------------------
--
-- Licensed Materials - Property of IBM
-- 5724-T05,5724-T06
--
-- (C) Copyright IBM Corp. 2003,2008. All Rights Reserved.
--
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
--
---------------------------------------------------------------------------
-- (#) ./base/db/Oracle8i/part_maint/createTables.sql BL_core_schema_8.0.7_8.0.7.4.02_20100413  064938
-- (#) 
--
-- partition  maintenance tables
--
---------------------------------------------------------------------------

CREATE TABLE part_table_datatype
(
  id        INTEGER CONSTRAINT pk_part_table_datatypeid PRIMARY KEY,
  datatype  VARCHAR2(30) NOT NULL
)
TABLESPACE wm_flexpm;

CREATE TABLE part_tables (
	part_table_id   INTEGER,
	table_name      VARCHAR2(30) NOT NULL,
	tablespace_name VARCHAR2(30) NOT NULL,
	period          CHAR(1) DEFAULT 'D' NOT NULL,
          CONSTRAINT part_tables_period_ck CHECK (period IN ('D', 'W', 'M','H')), 
	run_hourly	CHAR(1) DEFAULT 'N' NOT NULL,
          CONSTRAINT part_tables_run_hourly_ck CHECK (run_hourly IN ('Y', 'N')),
	run_daily	CHAR(1) DEFAULT 'N' NOT NULL,
          CONSTRAINT part_tables_run_daily_ck CHECK (run_daily IN ('Y', 'N')),
	run_weekly	CHAR(1) DEFAULT 'N' NOT NULL,
          CONSTRAINT part_tables_run_weekly_ck CHECK (run_weekly IN ('Y', 'N')),
	run_monthly	CHAR(1) DEFAULT 'N' NOT NULL,
          CONSTRAINT part_tables_run_monthly_ck CHECK (run_monthly IN ('Y', 'N')),
	needs_export    CHAR(1) DEFAULT 'N' NOT NULL,
          CONSTRAINT part_tables_needs_export_ck CHECK (needs_export IN ('Y', 'N')),
	needs_analyze   CHAR(1) DEFAULT 'Y' NOT NULL,
          CONSTRAINT part_tables_needs_analyze_ck CHECK (needs_analyze IN ('Y', 'N')),
	needs_move      CHAR(1) DEFAULT 'Y' NOT NULL,
          CONSTRAINT part_tables_needs_move_ck CHECK (needs_move IN ('Y', 'N')),
	needs_purge    CHAR(1) DEFAULT 'Y' NOT NULL,
          CONSTRAINT part_tables_needs_purge_ck CHECK (needs_purge IN ('Y', 'N')),
	future_part     INTEGER,
	past_part       INTEGER,
	add_sproc	VARCHAR2(2000),
	drop_sproc	VARCHAR2(2000),
	pre_drop_sproc  VARCHAR2(2000),
	datatypeID      number constraint fk_datatypeid references part_table_datatype(id),
	stat_mask INTEGER DEFAULT 127 NOT NULL, -- Add stat_mask for the reuse of statistics
	  CONSTRAINT part_tables_mask_ck CHECK (stat_mask >= 1 AND stat_mask <= 127),
	creation_date DATE, -- creation data for limiting SPLIT operations - AppEng is to populate,
	termination_date DATE, -- termination data for limiting ADD operations
	move_parallelism_degree number(2) 
	  CONSTRAINT part_tables_move_par_ck CHECK (nvl(move_parallelism_degree,0) >= 0),
	stats_parallelism_degree number(2) 
	  CONSTRAINT part_tables_stats_par_ck CHECK (nvl(stats_parallelism_degree,0) >= 0),    
	CONSTRAINT pk_part_table PRIMARY KEY (part_table_id)
)
tablespace wm_flexpm;

CREATE UNIQUE INDEX unq_part_tables_idx ON part_tables(UPPER(table_name));

CREATE TABLE part_exception (
	part_table_id   INTEGER,
	part_exception  DATE,
	CONSTRAINT pk_part_exception PRIMARY KEY (part_table_id, part_exception),
	CONSTRAINT fk_part_exception FOREIGN KEY (part_table_id) REFERENCES part_tables
		ON DELETE CASCADE
)
TABLESPACE wm_flexpm;


CREATE TABLE part_export (
	export_path      VARCHAR2(4000),
	files_to_keep    INTEGER,
        oracle_home      VARCHAR2(4000)
)
TABLESPACE wm_flexpm;

CREATE SEQUENCE part_table_seq;

-- create extended part maint objects

CREATE SEQUENCE class_table_seq;
CREATE SEQUENCE subclass_table_seq;

CREATE TABLE Class_Table (
  id     INTEGER CONSTRAINT pk_class_table PRIMARY KEY,
  name   VARCHAR2(50),
   CONSTRAINT unq_class_name UNIQUE (name)
) 
TABLESPACE wm_flexpm;

CREATE TABLE SubClass_Table (
  id               INTEGER CONSTRAINT  pk_subclass_table PRIMARY KEY,
  class_id         INTEGER CONSTRAINT fk_classid references class_table(id),
  name             VARCHAR2(50),
  past_part_func   VARCHAR2(64),
   CONSTRAINT unq_subclass_name UNIQUE (name)
)
TABLESPACE wm_flexpm;
     

CREATE TABLE SubClass_Map (
  subclass_id INTEGER CONSTRAINT fk_subclassid REFERENCES subclass_table(id),
  object_id   INTEGER,
   CONSTRAINT unq_subclass_map UNIQUE (subclass_id,object_id)
)
TABLESPACE wm_flexpm;

CREATE TABLE part_tablespaces (
	tablespace_name VARCHAR2(30) NOT NULL,
	move_parallelism_degree number(2) 
	  CONSTRAINT part_tablespaces_move_par_ck CHECK (nvl(move_parallelism_degree,0) >= 0),
	stats_parallelism_degree number(2) 
	  CONSTRAINT part_tablespaces_stats_par_ck CHECK (nvl(stats_parallelism_degree,0) >= 0),   
	CONSTRAINT pk_part_tablespaces PRIMARY KEY (tablespace_name)
)
tablespace wm_flexpm;


