-- (#) ./base/db/Oracle8i/part_maint/create_part_prepare_pkgb.sql BL_core_schema_8.0.7_8.0.7.4.02_20100413  064938
-- (#) 
--
-- Partition maintenance preparing package body
--

create or replace
PACKAGE BODY PART_PREPARE IS
-- -----------------------------------------------------------------------
--  Private functions/procedures
-- -----------------------------------------------------------------------
 function get_last_part_date(p_table_name in varchar2)
         return date;
 function PushAhead(p_wanted_date in date,
	   p_last_date  in date,
           p_tabledesc  in part_tables%ROWTYPE,
           p_check_date in boolean default false)
         return boolean;
 PROCEDURE PULLAHEAD(p_dataType in varchar2, p_wanted_date in date, p_check_date in boolean default false);
-- -----------------------------------------------------------------------
--  Public functions/procedures
-- -----------------------------------------------------------------------

PROCEDURE PULLAHEAD(p_dataType in varchar2, p_wanted_date in date, p_check_date in boolean default false)
  is
    cursor c_part_tab_list(p_datatypeID in number) is select * from part_tables
                          where datatypeID=p_datatypeID;
    v_last_date   date;
    v_status      boolean;
    v_datatypeID  number;
Begin
  dbms_output.enable(1000000);
  begin
    select id into v_datatypeID
      from Part_table_datatype
     where upper(datatype)=upper(p_dataType);
  exception
    when no_data_found then
     raise_application_error(-20100,'There is no match datatype in PART_TABLE_DATATYPE table.');
  end;

  for tabledesc in c_part_tab_list(v_datatypeID) loop

    v_last_date := get_last_part_date(tabledesc.table_name);

    v_status := PushAhead(p_wanted_date,
		          v_last_date,
		          tabledesc,
                          p_check_date);
    if v_status = false then
      raise_application_error(-20100,'PART_PREPARE.PULlAHEAD faild. '||to_char(SQLCODE)||': '||SQLERRM);
    end if;
  end loop;
End;

function get_last_part_date(p_table_name in varchar2)
         return date
  is
   v_max_part_name varchar2(100);
   v_max_date  date;
  begin
    select max(SUBOBJECT_NAME) into v_max_part_name
    from user_objects
    where OBJECT_NAME=p_table_name;
    if v_max_part_name is null then
      raise_application_error(-20100, 'ERROR in get_max_part_name, possible table '
           ||p_table_name||' is not partitioned; ORA-'||to_char(SQLCODE)||'-'||SQLERRM);
    end if;
    select to_date(substr(v_max_part_name,2),'YYYYMMDDHH24')  into v_max_date from dual;
    return v_max_date;
exception
    when others then
      raise_application_error(-20100, 'ERROR in get_max_part_name, possible table '
           ||p_table_name||' has invalid partition name(not like PYYYYMMDDHH24); ORA-'
           ||to_char(SQLCODE)||'-'||SQLERRM);
end;

function PushAhead(p_wanted_date in date,
	   p_last_date  in date,
           p_tabledesc  in part_tables%ROWTYPE,
           p_check_date in boolean)
         return boolean
is
 v_lastDate date := p_last_date;
 v_partDate date;
 sqlStr varchar2(2000);
 overwrite_partition_err EXCEPTION;
 PRAGMA EXCEPTION_INIT(overwrite_partition_err, -14080);
begin
   v_lastDate := wm_date.trunc_to_last_period(v_lastdate, p_tabledesc.period);

   if p_check_date and (v_lastDate > p_wanted_date) then
     raise_application_error(-20101,'PART_PREPARE.PULLAHEAD faild because the wanted partition date is too old'); 
   end if;

      WHILE (v_lastDate <= p_wanted_date) LOOP

	 v_partDate := wm_date.add_periods(v_lastDate, p_tabledesc.period, 1);

	 IF (NOT part_maint.PartitionExists(
	   p_tabledesc.table_name,
	   'P' || to_char(v_lastDate, 'YYYYMMDDHH24')))
	 THEN
	    BEGIN
               part_maint.LockTable(p_tabledesc.table_name);
	       sqlStr := 'ALTER TABLE '|| p_tabledesc.table_name ||
		 ' ADD PARTITION P' ||
		 to_char(v_lastDate, 'YYYYMMDDHH24') ||
		 ' VALUES LESS THAN ( to_date(' ||
		 '''' || to_char(v_partDate, 'YYYY/MM/DD HH24') || '''' ||
		 ', ' || '''' || 'YYYY/MM/DD HH24' || '''' ||
		 ')) TABLESPACE ' || p_tabledesc.tablespace_name;
	       
	       execute immediate sqlStr;
	       part_maint.RunProc(p_tabledesc.add_sproc, p_tabledesc.table_name, v_lastDate);
	    EXCEPTION
	       WHEN overwrite_partition_err THEN
		 NULL;
	       WHEN OTHERS THEN
                 raise_application_error(-20100,'PART_PREPARE.PUSHAHEAD faild. '||to_char(SQLCODE)||': '||SQLERRM);
                 return false;
	    END;
	 END IF;

	 v_lastDate := v_partDate;

      END LOOP;

  return true;
end;

PROCEDURE makeSure_highEnd(p_dataType in varchar2, p_wanted_date in date)
is
 wanted_date_too_old EXCEPTION;
 PRAGMA EXCEPTION_INIT(wanted_date_too_old, -20101);
Begin
  dbms_output.enable(1000000);
  PullAhead(p_dataType, p_wanted_date, false);
end;

END;
/
show error
