----------------------------------------------------------------------
--
-- Licensed Materials - Property of IBM
-- 5724-T05,5724-T06
--
-- (C) Copyright IBM Corp. 2003,2009. All Rights Reserved.
--
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
--
----------------------------------------------------------------------
-- (#) ./base/db/Oracle8i/rehoming/rhSchema.sql BL_core_schema_8.0.7_8.0.7.4.02_20100413  064938
-- (#) 
-- 

CREATE SEQUENCE seq_rh_trend_id
    START WITH  10000
    INCREMENT BY 1
    NOMAXVALUE
    NOCYCLE;

-- this is rehoming table
CREATE TABLE rh_trend
(
 trend_id        INTEGER,
 entity_ID       INTEGER,
 instanceID      INTEGER,
 started         DATE,
 ended           DATE,
 fullkey         VARCHAR2(900),
 localkey        VARCHAR2(90),
 instance_name   VARCHAR2(30)
-- since the start date could be NULL, so I can not put parmary key here
-- the no unique index unq_rh_trend is the substitution for PK
--  CONSTRAINT  pk_rh_trend PRIMARY KEY (trend_id, instanceID, started) 
)
TABLESPACE wm_flexpm;

CREATE INDEX ind_rh_trend on rh_trend(trend_id, instanceID);

-- this is temp table for rehome sub tree 
CREATE GLOBAL TEMPORARY TABLE rh_trend_tree
(
 trend_key       varchar2(900),
 entity_ID       INTEGER,
 instanceID      INTEGER,
 started         DATE,
 ended           DATE,
 fullkey         VARCHAR2(900),
 localkey        VARCHAR2(90),
 instance_name   VARCHAR2(30) 
) ON COMMIT PRESERVE ROWS;

CREATE INDEX ind_rh_trend_tree on rh_trend_tree(trend_key, entity_ID, instanceID);

-- process temp table 
CREATE GLOBAL TEMPORARY TABLE rh_map_tmp
( 
  entityID       INTEGER, 
  active_insID   INTEGER,
  instanceID     INTEGER,
  started        DATE,
  ended          DATE,
  localkey       VARCHAR2(90)
) ON COMMIT PRESERVE ROWS;

CREATE INDEX ind_rh_map_tmp on rh_map_tmp(active_insID);

-- this table is used by report
CREATE GLOBAL TEMPORARY TABLE wmda_scenario_map_tmp
(
  entity_id      INTEGER,
  instance_id    INTEGER,
  starttime      DATE,
  endtime        DATE,
  synthetic_id   INTEGER,
  parent_id      INTEGER,
  old_localkey   VARCHAR2(90),
  localkey       VARCHAR2(90)
);

-- most likely access will be entity_id, instance_id
CREATE INDEX idx_wmda_scen_map_tmp_entid 
  ON wmda_scenario_map_tmp( entity_id );

CREATE INDEX idx_wmda_scen_map_tmp_insid 
  ON wmda_scenario_map_tmp( instance_id );

CREATE INDEX idx_wmda_scen_map_tmp_entinsid 
  ON wmda_scenario_map_tmp( entity_id, instance_id );


-- create indexes to allow connect by on this table.
CREATE INDEX idx_wmda_scen_map_tmp_synid 
  ON wmda_scenario_map_tmp( synthetic_id );

CREATE INDEX idx_wmda_scen_map_tmp_pntid 
  ON wmda_scenario_map_tmp( parent_id );

CREATE INDEX idx_wmda_scen_map_tmp_synpntid 
  ON wmda_scenario_map_tmp( synthetic_id, parent_id );

CREATE INDEX idx_wmda_scen_map_tmp_pntsynid 
  ON wmda_scenario_map_tmp( parent_id, synthetic_id );


CREATE INDEX ind_wmda_scenario_map_tmp on wmda_scenario_map_tmp
    (entity_id,synthetic_id);

CREATE SEQUENCE seq_rh_history_id
    START WITH  1000
    INCREMENT BY 1
    NOMAXVALUE
    NOCYCLE
;

CREATE TABLE rh_reparent_history
( history_id          INTEGER,
  entity_name         VARCHAR2(30),
  oldFullkey          VARCHAR2(900),
  newFullkey          VARCHAR2(900),
  RHDateTime          DATE,
  StartDateOfOldFK    DATE,
  EndDateOfNewFK      DATE,
  operation_datetime  DATE,
  user_name           VARCHAR2(30),
  operation           VARCHAR2(10), -- INSERT, DELETE, or UPDATE
 CONSTRAINT  pk_rh_reparent_history PRIMARY KEY (history_id)
)
TABLESPACE wm_flexpm;
 

-- this is temp table for rehome reap
CREATE GLOBAL TEMPORARY TABLE rehoming_reap_tmp
( 
	entity_id                 INTEGER, 
	active_insid              INTEGER,
	instance_id               INTEGER,
	tstamp                    DATE
) ON COMMIT PRESERVE ROWS;

CREATE INDEX idx_rh_reap_tmp_insid on rehoming_reap_tmp(instance_id, tstamp);
CREATE INDEX idx_rh_reap_tmp_actid on rehoming_reap_tmp(active_insid, tstamp);

-- table to hold the entities ids of the entites we actually 
-- need to rehome on. Prevends reap table growing out of control.
CREATE GLOBAL TEMPORARY TABLE rh_active_entity_tmp
(
  entityID   INTEGER NOT NULL
) ON COMMIT PRESERVE ROWS;
