--
-- (#) ./base/db/Oracle8i/rg/PM_Schedule_patch.sql BL_core_schema_8.0.7_8.0.7.4.02_20100413  064938
-- (#) 
--

-- SEAde13550:
--    This file patches code broken by changes to the scheduler process.
--

-- SEAde19716: 3 Jan 2002
--    pm_schedule_ins_tr: modified the second field in the values list
--    from :new.FIRSTDATETIME to :new.FINALDATETIME
--
-- SEAde26542: 24 Jul 2002
--    pm_schedule_view: Added 'AND s.admin_task IS NULL' to pm_schedule_view


CREATE OR REPLACE FORCE VIEW  PM_RptGrp AS
  SELECT * FROM job_group;

CREATE OR REPLACE FORCE VIEW pm_schedule AS
SELECT t.rg_schedule_id id, s.start_time firstdatetime, s.end_time finaldatetime,
       s.next_time nextrundate, s.sched_time scheduledtime, s.tzregion tzregion,
       s.which_month_date whichmonthdate, s.which_week whichweek, 
       s.which_weekday whichweekday, s.period periodicity, s.frequency frequency, 
       decode(s.IS_SUSPENDED, 'N', 'Y', 'Y', 'N', 'Y') SCHEDULEACTIVE,
       s.inc_mondays includemondays, s.inc_tuesdays includetuesdays, s.inc_wednesdays includewednesdays, 
       s.inc_thursdays includethursdays, s.inc_fridays includefridays, s.inc_saturdays includesaturdays, 
       s.inc_sundays includesundays, s.inc_holidays includeholidays, s.inc_day_after_hol includedayafterhol,
       t.folderid folderid, t.userid userid, t.name name, t.description description,
       t.changed changed, t.clientmachineid clientmachineid, t.group_id rptgrpid, t.runmode runmode, 
       t.retrievemode retrievemode, t.autopurge autopurge, t.purgeinterval purgeinterval, 
       t.subfoldername subfoldername, t.ovrscenarioid ovrscenarioid, t.ovrchansetid ovrchansetid, 
       t.ovrdestinationid ovrdestinationid, t.ovrdtscopeid ovrdtscopeid, t.lastrundate lastrundate, 
       t.auto_organize
 FROM schedule s, rg_schedule t 
WHERE s.sched_fk = t.rg_schedule_id
  AND s.admin_task IS NULL;

CREATE OR REPLACE TRIGGER pm_schedule_ins_tr
  INSTEAD OF INSERT ON pm_schedule FOR EACH ROW
DECLARE
  r_time DATE;
  ovrride_period CHAR(1);
BEGIN

  IF (:new.runmode = 'S') THEN
      r_time := :new.firstDateTime;
      ovrride_period := :new.periodicity;
  ELSE
      r_time := sysdate;
      ovrride_period := 'I';
  END IF;

  
  INSERT INTO rg_schedule_view ( FIRSTDATETIME, FINALDATETIME, TZREGION, 
    WHICHMONTHDATE, WHICHWEEK, WHICHWEEKDAY, PERIODICITY, FREQUENCY, scheduleActive, 
    INCLUDEMONDAYS, INCLUDETUESDAYS, INCLUDEWEDNESDAYS, INCLUDETHURSDAYS, INCLUDEFRIDAYS, 
    INCLUDESATURDAYS, INCLUDESUNDAYS, INCLUDEHOLIDAYS, INCLUDEDAYAFTERHOL,
    FOLDERID, USERID, NAME, DESCRIPTION, CHANGED, CLIENTMACHINEID, RPTGRPID, OVRSCENARIOID, 
    OVRCHANSETID, OVRDESTINATIONID, OVRDTSCOPEID, RUNMODE, RETRIEVEMODE, AUTOPURGE, 
    PURGEINTERVAL, SUBFOLDERNAME, LASTRUNDATE, AUTO_ORGANIZE )
  VALUES ( r_time, :new.FINALDATETIME, :new.tzregion,
    :new.WHICHMONTHDATE, :new.WHICHWEEK, :new.WHICHWEEKDAY, ovrride_period, :new.FREQUENCY,
    :new.scheduleActive, :new.INCLUDEMONDAYS, :new.INCLUDETUESDAYS, :new.INCLUDEWEDNESDAYS,
    :new.INCLUDETHURSDAYS, :new.INCLUDEFRIDAYS, :new.INCLUDESATURDAYS, :new.INCLUDESUNDAYS, 
    :new.INCLUDEHOLIDAYS, :new.INCLUDEDAYAFTERHOL, :new.FOLDERID, :new.USERID, :new.NAME, 
    :new.DESCRIPTION, :new.CHANGED, :new.CLIENTMACHINEID, :new.RPTGRPID, :new.OVRSCENARIOID, 
    :new.OVRCHANSETID, :new.OVRDESTINATIONID, :new.OVRDTSCOPEID, :new.RUNMODE, 
    :new.RETRIEVEMODE, :new.AUTOPURGE, :new.PURGEINTERVAL, :new.SUBFOLDERNAME, :new.LASTRUNDATE,
    :new.auto_organize );
    
END;
/
SHOW ERRORS

CREATE OR REPLACE TRIGGER pm_schedule_upd_tr
  INSTEAD OF UPDATE ON pm_schedule FOR EACH ROW
DECLARE
  r_time DATE;
  ovrride_period CHAR(1);
BEGIN
     IF ( :NEW.folderid = :old.folderid ) AND
        ( :NEW.userid = :old.userid ) AND
        ( :NEW.name = :old.name ) AND
        ( (:NEW.description IS NULL AND :old.description IS NULL) OR
        ( :NEW.description = :old.description ) )
     THEN
	
       IF (:new.runmode = 'S') THEN
         r_time := :new.firstDateTime;
         ovrride_period := :new.periodicity;
       ELSE
         r_time := sysdate;
         ovrride_period := 'I';
       END IF;

       IF (:NEW.scheduleActive = :old.scheduleActive) THEN
           UPDATE rg_schedule_view SET
             FIRSTDATETIME = r_time,
             FINALDATETIME = :new.finalDateTime,
	     TZREGION = :new.tzregion,
             WHICHMONTHDATE = :new.whichMonthDate,
             WHICHWEEK = :new.whichWeek,
             WHICHWEEKDAY = :new.whichWeekDay,
             PERIODICITY = ovrride_period,
             frequency = :new.frequency,
             INCLUDEMONDAYS = :new.includeMondays,
             INCLUDETUESDAYS = :new.includeTuesdays,
             INCLUDEWEDNESDAYS = :new.includeWednesdays,
             INCLUDETHURSDAYS = :new.includeThursdays,
             INCLUDEFRIDAYS = :new.includeFridays,
             INCLUDESATURDAYS = :new.includeSaturdays,
             INCLUDESUNDAYS = :new.includeSundays,
             INCLUDEHOLIDAYS = :new.includeHolidays,
             INCLUDEDAYAFTERHOL = :new.includeDayAfterHol,
             needs_msg_update = 'Y',
             scheduleActive = :new.scheduleActive,
             auto_organize = :new.auto_organize
             WHERE id = ( select distinct schedule_id from schedule where sched_fk = :old.Id );
        ELSE
           UPDATE rg_schedule_view SET
             needs_msg_update = 'N',
             scheduleActive = :new.scheduleActive
             WHERE id = ( select distinct schedule_id from schedule where sched_fk = :old.Id );
        END IF;
    END IF;
END;
/
SHOW ERRORS


CREATE OR REPLACE TRIGGER pm_schedule_del_tr
  INSTEAD OF DELETE ON pm_schedule FOR EACH ROW
BEGIN
  DELETE FROM rg_schedule_view WHERE id = ( select distinct schedule_id from schedule where sched_fk = :old.Id );
END;
/
SHOW ERRORS

EXIT;

