-- --------------------------------------------------------------------------
--     COPYRIGHT WatchMark Corp 2001
--     @(#) ./base/db/Oracle8i/scheduler/build/createTables.sql ; BL_core_schema_8.0.7_8.0.7.4.02_20100413  064938
-- --------------------------------------------------------------------------
set serveroutput on;

CREATE TABLE schedule( 
	schedule_id		integer,
	job_type		integer  NOT NULL,
		-- Each job can only have one kind of task
	start_time		date NOT NULL,
		-- When is this schedule entry enabled?
	end_time		date,
		-- When does this schedule entry expire?
	next_time		date,
		-- When this schedule entry fires next.
	which_month_date	number(2),
	which_week		number(1),
	which_weekday		number(1),
	period			char(1) NOT NULL,
	frequency		integer NOT NULL,
	is_suspended            char(1) DEFAULT 'N' NOT NULL,
	admin_task              integer DEFAULT NULL,
	sched_fk                integer,
	inc_mondays		char(1) DEFAULT 'Y' NOT NULL,
	inc_tuesdays		char(1) DEFAULT 'Y' NOT NULL,
	inc_wednesdays		char(1) DEFAULT 'Y' NOT NULL,
	inc_thursdays		char(1) DEFAULT 'Y' NOT NULL,
	inc_fridays		char(1) DEFAULT 'Y' NOT NULL,
	inc_saturdays		char(1) DEFAULT 'Y' NOT NULL,
	inc_sundays		char(1) DEFAULT 'Y' NOT NULL,
	inc_holidays		char(1) DEFAULT 'Y' NOT NULL,
	inc_day_after_hol	char(1) DEFAULT 'Y' NOT NULL,
	needs_msg_update	char(1) DEFAULT 'Y' NOT NULL,
	cleanup_time		date,
	is_optional		char(1) DEFAULT 'N' NOT NULL,
		-- is the schedule "optional" ie. if we were shutdown don't run it...
	persistence_max         integer DEFAULT 0 NOT NULL,
                -- should we restart the job if it gets interruped by a M/W shutdown
        sched_time              date default NULL,
                -- the timezone region
        tzregion                varchar2(64) DEFAULT NULL,
CONSTRAINT pk_schedule PRIMARY KEY (schedule_id)
)
tablespace wm_flexpm;

CREATE TABLE schedule_hour_ex(
       schedule_id     integer,
       hour            number(4),
       -- I have to hard code the hour range with max possible value
       -- 0 to 1439, which means one minute file frequency.
       -- It might be better to make this one depend on "TimeSlices"
       -- in pm_product_info table
       CONSTRAINT schedule_hour_ex_ck  CHECK (hour BETWEEN 0 AND 1439),
       CONSTRAINT pk_schedule_hour_ex PRIMARY KEY (schedule_id, hour),
       CONSTRAINT fk_schedule_hour_ex FOREIGN KEY (schedule_id)
                  REFERENCES schedule (schedule_id) ON DELETE CASCADE
)
 ORGANIZATION INDEX COMPRESS
 PCTFREE 0
 TABLESPACE wm_flexpm;


--
-- A copy of relevant fields in schedule for a particular run of a schedule
--
CREATE TABLE active_job (
	job_id			integer,
	schedule_id		integer,
	job_type		integer,
	admin_task              integer,
	sched_fk		integer,
	job_time		date,
	cleanup_time		date,
        retry_count             integer,
        sniped                  integer,
	schedule_time           date,
        tzregion                varchar2(64),
CONSTRAINT pk_active_job PRIMARY KEY (job_id)
)
tablespace wm_flexpm;

--
-- Equivalent mapping of schedule_task, but for a particular instance of a schedule
--
CREATE TABLE active_task (
	task_id			integer,
	job_id			integer,
	sched_task_fk		integer,
	software_id		integer,
	cleanup_time		date,
CONSTRAINT pk_active_task PRIMARY KEY (task_id),
CONSTRAINT active_task_unq UNIQUE (job_id, task_id)
)
tablespace wm_flexpm
PCTFREE 35;

ALTER TABLE active_task ADD 
      (CONSTRAINT active_task_job_notnull 
       CHECK (job_id IS NOT NULL));

ALTER TABLE active_task ADD 
      (CONSTRAINT fk_active_task
       FOREIGN KEY (job_id) REFERENCES active_job (job_id) ON DELETE CASCADE);

--
--  Drill down for the table above.
--
CREATE TABLE task_status (
	job_id			integer not null,
	status_code             integer not null,
	task_id			integer,
	tstamp			date,
	started			date,
	ended			date,
	pid			integer,
	complete_flag		integer,
	message			varchar2(4000),
	event_id                integer, 
CONSTRAINT task_status_unq UNIQUE (job_id, task_id)
)
tablespace wm_flexpm;

ALTER TABLE task_status ADD
      (CONSTRAINT task_status_unq_task
       UNIQUE (task_id) USING INDEX TABLESPACE wm_flexpm PCTFREE 1);

CREATE INDEX task_status_job ON task_status (job_id)
       TABLESPACE wm_flexpm PCTFREE 1;


ALTER TABLE task_status ADD
      (CONSTRAINT fk_task_status_job
       FOREIGN KEY (job_id) REFERENCES active_job (job_id) ON DELETE CASCADE);

ALTER TABLE task_status ADD
      (CONSTRAINT fk_task_status_task
       FOREIGN KEY (task_id) REFERENCES active_task (task_id) ON DELETE CASCADE);


CREATE TABLE task_filename
(
    Id               INTEGER,
    JobId            INTEGER       NOT NULL,
    TaskId           INTEGER       , -- taskId is null for job-related files
    FileName         VARCHAR2(255) NOT NULL,
    SizeInBytes      INTEGER,
    Limit            CHAR(1)      DEFAULT 'N'
    CONSTRAINT task_filename_limit 
                CHECK (Limit IN ('Y', 'N') AND Limit IS NOT NULL),
    CONSTRAINT pk_task_filename PRIMARY KEY (id),
    constraint uq_Task_FileName unique (jobid, taskid, filename), -- SEAde17532
    CONSTRAINT FK_Task_File_Jobid
		FOREIGN KEY(JobId)  REFERENCES Active_Job(Job_Id),
    CONSTRAINT FK_Task_File_TaskId
		FOREIGN KEY(TaskId) REFERENCES Active_Task(Task_Id)
)
tablespace wm_flexpm;

CREATE SEQUENCE Task_FileNameSeq
    START WITH 1
    INCREMENT BY 1
    NOMAXVALUE
    NOCYCLE
;

CREATE INDEX task_filename_taskid ON task_filename ( taskid )
TABLESPACE wm_flexpm
PCTFREE 5;

CREATE TABLE WM_LockDown
(
    Id               INTEGER,
    query_text       VARCHAR2(500), 
    query_code       VARCHAR2(20) NOT NULL, 
    CONSTRAINT pk_wm_lockdown PRIMARY KEY (Id)
);

CREATE SEQUENCE WM_LockDownSeq
    START WITH 1
    INCREMENT BY 1
    NOMAXVALUE
    NOCYCLE
;

-- This should be PK access almost 100% of the time.  Table scans should be
-- few and far between.  Don't sweat fragmentation.
CREATE TABLE sched_license (
        job_type  integer,
        in_use    integer,
        maximum   integer,
	disabled  char DEFAULT 'N' 
	CONSTRAINT sched_license_disabled 
             CHECK (disabled IN ('Y', 'N') AND disabled IS NOT NULL),
        CONSTRAINT pk_sched_license PRIMARY KEY (job_type)
)
ORGANIZATION INDEX
PCTFREE 30
STORAGE
( INITIAL 16K
  NEXT 16K
);


CREATE TABLE sched_cleanup (
        job_type         integer,
        schedule_cleanup integer,
        job_cleanup      integer,
        CONSTRAINT pk_sched_cleanup PRIMARY KEY (job_type)
)
ORGANIZATION INDEX
PCTFREE 30
STORAGE
( INITIAL 16K
  NEXT 16K
);

-- TRUNCATE TABLE sched_cleanup;
-- truncate TABLE sched_license;

-- Use protected truncates - FORCE it to always be safe sine this is 
-- used BEFORE metadata is populated.
EXECUTE wm_ddl.protect_truncate('sched_cleanup', TRUE);
EXECUTE wm_ddl.protect_truncate('sched_license', TRUE);



INSERT INTO sched_cleanup VALUES (15, NULL, 60*60);
INSERT INTO sched_cleanup VALUES (20, NULL, 60*60*25);
INSERT INTO sched_cleanup VALUES (25, NULL, 60*60*24*8);
INSERT INTO sched_cleanup VALUES (30, NULL, 60*60*24*8);
INSERT INTO sched_cleanup VALUES (3,  60*60*24, 60*60*24);
INSERT INTO sched_cleanup VALUES (2,  60*60*24, 60*60*24);
INSERT INTO sched_cleanup VALUES (51, NULL, 60*60);
INSERT INTO sched_cleanup VALUES (4, 60*60*24*8, 60*60*25);
INSERT INTO sched_cleanup VALUES (8, 60*60*24*8, 60*60*24*8);


INSERT INTO sched_license (job_type, in_use, maximum) VALUES (1, 0,  2);
INSERT INTO sched_license (job_type, in_use, maximum) VALUES (2, 0,  4);
INSERT INTO sched_license (job_type, in_use, maximum) VALUES (3, 0,  2);
INSERT INTO sched_license (job_type, in_use, maximum) VALUES (4, 0,  1);
INSERT INTO sched_license (job_type, in_use, maximum) VALUES (8, 0,  1);
INSERT INTO sched_license (job_type, in_use, maximum) VALUES (10, 0, 2);
INSERT INTO sched_license (job_type, in_use, maximum) VALUES (15, 0, 1);
INSERT INTO sched_license (job_type, in_use, maximum) VALUES (20, 0, 1);
INSERT INTO sched_license (job_type, in_use, maximum) VALUES (25, 0, 1);
INSERT INTO sched_license (job_type, in_use, maximum) VALUES (30, 0, 1);
INSERT INTO sched_license (job_type, in_use, maximum) VALUES (51, 0, 5);
INSERT INTO sched_license (job_type, in_use, maximum) VALUES (40, 0,50);

commit;


--
-- Create sequences
--

create sequence schedule_seq;
create sequence schedule_task_seq;
create sequence job_seq;
create sequence task_seq;
create sequence priority_seq;

CREATE TABLE queue_multiplex (
       queue_name   VARCHAR2(30),
       sproc	    VARCHAR2(128),
       logging	    CHAR DEFAULT 'N',
       CONSTRAINT queue_multiplex_logging  CHECK (logging IN ('Y', 'N')),
       CONSTRAINT pk_queue_multiplex PRIMARY KEY (queue_name)
)
 ORGANIZATION INDEX
 PCTFREE 0
 TABLESPACE wm_flexpm;

INSERT INTO queue_multiplex (queue_name, sproc) VALUES ('exception_q', 'except.dequeue_exception');
INSERT INTO queue_multiplex (queue_name, sproc) VALUES ('heartbeat_q', 'heartbeat.dequeue_heartbeat');
INSERT INTO queue_multiplex (queue_name, sproc) VALUES ('pending_q',   'pending.dequeue_pending');
INSERT INTO queue_multiplex (queue_name, sproc) VALUES ('schedule_q',  'sched.dequeue_schedule');
INSERT INTO queue_multiplex (queue_name, sproc) VALUES ('status_q',    'status.dequeue_status');
commit;

CREATE SEQUENCE sched_para_seq START WITH 1000  INCREMENT BY 1;  

CREATE TABLE sched_parameters
( ID         INTEGER,
  NAME       VARCHAR2(64),
  TYPE       VARCHAR2(20),
  VALUE      VARCHAR2(256),
  SCHED_ID   INTEGER,
  CONSTRAINT pk_sched_parameters PRIMARY KEY (ID),
  CONSTRAINT fk_sched_id FOREIGN KEY ( sched_id )
    REFERENCES schedule (schedule_id) ON DELETE CASCADE,
  CONSTRAINT uni_sched_para_sid_name UNIQUE (sched_id, name)
)
TABLESPACE wm_flexpm;

-- the following content is taken from
-- vendor/EnterpriseTrafficCache/sched_info.sql

PROMPT creating table SCHED_JOB_TYPES ...

CREATE TABLE SCHED_JOB_TYPES
(
 JOB_TYPE INTEGER,
 NAME     VARCHAR2(256),
 JNDI     VARCHAR2(256),
 COMMAND  VARCHAR2(256),
 SNAPSHOT VARCHAR2(256),
 POSTPROC VARCHAR2(256),
 CONSTRAINT pk_sched_job_types PRIMARY KEY (job_type),
 CONSTRAINT fk_sched_job_types_id FOREIGN KEY (job_type)
        REFERENCES sched_license(job_type)
)
TABLESPACE wm_flexpm;

PROMPT creating VIEW SCHED_JOB_TYPES_VW ...

CREATE OR REPLACE VIEW SCHED_JOB_TYPES_VW AS
SELECT
 jt.JOB_TYPE,
 jt.NAME,
 jt.JNDI,
 jt.COMMAND,
 jt.SNAPSHOT,
 jt.POSTPROC
FROM
      sched_job_types jt,
      sched_license sl
WHERE jt.job_type = sl.job_type;

-- end of the section 

exit;
