---------------------------------------------------------------------------
--
-- Licensed Materials - Property of IBM
-- 5724-T05,5724-T06
--
-- (C) Copyright IBM Corp. 2003,2008. All Rights Reserved.
--
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
--
---------------------------------------------------------------------------
-- (#) ./base/db/Oracle8i/sentryloader/createSchema.sql BL_core_schema_8.0.7_8.0.7.4.02_20100413  064938
-- (#) 
--
-- ------------------------------------------------------------------
--
-- ------------------------------------------------------------------
CREATE TABLE pm_loader_config
(
  loader_config_id        INTEGER       NOT NULL,
  node_name               VARCHAR2(255) NOT NULL,
  active                  CHAR(1)       NOT NULL,
  max_worker_threads      INTEGER       NOT NULL,
  most_recent_bias        INTEGER       NOT NULL,
  CONSTRAINT pk_pm_loader_config PRIMARY KEY (loader_config_id),
  CONSTRAINT uq_pm_loader_node_name UNIQUE (node_name),
  CONSTRAINT ck_pm_loader_config_active CHECK (active IN ('Y', 'N'))
)
TABLESPACE wm_flexpm;


-- ------------------------------------------------------------------
--
-- ------------------------------------------------------------------
CREATE TABLE pm_sentry_config
(
  sentry_config_id        INTEGER       NOT NULL,
  node_name               VARCHAR2(255) NOT NULL,
  active                  CHAR(1)       NOT NULL,
  CONSTRAINT pk_pm_sentry_config PRIMARY KEY (sentry_config_id),
  CONSTRAINT uq_pm_sentry_node_name UNIQUE (node_name),
  CONSTRAINT ck_pm_sentry_config CHECK (active IN ('Y', 'N'))
)
TABLESPACE wm_flexpm;


-- ------------------------------------------------------------------
--
-- ------------------------------------------------------------------
CREATE TABLE pm_loader_action
(
  loader_action_id     INTEGER        NOT NULL,
  name                 VARCHAR2(255)  NOT NULL,
  description          VARCHAR2(500),
  max_concurrency      INTEGER DEFAULT 1 NOT NULL,
  CONSTRAINT pm_loader_action_pk PRIMARY KEY (loader_action_id),
  CONSTRAINT uq_loader_action_name UNIQUE (name)
)
TABLESPACE wm_flexpm;

-- ------------------------------------------------------------------
--
-- ------------------------------------------------------------------
CREATE TABLE pm_loader_task
(
  loader_task_id      INTEGER                   NOT NULL,  
  name                VARCHAR2(255 CHAR)        NOT NULL,   
  description         VARCHAR2(500),              
  task_name       VARCHAR2(100)         NOT NULL, 
  sequence        INTEGER           NOT NULL,
  loader_action_id    INTEGER,
  CONSTRAINT pk_pm_loader_task PRIMARY KEY (loader_task_id),
  CONSTRAINT uq_pm_loader_task_name UNIQUE (name),
  CONSTRAINT fk_pm_loader_task_laid FOREIGN KEY (loader_action_id) REFERENCES pm_loader_action(loader_action_id)
)
TABLESPACE wm_flexpm;


-- ------------------------------------------------------------------
--
-- ------------------------------------------------------------------
CREATE TABLE pm_loader_task_param
(
  loader_task_param_id   INTEGER          NOT NULL,
  name                   VARCHAR2(255)    NOT NULL,
  value                  VARCHAR2(255)    NOT NULL,
  loader_task_id         INTEGER          NOT NULL,
  CONSTRAINT pk_pm_loader_task_param PRIMARY KEY (loader_task_param_id),
  CONSTRAINT fk_pm_loader_task_param_ltid FOREIGN KEY (loader_task_id) REFERENCES pm_loader_task(loader_task_id)
)
TABLESPACE wm_flexpm;



-- ------------------------------------------------------------------
--
-- ------------------------------------------------------------------
CREATE TABLE pm_file_config
(
  file_config_id     INTEGER              NOT NULL,
  scan_directory     VARCHAR2(255)        NOT NULL,
  dest_directory     VARCHAR2(255)        NOT NULL,
  reg_expression     VARCHAR2(255)        NOT NULL,
  mod_interval       INTEGER              NOT NULL,
  max_load_attempts  INTEGER              NOT NULL,
  backoff_time       INTEGER              NOT NULL,
  active             CHAR(1)              NOT NULL,
  file_type          VARCHAR2(20)         NOT NULL,
  sentry_config_id   INTEGER              NOT NULL,
  loader_action_id   INTEGER        NOT NULL,
  system_id      INTEGER        NOT NULL,
  date_reg_expression VARCHAR2(255)         NULL,
  date_format         VARCHAR2(255)         NULL,
  time_reg_expression VARCHAR2(255)         NULL,
  time_format         VARCHAR2(255)         NULL,
  ne_name             VARCHAR2(255)         NULL,
  sweep_action        VARCHAR2(20)          NULL,
  allow_zero_length   CHAR(1) NOT NULL,
  CONSTRAINT pk_pm_file_config PRIMARY KEY (file_config_id),
  CONSTRAINT uq_pm_file_ids UNIQUE (scan_directory,dest_directory, loader_action_id,sentry_config_id,system_id,ne_name),
  CONSTRAINT fk_pm_file_config_scid FOREIGN KEY (sentry_config_id) REFERENCES pm_sentry_config(sentry_config_id),
  CONSTRAINT fk_pm_file_config_laid FOREIGN KEY (loader_action_id) REFERENCES pm_loader_action(loader_action_id),
  CONSTRAINT ck_pm_file_config CHECK (active IN ('Y', 'N')),
  CONSTRAINT ck_pm_file_config_2 CHECK (allow_zero_length IN ('Y', 'N')),
  CONSTRAINT ck_file_config_sweep_action CHECK (sweep_action IN ('MOVE', 'DELETE'))
)
TABLESPACE wm_flexpm;


-- ------------------------------------------------------------------
--
-- ------------------------------------------------------------------
CREATE TABLE pm_sentry_file
(
  sentry_file_id           INTEGER      NOT NULL,
  directory                VARCHAR2(255)    NOT NULL,
  name                     VARCHAR2(255)    NOT NULL,
  current_status         VARCHAR2(20)   NOT NULL,
  last_modified            INTEGER        NOT NULL,
  suffix             VARCHAR2(20),
  load_attempts            INTEGER          DEFAULT 0 NOT NULL,
  file_config_id           INTEGER        NOT NULL,
  parent_sentry_file_id    INTEGER,
  last_load_time       DATE,
  loader_config_id       INTEGER,
  group_id                 INTEGER,
  network_tstamp           TIMESTAMP        NOT NULL,
  loader_ticket_no         INTEGER,
  CONSTRAINT pk_pm_sentry_file PRIMARY KEY (sentry_file_id),
  CONSTRAINT fk_pm_sentry_file_fcid FOREIGN KEY (file_config_id) REFERENCES pm_file_config(file_config_id),
  CONSTRAINT fk_pm_sentry_file_lcid FOREIGN KEY (loader_config_id) REFERENCES pm_loader_config(loader_config_id),
  CONSTRAINT ck_pm_sentry_file_current_sts CHECK (current_status IN ('NEW', 'STAGED', 'PROCESSING', 'SUCCEEDED', 'FAILED', 'RETRY', 'FATAL'))
)
TABLESPACE wm_flexpm;

CREATE INDEX idx_pm_current_status on PM_SENTRY_FILE(current_status) TABLESPACE wm_flexpm;
CREATE INDEX idx_pm_loader_config on PM_SENTRY_FILE(loader_config_id) TABLESPACE wm_flexpm;
CREATE INDEX idx_pm_file_config on PM_SENTRY_FILE(file_config_id) TABLESPACE wm_flexpm;
CREATE INDEX idx_pm_suffix on PM_SENTRY_FILE(UPPER(suffix)) TABLESPACE wm_flexpm;
CREATE INDEX idx_pm_last_load_time on PM_SENTRY_FILE(last_load_time) TABLESPACE wm_flexpm;

-- ------------------------------------------------------------------
--
-- ------------------------------------------------------------------
CREATE TABLE pm_sentry_file_history
(
  sentry_file_id           INTEGER      NOT NULL,
  tstamp                   DATE             NOT NULL,
  status                   VARCHAR2(20)     NOT NULL,
  message                  VARCHAR2(500),
--  CONSTRAINT fk_pm_sentry_file_hist_sfid FOREIGN KEY (sentry_file_id)  REFERENCES pm_sentry_file(sentry_file_id),
  CONSTRAINT ck_pm_sentry_file_history_sts CHECK (status IN ('NEW', 'STAGED', 'PROCESSING', 'SUCCEEDED', 'FAILED', 'RETRY', 'FATAL'))
)
PARTITION BY RANGE (tstamp)
(
  PARTITION  p2001010100 VALUES less than (TO_DATE('2001-01-02 00','YYYY-MM-DD HH24'))
)
TABLESPACE wm_flexpm;

-- ------------------------------------------------------------------
-- SEAde62755 - ofagan
-- Add group_id column to correct errors in sentry/loader install
--
-- ------------------------------------------------------------------
CREATE TABLE pm_sentry_file_completed
(
  sentry_file_id           INTEGER      NOT NULL,
  directory                VARCHAR2(255)    NOT NULL,
  name                     VARCHAR2(255)    NOT NULL,
  current_status         VARCHAR2(20)   NOT NULL,
  last_modified            INTEGER        NOT NULL,
  suffix             VARCHAR2(20),
  load_attempts            INTEGER          DEFAULT 0 NOT NULL,
  file_config_id           INTEGER        NOT NULL,
  parent_sentry_file_id    INTEGER,
  last_load_time       DATE,
  loader_config_id       INTEGER,
  group_id                 INTEGER,
  network_tstamp           TIMESTAMP        NOT NULL,
  loader_ticket_no         INTEGER,
  sweep_status             VARCHAR2(20),
  CONSTRAINT pk_pm_sentry_comp PRIMARY KEY (sentry_file_id),
  CONSTRAINT ck_pm_sentry_comp_current_sts CHECK (current_status IN ('NEW', 'STAGED', 'PROCESSING', 'SUCCEEDED', 'FAILED', 'RETRY', 'FATAL')),
  CONSTRAINT ck_sentry_file_comp_sweep_sts CHECK (sweep_status IN ('MOVED', 'DELETED', 'ERROR'))
)
TABLESPACE wm_flexpm;

CREATE INDEX idx_pmc_last_load_time on PM_SENTRY_FILE_COMPLETED(last_load_time) TABLESPACE wm_flexpm;

-- ----------------------------------------------------------------------------------------
-- Following anonymous block will move the one partition we created above up to the present
-- day. When part-maint kicks off next time it takes over the full back- and forward
-- rollouts. (see the DML insert into part_tables below...all this should be one stored 
-- proc call, but it does the job).
-- ----------------------------------------------------------------------------------------
DECLARE
  v_old_part_name VARCHAR2(35);
  v_new_part_name VARCHAR2(35);
  v_sql_stmt VARCHAR2(2000);
  v_part_DATE DATE;
  v_sysdate DATE := trunc(sysdate,'DDD');
  p_table_name VARCHAR2(30) := 'pm_sentry_file_history';
BEGIN
  dbms_output.enable(1000000);

  SELECT SUBOBJECT_NAME
    INTO v_old_part_name
    FROM user_objects
   WHERE object_name = upper(p_table_name)
     AND object_type = 'TABLE PARTITION';

  IF TO_DATE(substr(v_old_part_name,2),'YYYYMMDDHH24') < v_sysdate
  THEN
      v_new_part_name := 'p'||to_char(v_sysdate,'YYYYMMDDHH24');
      v_sql_stmt := 'alter table '||p_table_name||' add partition '||v_new_part_name
                 || ' values less than ('
                 ||'to_DATE('||to_char(v_sysdate+1,'YYYYMMDDHH24')||',''YYYYMMDDHH24''))';
--dbms_output.put_line(v_sql_stmt);
    execute immediate v_sql_stmt;
    v_sql_stmt := 'alter table '||p_table_name||' drop partition '||v_old_part_name;
--dbms_output.put_line(v_sql_stmt);
    execute immediate v_sql_stmt;
  END IF;
EXCEPTION
  WHEN TOO_MANY_ROWS THEN
    raise_application_error('-20100', 'ERROR: the table should have only one partition CREATED');
  WHEN OTHERS THEN
    raise_application_error('-20100', 'ERROR: ORA'||to_char(SQLCODE)||SQLERRM);
END;
/
show error

-- Now register this puppy with part_maint
INSERT INTO part_tables(part_table_id, table_name, tablespace_name, period, run_hourly, run_daily,
run_weekly, run_monthly, needs_export, needs_analyze, needs_move, needs_purge,
future_part, past_part, drop_sproc)
VALUES
(PART_TABLE_SEQ.nextval, 'PM_SENTRY_FILE_HISTORY', 'WM_FLEXPM', 'D', 'N', 'Y', 'N', 'N', 'N', 'Y', 'N', 'Y', 5, 14,
'pm_sentry_loader.cleanup');
COMMIT;

-- We need to turn on monitoring so part-maint can do some maintainance
ALTER TABLE pm_sentry_file_history MONITORING;

-- The following types are created to support the use of nested tables
-- in the get_loader_tasks routine. The routine returns a list of
-- files to process, and the quickest way to do this is to use
-- a TABLE CAST of the nested table created within the procedure.
CREATE OR REPLACE TYPE SentryFileArray AS TABLE OF NUMBER;
/

CREATE SEQUENCE seq_loader_file_ticket;
