---------------------------------------------------------------------------
--
-- Licensed Materials - Property of IBM
-- 5724-T05,5724-T06
--
-- (C) Copyright IBM Corp. 2003,2008. All Rights Reserved.
--
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
--
---------------------------------------------------------------------------
-- (#) ./base/db/Oracle8i/sentryloader/createViews.sql BL_core_schema_8.0.7_8.0.7.4.02_20100413  064938
-- (#) 
--
CREATE OR REPLACE VIEW pm_sentry_config_vw AS
SELECT 
  pm_file_config.file_config_id, 
  pm_file_config.scan_directory, 
  pm_file_config.reg_expression,
  pm_file_config.file_type, 
  pm_file_config.dest_directory, 
  pm_file_config.mod_interval,
  pm_file_config.date_reg_expression,
  pm_file_config.date_format,
  pm_file_config.time_reg_expression,
  pm_file_config.time_format,
  pm_sentry_config.node_name,
  pm_file_config.sweep_action,
  pm_file_config.allow_zero_length
FROM 
  pm_file_config, 
  pm_sentry_config
WHERE 
  pm_file_config.sentry_config_id = pm_sentry_config.sentry_config_id
AND pm_file_config.active = 'Y'
AND pm_sentry_config.active = 'Y';

CREATE OR REPLACE VIEW PM_SENTRY_FILE_VW
(SENTRY_FILE_ID, PARENT_SENTRY_FILE_ID, FILE_CONFIG_ID, DIRECTORY, NAME, 
 SUFFIX, FILE_TYPE, CURRENT_STATUS, LAST_MODIFIED, LOAD_ATTEMPTS, 
 LAST_LOAD_TIME, MAX_LOAD_ATTEMPTS, MOD_INTERVAL, SYSTEM_ID, NETWORK_TSTAMP,
 LOADER_TICKET_NO, SENTRY_NODE_NAME, GROUP_ID)
AS 
select
  pm_sentry_file.sentry_file_id,
  pm_sentry_file.parent_sentry_file_id,
  pm_file_config.file_config_id,
  pm_sentry_file.directory, 
  pm_sentry_file.name,
  pm_sentry_file.suffix,
  pm_file_config.file_type,
  pm_sentry_file.current_status, 
  pm_sentry_file.last_modified,
  pm_sentry_file.load_attempts,
  pm_sentry_file.last_load_time,
  pm_file_config.max_load_attempts, 
  pm_file_config.mod_interval,
  pm_file_config.system_id, 
  pm_sentry_file.network_tstamp,
  pm_sentry_file.loader_ticket_no,
  pm_sentry_config.node_name sentry_node_name,
  pm_sentry_file.group_id
FROM
  pm_sentry_file, pm_file_config, pm_sentry_config
WHERE
  pm_sentry_file.file_config_id = pm_file_config.file_config_id
  AND pm_file_config.sentry_config_id = pm_sentry_config.sentry_config_id;
  
CREATE OR REPLACE VIEW PM_FILE_TASK_VW
(SENTRY_FILE_ID, FILE_NAME, LOADER_TASK_ID, LOADER_TASK_NAME, 
LOADER_TASK_DESC, TASK_NAME,LOADER_TASK_SEQ, PARAM_NAME, PARAM_VALUE,
 LOADER_TICKET_NO)
AS 
select 
  f.sentry_file_id,
  f.name || f.suffix file_name,
  lt.loader_task_id loader_task_id,
  lt.name loader_task_name, 
  lt.description loader_task_desc,
  lt.task_name,
  lt.sequence loader_task_seq,
  p.name param_name,
  p.value param_value,
  f.loader_ticket_no
from 
  pm_sentry_file f, 
  pm_file_config fc,
  pm_loader_action la, 
  pm_loader_task lt,
  pm_loader_task_param p
where 
  f.file_config_id = fc.file_config_id
  and fc.loader_action_id = la.loader_action_id
  and la.loader_action_id = lt.loader_action_id
  and lt.loader_task_id = p.loader_task_id (+);

CREATE OR REPLACE VIEW PM_LOADER_AVAILABLE_TASKS_VW
(SENTRY_FILE_ID, MAX_CONCURRENCY, LOADER_ACTION_ID, SCHEDULED_TIME)
AS
select 
  f.sentry_file_id,
  la.max_concurrency,
  la.loader_action_id,
  (case  
    when f.last_load_time is null then f.network_tstamp 
    else f.last_load_time + (fc.backoff_time/86400)
  end) scheduled_time
from
  pm_sentry_file f, 
  pm_file_config fc, 
  pm_loader_action la
where 
  f.file_config_id = fc.file_config_id
  and fc.loader_action_id = la.loader_action_id
  and fc.active = 'Y'
  and ( current_status = 'STAGED'
        or
        current_status = 'RETRY'
      );

/
show errors;

