--
-- (#) ./base/db/Oracle8i/softalarm/create_sa_schedule_schema.sql BL_core_schema_8.0.7_8.0.7.4.02_20100413  064938
-- (#) 
--

-- SEAde13550:
--   Table, view and triggers to allow generalized scheduling of soft alarm groups.
-- History
-------------------------------
-- 2001.04.20 - Kevin Wagner - Authored.
-- 2002.11.21 - ntalon 
--      SEAde29114 : add unique index on SA_SCHEDULE (folderid, upper(name))
--
PROMPT Creating table sa_schedule...
CREATE TABLE sa_schedule (
  sa_schedule_id NUMBER,
    CONSTRAINT sa_schedule_pk PRIMARY KEY (sa_schedule_id) USING INDEX TABLESPACE wm_client,
  group_id       NUMBER,
--    CONSTRAINT sa_schedule_group_id_fk FOREIGN KEY (group_id) REFERENCES job_group(id),
  ovrscenarioid  NUMBER,
  FolderId           INTEGER       NOT NULL,
  UserId             INTEGER       NOT NULL,
  Name               VARCHAR2(64)  NOT NULL,
  DESCRIPTION        VARCHAR2(255),
  Changed            DATE          DEFAULT TRUNC(SYSDATE,'MI') NOT NULL,
  ClientMachineId    INTEGER       NOT NULL, -- sub-object id
  RunMode            CHAR(1)       DEFAULT 'I' NOT NULL,
    CONSTRAINT sa_schedule_RunMode_ck CHECK (RunMode IN ('I','S')),
  RetrieveMode       CHAR(1)       DEFAULT 'D' NOT NULL,
    CONSTRAINT sa_schedule_RetrieveMode_ck CHECK (RetrieveMode IN ('I','D')),
  AutoPurge          CHAR(1)       DEFAULT 'Y' NOT NULL,
    CONSTRAINT sa_schedule_AutoPurge_ck CHECK (AutoPurge IN ('Y','N')),
  PurgeInterval      INTEGER       DEFAULT 0 NOT NULL, -- 0 means immediate purge
  SUBFOLDERNAME  VARCHAR2(255),
  lastrundate        DATE,
  data_time          DATE,
  timeout            INTEGER,
  timeout_unit       CHAR(1),
    CONSTRAINT sa_schedule_ovrscenarioid_fk
        FOREIGN KEY(ovrscenarioid)     REFERENCES PM_Scenario(Id),
    CONSTRAINT sa_schedule_ClientMachin_fk 
	FOREIGN KEY(ClientMachineId)     REFERENCES PM_ClientMachine(Id),
    CONSTRAINT sa_schedule_FolderId_fk 
	FOREIGN KEY(FolderId)            REFERENCES PM_Folder(Id),
    CONSTRAINT sa_schedule_UserId_fk 
	FOREIGN KEY(UserId)              REFERENCES PM_User(Id),
    CONSTRAINT sa_sched_timeout_chk CHECK ( timeout > 0 ),
    CONSTRAINT sa_sched_timeout_unit_chk CHECK ( timeout_unit IN ('M', 'H', 'D')),
    CONSTRAINT sa_sched_to_and_to_unit_chk CHECK(
      ( timeout IS NULL AND timeout_unit IS NULL )
      OR (timeout IS NOT NULL AND timeout_unit IS NOT NULL )
    )
) TABLESPACE wm_client;


PROMPT Creating unique index sa_Schedule_Name_unq...
CREATE UNIQUE INDEX sa_Schedule_Name_unq ON sa_Schedule(FolderId, UPPER(Name))
TABLESPACE WM_Client;

exec gen_scheduler_view.write_code( 'SA_SCHEDULE', 2, 3 );

EXIT

-- Done.

