create sequence sa_seq start with 1;
create sequence sa_action_seq start with 1;
create sequence sa_annotation_seq start with 1;
create table sa_archive_master
(
master_id           number constraint pk_sa_arc_mst primary key 
)
tablespace wm_sa
;
create table sa_action
(
id               number
 constraint pk_sa_act primary key,
sa_master_id     number not null
 constraint fk_sa_act_mid references sa_archive_master(master_id),
action_type      varchar2(15) not null
 constraint chk_sa_act_type check
    (action_type in ('userClear','sysClear','Acknowledge','Annotate')),
user_id          number
 constraint fk_sa_act_uid references pm_user(id),
time             date
)
tablespace wm_sa;
CREATE INDEX SA_Act_MID_ndx ON sa_action (sa_master_id)
TABLESPACE wm_sa; 
CREATE INDEX SA_Act_UID_ndx ON SA_Action ( User_ID )
TABLESPACE WM_SA;
create table sa_archive
(
master_id           integer not null
 constraint fk_sa_arc_mid references sa_archive_master(master_id),
id                  integer not null,
entity_id           integer not null
 ,--constraint fk_sa_arc_eid references wmn_entity(entity_id),
instance_id         integer not null
 ,--constraint fk_sa_arc_iid references wmn_instance(instance_id), 
instance_name       varchar2(256) not null,
scenario_instance_id  integer not null,
alarm_type          number(3) not null
 constraint fk_sa_arc_almtyp references sa_alarm_type(id),
probable_cause      number(3) not null
 constraint fk_sa_arc_probcaus references sa_alarm_cause(id), 
perceived_severity  number(3) not null
 constraint fk_sa_arc_severity references sa_severity(id), 
additional_text     varchar2(1000),
alarm_time          date not null,
generation_time     date not null,
summary             varchar2(256),
fdn                 varchar2(256) not null,
sa_template_id      integer not null
,-- constraint fk_sa_arch_sa_template references sa_template(id),
ack_action_id       integer
,--constraint fk_sa_arc_ack_act references sa_action(id),
clear_action_id     integer
,--constraint fk_sa_arc_clr_act references sa_action(id),
clear_alarm_id      integer
)
partition by range (alarm_time)
(
  partition  p2001010100 values less than (to_date('2001010200','YYYYMMDDHH24'))
)
tablespace wm_sa;
create index idx_sa_arc_mid_id on sa_archive (master_id,id)
local
( 
  partition  p2001010100
)
tablespace wm_sa;
create global temporary table sa_archive_tmp
(
id                  integer
 constraint pk_sa_arc_tmp primary key,
entity_id           integer not null
,-- constraint fk_sa_arc_tmp_eid references wmn_entity(entity_id),
instance_id         integer not null
,-- constraint fk_sa_arc_tmp_iid references wmn_instance(instance_id),
instance_name       varchar2(256) not null,
scenario_instance_id  integer not null,
alarm_type          number(3) not null
,-- constraint fk_sa_arc_tmp_almtyp references sa_alarm_type(id),
probable_cause      number(3) not null
,-- constraint fk_sa_arc_tmp_probcaus references sa_alarm_cause(id),
perceived_severity  number(3) not null
,-- constraint fk_sa_arc_tmp_severity references sa_severity(id),
additional_text     varchar2(1000),
alarm_time          date not null,
generation_time     date not null,
summary             varchar2(256),
fdn                 varchar2(256) not null,
sa_template_id      integer not null
)
on commit delete rows 
/
create global temporary table sa_action_tmp
(
act_type                  varchar2(20)  not null
 constraint chk_sa_act_tmp_typ check(act_type in ('userClear','Acknowledge','Annotate')),
master_id number not null,
user_id number,
annotation_text varchar2(512)
)
on commit delete rows
/
create global temporary table sa_softalarm_tmp
(
id  number constraint sa_softalarm_tmp_id primary key
)
on commit delete rows
/
create table sa_state
(
master_id           integer
 constraint pk_sa_state primary key
 constraint fk_sa_stat_mid references sa_archive_master(master_id),
entity_id           integer not null
 ,--constraint fk_sa_stat_eid references wmn_entity(entity_id),
instance_id         integer not null
 ,--constraint fk_sa_stat_iid references wmn_instance(instance_id),
instance_name       varchar2(256) not null,
scenario_instance_id  integer not null,
alarm_type          number(3) not null
 constraint fk_sa_stat_aLmtyp references sa_alarm_type(id),
probable_cause      number(3) not null
 constraint fk_sa_stat_probcaus references sa_alarm_cause(id),
perceived_severity  number(3) not null
 constraint fk_sa_stat_severity references sa_severity(id),
additional_text     varchar2(1000),
alarm_time          date not null,
generation_time     date not null,
summary             varchar2(256),
fdn                 varchar2(256) not null,
sa_template_id      integer not null
 ,--constraint fk_sa_stat_sa_template references sa_template(id),
ack_action_id       integer
 constraint fk_sa_stat_ack_act references sa_action(id),
alarm_count         integer not null,
first_occurence      date not null
 ,constraint uni_sa_stat unique 
 (instance_id, alarm_type, probable_cause, summary)
)
tablespace wm_sa
;
CREATE INDEX SA_Stat_Act_Ack_ndx on SA_State ( Ack_Action_ID )
TABLESPACE wm_sa;
CREATE INDEX SA_Stat_AlmTyp_ndx on SA_State ( Alarm_Type )
TABLESPACE wm_sa;
CREATE INDEX SA_Stat_ProbCaus_ndx on SA_State ( Probable_Cause )
TABLESPACE wm_sa;
CREATE INDEX SA_Stat_Severity_ndx on SA_State ( Perceived_Severity )
TABLESPACE wm_sa;
create table sa_annotation
(
 id              number
  constraint pk_sa_annot primary key,  
 sa_master_id    number not null
  constraint fk_sa_annot_mid references sa_archive_master(master_id),
 act_id          number not null
  constraint fk_sa_annot_act references sa_action(id),
 time            date not null,
 text            varchar2(512)
)
tablespace wm_sa
;
CREATE INDEX SA_Annot_Act_ndx on SA_Annotation ( Act_ID )
TABLESPACE wm_sa;
CREATE INDEX SA_Annot_MID_ndx on SA_Annotation ( SA_Master_ID )
TABLESPACE wm_sa;
create table sa_inflight(
 jobid           number not null,
 taskid          number not null,
 count           number default 0 not null,
 started         date not null,
 job_time        date not null,
 softalarm_id    number not null,
   constraint pk_sa_inflight primary key(jobid, taskid)
);
create or replace PROCEDURE sa_config_part wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
7
9200000
1
4
0 
31
2 :e:
1SA_CONFIG_PART:
1P_TABLE_NAME:
1VARCHAR2:
1V_OLD_PART_NAME:
135:
1V_NEW_PART_NAME:
1V_SQL_STMT:
12000:
1V_PART_DATE:
1DATE:
1V_SYSDATE:
1TRUNC:
1SYSDATE:
1DDD:
1DBMS_OUTPUT:
1ENABLE:
11000000:
1SUBOBJECT_NAME:
1USER_OBJECTS:
1OBJECT_NAME:
1UPPER:
1OBJECT_TYPE:
1SELECT SUBOBJECT_NAME  into v_old_part_name:n    from user_objects:n   where +
1object_name = upper(p_table_name):n     and object_type = 'TABLE PARTITION':
1TO_DATE:
1SUBSTR:
12:
1YYYYMMDDHH24:
1<:
1p:
1||:
1TO_CHAR:
1alter table :
1 add partition :
1 values less than (:
1to_date(:
1+:
11:
1,'YYYYMMDDHH24')):
1EXECUTE:
1IMMEDIATE:
1 drop partition :
1TOO_MANY_ROWS:
1RAISE_APPLICATION_ERROR:
1-20100:
1ERROR:: the table should have only one partition created:
1OTHERS:
1ERROR:: ORA:
1SQLCODE:
1SQLERRM:
0

0
0
bd
2
0 9a 8f a0 b0 3d b4 55
6a a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
1c 81 b0 a3 a0 1c :2 a0 6e
a5 b 81 b0 :2 a0 6b 51 a5
57 :7 a0 12a :3 a0 51 a5 b 6e
a5 b a0 7e b4 2e a0 6e
7e :2 a0 6e a5 b b4 2e d
a0 6e 7e a0 b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :2 a0
7e 51 b4 2e 6e a5 b b4
2e 7e 6e b4 2e d :3 a0 11e
11d a0 6e 7e a0 b4 2e 7e
6e b4 2e 7e a0 b4 2e d
:3 a0 11e 11d b7 19 3c b7 :2 a0
:2 6e a5 57 b7 a6 9 a0 53
a0 :2 6e 7e :2 a0 a5 b b4 2e
7e a0 b4 2e a5 57 b7 a6
9 a4 b1 11 68 4f 1d 17
b5 
bd
2
0 3 1f 1b 1a 27 17 2c
30 4d 38 3c 3f 40 48 37
6a 58 34 5c 5d 65 57 87
75 54 79 7a 82 74 a3 92
96 9e 71 cb aa ae b6 ba
be c3 c4 c6 91 d2 d6 8e
da dd de e3 e7 eb ef f3
f7 fb ff 10b 10f 113 117 11a
11b 11d 122 123 125 129 12c 12d
132 136 13b 13e 142 146 14b 14c
14e 14f 154 158 15c 161 164 168
169 16e 171 176 177 17c 17f 183
184 189 18c 191 192 197 19a 19f
1a0 1a5 1a8 1ac 1b0 1b3 1b6 1b7
1bc 1c1 1c2 1c4 1c5 1ca 1cd 1d2
1d3 1d8 1dc 1e0 1e4 1e8 1ed 1f1
1f5 1fa 1fd 201 202 207 20a 20f
210 215 218 21c 21d 222 226 22a
22e 232 237 23b 23d 241 244 246
24a 24e 253 258 259 25e 260 261
266 1 26a 26e 273 278 27b 27f
283 284 286 287 28c 28f 293 294
299 29a 29f 2a1 2a2 2a7 2ab 2ad
2b9 2bd 2bf 2c0 2c9 
bd
2
0 b 1a 2a :2 1a 19 :3 1 11
1a 19 :2 11 :2 1 11 1a 19 :2 11
:2 1 c 15 14 :2 c :2 1 :3 d :2 1
:2 b 13 19 21 :2 13 b :2 1 :2 d
14 :2 1 a 1f :2 a 18 1e a
3 6 e 15 25 :2 e 28 :2 6
3a :3 38 7 1a 1d 1f 27 31
:2 1f :2 1a :2 7 15 23 25 :2 15 31
33 :2 15 44 46 :2 15 12 :3 15 12
14 :2 15 1e 20 28 31 32 :2 28
34 :2 20 :2 15 43 45 :2 15 7 5
d 17 :3 5 13 21 23 :2 13 2f
31 :2 13 43 45 :2 13 :2 5 d 17
:2 5 44 :2 3 1 8 5 1d 27
:2 5 16 :2 3 :2 8 5 1d 27 33
35 3d :2 35 :2 27 45 47 :2 27 :2 5
f :2 3 :8 1 
bd
4
0 :8 1 :7 2 :7 3
:7 4 :5 5 :a 6 :6 8
:2 9 a :3 b c
9 :d d :b e :e f
:2 10 :2 f :2 11 :2 f
:a 11 :2 f :2 11 :3 f
:5 13 :f 14 :5 16 :3 d
7 19 :5 1a :3 19
:2 1b :10 1c :3 1b 18
:7 1 
2cb
4
:3 0 1 :a 0 b8
1 :7 0 5 :2 0
:2 3 :3 0 2 :7 0
4 3 :3 0 6
:2 0 b8 1 7
:2 0 5 :2 0 9
3 :3 0 5 :2 0
7 a c :6 0
f d 0 b6
0 4 :6 0 8
:2 0 d 3 :3 0
b 11 13 :6 0
16 14 0 b6
0 6 :6 0 13
8e 0 11 3
:3 0 f 18 1a
:6 0 1d 1b 0
b6 0 7 :6 0
2d 2e 0 18
a :3 0 1f :7 0
22 20 0 b6
0 9 :6 0 a
:3 0 24 :7 0 c
:3 0 d :3 0 e
:4 0 15 26 29
2c 25 2a b6
0 b :6 0 f
:3 0 10 :3 0 11
:2 0 1a 2f 31
:2 0 96 12 :3 0
4 :3 0 13 :3 0
14 :3 0 15 :3 0
2 :3 0 16 :4 0
17 1 :8 0 96
18 :3 0 19 :3 0
4 :3 0 1a :2 0
1c 3c 3f 1b
:4 0 1f 3b 42
b :3 0 1c :2 0
24 45 46 :3 0
6 :3 0 1d :4 0
1e :2 0 1f :3 0
b :3 0 1b :4 0
27 4b 4e 2a
4a 50 :3 0 48
51 0 93 7
:3 0 20 :4 0 1e
:2 0 2 :3 0 2d
55 57 :3 0 1e
:2 0 21 :4 0 30
59 5b :3 0 1e
:2 0 6 :3 0 33
5d 5f :3 0 1e
:2 0 22 :4 0 36
61 63 :3 0 1e
:2 0 23 :4 0 39
65 67 :3 0 1e
:2 0 1f :3 0 b
:3 0 24 :2 0 25
:2 0 3c 6c 6e
:3 0 1b :4 0 3f
6a 71 42 69
73 :3 0 1e :2 0
26 :4 0 45 75
77 :3 0 53 78
0 93 27 :3 0
28 :3 0 7 :3 0
7c :4 0 7d :2 0
93 7 :3 0 20
:4 0 1e :2 0 2
:3 0 48 81 83
:3 0 1e :2 0 29
:4 0 4b 85 87
:3 0 1e :2 0 4
:3 0 4e 89 8b
:3 0 7f 8c 0
93 27 :3 0 28
:3 0 7 :3 0 90
:4 0 91 :2 0 93
51 94 47 93
0 95 57 0
96 59 b7 2a
:3 0 2b :3 0 2c
:4 0 2d :4 0 5d
98 9b :2 0 9d
60 9f 62 9e
9d :2 0 b5 2e
:3 0 2b :3 0 2c
:4 0 2f :4 0 1e
:2 0 1f :3 0 30
:3 0 64 a6 a8
66 a5 aa :3 0
1e :2 0 31 :3 0
69 ac ae :3 0
6c a2 b0 :2 0
b2 6f b4 71
b3 b2 :2 0 b5
73 :2 0 b7 76
b7 b6 96 b5
:6 0 b8 :2 0 1
7 b7 bb :3 0
ba b8 bc :8 0

7c
4
:3 0 1 2 1
5 1 b 1
9 1 12 1
10 1 19 1
17 1 1e 2
27 28 1 23
1 30 2 3d
3e 2 40 41
1 44 2 43
44 2 4c 4d
2 49 4f 2
54 56 2 58
5a 2 5c 5e
2 60 62 2
64 66 2 6b
6d 2 6f 70
2 68 72 2
74 76 2 80
82 2 84 86
2 88 8a 5
52 79 7e 8d
92 1 94 3
32 3a 95 2
99 9a 1 9c
1 97 1 a7
2 a4 a9 2
ab ad 2 a3
af 1 b1 1
a1 2 9f b4
5 e 15 1c
21 2b 
1
4
0 
bb
0
1
14
1
7
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 
1e 1 0
23 1 0
2 1 0
9 1 0
1 0 1
17 1 0
10 1 0
0

/
show error
set serveroutput on
execute sa_config_part('sa_archive');
set serveroutput off
drop procedure sa_config_part;
exit
