---------------------------------------------------------------------------
--
-- Licensed Materials - Property of IBM
-- 5724-T05,5724-T06
--
-- (C) Copyright IBM Corp. 2008. All Rights Reserved.
--
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
--
---------------------------------------------------------------------------
-- (#) ./base/db/Oracle8i/softalarm/sa_softalarm_trigger.sql BL_core_schema_8.0.7_8.0.7.4.02_20100413  064938
-- (#) 
--
-- This trigger is used to test whether the client is compatible with 
-- SAEXT. Some old clients could be compatible with the DB Server but
-- not with SAEXT. This was due to the client hard-coding the list
-- of SA_TIME_RANGE values. We ONLY check when the client tries to 
-- change an SAEXT sa_time_range (6).
--
-- This is a workaround until we make the old clients incompatible
-- with the DB Server.
--
CREATE OR REPLACE TRIGGER sa_softalarm_bu
BEFORE UPDATE
ON sa_softalarm
FOR EACH ROW
DECLARE
   l_client_info VARCHAR2(64);
BEGIN
   -- Did the client update from External (6) to something else?
   IF ( :old.time_range_id IS NOT NULL
        AND :old.time_range_id = 6
        AND ( :new.time_range_id IS NULL 
              OR :new.time_range_id != 6 ) ) THEN

      DBMS_APPLICATION_INFO.READ_CLIENT_INFO( l_client_info );

      -- Is this an SAEXT client?
      IF ( l_client_info IS NULL OR l_client_info != 'SAEXT' ) THEN
         RAISE_APPLICATION_ERROR( -20085, 'The client is not compatible with SAEXT. Please update your client.' );
      END IF;

   END IF;

END;
/

show errors trigger sa_softalarm_bu

