-- --------------------------------------------------------------------------
--     COPYRIGHT WatchMark Corp 1999
-- --------------------------------------------------------------------------
set serveroutput on;

-- NOTE: The Lucent-specific versions of these views are maintained in
--       vendor/Lucent/ECP/ses/status_views.sql
--
-- These views are used below.

CREATE or REPLACE VIEW report_joblist_v as
     SELECT id, scheduleuserid, reportgroupname, schedulename, machinename
       FROM RG_JobList
      UNION ALL
     SELECT id, scheduleuserid, reportgroupname, schedulename, machinename
       FROM ag_joblist
      UNION ALL
     SELECT id, scheduleuserid, reportgroupname, schedulename, machinename
       FROM sa_joblist;
show errors view report_joblist_v;       

CREATE or REPLACE VIEW report_tasklist_v as
     SELECT id, reportname, reporttype, autopurge, purgeinterval, retrievemode,
            reporttemplateid, reportkind, reportspecid, spoolfileid
       FROM RG_TaskList
      UNION ALL
     SELECT task_id id, name, 'Aggregator', autopurge, purgeinterval, retrievemode,
            TO_NUMBER( NULL ), TO_CHAR( NULL ), TO_NUMBER( NULL ), TO_NUMBER( NULL )
       FROM ag_def_snap
      UNION ALL
     SELECT task_id id, name, 'Soft Alarm', autopurge, purgeinterval, retrievemode,
            TO_NUMBER( NULL ), TO_CHAR( NULL ), TO_NUMBER( NULL ), TO_NUMBER( NULL )
       FROM sa_softalarm_snap;
show errors view report_tasklist_v;

CREATE or REPLACE VIEW report_schedule_v as
     SELECT ID, Userid, rptgrpid, clientmachineid, AutoPurge, PurgeInterval, RetrieveMode, name
       FROM rg_schedule_view
      UNION ALL
     SELECT ID, Userid, rptgrpid, clientmachineid, AutoPurge, PurgeInterval, RetrieveMode, name
       FROM ag_schedule_view
      UNION ALL
     SELECT ID, Userid, rptgrpid, clientmachineid, AutoPurge, PurgeInterval, RetrieveMode, name
       FROM sa_schedule_view;
show errors view report_schedule_v;
       
-- --------------------------------------------------------------------------
--   These are the important views.
-- --------------------------------------------------------------------------

CREATE or REPLACE VIEW report_status_v as
select /*+ USE_HASH( at aj ts PM_User tasklist joblist spoolfiles sched rgdl ) */
	at.task_id		task_id,
	aj.job_id		job_id,
	tasklist.reportName	report_name,
        tasklist.reportType	report_type,
        joblist.reportGroupName group_name,
	pm_user.name		owner,
        joblist.MachineName     machinename,
	spoolfiles.FileName	spool_filename,
	tasklist.AutoPurge	AutoPurge,
	tasklist.PurgeInterval	PurgeInterval,
	tasklist.RetrieveMode	RetrieveMode,
	joblist.ScheduleName	schedule_name,
        aj.job_time		job_scheduled_start,
        ts.started		task_started,
	ts.ended		task_ended,
        sched.is_suspended      is_suspended,
	substr(
         sched_general.status_code_to_name(ts.status_code), 
         1, 16) status_word,
	substr(ts.message, 1, 255) status_message,
	tasklist.ReportTemplateId  templateId,
	tasklist.ReportKind     ReportKind,
	tasklist.ReportSpecId   ReportSpecId,
	decode(rgdl.task_id, at.task_id, 'Y', 'N') was_downloaded
from active_task at,
     active_job  aj,
     task_status ts,
     PM_User,
   ( SELECT id, reportname, reporttype, autopurge, purgeinterval, retrievemode,
            reporttemplateid, reportkind, reportspecid, spoolfileid
       FROM RG_TaskList
      UNION ALL
     SELECT task_id id, name, 'Soft Alarm', autopurge, purgeinterval, retrievemode,
            TO_NUMBER( NULL ), TO_CHAR( NULL ), TO_NUMBER( NULL ), TO_NUMBER( NULL )
       FROM sa_softalarm_snap
   ) tasklist,
   ( SELECT id, scheduleuserid, reportgroupname, schedulename, machinename
       FROM RG_JobList
      UNION ALL
     SELECT id, scheduleuserid, reportgroupname, schedulename, machinename
       FROM sa_joblist
   ) joblist,
     Task_FileName spoolfiles,
     schedule    sched,
     RG_Download rgdl
where
      ts.task_id (+)= at.task_id
  and at.job_id     = aj.job_id
  and aj.job_type IN (1, 10, 40, 2, 3)
  and aj.admin_task IS NULL
  and tasklist.id   = at.task_id
  and joblist.id    = at.job_id
  and spoolfiles.id (+)= tasklist.spoolFileId
  and sched.schedule_id (+)= aj.schedule_id
  and pm_user.id (+) = joblist.scheduleUserId
  and nvl(at.cleanup_time, SYSDATE+1) > SYSDATE
  and nvl(aj.cleanup_time, SYSDATE+1) > SYSDATE
  and at.task_id = rgdl.task_id(+);
show errors view report_status_v;

create or replace view report_group_status_v as
select /*+ USE_NL( TS )
           USE_HASH( AJ JobList Usr Usr2 Sched PM_Sched PM_rptgrp LogFiles PM_Client ) */ 
	aj.job_id                                         job_id,
	aj.job_time                                       schedule_date_time,
	NVL(joblist.reportGroupName, PM_RptGrp.Name)      group_name,
	NVL(usr.name, usr2.name)                          owner,
        NVL(joblist.machinename, PM_Client.machinename)   machinename,
	NVL(joblist.scheduleName, PM_Sched.name)          schedule_name,
	pm_sched.AutoPurge				  AutoPurge,
	pm_sched.PurgeInterval				  PurgeInterval,
	pm_sched.RetrieveMode				  RetrieveMode,
	ts.started                                        job_started,
	ts.ended                                          job_ended,
	ts.pid                                            process_id,
	sched.is_suspended                                is_suspended,
	substr(
         sched_general.status_code_to_name(ts.status_code),
         1, 16)                                           status_word,
	substr(ts.message, 1, 255)                         status_message,
	logfiles.FileName                                 logfile_name,
        aj.job_type                               job_type
from active_job aj,
     task_status  ts,
     report_joblist_v joblist,     
     PM_User      usr,
     PM_User      usr2,
     schedule     sched,
     report_schedule_v pm_sched,
     PM_RptGrp,
     Task_FileName logfiles,
     PM_ClientMachine pm_client
where ts.task_id is null
  and ( NOT (sched.job_type = 40 AND sched.sched_fk IS NULL) )
  and ts.job_id  (+)= aj.job_id
  and joblist.id (+)= aj.job_id
  and logfiles.jobid (+)= aj.job_id
  and logfiles.taskid is null
  and aj.job_type IN (1, 10, 40, 2, 3)
  and aj.admin_task IS NULL
  and sched.schedule_id (+)= aj.schedule_id
  and joblist.scheduleuserid = usr.id(+)
  and pm_sched.id (+)= sched.schedule_id
  and pm_sched.userid = usr2.id(+)
  and pm_sched.rptgrpid = pm_RptGrp.id(+)
  and pm_sched.clientmachineid = pm_client.id(+)
  and (aj.cleanup_time is null OR aj.cleanup_time > SYSDATE)
  and not (
              (ts.message = 'Schedule deactivated')
           or (sched.is_suspended = 'Y' and ts.status_code = 0) -- status_code='Scheduled'
          )
  ;
show errors view report_group_status_v;

