-- NOTE: The Lucent-specific versions of these views are maintained in
--       vendor/Lucent/ECP/ses/status_views.sql
--
--  SEAde25889 EA: No scheduler log in status monitor
--  Please make appropriate changes to status_views.sql in Enterprise Space whenever these views are modified.

create or replace view archive_report_status as
select 
	at.task_id		task_id,
	aj.job_id		job_id,
	tasklist.reportName	report_name,
        tasklist.reportType	report_type,
        joblist.reportGroupName group_name,
	pm_user.name		owner,
        joblist.MachineName     machinename,
	spoolfiles.FileName	spool_filename,
	tasklist.AutoPurge	AutoPurge,
	tasklist.PurgeInterval	PurgeInterval,
	tasklist.RetrieveMode	RetrieveMode,
	joblist.ScheduleName	schedule_name,
        aj.job_time		job_scheduled_start,
        sched.is_suspended      is_suspended,
	tasklist.ReportTemplateId  templateId,
	tasklist.ReportKind     ReportKind,
	tasklist.ReportSpecId   ReportSpecId,
	decode(rgdl.task_id, at.task_id, 'Y', 'N') was_downloaded
from active_task at,
     active_job  aj,
     PM_User,
   ( SELECT id, reportname, reporttype, autopurge, purgeinterval, retrievemode,
            reporttemplateid, reportkind, reportspecid, spoolfileid
       FROM RG_TaskList
      UNION ALL
     SELECT task_id id, name, 'Aggregator', autopurge, purgeinterval, retrievemode,
            TO_NUMBER( NULL ), TO_CHAR( NULL ), TO_NUMBER( NULL ), TO_NUMBER( NULL )
       FROM ag_def_snap
   ) tasklist,
   ( SELECT id, scheduleuserid, reportgroupname, schedulename, machinename 
       FROM RG_JobList
      UNION ALL
     SELECT id, scheduleuserid, reportgroupname, schedulename, machinename
       FROM ag_joblist
   ) joblist,
     Task_FileName spoolfiles,
     schedule    sched,
     RG_Download rgdl
where
      at.job_id     = aj.job_id
  and aj.job_type IN (1, 10, 40, 3)
  and aj.admin_task IS NULL
  and tasklist.id   = at.task_id
  and joblist.id    = at.job_id
  and spoolfiles.id (+)= tasklist.spoolFileId
  and sched.schedule_id (+)= aj.schedule_id
  and pm_user.id (+) = joblist.scheduleUserId
  and nvl(at.cleanup_time, SYSDATE+1) > SYSDATE
  and nvl(aj.cleanup_time, SYSDATE+1) > SYSDATE
  and at.task_id = rgdl.task_id(+);


create or replace view archive_report_group_status as
select 
	aj.job_id                                         job_id,
	aj.job_time                                       schedule_date_time,
	NVL(joblist.reportGroupName, PM_RptGrp.Name)      group_name,
	NVL(usr.name, usr2.name)                          owner,
        NVL(joblist.machinename, PM_Client.machinename)   machinename,
	NVL(joblist.scheduleName, PM_Sched.name)          schedule_name,
	pm_sched.AutoPurge				  AutoPurge,
	pm_sched.PurgeInterval				  PurgeInterval,
	pm_sched.RetrieveMode				  RetrieveMode,
	sched.is_suspended                                is_suspended,
	logfiles.FileName                                 logfile_name,
        aj.job_type                               job_type
from active_job aj,
   ( SELECT id, scheduleuserid, reportgroupname, schedulename, machinename
       FROM RG_JobList
      UNION ALL
     SELECT id, scheduleuserid, reportgroupname, schedulename, machinename
       FROM ag_JobList
   ) joblist,
     PM_User     usr,
     PM_User     usr2,
     schedule    sched,
   ( SELECT ID, Userid, rptgrpid, clientmachineid, AutoPurge, PurgeInterval, RetrieveMode, name
       FROM rg_schedule_view
      UNION ALL
     SELECT ID, Userid, rptgrpid, clientmachineid, AutoPurge, PurgeInterval, RetrieveMode, name
       FROM ag_schedule_view
   ) pm_sched,
     PM_RptGrp,
     Task_FileName logfiles,
     PM_ClientMachine pm_client
where 
     ( NOT (sched.job_type = 40 AND sched.sched_fk IS NULL) )
  and joblist.id (+)= aj.job_id
  and logfiles.jobid (+)= aj.job_id
  and logfiles.taskid is null
  and aj.job_type IN (1, 10, 40, 3)
  and aj.admin_task IS NULL
  and sched.schedule_id (+)= aj.schedule_id
  and joblist.scheduleuserid = usr.id(+)
  and pm_sched.id (+)= sched.schedule_id
  and pm_sched.userid = usr2.id(+)
  and pm_sched.rptgrpid = pm_RptGrp.id(+)
  and pm_sched.clientmachineid = pm_client.id(+)
  and (aj.cleanup_time is null OR aj.cleanup_time > SYSDATE);

exit;
