PROMPT Creating table exp_tab_def...
CREATE TABLE exp_tab_def (
  version        NUMBER,        -- For defining more than one set of metadata.
  table_name     VARCHAR2(30),
  ordinal        NUMBER,        -- First order import order.
  exists_action  VARCHAR2(7),   -- Action to be taken if an import row already exists.
  name_column    VARCHAR2(30),  -- Column to reference when a RENAME action is performed.
  key_source     VARCHAR2(30),  -- Sequence to reference on import of a new row.
  key_column     VARCHAR2(30),  -- Destination column for key_source values.
  permit_change  CHAR(1),
  change_column  VARCHAR2(30),
    CONSTRAINT exp_tab_def_pk PRIMARY KEY ( version, table_name ),
    CONSTRAINT exp_tab_def_keys_ck 
      CHECK ( ( key_source IS NULL ) OR
              ( key_source IS NOT NULL AND key_column IS NOT NULL ) ),
    CONSTRAINT exp_tab_def_name_ck
      CHECK ( ( exists_action = 'RENAME' AND name_column IS NOT NULL ) OR
              ( exists_action IN ( 'REUSE', 'REPLACE', 'REJECT', 'UPIFOWN' )))
) TABLESPACE wm_flexpm;
CREATE TABLE exp_tab_rel (
   version            NUMBER,       -- For defining more than one set of metadata.
   parent_table_name  VARCHAR2(30),
   parent_column_name VARCHAR2(30),
   child_table_name   VARCHAR2(30),
   child_column_name  VARCHAR2(30)
) TABLESPACE wm_flexpm;
PROMPT Creating table exp_def_tmp...
CREATE GLOBAL TEMPORARY TABLE exp_def_tmp (
  table_name   VARCHAR2(30),
  column_name  VARCHAR2(30),
  ordinal      NUMBER,
    CONSTRAINT exp_def_tmp_pk PRIMARY KEY ( table_name, column_name )
) ON COMMIT DELETE ROWS;
PROMPT Creating table exp_dest_tmp...
CREATE GLOBAL TEMPORARY TABLE exp_dest_tmp (
  id                ROWID,
  p_id              ROWID,
  new_id            ROWID,
  table_name        VARCHAR2(30),
  data              LONG,
    CONSTRAINT exp_dest_tmp_pk PRIMARY KEY ( id, table_name )
) ON COMMIT DELETE ROWS;
create index exp_dest_tmp_p_id_idx on exp_dest_tmp ( p_id );
PROMPT Creating table exp_key_trans_tmp...
CREATE GLOBAL TEMPORARY TABLE exp_key_trans_tmp (
  table_name  VARCHAR2(30),
  column_name VARCHAR2(30),
  old_key     NUMBER,
  new_key     NUMBER,
    CONSTRAINT exp_key_trans_tmp_pk 
      PRIMARY KEY ( TABLE_NAME, COLUMN_NAME, OLD_KEY ), 
    CONSTRAINT exp_key_trans_tmp_new_key_nn
      CHECK ( new_key IS NOT NULL )
) ON COMMIT DELETE ROWS;
PROMPT Creating table exp_ind_columns_tmp...
CREATE GLOBAL TEMPORARY TABLE exp_ind_columns_tmp (
  index_name VARCHAR2(30),
  column_expression LONG
) ON COMMIT DELETE ROWS;
PROMPT Creating table exp_tab_columns...
CREATE TABLE exp_tab_columns (
      version               NUMBER,
      is_key                NUMBER,
      parent_table_name     VARCHAR2(30),
      parent_column_name    VARCHAR2(30),
      child_table_name      VARCHAR2(30),
      child_column_name     VARCHAR2(30),
      data_type             VARCHAR2(106),
      parent_table_ordinal  NUMBER,
      child_table_ordinal   NUMBER,
      parent_column_order   NUMBER
) TABLESPACE wm_flexpm;
PROMPT Patch unique index on pm_cfgtpl...
CREATE UNIQUE INDEX unq_pm_cfgtpl ON pm_cfgtpl ( FOLDERID, UPPER("NAME"), CATEGORY, ENTITY_ID );
CREATE INDEX exp_tab_columns_par_idx ON exp_tab_columns( parent_table_name, parent_column_name );
CREATE INDEX exp_tab_columns_chi_idx ON exp_tab_columns( child_table_name, child_column_name );
CREATE INDEX exp_tab_def_tab_idx ON exp_tab_def( table_name );
CREATE INDEX exp_tab_rel_par_idx ON exp_tab_rel( parent_table_name, parent_column_name );
CREATE INDEX exp_tab_rel_chi_idx ON exp_tab_rel( child_table_name, child_column_name );
create index EXP_DEST_TMP_TAB_IDX on EXP_DEST_TMP(table_name);
PROMPT Patch trigger WMD_DICT_NAME_TR_BI...
CREATE OR REPLACE TRIGGER WMD_DICT_NAME_TR_BI
  BEFORE INSERT ON WMD_DICT_NAME FOR EACH ROW
BEGIN
   IF ( :NEW.Entity_ID IS NULL ) THEN
     SELECT Entity_ID INTO :new.Entity_ID
        FROM wmd_Field_Def WHERE Field_ID = :new.Field_ID;
   END IF;
END;
/
SHOW ERRORS
PROMPT Patch trigger WMQ_QUERY_TR_BI...
CREATE OR REPLACE TRIGGER WMQ_QUERY_TR_BI
  BEFORE INSERT ON WMQ_QUERY FOR EACH ROW
BEGIN
  IF ( :new.Query_ID IS NULL ) THEN
    SELECT wmq_Query_Seq.NextVal 
      INTO :new.Query_ID FROM DUAL;
  END IF;
END;
/
SHOW ERRORS
PROMPT Patch trigger WMD_FIELD_DEF_TR_BI...
CREATE OR REPLACE TRIGGER WMD_FIELD_DEF_TR_BI
  BEFORE INSERT ON WMD_FIELD_DEF FOR EACH ROW
BEGIN
  IF ( :new.Field_ID IS NULL ) THEN
    SELECT wmd_Field_Def_Seq.NextVal
      INTO :new.Field_ID FROM DUAL;
  END IF;
END;
/
SHOW ERRORS
PROMPT Patch trigger WMN_ENTITY_TR_BI...
create or replace trigger WMN_ENTITY_TR_BI BEFORE INSERT ON WMN_ENTITY FOR EACH ROW
DECLARE
   newID INTEGER;
BEGIN
  IF ( :new.Entity_ID IS NULL ) THEN
    SELECT wmn_Entity_Seq.NextVal INTO newID FROM DUAL;
    :new.Entity_ID := newID;
  END IF;
END;
/
SHOW ERRORS
PROMPT Patch trigger WMD_TECHNOLOGY_TR_BI...
create or replace trigger WMD_TECHNOLOGY_TR_BI BEFORE INSERT ON WMD_TECHNOLOGY FOR EACH ROW
DECLARE
   newID INTEGER;
BEGIN
  IF ( :new.Tech_ID IS NULL ) THEN
    SELECT wmd_Technology_Seq.NextVal INTO newID FROM DUAL;
    :new.Tech_ID := newID;
  END IF;
END;
/
SHOW ERRORS
PROMPT Create table exp_proc_log...
CREATE TABLE exp_proc_log ( 
  id number, 
  time date, 
  msg long
) TABLESPACE wm_flexpm;
PROMPT Create sequence exp_proc_log_seq...
create sequence exp_proc_log_seq order;
PROMPT Create procedure exp_log_proc...
create or replace procedure exp_log_proc wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
7
9200000
1
4
0 
e
2 :e:
1EXP_LOG_PROC:
1PV_MSG:
1VARCHAR2:
1PRAGMA:
1AUTONOMOUS_TRANSACTION:
1EXP_PROC_LOG:
1ID:
1TIME:
1MSG:
1EXP_PROC_LOG_SEQ:
1NEXTVAL:
1SYSDATE:
1INSERT into exp_proc_log ( id, time, msg ):n    values ( exp_proc_log_seq.nex+
1tval, sysdate, pv_msg ):
1COMMIT:
0

0
0
24
2
0 9a 8f a0 b0 3d b4 55
6a :2 a0 b4 5d :8 a0 12a a0 57
a0 b4 e9 b7 a4 b1 11 68
4f 1d 17 b5 
24
2
0 3 1f 1b 1a 27 17 2c
30 34 38 3c 3d 40 44 48
4c 50 54 58 5c 60 6c 70
75 79 7a 7f 81 85 87 93
97 99 9a a3 
24
2
0 b 19 20 :2 19 17 :3 1 8
:2 1 f 1e 22 28 e 1f 28
31 :6 3 :9 1 
24
4
0 :8 1 :4 2 :4 4
:4 5 4 :5 6 :2 3
:7 1 
a5
4
:3 0 1 :a 0 1f
1 :7 0 5 :2 0
:2 3 :3 0 2 :7 0
4 3 :3 0 6
:2 0 1f 1 7
:2 0 4 :3 0 5
:4 0 a b 1d
6 :3 0 7 :3 0
8 :3 0 9 :3 0
a :3 0 b :3 0
c :3 0 2 :4 0
d 1 :8 0 1b
e :3 0 18 19
:2 0 1a e :5 0
17 :2 0 1b 7
1e :3 0 1e a
1e 1d 1b 1c
:6 0 1f :2 0 1
7 1e 22 :3 0
21 1f 23 :8 0

c
4
:3 0 1 2 1
5 2 15 1a
1 c 
1
4
0 
22
0
1
14
1
2
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 
2 1 0
1 0 1
0

/
SHOW ERRORS
