-- ---------------------------------------------------------------
-- (#) ./base/db/Oracle8i/utility/create_util_trace.sql BL_core_schema_8.0.7_8.0.7.4.02_20100413  064938
-- (#) 
-- Script Name: create_util_trace.sql
-- Object Name: ut_tracing, ut_trace
-- Description: trace on/off table used in util_pack, and trace
--              table
-- ---------------------------------------------------------------
-- Modification Log:
-- Date         Programmer              Description
-- 09/04/02     B Griffith              Created
-- 05/03/07                             added gates
-- ---------------------------------------------------------------

CREATE TABLE  ut_tracing
(
  interface_name  VARCHAR2(32) NOT NULL
, turn_on_tracing NUMBER DEFAULT 0
, CONSTRAINT ut_tracing_pk  PRIMARY KEY ( interface_name))
;

COMMENT ON TABLE ut_tracing IS 
  'Turn on Trace table for a specific package';
COMMENT ON COLUMN  ut_tracing.interface_name IS 
  'Interface package name';
COMMENT ON COLUMN  ut_tracing.turn_on_tracing IS 
  '1=on 0=off';
  
insert into ut_tracing ( interface_name, turn_on_tracing )
               values    ( 'COMMON' ,1);

CREATE TABLE  ut_trace
(
  id                    NUMBER(9) NOT NULL
, msg                   VARCHAR2(240)
, pack_name             VARCHAR2(40)
, proc_name             VARCHAR2(40)
, time_stamp            DATE
, pid      		  NUMBER
, row_seq_id	      	  NUMBER
, lvl	      		  NUMBER
, CONSTRAINT ut_trace_pk  PRIMARY KEY ( pid, id));
COMMENT ON TABLE ut_trace IS 
  'Trace table for debugging';
COMMENT ON COLUMN  ut_trace.id IS 
  'row id';
COMMENT ON COLUMN  ut_trace.msg IS 
  'Message';
COMMENT ON COLUMN  ut_trace.pack_name IS 
  'calling package';
COMMENT ON COLUMN  ut_trace.proc_name IS 
  'procedure or function name';
COMMENT ON COLUMN  ut_trace.time_stamp IS 
  'date time created';
COMMENT ON COLUMN  ut_trace.pid IS 
  'process id';
COMMENT ON COLUMN  ut_trace.row_seq_id IS 
  'id of associated row';
COMMENT ON COLUMN  ut_trace.lvl IS 
  'lvl of trace';
  
create sequence ut_trace_s;
  
CREATE OR REPLACE TRIGGER t_bri_ut_trace  
    BEFORE INSERT  
    ON ut_trace  
    REFERENCING NEW AS NEW OLD AS OLD  
    FOR EACH ROW  
BEGIN
        IF :NEW.id IS NULL THEN
	    select ut_trace_s.nextval into :new.id from dual;
        END IF;
        :NEW.time_stamp := SYSDATE;
	IF :NEW.lvl IS NULL THEN
	   :NEW.lvl := 1;
        END IF;
		
END;
/

CREATE TABLE  ut_gate
(
  id                NUMBER(9) NOT NULL
, pid		    NUMBER(16) not NULL
, gate_name         VARCHAR2(240)
, gate_opened	    DATE
, gate_closed       DATE
, CONSTRAINT ut_gate_pk  PRIMARY KEY ( id)) ;

COMMENT ON TABLE ut_gate IS
  'Valdate upgrade process table';
COMMENT ON COLUMN  ut_gate.id IS 'row id';
COMMENT ON COLUMN  ut_gate.gate_name IS 'Gate Name';
COMMENT ON COLUMN  ut_gate.pid IS 'Process Id';
COMMENT ON COLUMN  ut_gate.gate_opened IS 'Gate opened';
COMMENT ON COLUMN  ut_gate.gate_closed IS 'Gate closed';

create sequence ut_gate_s;
  
CREATE OR REPLACE TRIGGER t_bri_ut_gate  
    BEFORE INSERT  
    ON ut_gate 
    REFERENCING NEW AS NEW OLD AS OLD  
    FOR EACH ROW  
BEGIN
        IF :NEW.id IS NULL THEN
	    select ut_gate_s.nextval into :new.id from dual;
        END IF;
        :NEW.gate_opened := SYSDATE;		
END;
/
