---------------------------------------------------------------------------
--
-- Licensed Materials - Property of IBM
-- 5724-T05,5724-T06
--
-- (C) Copyright IBM Corp. 2001, 2008. All Rights Reserved.
--
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
--
---------------------------------------------------------------------------
-- (#) ./base/dbuser/prospect_grants.sql BL_core_schema_8.0.7_8.0.7.4.02_20100413  064938
-- (#) 
--
remark USAGE:  sqlplus {DB_CONNECT} @grants.sql SYSPASSWD DBUSER DBSID
  
--sqlplus /nolog
  
--connect sys/&1@&3;

set verify off
set serveroutput on SIZE 500000 format wrapped
set feed off
  
Prompt Granting Privileges ...
  
Declare 
  Type vTable  IS TABLE OF VARCHAR2(500) INDEX BY Binary_Integer; 

  vCG vTable;
  vTG vTable;
  vOG vTable;
  vQG   vTable;
  vSOG vTable;

  vDba_users_rec  DBA_USERS%RowType;
  vSql Varchar2(600);
  vMax_Row INTEGER;
  vSchema VARCHAR2(30);
  
BEGIN
   
   SELECT Upper('&2') INTO vSchema FROM Dual;
   
   --  Privileges required to connect
   vCG(Nvl(vCG.last,0)+1) := 'grant create session ';
   vCG(Nvl(vCG.last,0)+1) := 'grant alter session ';

   -- unlimited tbs can't be granted to role
   vTG(Nvl(vTG.last,0)+1) := 'grant unlimited tablespace ';
   vTG(Nvl(vTG.last,0)+1) := 'grant alter tablespace ';

   -- Privileges required for object creation and from stored proc.
   vOG(Nvl(vOG.last,0)+1) := 'grant create table ';
   vOG(Nvl(vOG.last,0)+1) := 'grant create trigger ';
   vOG(Nvl(vOG.last,0)+1) := 'grant create view ';
   vOG(Nvl(vOG.last,0)+1) := 'grant query rewrite ';
   vOG(Nvl(vOG.last,0)+1) := 'grant create procedure ';
   vOG(Nvl(vOG.last,0)+1) := 'grant create sequence ';
   vOG(Nvl(vOG.last,0)+1) := 'grant create synonym ';
   vOG(Nvl(vOG.last,0)+1) := 'grant create type ';
   vOG(Nvl(vOG.last,0)+1) := 'grant create library ';
   vOG(Nvl(vOG.last,0)+1) := 'grant create any directory ';
   vOG(Nvl(vOG.last,0)+1) := 'grant drop any directory ';
   vOG(Nvl(vOG.last,0)+1) := 'grant create database link ';
   vOG(Nvl(vOG.last,0)+1) := 'grant create materialized view ';

   -- Privileges required for queue
   -- the administrator role  has all from aq_user_role
   vQG(Nvl(vQG.last,0)+1) := 'grant aq_administrator_role ';

   -- Privileges required for select, execute in stored proc.
   vSOG(Nvl(vSOG.last,0)+1) := 'grant execute on sys.aq$_agent ';
   vSOG(Nvl(vSOG.last,0)+1) := 'grant execute on sys.aq$_dequeue_history ';
   vSOG(Nvl(vSOG.last,0)+1) := 'grant execute on sys.aq$_dequeue_history_t ';
   vSOG(Nvl(vSOG.last,0)+1) := 'grant execute on sys.aq$_history ';
   vSOG(Nvl(vSOG.last,0)+1) := 'grant execute on sys.aq$_recipients ';
   vSOG(Nvl(vSOG.last,0)+1) := 'grant execute on sys.aq$_subscribers ';
   vSOG(Nvl(vSOG.last,0)+1) := 'grant execute any procedure ';
   vSOG(Nvl(vSOG.last,0)+1) := 'grant execute on sys.utl_file ';

   vSOG(Nvl(vSOG.last,0)+1) := 'grant execute on sys.dbms_alert ';
   vSOG(Nvl(vSOG.last,0)+1) := 'grant execute on sys.dbms_lock ';
   vSOG(Nvl(vSOG.last,0)+1) := 'grant execute on sys.dbms_aq ';
   vSOG(Nvl(vSOG.last,0)+1) := 'grant execute on sys.dbms_aqadm ';

   vSOG(Nvl(vSOG.last,0)+1) := 'grant select  on sys.v_$database ';
   vSOG(Nvl(vSOG.last,0)+1) := 'grant select  on sys.v_$parameter ';
   vSOG(Nvl(vSOG.last,0)+1) := 'grant select  on sys.v_$session ';
   vSOG(Nvl(vSOG.last,0)+1) := 'grant select  on sys.v_$tablespace ';
   vSOG(Nvl(vSOG.last,0)+1) := 'grant select  on sys.v_$datafile ';
   vSOG(Nvl(vSOG.last,0)+1) := 'grant select  on sys.dba_users ';

   -- SEAde46566
   -- DBMS_STATS.FLUSH_SCHEMA_MONITORING_INFO
   vSOG(Nvl(vSOG.last,0)+1) := 'grant execute on sys.dbms_stats ';
   vSOG(Nvl(vSOG.last,0)+1) := 'grant ANALYZE ANY ';

   Select * into vDBA_Users_Rec
     From DBA_USERS
     Where UserName = vSchema;
   
   Dbms_Output.Put_Line (' ');
   Dbms_Output.Put_Line ('User Name                Account Status           Date Created');
   Dbms_Output.Put_Line ('-------------------      ------------------       --------------------');
   Dbms_Output.Put_Line (Rpad(vDba_users_rec.UserName,25,' ') || Rpad(vDba_users_rec.Account_Status,25,' ') || To_Char(vDba_users_rec.Created,'yyyy-Mon-dd hh24:mi:ss') );
   Dbms_Output.Put_Line (' ');

   Dbms_Output.Put_line ('Granting Connect Privileges ...');
   vMax_Row := vCG.Count;

   For I in 1..vMax_Row
   Loop
      Begin
         vSql := vCG(I) || ' TO ' || vSchema;
         Execute Immediate vSql;
      Exception
         When Others Then
           Dbms_output.put_line ('ERROR : ' || vSql );
           Dbms_output.put_line (SQLERRM);
           Dbms_Output.Put_Line (' ');
      End;
   End Loop;
   
   Dbms_Output.Put_line ('Granting Tablespace Privileges ...');
   vMax_Row := vTG.Count;

   For I in 1..vMax_Row
   Loop
      Begin
         vSql := vTG(I) || ' TO ' || vSchema;
         Execute Immediate vSql;
      Exception
         When Others Then
           Dbms_output.put_line ('ERROR : ' || vSql );
           Dbms_output.put_line (SQLERRM);
           Dbms_Output.Put_Line (' ');
      End;
   End Loop;
   
   Dbms_Output.Put_line ('Granting Queue Privileges ...');
   vMax_Row := vQG.Count;

   For I in 1..vMax_Row
   Loop
      Begin
         vSql := vQG(I) || ' TO ' || vSchema;
         Execute Immediate vSql;
      Exception
         When Others Then
           Dbms_output.put_line ('ERROR : ' || vSql );
           Dbms_output.put_line (SQLERRM);
           Dbms_Output.Put_Line (' ');
      End;
   End Loop;
   
   Dbms_Output.Put_line ('Granting Object Privileges ...');
   vMax_Row := vOG.Count;

   For I in 1..vMax_Row
   Loop
      Begin
         vSql := vOG(I) || ' TO ' || vSchema;
         Execute Immediate vSql;
      Exception
         When Others Then
           Dbms_output.put_line ('ERROR : ' || vSql );
           Dbms_output.put_line (SQLERRM);
           Dbms_Output.Put_Line (' ');
      End;
   End Loop;
   
   Dbms_Output.Put_line ('Granting Stored Object Privileges ...');
   vMax_Row := vSOG.Count;

   For I in 1..vMax_Row
   Loop
      Begin
         vSql := vSOG(I) || ' TO ' || vSchema;
         Execute Immediate vSql;
      Exception
         When Others Then
           Dbms_output.put_line ('ERROR : ' || vSql );
           Dbms_output.put_line (SQLERRM);
           Dbms_Output.Put_Line (' ');
      End;
   End Loop;
   
   Dbms_Output.Put_Line ('All Prospect Owner Grants Completed ');
   Dbms_Output.Put_Line (' ');
Exception
   When NO_DATA_FOUND THEN
     Dbms_Output.Put_Line (' ');
     Dbms_Output.Put_Line ('"' || vSchema ||'"  SCHEMA DOES NOT EXISTS'); 
     Dbms_Output.Put_Line (' ');
End;
/

Exit;

EOF
  


--
------------------------------------------------------------------------
--
-- Local Variables:
-- mode: pls
-- End:

