#-----------------------------------------------------------------------
# (#) ./base/ds/scripts/Entity_fx.pm BL_core_schema_8.0.7_8.0.7.4.02_20100413  064938
# (#) 
# Copyright 2003 WatchMark Corp.
#-----------------------------------------------------------------------
#
package Entity_fx;

use English;
use File::Copy;

my @entityList;
my %entityData;
my %entityGroup;

my $outputDir;
my $connectString;
my $exc_file;
my $alert_prefix;

sub read_ent;
sub read_fld;
sub read_exceptions;
sub make_def;
sub make_tpl;
sub make_alert;


sub start
{  

  ($connectString, $outputDir, $exc_file, $alert_prefix) = @_;

  # Get the directory for output
  defined $outputDir or $outputDir='.';
  defined $alert_prefix or $alert_prefix = "_UPDATE";

  # create/check output dir
  #    check for reqd files?
  # set permissions on output files:
  #     def.txt
  #     ds.alert
  #     rep.def

  # Read Entity Group Template
  read_group_tpl( "$outputDir/templates/EntityGroup.tpl" );

  # Read Entity data from Oracle
  read_ent;
  # Read field info from Oracle
  read_fld;
  # Read file of exception info (if exists)
  defined $exc_file and read_exceptions;

  # write the ds.alert file
  make_alert;
  # write the def.txt and rep.def files
  make_def;
  # write the template (.tpl) files
  make_tpl;
}

sub read_ent {

  print "Read Entity Data\n";

  # Get Entity info from Oracle
  my @resultSet = `sqlplus -s $connectString \<<EOF
SET FEEDBACK OFF
SET TAB OFF
SET COLSEP |
SET PAGESIZE 0
SET LINESIZE 32767
SELECT ent.Entity_Name, ent.IsGroup, ent.Entity_Table, ent.DefaultNameExpr, 
       ent.LabelExpr, ent.EntityOrderExpr, ent.EntityOrderNum, par.Entity_Name
  FROM wmn_Entity ent, wmn_Entity_Context ec, wmn_Entity par
  WHERE ent.Entity_ID = ec.Entity_ID
    AND ec.Context_ID = wm_Network.Get_Context('Scenario')
    AND ec.parent_entity_id = par.Entity_ID (+)
  ORDER BY EntityOrderNum;
EXIT;
EOF`;


  # Split up each line of data into fields
  for ( my $ind = 0; $ind <= $#resultSet; $ind++ ) {
    chomp $resultSet[ $ind ];
    
    #  print "In  = ", $resultSet[ $ind ], "\n";
    my @setFields = split /\|/, $resultSet[ $ind ];
    for ( my $setInd = 0; $setInd < $#setFields; $setInd++ ) {
      $setFields[ $setInd ] =~ s/(\s+$|^\s+)//g;
    }
    my ( $entityName, $grp, $table, $defName, $label, $entOrder, $orderNum, $parent ) = @setFields;
    
    # Use entitylist for ordering output
    push @entityList, $entityName;
    # save all the known info
    $entityData{ $entityName } = { Group => ( $grp eq 'y' ),
				   DefaultName => $defName,
				   LabelExpr => $label,
				   OrderExpr => $entOrder,
				   OrderNum => $orderNum };
    # Only define parent hash key if a parent exists
    defined $parent and $entityData{ $entityName }->{ Parent } = $parent;
    # Only define entity table hash key if an entity table exists
    defined $table and $table ne '' and $entityData{ $entityName }->{ Table } = $table;
    
    #  printf "Name='%s', Group?= %s, Table='%s', OrderNum=%i", $entityName, $grp, $table, $orderNum;
    #  defined $parent and printf ", Parent='%s'", $parent;
    #  printf "\n   Def='%s'\n   Lbl='%s'\n   Ord='%s'\n", $defName, $label, $entOrder;
  }
  print "Read Entity Data -- COMPLETE\n";
}


sub read_fld {

  print "Read Field Data\n";

  # Get Entity info from Oracle
  my @resultSet = `sqlplus -s $connectString \<<EOF
SET FEEDBACK OFF
SET TAB OFF
SET COLSEP |
SET PAGESIZE 0
SET LINESIZE 32767
SELECT ent.Entity_Name, fld.Field_Name, tab.Table_Name, fld.Table_Column, fld.Field_DataType, fld.Field_Type
  FROM wmd_Dict_Field fld, wmn_Entity ent, wmd_Dict_Table tab
  WHERE DataSource_ID = ( SELECT DataSource_ID FROM wmd_Data_Source WHERE DataSource_Name = 'Client' )
    AND fld.Entity_ID = ent.Entity_ID
    AND fld.Table_ID = tab.Table_ID
  ORDER BY ent.Entity_Name, fld.Field_Name;
EXIT;
EOF`;


  # Split up each line of data into fields
  for ( my $ind = 0; $ind <= $#resultSet; $ind++ ) {
    chomp $resultSet[ $ind ];
    
    #  print "In  = ", $resultSet[ $ind ], "\n";
    my @setFields = split /\|/, $resultSet[ $ind ];
    for ( my $setInd = 0; $setInd < $#setFields; $setInd++ ) {
      $setFields[ $setInd ] =~ s/(\s+$|^\s+)//g;
    }
    my ( $entityName, $fieldName, $tableName, $tableColumn, $dataType, $fieldType ) = @setFields;
    
    if ( not exists $entityData{ $entityName } ) {
      printf "** Warning: Entity %s in Client Dictionary, but not in Template list\n", $entityName;
    } 
    elsif ( $fieldType ne 'C' ) {
      printf "** Warning: Field %s.%s has Field_Type of '%s' - should be 'C'\n", $entityName, $fieldName, $fieldType;
    }
    elsif ( uc $tableName eq 'WMN_INSTANCE' or 
	    ( exists $entityData{ $entityName }->{ Table } and uc $entityData{ $entityName }->{ Table } eq uc $tableName ) ) {
      $entityData{ $entityName }->{ Fields }->{ $fieldName } = { Table => $tableName,
								 Column => $tableColumn,
								 DataType => $dataType };
    }
    else {
      $entityData{ $entityName }->{ Fields }->{ $fieldName } = { Table => $tableName,
								 Column => $tableColumn,
								 DataType => $dataType };
      if ( exists $entityData{ $entityName }->{ OtherTables } ) {
	my $found = 0;
	for ( my $tableID = 0; $tableID < $#{  $entityData{ $entityName }->{ OtherTables } }; $tableID++ ) {
	  if ( uc $tableName eq uc $entityData{ $entityName }->{ OtherTables }->[ $tableID ] ) {
	    $entityData{ $entityName }->{ Fields }->{ $fieldName }->{ TableID } = $tableID;
	    $found = 1;
	    last;
	  }
	}
	if ( not $found ) {
	  push @{ $entityData{ $entityName }->{ OtherTables } },  $tableName;
	  $entityData{ $entityName }->{ Fields }->{ $fieldName }->{ TableID } = $#{ $entityData{ $entityName }->{ OtherTables } };
	}
      }
      else {
	$entityData{ $entityName }->{ OtherTables } = [ $tableName ];
	$entityData{ $entityName }->{ Fields }->{ $fieldName }->{ TableID } = 0;
      }
      #printf "** Warning: Field %s.%s uses table '%s' which is not the Entity Table\n", $entityName, $fieldName, $tableName;
    }
  }
  print "Read Field Data -- COMPLETE\n";
}


sub read_exceptions{
  my %DataTypeConvert = ( FLOAT => "F", INT => "I", STRING => "S" );

  if ( -f $exc_file ) {

     print "Read exceptions file '$exc_file'\n";
   
     open EXCFILE, "<$exc_file" or die "Can't open exception file '$exc_file' for input\n";
     while ( <EXCFILE> ) {
       next if m/^\#/;
       chomp;
       my @excList = split;
   
       for ( my $listInd = 0; $listInd < $#excList; $listInd++ ) {
         if ( $excList[ $listInd ] =~ m/^[^\"]*\"[^\"]*$/ ) {
   	splice @excList, $listInd, 0, join(' ', splice( @excList, $listInd, 2 ) );
   	redo;
         }
       }
       my ( $entityName, $dataType, $fieldName, $alias ) = @excList;
   
   
       if ( exists $DataTypeConvert{ $dataType } ) {
         if ( exists $entityData{ $entityName } ) {
   	$entityData{ $entityName }->{ Fields }->{ $fieldName } = { Alias => $alias,
   								   DataType => $DataTypeConvert{ $dataType } };
         }
         else {
   	printf "** Warning: Exception entity '%s' is undefined - %s.%s record rejected\n", $entityName, $entityName, $fieldName;
         }
       }
       else {
         printf "** Warning: Exception data type '%s' is undefined - %s.%s record rejected\n", $dataType, $entityName, $fieldName;
       }
     }
     close EXCFILE;
     print "Read exceptions file '$exc_file' -- COMPLETE\n";
   }
   else {
      print "** Warning: Exceptions file is invalid, skipping\n";
   }
}


sub make_def {
  print "Write def.txt\n";
  open DEFFILE, ">$outputDir/def.txt" or die "Can't open $outputDir/def.txt for output\n";

  # 
  my @templateList = @entityList;

  push @templateList, "EntityType", "EntityDataAttributes";

  print "Write rep.def\n";
  open REPFILE, ">$outputDir/rep.def" or die "Can't open $outputDir/rep.def for output\n";
  foreach my $entityName ( @templateList ) {
    printf REPFILE "%s\tDATABASE\tTest\n", $entityName;
  }
  close REPFILE;
  print "Write rep.def -- COMPLETE\n";

  unshift @templateList, "EntityGroup";

  print DEFFILE "\n# User defined template files start here.\n\n";
  foreach my $entityName ( @templateList ) {
    printf DEFFILE "TEMPLATE  ./templates/%s.tpl\n", $entityName;
  }
  print DEFFILE "\n# File that lists which database contains each package.\n";
  print DEFFILE "REPOSITORYFILE rep.def\n";
  print DEFFILE "\n# File containing a list of the databases that are available.\n";
  print DEFFILE "DATABASEFILE db.txt\n";
  close DEFFILE;
  print "Write def.txt -- COMPLETE\n";
}


sub make_alert {
  print "Write ds.alerts\n";

  open ALERTFILE, ">$outputDir/ds.alert" or die "Can't open $outputDir/ds.alert for output\n";

  printf ALERTFILE "        (ALERT \$Connect.schema (STRING _SCENARIO_UPDATE)\n";
  printf ALERTFILE "          (SEND EntityDataAttributes)\n";
  printf ALERTFILE "          (SEND EntityType)\n";

  foreach my $entityName ( sort @entityList ) {
    printf ALERTFILE "          (SEND %s)\n", $entityName;
  }
  printf ALERTFILE "        )\n";

  foreach my $entityName ( @entityList ) {
    if ( not $entityData{ $entityName }->{ Group } ) {
      printf ALERTFILE "        (ALERT \$Connect.schema (STRING %s_%s)\n", uc $alert_prefix, uc $entityName;
      printf ALERTFILE "          (SEND %s)\n", $entityName;
      my $parentName = $entityData{ $entityName }->{ Parent };
      while ( defined $parentName and $entityData{ $parentName }->{ Group } ) {
	printf ALERTFILE "          (SEND %s)\n", $parentName;
	$parentName = $entityData{ $parentName }->{ Parent };
      }
      printf ALERTFILE "        )\n";
    }
  }
  close ALERTFILE;
  print "Write ds.alerts -- COMPLETE\n";
}


sub make_tpl {
  my %DataTypeConvert = ( F => "FLOAT", I => "INT", S => "STRING", E => "STRING" );
  my $group_name;

  foreach my $entityName ( @entityList ) {
    print "Write $entityName.tpl\n";
    open TPLFILE, ">$outputDir/templates/$entityName.tpl" or die "Can't open $outputDir/templates/$entityName.tpl for output\n";
    print TPLFILE "PACKAGE $entityName\n";
    print TPLFILE "{\n";

    if ( $entityData{ $entityName }->{ Group } ) {
      $group_name = "EntityNoDataGroup";
    }
    else {
      $group_name = "EntityGroup";
    }
    print TPLFILE "   GROUP $group_name\n";

    if ( exists $entityData{ $entityName }->{ Fields } ) {
      foreach my $fieldName ( sort keys %{ $entityData{ $entityName }->{ Fields } } ) {

        unless ( exists $entityGroup{ $group_name }->{ $fieldName } )
        {
           my $fldRef = $entityData{ $entityName }->{ Fields }->{ $fieldName };
           my $dataType = 'STRING' ;
           exists $DataTypeConvert{ $fldRef->{ DataType } } or printf "** Warning: Can't find datatype '%s' for %s.%s using STRING\n", $fldRef->{ DataType }, $entityName, $fieldName;
           exists $DataTypeConvert{ $fldRef->{ DataType } } and $dataType =  $DataTypeConvert{ $fldRef->{ DataType } };
           if ( exists $fldRef->{ Alias } ) {
             printf TPLFILE "   %-10s   %-15s ALIAS %s\n", $dataType, $fieldName, $fldRef->{ Alias };
           }
           elsif ( exists $fldRef->{ TableID } ) {
             printf TPLFILE "   %-10s   %-15s ALIAS tab%03i.%s\n", $dataType, $fieldName, $fldRef->{ TableID }, $fldRef->{ Column };
           }
           else {
             my $tableName = 'enttab';
             $fldRef->{ Table } eq 'WMN_INSTANCE' and $tableName = 'ins';
             printf TPLFILE "   %-10s   %-15s ALIAS %s.%s\n", $dataType, $fieldName, $tableName, $fldRef->{ Column };
           }
        }

      }
    }
    if ( exists $entityData{ $entityName }->{ Parent } ) {
      printf TPLFILE "   RELATION     ParentId        ALIAS inscxt.ParentInstance_ID %s PARENT\n", $entityData{ $entityName }->{ Parent };
    }
    print TPLFILE "}\n";
    print TPLFILE "CONDITION\n";
    print TPLFILE "\"FROM      \n";
    print TPLFILE "     wmn_entity   ent,\n";
    print TPLFILE "     wmn_context  cxt,\n";
    if ( exists $entityData{ $entityName }->{ Table } ) {
      printf TPLFILE "     %s enttab,\n", $entityData{ $entityName }->{ Table };
    }
    if ( exists $entityData{ $entityName }->{ OtherTables } ) {
      for ( my $tableID = 0; $tableID <= $#{  $entityData{ $entityName }->{ OtherTables } }; $tableID++ ) {
	printf TPLFILE "     %s tab%03i,\n", $entityData{ $entityName }->{ OtherTables }->[ $tableID ], $tableID ;
      }
    }
    print  TPLFILE "     wmn_instance ins,\n";
    print  TPLFILE "     wmn_instance_context inscxt\n";
    printf TPLFILE "WHERE ent.entity_name = '%s'\n", $entityName;
    print  TPLFILE "  and cxt.context_use = 'S'\n";
    print  TPLFILE "  and ent.entity_id = ins.entity_id\n";
    print  TPLFILE "  and ent.entity_id = inscxt.entity_id\n";
    print  TPLFILE "  and cxt.context_id = inscxt.context_id\n";
    print  TPLFILE "  and ins.instance_id = inscxt.instance_id";
    if ( exists $entityData{ $entityName }->{ Table } ) {
      print  TPLFILE "\n";
      print  TPLFILE "  and ins.instance_id = enttab.instance_id\n";
      print  TPLFILE "  and inscxt.instance_id = enttab.instance_id";
    }
    if ( exists $entityData{ $entityName }->{ OtherTables } ) {
      for ( my $tableID = 0; $tableID <= $#{  $entityData{ $entityName }->{ OtherTables } }; $tableID++ ) {
	print  TPLFILE "\n";
	printf TPLFILE "  and ins.instance_id = tab%03i.instance_id (+)", $tableID ;
      }
    }
    print  TPLFILE ";\"\n";

    close TPLFILE;
    print "Write $entityName.tpl -- COMPLETE\n";
  }  
}


#---------------------------------------------------------------------------
sub read_group_tpl($)
#---------------------------------------------------------------------------
{
   my $xfile = shift;

   my @splitter;
   my $group_name;

   print "Read Entity Group Template\n";

   open (EGFILE, "< $xfile") or die "Cannot open $xfile for reading.";
   while ( <EGFILE> )
   {

      chomp;
      if ( $_ =~/\s+[a-zA-Z]/ )
      {
         if ( $_ =~ /^GROUP / )
         {
            @splitter = split(' ', $_, 2);
            $group_name = $splitter[1];
            $entityGroup{ $group_name } = {};
         }
         else
         {
            @splitter = split(' ', $_, 3);
            $entityGroup{ $group_name }->{ $splitter[1] } = 'XYZ';
         }

      }

   }

   close(EGFILE);

   print "Read Entity Group Template -- COMPLETE\n";

}

1;
