#---------------------------------------------------------
# (#) ./base/ds/scripts/TemplateField_fx.pm BL_core_schema_8.0.7_8.0.7.4.02_20100413  064938
# (#) 
# COPYRIGHT 2003 WatchMark Corp.
#---------------------------------------------------------
#
# This script would generate PACKAGEs TemplateField.tpl
# and TemplateFieldExtraColumn.tpl. It will also update
# def.txt and rep.def
#
# Execute from makefx.pl
#
# ENV dependencies:
#    DB_CONNECT
#
# Assumptions:
#    Templates directory is <FX_DIR param>/templates
#    Def file is def.txt
#
# NOTES:
# See SEAde39524 for details
#
package TemplateField_fx;

#Updated 11/02/2009 - valnt00077479

use Env;
use File::Basename;
use File::Copy;

my $SCRIPT_ID   = basename($0);

my $DB_CONNECT; # set at runtime via params
my $DBUSER;     # set at runtime
my $DBPASSWD;   # set at runtime
my $DBSID;      # set at runtime

my $FX_DIR;     # set at runtime via params
my $TPL_DIR;    # set at runtime

my $TFL_NAME     = "TemplateField";
my $TFL_FILENAME = "$TFL_NAME.tpl";
my $TFX_NAME     = "TemplateFieldExtraColumn";
my $TFX_FILENAME = "$TFX_NAME.tpl";
my $DEF_FILENAME = "def.txt";
my $REP_FILENAME = "rep.def"; # Default. May be changed at runtime
my $DBS_NAME     = "Test";    # Default. may be changed at runtime
my $DBS_FILENAME = "db.txt";  # Default. May be changed at runtime
my $TEMP_FILE    = "/tmp/$SCRIPT_ID.$$.tmp";

my $DELIMITER     = '|';
my $DELIMITER_ESC = '\|';


#---------------------------------------------------------------------------
sub set_dbname()
#---------------------------------------------------------------------------
{
   my $xline;
   my $dbname;
   my $restofline;

   if ( open ( DBTXT, "< $FX_DIR/$DBS_FILENAME") )
   {
      while ( <DBTXT> )
      {
         chomp;
         $xline = $_;

         if ( $xline !~ /^\s+#/ )
         {
            ( $dbname, $restofline) = split(' ', $_, 2);
            if ( defined $dbname )
            {
               $DBS_NAME = $dbname;
            }
         }
      }
      close DBTXT;
   }
   else
   {
      # Database File does not exists. Try to create one.
      #
      open ( DBTXT, "> $FX_DIR/$DBS_FILENAME")
         or main::error_out("Cannot open $FX_DIR/$DBS_FILENAME for writing");
      print DBTXT "$DBS_NAME\t$DBSID\t$DBUSER\n";
      close DBTXT;
   }
}

#---------------------------------------------------------------------------
sub create_templatefield_tpl()
#---------------------------------------------------------------------------
{
   my @spiltFields;
   my $PrvDataSource = -5678;
   my $SubFromSQL = '';
   my $b4_1stgroup = 1;

   print "Write $TFL_FILENAME\n";

   my @SQLResult =  `sqlplus -s /NOLOG <<EOF | grep -v Connected
      connect $DB_CONNECT
      SET FEEDBACK OFF
      SET TAB OFF
      SET HEAD OFF
      SET COLSEP |
      SET PAGESIZE 0
      SET LINESIZE 32767
   
      select TemplateField_fx.build_FXPackage_text
        from dual
           ;
      
      exit
   EOF`;

   open( TPLFILE, "> $TPL_DIR/$TFL_FILENAME")
      or main::error_out("Cannot open $TPL_DIR/$TFL_FILENAME for writing.");

   for ( my $ind = 0; $ind <= $#SQLResult; $ind++ )
   {
      print TPLFILE "$SQLResult[$ind]";
   }

   close TPLFILE;

   print "Write $TFL_FILENAME -- COMPLETE\n";

}

#---------------------------------------------------------------------------
sub create_extracolumn_tpl()
#---------------------------------------------------------------------------
{
   print "Write $TFX_FILENAME\n";

   open( TPLFILE, "> $TPL_DIR/$TFX_FILENAME")
      or main::error_out("Cannot open $TPL_DIR/$TFX_FILENAME for writing.");

   print TPLFILE qq(PACKAGE TemplateFieldExtraColumn) . "\n";
   print TPLFILE qq({) . "\n";
   print TPLFILE qq(   STRING   Id           ALIAS "to_char(e.DATASOURCE_ID)||to_char(e.E_TYPE)||to_char(e.E_ID)||e.COL_TITLE") . "\n";
   print TPLFILE qq(   INT      DatasourceId ALIAS "e.DATASOURCE_ID") . "\n";
   print TPLFILE qq(   STRING   FieldName    ALIAS "translate(e.COL_TITLE, ' 	!@#\$\%^&*()+|-=\\~`;:,.?/''','___________________________')") . "\n";
   print TPLFILE qq(   STRING   ColumnHeader ALIAS "e.COL_TITLE") . "\n";
   print TPLFILE qq(   STRING   Editable     ALIAS "e.EDITABLE") . "\n";
   print TPLFILE qq(}) . "\n";
   print TPLFILE qq(CONDITION) . "\n";
   print TPLFILE qq("FROM) . "\n";
   print TPLFILE qq(      WMD_DATASOURCE_EXTRA_COLS e) . "\n";
   print TPLFILE qq(;") . "\n";

   close TPLFILE;

   print "Write $TFX_FILENAME -- COMPLETE\n";
}

#---------------------------------------------------------------------------
sub write_template()
#---------------------------------------------------------------------------
{

   create_templatefield_tpl();
   create_extracolumn_tpl();

}

#---------------------------------------------------------------------------
sub write_def()
#---------------------------------------------------------------------------
{
   my $Field1;
   my $Field2;
   my $FieldRest;
   my $xline;
   my $tpl_written = 0;

   print "Update $DEF_FILENAME\n";

   if ( !open ( DEFFILE, "< $FX_DIR/$DEF_FILENAME"))
   {
      # Def File does not exists. Try to create one.
      #
      open ( DEFFILE, "> $FX_DIR/$DEF_FILENAME")
         or main::error_out("Cannot open $FX_DIR/$DEF_FILENAME for writing");

      print DEFFILE "# User defined template files start here.\n";
      print DEFFILE "TEMPLATE  ./templates/$TFL_FILENAME\n";
      print DEFFILE "TEMPLATE  ./templates/$TFX_FILENAME\n";
      print DEFFILE "\n";
      print DEFFILE "# File that lists which database contains each package.\n";
      print DEFFILE "REPOSITORYFILE $REP_FILENAME\n";
      print DEFFILE "\n";
      print DEFFILE "# File containing a list of the databases that are available.\n";
      print DEFFILE "DATABASEFILE $DBS_FILENAME\n";

      close DEFFILE;

   }
   else
   {

      open ( TMPFILE, "> $TEMP_FILE")
         or main::error_out("Cannot open $TEMP_FILE for writing");
   
      while ( <DEFFILE> )
      {
         chomp;
         $xline = $_;
   
         ( $Field1, $Field2, $FieldRest) = split(' ', $xline, 3);
   
         if ( $xline =~ /^REPOSITORYFILE/ )
         {
            # Repository filename is defined here.
            # Override the default
            #
            $REP_FILENAME = $Field2;
         }
         if ( $xline =~ /^DATABASEFILE/ )
         {
            # Database filename is defined here.
            # Override the default
            #
            $DBS_FILENAME = $Field2;
         }
         elsif ( $xline =~ /^TEMPLATE/ )
         {
   
            if ( $Field2 eq "./templates/$TFL_FILENAME" ||
                 $Field2 eq "./templates/$TFX_FILENAME" 
               )
            {
               next;
            }
            elsif (!$tpl_written)
            {
               print TMPFILE "TEMPLATE  ./templates/$TFL_FILENAME\n";
               print TMPFILE "TEMPLATE  ./templates/$TFX_FILENAME\n";
               $tpl_written = 1;
            }
         }
   
         print TMPFILE "$xline\n";
   
      }
   
      close DEFFILE;
      close TMPFILE;
   
      copy( "$TEMP_FILE", "$FX_DIR/$DEF_FILENAME")
         or main::error_out("Cannot copy $TEMP_FILE to $FX_DIR/$DEF_FILENAME");
   }

   print "Update $DEF_FILENAME -- COMPLETE\n";

}

#---------------------------------------------------------------------------
sub write_rep()
#---------------------------------------------------------------------------
{
   my $Field1;
   my $Field2;
   my $Field3;
   my $FieldRest;
   my $xline;
   my $tpl_written = 0;

   print "Update $REP_FILENAME\n";

   if ( !open ( REPFILE, "< $FX_DIR/$REP_FILENAME"))
   {
      # Repository File does not exists. Try to create one.
      #
      open ( REPFILE, "> $FX_DIR/$REP_FILENAME")
         or main::error_out("Cannot open $FX_DIR/$REP_FILENAME for writing");

      print REPFILE "$TFL_NAME\tDATABASE\t$DBS_NAME\n";
      print REPFILE "$TFX_NAME\tDATABASE\t$DBS_NAME\n";

      close REPFILE;

   }
   else
   {

      open ( TMPFILE, "> $TEMP_FILE")
         or main::error_out("Cannot open $TEMP_FILE for writing");
   
      while ( <REPFILE> )
      {
         chomp;
         $xline = $_;
   
         ( $Field1, $Field2, $Field3, $FieldRest) = split(' ', $xline, 4);
   
         if ( defined $Field1 )
         {
            if ( $Field1 ne $TFL_NAME && $Field1 ne $TFX_NAME )
            {
               print TMPFILE "$xline\n";
            }
         }
   
      }
   
      print TMPFILE "$TFL_NAME\tDATABASE\t$DBS_NAME\n";
      print TMPFILE "$TFX_NAME\tDATABASE\t$DBS_NAME\n";
   
      close REPFILE;
      close TMPFILE;
   
      copy( "$TEMP_FILE", "$FX_DIR/$REP_FILENAME")
         or main::error_out("Cannot copy $TEMP_FILE to $FX_DIR/$REP_FILENAME");

   }

   print "Update $REP_FILENAME -- COMPLETE\n";

}

   
#---------------------------------------------------------------------------
sub start($$)
#---------------------------------------------------------------------------
{
   $DB_CONNECT = shift;
   $FX_DIR     = shift;
   $TPL_DIR    = "$FX_DIR/templates";

   my $uspwd;

   ($uspwd, $DBSID) = split('\@', $DB_CONNECT, 2);
   ($DBUSER, $DBPASSWD) = split('/', $uspwd, 2);

   write_template();
   write_def();
   set_dbname();
   write_rep();

   unlink($TEMP_FILE);

}

1;
