#!/usr/bin/env perl
#-----------------------------------------------------------------------
# (#) ./base/ds/scripts/makefx.pl BL_core_schema_8.0.7_8.0.7.4.02_20100413  064938
# (#) 
# Copyright 2003 WatchMark Corp.
#-----------------------------------------------------------------------
#

#
#

BEGIN {
  use File::Basename;
  unshift @INC, dirname($0);
}

use DBI;
#Updated 11/02/2009 - valnt00077479
use pass_crypt;
use Entity_fx;
use TemplateField_fx;

use Getopt::Long;
use Env;

my $DBUSER      = $ENV{'DBUSER'}   || 'NO-USER';
my $DBPASSWD    = pass_crypt::getValue($DBUSER) || 'NO-PASSWD';
my $DBSID       = $ENV{'DBSID'}    || 'NO-SID';
my $DB_CONNECT  = pass_crypt::getConnectForUser($DBUSER);

my $SCRIPT_ID   = basename($0);

my $FX_DIR;
my $EXC_FILE;
my $ALERT_PREFIX;

#----------------------------------------------------------------------
sub show_usage
#----------------------------------------------------------------------
{
   print STDERR "Usage:\n";
   print STDERR "$SCRIPT_ID --help\n";
   print STDERR "$SCRIPT_ID [--dir <targetdir>][--alert_prefix <alert>][--exc <excfile>]\n";
   print STDERR "\n";
   print STDERR "Where:\n";
   print STDERR "<targetdir>  : The target directory for the out put files. This \n";
   print STDERR "               would usually be the FX directory (\$FLEXPM_HOME/ds/fx)\n";
   print STDERR "               If not specified, the default is the current directory.\n";
   print STDERR "<alert>      : The prefix for the DBMS_ALERT. Default is \"_UPDATE\"\n";
   print STDERR "<excfile>    : Exception file (for systems that have exceptions)\n";
   print STDERR "\n";
}

#----------------------------------------------------------------------
sub error_out($)
#----------------------------------------------------------------------
{
   $error_message = shift;

   die "$SCRIPT_ID: $error_message\n";
}

#----------------------------------------------------------------------
sub DBSystemValues
#----------------------------------------------------------------------
{

  # Set the datasource.

  my $data_source = "dbi:Oracle:$DBSID";

  # Get a handle to a connection. Set RaiseError ON 
  # so we don't have to test every method for errors.

  my $dbh = DBI->connect($data_source, 
			 $DBUSER, 
			 $DBPASSWD, 
			 { RaiseError => 1 });

  # Check to see if this option was set on the command line.

  if ( ! defined $EXC_FILE ) {
    print "Checking DB for exclusion file name...\n";

    # Select the system variable from the database.

    $statement = " SELECT name, value " .
                 "   FROM wm_system_values_v " .
	         "  WHERE UPPER( name ) = UPPER( \'ExclusionFile\' ) ";
    my $sth = $dbh->prepare( $statement );
    my $rc = $sth->execute;

    # Loop over the result set. Even though we're expecting only
    # one row, the loop will save us from having to test for zero
    # rows returned. This is nice because NULL is neither def nor undef!

    while (($attribute, $value) = $sth->fetchrow_array)  {

      # Only define the EXC_FILE if we have a non-NULL $value
      if ( defined $value ) { 

         print "$attribute = $value\n";

         # Assign the result!
         $EXC_FILE = $ENV{'FLEXPM_HOME'} . '/' . $value;
      }
    }

    # Free up the statement handle now - because were 
    # going to reuse it very soon.

    $sth->finish;
  }

  if ( ! defined $ALERT_PREFIX ) {
    print "Checking DB for alert prefix name...\n";
    $statement = " SELECT name, value " .
                 "   FROM wm_system_values_v " .
                 "  WHERE UPPER( name ) = UPPER( \'AlertPrefix\' ) ";
    my $sth = $dbh->prepare( $statement );
    my $rc = $sth->execute;

    while (($attribute, $value) = $sth->fetchrow_array)  {
      if ( ! defined $value ) 
	{ $value = ''; } 
      else 
	{ $value = '_' . $value; }
      print "$attribute = $value\n";
      $ALERT_PREFIX = $value;
    }
    $sth->finish;
  }
  
  $dbh->disconnect;

}

#----------------------------------------------------------------------
sub DBConnection_OK
#----------------------------------------------------------------------
{
   my $TestStatus = 1;

   if ( $DB_CONNECT eq 'NO-CONNECTION' )
   {
      $TestStatus = 0;
   }
   else
   {
		 my $runTestConnect=<<EOC
		 sqlplus -s $DB_CONNECT <<EOF
         exit 0
      EOF
EOC
;
		 my $TestConnect = system($runTestConnect);
      $TestStatus=$?;

      if ( $TestStatus ne 0 || $TestConnect =~ /SP2/)
      {
         $TestStatus = 0
      }
      else
      {
         $TestStatus = 1;
      }
   }
   return $TestStatus;

}

#----------------------------------------------------------------------
sub main
#----------------------------------------------------------------------
{
   my $ShowUsage = 0;
   my $optstat = GetOptions( "help" => \$ShowUsage
                           , "dir=s" => \$FX_DIR
                           , "exc=s" => \$EXC_FILE
                           , "alert_prefix:s" => \$ALERT_PREFIX );
   error_out("try --help")
      if ( $optstat != 1 );

   if ( $ShowUsage )
   { 
      show_usage;
      exit(0);
   }

   defined($FX_DIR) or $FX_DIR = '.';

   error_out("\$DBUSER not set")
      if ( $DBUSER eq 'NO-USER');
   error_out("\$DBPASSWD not set")
      if ( $DBPASSWD eq 'NO-PASSWD');
   error_out("\$DBSID not set")
      if ( $DBSID eq 'NO-SID');
   error_out("Cannot connect to Oracle using \$DBUSER/\@\$DBSID")
      if (!DBConnection_OK());
   error_out("Directory $FX_DIR/templates does not exist")
      if (! -d "$FX_DIR/templates" );
   error_out("Failure in DBSystemValues, using \$DBUSER/\@\$DBSID")
      if (! DBSystemValues() );

   Entity_fx::start($DB_CONNECT, $FX_DIR, $EXC_FILE, $ALERT_PREFIX);
   TemplateField_fx::start($DB_CONNECT, $FX_DIR);

   return(0);

}

exit main;
