#!/bin/ksh
###########################################################################
#
# Licensed Materials - Property of IBM
# 5724-T05,5724-T06
#
# (C) Copyright IBM Corp. 2003,2010. All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
###########################################################################
# (#) ./base/install/core_inst.sh BL_core_schema_8.0.7_8.0.7.4.02_20100413  064938
# (#) 
#
machine=`/bin/hostname`
account=`/bin/id  | tr '(=)' '   ' | awk '{ print $3 }'`
product=`/bin/ksh -pc "echo ~$account`  ;# aka FLEXPM_USER
install=`/bin/pwd`

cd $FLEXPM_HOME

export ORACLE_VERS=`basename ${ORACLE_HOME}`

chmod 755 sw/oracle/preset_oracle_paths

sw/oracle/preset_oracle_paths -f

# save the vendor so .profile is fixed

export save_vendor=$vendor
export save_product=$wm_product

. ./.profile

export vendor=$save_vendor
export wm_product=$save_product

chmod 700 pm/adm/crypt_util.ksh
pm/adm/crypt_util.ksh -p ${DBUSER} ${DBPASSWD}

chmod 755 pm/adm/setup-runable

if [[ $? -ne 0 ]]
then 
   echo "chmod setup-runable failed"
   exit 2
fi

pm/adm/setup-runable -config

if [[ $? -ne 0 ]]
then 
   echo "setup-runable -config failed"
   exit 2
fi

pm/adm/setup-runable -schema

if [[ $? -ne 0 ]]
then 
   echo "setup-runable -schema failed"
   exit 2
fi

DBCONN=`${FLEXPM_HOME}/pm/adm/crypt_util.ksh -g ${DBUSER} -c`   

## Ensure no errors exist in schema
echo "\nChecking for errors in the schema."
sqlplus -s /nolog <<END

   set serveroutput on size 1000000;
   WHENEVER SQLERROR EXIT FAILURE;
   VARIABLE return_status NUMBER;
   CONNECT ${DBCONN}
    
   DECLARE
      v_errors INTEGER := 0;
   BEGIN
      :return_status := 0;
      SELECT count(*) 
        INTO v_errors
        FROM user_objects
       WHERE status != 'VALID';

      IF v_errors != 0 THEN
         dbms_output.put_line('Errors found: ' || v_errors);
         :return_status := 1;
      END IF;
   END;
   /
   EXIT :return_status;
END

if [[ $? -ne 0 ]]
then 
   echo "FAILED: Errors exist in schema after install"
   exit 2
fi   

echo "No errors found."
