package wm_runtype;

###################################################################
#
# Licensed Materials - Property of IBM
# 5724-T05,5724-T06
#
# (C) Copyright IBM Corp. 2003,2009. All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
###################################################################
# (#) ./install/lib/wm_runtype.pm BL_wminstall_8.0.7_8.0.7.4.02_20100413  062726
# (#) 
#
###################################################################
# Script   : wm_runtype                                           #
# Function : Determine tarball prerequisites, status (install,    #
#            upgrade, or skip)                                    #
###################################################################

use strict;
use Env;

my ($package_tar_process) = "";
my (@register_values);

sub pad_elements ( $$ ){
##############################################################
# Pad elements in a version string so that each field has    #
# the same number of characters in it for comparison.        #
##############################################################
    my ( $field1, $field2 ) = @_;

    while ( length($field1) > length($field2) ) {
        $field2 = '0' . $field2;
    }

    while ( length($field2) > length($field1) ) {
        $field1 = '0' . $field1;
    }

    return ( $field1, $field2 );

}

sub compare_versions ( $$ ) {
##############################################################
#  Called by : search_array                                  #
#              compare_arrays                                #
#------------------------------------------------------------#
#  return 1  = new version > old version                     #
#  return 0  = versions identical                            #
#  return -1 = old version > new_version                     #
##############################################################

    my ( $old, $new ) = @_;

    my (@old_array) = split ( /\./, $old );
    my (@new_array) = split ( /\./, $new );

    my ($determinate) = ( $#old_array ge $#new_array ) ? $#old_array : $#new_array;

    for ( my $x = $#old_array ; $x < $determinate ; ++$x ) {
        push @old_array, '0';
    }

    for ( my $x = $#new_array ; $x < $determinate ; ++$x ) {
        push @new_array, '0';
    }

    for ( my $x = 0 ; $x <= $determinate ; $x++ ) {
        my ( $field1, $field2 ) =
          &pad_elements( $old_array[$x], $new_array[$x] );
        $old_array[$x] = $field1;
        $new_array[$x] = $field2;
    }

    for ( my $x = 0 ; $x <= $determinate ; $x++ ) {
        if ( $new_array[$x] lt $old_array[$x] ) {
            return (-1);
        }
        else {
            if ( $new_array[$x] gt $old_array[$x] ) {
                return (1);
            }
        }
    }

    return (0);
}

sub search_for_prerequisite ( $$$@ ) {
##############################################################
#                                                            #
##############################################################

  my ( $passed_spec, $passed_platform, $passed_version, @passed_array ) = @_;

  my $return_value;
  my $highest_version = -2;

  foreach my $entry (@passed_array) {
    my ($reg_spec,$reg_platform,$reg_version) = split ( /\|/, $entry );
    if ( ( $passed_spec eq $reg_spec )
         && ( $passed_platform eq $reg_platform ) )
      {
        if ( !$passed_version ) {
          $passed_version = 0;
        }

        if (compare_versions($highest_version,$reg_version) >= 0) {
          $highest_version = $reg_version;
        }
      }
  }
  my $return_value = &compare_versions( $highest_version, $passed_version );

  $return_value = "NF" if ($return_value == -2);

  return ($return_value);

}

sub process_core_prerequisites ( $ ) {
##############################################################
#                                                            #
##############################################################
    
    my ($xml_record) = @_;
    my (
        $xml_spec,       $xml_name,            $xml_platform,
        $xml_version,    $xml_process,         $xml_pc_platform,
        $xml_pc_version, $xml_premod_platform, $xml_premod_version
       )
         = split ( ":", $xml_record );
 
    &wm_audit::print_section( "  Core Tarball  ", "Y", "Y", "Y" );

    my $xml_platform_found = '0';

    my $register_count = $#register_values;

    for ( my $core_idx = 0 ; $core_idx <= $register_count ; $core_idx++ ) {
        my ( $register_spec, $register_platform, $register_version ) =
            split ( /\|/, $register_values[$core_idx] );
        if ( $xml_platform eq $register_platform ) {
	        $xml_platform_found = '1';
            if ( !$xml_pc_version || !$xml_pc_platform ) {
                 &wm_audit::print_detail( "Platform ($xml_platform) already exists",
                       "Spec has no prerequisites", "Y", "Y", "Y" );
                 $package_tar_process = 'S';
		         return;
	        }
            else
	        {
                # old product is R23.0 and new version is 8.0.7, then adjust new version so it thinks its bigger.
                # This if check can be removed after R23 has been upgraded to 8.0.7
                if ((substr($xml_pc_version,0,5) eq "R23.0") && (substr($xml_version,0,5) eq "8.0.7"))
                {
                   $xml_version = "R80" . substr($xml_version, 1);     
                }
                # End of R23/807 special code
                
                ## Check that new version is greater than the register version
                my ($test_version) = &search_for_prerequisite($xml_spec, $xml_platform, $xml_version, @register_values);
                if ( $test_version eq '1') { 
                    ## Check that prerequisite version (depends) is less than or equal to the installed_version
                    my ($retest) = &search_for_prerequisite( 'CORE', $xml_pc_platform, $xml_pc_version, @register_values);
                    if ( $retest ne '1' ) {
                        $package_tar_process = 'U';
                        &wm_audit::print_detail( "Spec Prerequisite $xml_pc_platform - $xml_pc_version",
                           "Less than or equal to register - $register_platform - $register_version", "Y", "Y", "Y" );
                        return;
		            }
                    else
		            {
                        $package_tar_process = 'S';
                        &wm_audit::print_detail( "Spec Prerequisite version - $xml_pc_version",
                           "Greater than register - $register_version", "Y", "Y", "Y" );
                        return;
		            } 
		        }
                else
		        {
                    $package_tar_process = 'S';
                    &wm_audit::print_detail( "Spec version - $xml_version",
                          "Less than or equal to register - $register_version", "Y", "Y", "Y" );
                    return;
		        }
	        }
	    }
    }

    if ( !$xml_platform_found ) {
         $package_tar_process = 'I';
         &wm_audit::print_detail( "Spec platform - $xml_platform ",
                           "Does not exist in register", "Y", "Y", "Y" );
         return;
    }

}


sub process_vendor_prerequisites ( $ ) {
##############################################################
#                                                            #
##############################################################
    my ($xml_record) = @_;

    my (
        $xml_spec,       $xml_name,            $xml_platform,
        $xml_version,    $xml_process,         $xml_pc_platform,
        $xml_pc_version, $xml_premod_platform, $xml_premod_version
      )
      = split ( ":", $xml_record );

    my $register_count = $#register_values;

    &wm_audit::print_section( " Vendor Tarball  ", "Y", "Y", "Y" );

    my ( $xml_platform_found ) = '0';

    for ( my $vendor_idx = 0 ; $vendor_idx <= $register_count ; $vendor_idx++ ) {
        my ( $register_spec, $register_platform, $register_version ) =
          split ( /\|/, $register_values[$vendor_idx] );
            if ( $xml_platform eq $register_platform ) {
	        $xml_platform_found = '1';                            # vendor platform exists in registry
                #################################################
                # Check for core prerequisites
                #################################################
                if ( !$xml_pc_version || !$xml_pc_platform ) {        # No core prerequisites
                      &wm_audit::print_detail( "Modules spec $xml_platform - $xml_version",
                         "Without Core Prerequisites", "Y", "Y", "Y" );
                     $package_tar_process = 'S';
                    return;
                }
                #################################################
                # Check for vendor prerequisites
                #################################################
                if ( ! $xml_premod_version || ! $xml_premod_platform ) {  # No vendor prerequisites
                       &wm_audit::print_detail( "Spec version - $xml_platform",
                         "Exists in registry", "Y", "Y", "Y" );
                       &wm_audit::print_detail( "Spec $xml_platform - $xml_version",
                         "Without Vendor Prerequisites", "Y", "Y", "Y" );
                     $package_tar_process = 'S';
                    return;
                }
                #################################################################
                # We are here because we have a xml record that has the same 
                # platform as one in the registry, the xml record has a core 
                # prerequisite and a vendor prerequisite
                #################################################################

                #################################################
                # Check that the vendor version is greater than the 
                # register version
                #################################################
                my ( $vendor_spec_version) = &search_for_prerequisite ( 'VENDOR', $xml_platform, $xml_version, @register_values );
                if ( $vendor_spec_version ne '1' )  {  # xml_version not greater than registered version
	             &wm_audit::print_detail( "Module ($xml_platform) version $xml_version",
                     "Less than register version - $register_version", "Y", "Y", "Y" );
                     $package_tar_process = 'S';
                     return;
		   }

                #################################################
                # Check that the vendor register'd version is
                # less than or equal to the vendor prerequisite
                # version.
                #################################################
                my ( $vendor_depend_version ) = &search_for_prerequisite ( 'VENDOR', $xml_premod_platform, $xml_premod_version, @register_values ) ;
                if ( $vendor_depend_version eq '1' ) {
                     &wm_audit::print_detail( "Module ($xml_platform) version $xml_version",
                     "Greater than register version - $register_version", "Y", "Y", "Y" );
                     $package_tar_process = 'S';
                     return;
		   }

                #################################################
                # Check that the prerequisite core version exists
                # and that the spec core pre version is less than
                # or equal to the register version.
                #################################################
                my ( $core_test_version ) =  &search_for_prerequisite ( 'CORE', $xml_pc_platform, $xml_pc_version, @register_values ) ;
                if ( $core_test_version eq '1' ) {
                    &wm_audit::print_detail( "Module ($xml_platform) version $xml_version",
                     "Required Core Version $xml_pc_version does not exist", "Y", "Y", "Y" );
                     $package_tar_process = 'S';
                     return;
		   }
                #################################################
                # Existing Vendor can be upgraded
                #################################################
                &wm_audit::print_detail( "Module - $xml_platform, version - $xml_version",
                       "All prerequisites met", "Y", "Y", "Y" );
                $package_tar_process = 'U';
                return;
	      }
      }
 
      #################################################
      # The vendor does not exist in the registry
      #################################################
      #################################################
      # Check for core prerequisites
      #################################################
      if ( !$xml_pc_version || !$xml_pc_platform ) {        # No core prerequisites
           &wm_audit::print_detail( "New Vendor $xml_platform - $xml_version",
                       "Without Core Prerequisites", "Y", "Y", "Y" );
           $package_tar_process = 'S';
           return;
      }
      #################################################
      # Check that core prerequisite is less than or
      # equal to the registered version
      #################################################
      my ( $core_test_version ) =  &search_for_prerequisite ( 'CORE', $xml_pc_platform, $xml_pc_version, @register_values ) ;
      if ( $core_test_version eq '1' ) {
	&wm_audit::print_detail( "Module ($xml_platform) version $xml_version",
				 "Required Core Version $xml_pc_version does not exist", "Y", "Y", "Y" );
	$package_tar_process = 'S';
	return;
      }

      #################################################
      # Check for vendor prerequisites.  For an install
      # there should be no vendor prerequisities.
      #################################################
      if ( $xml_premod_platform || $xml_premod_version ) {
	my ( $vendor_depend_version ) = &search_for_prerequisite ( 'VENDOR', $xml_premod_platform, $xml_premod_version, @register_values ) ;
	if ( $vendor_depend_version eq '1' ) {
	  &wm_audit::print_detail( "Module ($xml_platform) version $xml_version",
				   "Required Vendor Version $xml_premod_version does not exist", "Y", "Y", "Y" );
	  $package_tar_process = 'S';
	  return;
	}
      }

      #################################################
      # Existing Vendor can be upgraded
      #################################################
      &wm_audit::print_detail( "Module - $xml_platform, version - $xml_version",
                      "All prerequisites met", "Y", "Y", "Y" );
      $package_tar_process = 'I';
      return;
}


sub compare_arrays ( $ ){
##############################################################
#  Called by evaluate_prerequisites                          #
##############################################################

    my ($xml_record) = @_;
    my (
        $xml_spec,       $xml_name,            $xml_platform,
        $xml_version,    $xml_process,         $xml_pc_platform,
        $xml_pc_version, $xml_premod_platform, $xml_premod_version
      )
      = split ( ":", $xml_record );

    $package_tar_process = "";

    if ( $#register_values < 0 ) {
        my ($array_line) = join "|", $xml_spec, $xml_platform, $xml_version;
        if ( $xml_spec eq 'CORE' ) {
            $package_tar_process = 'I';
            push @register_values, $array_line;
        }
        else {
            $package_tar_process = 'S';
        }
        return;
    }

    my ($matched_spec) = 0;

    if ( $xml_spec eq 'CORE' ) {
        &process_core_prerequisites($xml_record);
    }
    else {
        &process_vendor_prerequisites($xml_record);
    }
    if ( ( $package_tar_process eq 'I' ) || ( $package_tar_process eq 'U' ) ) {
        my ($array_line) = join "|", $xml_spec, $xml_platform, $xml_version;
        push @register_values, $array_line;
    }

}

sub init_register_values ( $$ ) {
##############################################################
#  Called by evaluate prerequisites                          #
##############################################################

    my ( $filesystem, $schema ) = @_;

    my @register_info;
    
    if ( $filesystem && $schema ) {
        my ($flexpm_home) = $ENV{'FLEXPM_HOME'};
        my ($exec_path)   =
          join ( '/', "$flexpm_home/pm/adm", "show_installed" );
        chmod 0755, $exec_path;
        my $return_code = system("$exec_path > /tmp/show_installed.txt 2>&1");
        open SHOW_INSTALL, "< /tmp/show_installed.txt"
          or die "Unable to open show_installed.txt : $!";
        while ( <SHOW_INSTALL> ) {
            chomp;
            push @register_info, $_;
        }
        close SHOW_INSTALL
          or die "Unable to close /tmp/show_installed.txt : $!";
        unlink "/tmp/show_installed.txt";
    }
    else {
        undef @register_info;
        my @register_info;
    }

    &wm_audit::print_section( "  Registry Info  ", "Y", "Y", "Y" );

    for ( my $i = 0 ; $i <= $#register_info ; $i++ ) {
        next if ( $register_info[$i] =~ /^COMPONENT/ );
        next if ( $register_info[$i] =~ /^\-/ );
        next if ( $register_info[$i] =~ /^\\n/ );
        next if ( $register_info[$i] eq '' );
        my ( $product, $platform, $dummy, $release, $build, @rest ) =
          split ( ' ', $register_info[$i] );
        $_ = $build;
        s/b//csi;
        $build = $_;
        $release = join "\.", $release, $build;
        &wm_audit::print_detail( "Product ($product)", "Platform ($platform) Release ($release)",
                 "Y", "Y", "Y" );
        my ($push_string) = join "|", $product, $platform, $release;

        if ( $push_string ne '||.' ) {
            push @register_values, $push_string;
        }
    }

    return;

}

sub evaluate_prerequisites ( $ ){
##############################################################
#  Entry point to module.  Called externally.                #
##############################################################
    my ($verbose) = @_;

    my (
        $Core_Default_DBCONNECT,       $Core_Default_BASEDIR,
        $Core_Default_CORE_INSTALLDIR, $Core_Default_PORTBASE,
        $Core_Default_TMPDIR,          $Core_Default_CLASSPATH
      )
      = &wm_xml_handler::return_core_defaults;

    my ($core_pathname) = join "/", $Core_Default_BASEDIR,
      $Core_Default_CORE_INSTALLDIR;

    my ($installdir) = '0';

    my (@prerequisite_array);

    my (@tarball_array) = &wm_xml_handler::return_tarballs;

    my $tarball_count = &wm_xml_handler::return_number_of_modules;

    my $DBCONNECT = $Core_Default_DBCONNECT;

    &wm_audit::print_section( "Check Depends   ", "Y", "Y", "Y" );

    for ( my $z = 0 ; $z <= $tarball_count ; $z++ ) {
        my (
            $spec_type,         $name,              $platform,
            $version,           $process_type,      $preq_core_platform,
            $preq_core_version, $preq_mod_platform, $preq_mod_version
          )
          = &wm_xml_handler::return_prerequisite_versions($z);

	if ( $spec_type ne 'CORE' ) { $spec_type = 'VENDOR'; }
        if ( $name ne 'CORE' ) { $name = 'VENDOR'; }
        push @prerequisite_array, join ":", $spec_type, $name, $platform,
          $version, $process_type, $preq_core_platform, $preq_core_version,
          $preq_mod_platform, $preq_mod_version;
    }

    my ($flexpm_home) = $ENV{'FLEXPM_HOME'};

    my ( $filesystem_exists, $schema_exists );

    my ($return_value) = "";

    my $basedir = "";

    if ( !-d $Core_Default_BASEDIR ) {
        &wm_audit::print_detail( "Basedir",
            "$Core_Default_BASEDIR does not exist", "Y", "Y", "Y" );
        $basedir = 0;
    }
    else {
        &wm_audit::print_detail( "Basedir", "$Core_Default_BASEDIR exists", "Y",
            "Y", "Y" );
        $basedir = 1;
    }

    if ( !-d $core_pathname ) {
        &wm_audit::print_detail( "Installdir", "$core_pathname does not exist",
            "Y", "Y", "Y" );
        $filesystem_exists = 0;
    }
    else {
        &wm_audit::print_detail( "Installdir", "$core_pathname exists", "Y",
            "Y", "Y" );
        $filesystem_exists = 1;
    }

    my (@sqlplus_return) = `echo "quit" | sqlplus "$DBCONNECT"`;

    $schema_exists = '1';

    for ( my $z = 0 ; $z <= $#sqlplus_return; $z++) {
        if ( $sqlplus_return[$z] =~ /ERROR/ ) {
            $schema_exists = '0';
        }
    }

    if ( $schema_exists eq '0' ) {
          &wm_audit::print_detail( "sqlplus", 'Schema does not exist',
                 "Y", "Y", "Y" );
    }
    else
       {
          &wm_audit::print_detail( "sqlplus", 'Schema Exists',
                 "Y", "Y", "Y" );
       }
       
    my (@db_user) = split('/',$DBCONNECT);

    if ( $schema_exists ) {
      if ( ! $filesystem_exists ) {
           &wm_err::accum_error(
               "Schema exists without filesystem.", "Error",
               "Schema($db_user[0]) Filesystem($core_pathname)" );
           return;
	 }
    }
     else
         {
           if ( $filesystem_exists) {
                &wm_err::accum_error(
               "Filesystem ($core_pathname) exists without schema", "Error",
               "Schema - $db_user[0] " );
           return;
	   }
      }
            
    &init_register_values( $filesystem_exists, $schema_exists );

    my ($idx) = 0;

    for ( my $tmp_idx = 0 ; $tmp_idx <= $#prerequisite_array ; $tmp_idx++ ) {
        my (
            $tar_spec,       $tar_name,            $tar_platform,
            $tar_version,    $tar_process,         $tar_pc_platform,
            $tar_pc_version, $tar_premod_platform, $tar_premod_version
          )
          = split ( ":", $prerequisite_array[$tmp_idx] );
    
        &compare_arrays( $prerequisite_array[$tmp_idx] );

        $prerequisite_array[$tmp_idx] = join ":", $tar_spec, $tar_name, $tar_platform,
          $tar_version, $package_tar_process, $tar_pc_platform, $tar_pc_version,
          $tar_premod_platform, $tar_premod_version;

        my ( $field1, $field2, $field3, $field4 ) = split ":",
          $tarball_array[$idx];

        if ( $package_tar_process eq 'I' ) {
            &wm_audit::print_detail( "$field3",
                "INSTALL - $tar_name - $tar_version", "Y", "Y", "Y" );
        }
        if ( $package_tar_process eq 'U' ) {
            &wm_audit::print_detail( "$field3",
                "UPGRADE - $tar_name - $tar_version", "Y", "Y", "Y" );
        }
        if ( $package_tar_process eq 'S' ) {
            &wm_audit::print_detail( "$field3",
                "SKIP    - $tar_name - $tar_version", "Y", "Y", "Y" );
        }

        $tarball_array[$idx] = join ":", $field1, $field2, $field3,
          $package_tar_process;

        $idx++;
    }

    &wm_xml_handler::update_tarballs(@tarball_array);
}

1;
