#!/bin/ksh
#
# @(#) drop_watchmark_subtree.ksh 1.2.0 03/11/21 11:17:56
# @(#) 
#
# COPYRIGHT Watchmark Corp. 2003
#

function usage {
   echo "Usage: $0 -h host -p port -D bind_dn -w password -u wmunit -s wmsuffix"
   exit 1
}

function build_drop {
# $1 - source dn file
# $2 - drop file

   # Build the drop statements ... one line at a time
   while read i
   do
      if [[ ${i} != "" ]]
      then
         echo "dn: $i"
         echo "changetype: delete"
         echo ""
      fi
   done < ${1} > ${2}

}

function drop_dn {
# $1 drop file

   ldapmodify  -h ${WMLDAP_HOST} -p ${WMLDAP_PORT} -D "${WMLDAP_BIND_DN}" -w "${WMLDAP_PASSWORD}" -f ${1}
}

function drop_services {
#
# Drop all watchmarkService entries across all servers
#
   FDN=/tmp/wmldap.service_dn
   FDROP=/tmp/wmldap.service_drop

   echo ""
   echo "Dropping watchmarkService entries ..."
   echo ""

   # Generate the list
   ldapsearch -h ${WMLDAP_HOST} -p ${WMLDAP_PORT} -D "${WMLDAP_BIND_DN}" -w "${WMLDAP_PASSWORD}" \
      -s sub -b "ou=Servers, ${WMSUFFIX}" "objectClass=watchmarkService" dn > ${FDN}.${LOGID}

   build_drop ${FDN}.${LOGID} ${FDROP}.${LOGID}

   drop_dn ${FDROP}.${LOGID}

}

function drop_server_users {
#
# Drop all watchmarkUser entries under all watchmarkServer entries
#
   FDN=/tmp/wmldap.server_user_dn
   FDROP=/tmp/wmldap.server_user_drop

   echo ""
   echo "Dropping watchmarkUser entries under all watchmarkServer entries ..."
   echo ""

   # Generate the list
   ldapsearch -h ${WMLDAP_HOST} -p ${WMLDAP_PORT} -D "${WMLDAP_BIND_DN}" -w "${WMLDAP_PASSWORD}" \
      -s sub -b "ou=Servers, ${WMSUFFIX}" "objectClass=watchmarkUser" dn > ${FDN}.${LOGID}

   build_drop ${FDN}.${LOGID} ${FDROP}.${LOGID}

   drop_dn ${FDROP}.${LOGID}

#
# Now drop the ou=Users entries
#
   FDN=/tmp/wmldap.server_user_ou_dn
   FDROP=/tmp/wmldap.server_user_ou_drop

   echo ""
   echo "Dropping ou=Users entries under all watchmarkServer entries ..."
   echo ""

   # Generate the list
   ldapsearch -h ${WMLDAP_HOST} -p ${WMLDAP_PORT} -D "${WMLDAP_BIND_DN}" -w "${WMLDAP_PASSWORD}" \
      -s sub -b "ou=Servers, ${WMSUFFIX}" "(&(objectClass=organizationalUnit)(ou=Users))" dn > ${FDN}.${LOGID}

   build_drop ${FDN}.${LOGID} ${FDROP}.${LOGID}

   drop_dn ${FDROP}.${LOGID}

}

function drop_servers {
#
# Drop all watchmarkServer entries, including the ou=Servers entry
#
   FDN=/tmp/wmldap.server_dn
   FDROP=/tmp/wmldap.server_drop

   echo ""
   echo "Dropping watchmarkServer entries ..."
   echo ""

   # Generate the list
   ldapsearch -h ${WMLDAP_HOST} -p ${WMLDAP_PORT} -D "${WMLDAP_BIND_DN}" -w "${WMLDAP_PASSWORD}" \
      -s sub -b "ou=Servers, ${WMSUFFIX}" "objectClass=watchmarkServer" dn > ${FDN}.${LOGID}

   build_drop ${FDN}.${LOGID} ${FDROP}.${LOGID}

   drop_dn ${FDROP}.${LOGID}

#
# Now drop the ou=Servers
#
   FDN=/tmp/wmldap.server_ou_dn
   FDROP=/tmp/wmldap.server_ou_drop

   echo ""
   echo "Dropping ou=Servers under Watchmark suffix ..."
   echo ""

   # Generate the list
   ldapsearch -h ${WMLDAP_HOST} -p ${WMLDAP_PORT} -D "${WMLDAP_BIND_DN}" -w "${WMLDAP_PASSWORD}" \
      -s base -b "ou=Servers, ${WMSUFFIX}" "(&(objectClass=organizationalUnit)(ou=Servers))" dn > ${FDN}.${LOGID}

   build_drop ${FDN}.${LOGID} ${FDROP}.${LOGID}

   drop_dn ${FDROP}.${LOGID}


}

function drop_users {
#
# Drop all watchmarkUser entries, including the ou=Users entry
#
   FDN=/tmp/wmldap.user_dn
   FDROP=/tmp/wmldap.user_drop

   echo ""
   echo "Dropping watchmarkUser entries ..."
   echo ""

   # Generate the list
   ldapsearch -h ${WMLDAP_HOST} -p ${WMLDAP_PORT} -D "${WMLDAP_BIND_DN}" -w "${WMLDAP_PASSWORD}" \
      -s sub -b "ou=Users, ${WMSUFFIX}" "objectClass=watchmarkUser" dn > ${FDN}.${LOGID}

   build_drop ${FDN}.${LOGID} ${FDROP}.${LOGID}

   drop_dn ${FDROP}.${LOGID}

#
# Now drop the ou=Users
#
   FDN=/tmp/wmldap.user_ou_dn
   FDROP=/tmp/wmldap.user_ou_drop

   echo ""
   echo "Dropping ou=Users under Watchmark suffix ..."
   echo ""

   # Generate the list
   ldapsearch -h ${WMLDAP_HOST} -p ${WMLDAP_PORT} -D "${WMLDAP_BIND_DN}" -w "${WMLDAP_PASSWORD}" \
      -s base -b "ou=Users, ${WMSUFFIX}" "(&(objectClass=organizationalUnit)(ou=Users))" dn > ${FDN}.${LOGID}

   build_drop ${FDN}.${LOGID} ${FDROP}.${LOGID}

   drop_dn ${FDROP}.${LOGID}

}

function drop_roles {
#
# Drop all watchmarkRole entries, including the ou=Roles entry
#
   FDN=/tmp/wmldap.role_dn
   FDROP=/tmp/wmldap.role_drop

   echo ""
   echo "Dropping watchmarkRole entries ..."
   echo ""

   # Generate the list
   ldapsearch -h ${WMLDAP_HOST} -p ${WMLDAP_PORT} -D "${WMLDAP_BIND_DN}" -w "${WMLDAP_PASSWORD}" \
      -s sub -b "ou=Roles, ${WMSUFFIX}" "objectClass=watchmarkRole" dn > ${FDN}.${LOGID}

   build_drop ${FDN}.${LOGID} ${FDROP}.${LOGID}

   drop_dn ${FDROP}.${LOGID}

#
# Now drop the ou=Roles
#
   FDN=/tmp/wmldap.role_ou_dn
   FDROP=/tmp/wmldap.role_ou_drop

   echo ""
   echo "Dropping ou=Roles under Watchmark suffix ..."
   echo ""

   # Generate the list
   ldapsearch -h ${WMLDAP_HOST} -p ${WMLDAP_PORT} -D "${WMLDAP_BIND_DN}" -w "${WMLDAP_PASSWORD}" \
      -s base -b "ou=Roles, ${WMSUFFIX}" "(&(objectClass=organizationalUnit)(ou=Roles))" dn > ${FDN}.${LOGID}

   build_drop ${FDN}.${LOGID} ${FDROP}.${LOGID}

   drop_dn ${FDROP}.${LOGID}

}

function drop_privileges {
#
# Drop all watchmarkPrivilege entries, including the ou=Privileges entry
#
   FDN=/tmp/wmldap.privilege_dn
   FDROP=/tmp/wmldap.privilege_drop

   echo ""
   echo "Dropping watchmarkPrivilege entries ..."
   echo ""

   # Generate the list
   ldapsearch -h ${WMLDAP_HOST} -p ${WMLDAP_PORT} -D "${WMLDAP_BIND_DN}" -w "${WMLDAP_PASSWORD}" \
      -s sub -b "ou=Privileges, ${WMSUFFIX}" "objectClass=watchmarkPrivilege" dn > ${FDN}.${LOGID}

   build_drop ${FDN}.${LOGID} ${FDROP}.${LOGID}

   drop_dn ${FDROP}.${LOGID}

#
# Now drop the ou=Privileges
#
   FDN=/tmp/wmldap.privilege_ou_dn
   FDROP=/tmp/wmldap.privilege_ou_drop

   echo ""
   echo "Dropping ou=Privileges under Watchmark suffix ..."
   echo ""

   # Generate the list
   ldapsearch -h ${WMLDAP_HOST} -p ${WMLDAP_PORT} -D "${WMLDAP_BIND_DN}" -w "${WMLDAP_PASSWORD}" \
      -s base -b "ou=Privileges, ${WMSUFFIX}" "(&(objectClass=organizationalUnit)(ou=Privileges))" dn > ${FDN}.${LOGID}

   build_drop ${FDN}.${LOGID} ${FDROP}.${LOGID}

   drop_dn ${FDROP}.${LOGID}

}

function drop_groups {
#
# Drop all watchmarkGroup entries, including the ou=Groups entry
#
   FDN=/tmp/wmldap.group_dn
   FDROP=/tmp/wmldap.group_drop

   echo ""
   echo "Dropping watchmarkGroup entries ..."
   echo ""

   # Generate the list
   ldapsearch -h ${WMLDAP_HOST} -p ${WMLDAP_PORT} -D "${WMLDAP_BIND_DN}" -w "${WMLDAP_PASSWORD}" \
      -s sub -b "ou=Groups, ${WMSUFFIX}" "objectClass=watchmarkGroup" dn > ${FDN}.${LOGID}

   build_drop ${FDN}.${LOGID} ${FDROP}.${LOGID}

   drop_dn ${FDROP}.${LOGID}

#
# Now drop the ou=Groups
#
   FDN=/tmp/wmldap.group_ou_dn
   FDROP=/tmp/wmldap.group_ou_drop

   echo ""
   echo "Dropping ou=Groups under Watchmark suffix ..."
   echo ""

   # Generate the list
   ldapsearch -h ${WMLDAP_HOST} -p ${WMLDAP_PORT} -D "${WMLDAP_BIND_DN}" -w "${WMLDAP_PASSWORD}" \
      -s base -b "ou=Groups, ${WMSUFFIX}" "(&(objectClass=organizationalUnit)(ou=Groups))" dn > ${FDN}.${LOGID}

   build_drop ${FDN}.${LOGID} ${FDROP}.${LOGID}

   drop_dn ${FDROP}.${LOGID}

}

function drop_datasources {
#
# Drop all watchmarkDatasource entries, including the ou=Datasources entry
#
   FDN=/tmp/wmldap.datasource_dn
   FDROP=/tmp/wmldap.datasource_drop

   echo ""
   echo "Dropping watchmarkDatasource entries ..."
   echo ""

   # Generate the list
   ldapsearch -h ${WMLDAP_HOST} -p ${WMLDAP_PORT} -D "${WMLDAP_BIND_DN}" -w "${WMLDAP_PASSWORD}" \
      -s sub -b "ou=Datasources, ${WMSUFFIX}" "objectClass=watchmarkDatasource" dn > ${FDN}.${LOGID}

   build_drop ${FDN}.${LOGID} ${FDROP}.${LOGID}

   drop_dn ${FDROP}.${LOGID}

#
# Now drop the ou=Datasources
#
   FDN=/tmp/wmldap.datasource_ou_dn
   FDROP=/tmp/wmldap.datasource_ou_drop

   echo ""
   echo "Dropping ou=Datasources under Watchmark suffix ..."
   echo ""

   # Generate the list
   ldapsearch -h ${WMLDAP_HOST} -p ${WMLDAP_PORT} -D "${WMLDAP_BIND_DN}" -w "${WMLDAP_PASSWORD}" \
      -s base -b "ou=Datasources, ${WMSUFFIX}" "(&(objectClass=organizationalUnit)(ou=Datasources))" dn > ${FDN}.${LOGID}

   build_drop ${FDN}.${LOGID} ${FDROP}.${LOGID}

   drop_dn ${FDROP}.${LOGID}

}

function drop_configuration {
#
# Drop all watchmarkConfig entries, including the ou=Configuration entry
#
   FDN=/tmp/wmldap.configuration_dn
   FDROP=/tmp/wmldap.configuration_drop

   echo ""
   echo "Dropping watchmarkConfig entries ..."
   echo ""

   # Generate the list
   ldapsearch -h ${WMLDAP_HOST} -p ${WMLDAP_PORT} -D "${WMLDAP_BIND_DN}" -w "${WMLDAP_PASSWORD}" \
      -s sub -b "ou=Configuration, ${WMSUFFIX}" "objectClass=watchmarkConfig" dn > ${FDN}.${LOGID}

   build_drop ${FDN}.${LOGID} ${FDROP}.${LOGID}

   drop_dn ${FDROP}.${LOGID}

#
# Now drop the ou=Configuration
#
   FDN=/tmp/wmldap.configuration_ou_dn
   FDROP=/tmp/wmldap.configuration_ou_drop

   echo ""
   echo "Dropping ou=Configuration under Watchmark suffix ..."
   echo ""

   # Generate the list
   ldapsearch -h ${WMLDAP_HOST} -p ${WMLDAP_PORT} -D "${WMLDAP_BIND_DN}" -w "${WMLDAP_PASSWORD}" \
      -s base -b "ou=Configuration, ${WMSUFFIX}" "(&(objectClass=organizationalUnit)(ou=Configuration))" dn > ${FDN}.${LOGID}

   build_drop ${FDN}.${LOGID} ${FDROP}.${LOGID}

   drop_dn ${FDROP}.${LOGID}

}
function drop_ldap_admin {
#
# Drop the ou=watchmark entry
#
   FDN=/tmp/wmldap.ldap_admin_ou_dn
   FDROP=/tmp/wmldap.ldap_admin_ou_drop

	echo ""
	echo "Dropping the cn=LDAPAdmin"
	echo ""

	# Generate the list
	ldapsearch -h ${WMLDAP_HOST} -p ${WMLDAP_PORT} -D "${WMLDAP_BIND_DN}" -w "${WMLDAP_PASSWORD}" \
	-s base -b "cn=LDAPAdmin, ${WMSUFFIX}" "(&(objectClass=groupofuniquenames)(cn=LDAPAdmin))" dn > ${FDN}.${LOGID}

	build_drop ${FDN}.${LOGID} ${FDROP}.${LOGID}
	drop_dn ${FDROP}.${LOGID}

}

function drop_watchmark {
#
# Drop the ou=watchmark entry
#
   FDN=/tmp/wmldap.watchmark_ou_dn
   FDROP=/tmp/wmldap.watchmark_ou_drop

   echo ""
   echo "Dropping the ${WMUNIT} suffix ..."
   echo ""

   # Generate the list
   ldapsearch -h ${WMLDAP_HOST} -p ${WMLDAP_PORT} -D "${WMLDAP_BIND_DN}" -w "${WMLDAP_PASSWORD}" \
      -s base -b "${WMSUFFIX}" "(&(objectClass=organizationalUnit)(ou=${WMUNIT}))" dn > ${FDN}.${LOGID}

   build_drop ${FDN}.${LOGID} ${FDROP}.${LOGID}

   drop_dn ${FDROP}.${LOGID}

}

#
# Main
#

#
# Env check
#
if [[ -z ${FLEXPM_HOME} ]]
then
   echo 'ERROR: $FLEXPM_HOME has not been set.'
   exit 1
fi

WMLDAP_HOME=${FLEXPM_HOME}/ldap

WMLDAP_HOST=""
WMLDAP_PORT=""
WMLDAP_BIND_DN=""
WMLDAP_PASSWORD=""
WMUNIT=""
WMSUFFIX=""
LOGID="$$"

USAGE="h:p:D:w:u:s:"

while getopts "${USAGE}" opt
do
   case $opt in
      h) WMLDAP_HOST=${OPTARG};;
      p) WMLDAP_PORT=${OPTARG};;
      D) WMLDAP_BIND_DN=${OPTARG};;
      w) WMLDAP_PASSWORD=${OPTARG};;
      s) WMSUFFIX=${OPTARG};;
      u) WMUNIT=${OPTARG};;
      *) usage;;
   esac
done

if [[ -z ${WMLDAP_HOST} || -z ${WMLDAP_PORT} || -z ${WMLDAP_BIND_DN} || -z ${WMLDAP_PASSWORD} || -z ${WMSUFFIX} || -z ${WMUNIT} ]]
then
   usage
fi

echo ""
echo "The LOGID for this drop is: ${LOGID}"
echo ""

#
# LDAP does not have a 'drop subtree' capability so we must create our own.
# This is fixed in structure and should be genericized later.
#

drop_services
drop_server_users
drop_servers
drop_users
drop_roles
drop_privileges
drop_groups
drop_datasources
drop_configuration
drop_ldap_admin
drop_watchmark
