#!/bin/ksh
###########################################################################
#
# Licensed Materials - Property of IBM
# 5724-T05,5724-T06
#
# (C) Copyright IBM Corp. 2003,2008. All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
###########################################################################
#
# (#) ./base/migrate/upgrades/bin/install.sh BL_core_schema_8.0.7_8.0.7.4.02_20100413  064938
# (#) 
#

if test "${vendor}" != "Hydrogen"
then
   #USAGE: install.sh [directory containing jboss zip]

   case $1 in -help|-usage)
     echo 'USAGE: install.sh [directory containing jboss zip]'
     exit 0
   ;;
   esac
   if test $# -ne 1
   then
     echo 'USAGE: install.sh [directory containing jboss zip]'
     exit 1
   fi

   export jboss_zip_location=$1
   export JBOSS_VERSION=jboss-4.0.5.GA
   export jboss_zip=${jboss_zip_location}/${JBOSS_VERSION}.zip
fi

# exit if can't find the jboss zip file
if [[ ! -e ${jboss_zip} ]]; then
  echo "Missing Jboss zip file ${jboss_zip}"
  exit 1;
fi

if [ "x$release"  = "x" ] ; then
     pro_release=`grep release\=\" ${FLEXPM_HOME}/.profile`
     parse_release=`echo ${pro_release}  | sed s/release\=//g | sed s/\ *//g | sed s/\;\#*[a-z]*//g | sed s/\"//g`
     export release
            release=${parse_release}
fi

if test "${vendor}" = "EnterpriseTrafficCache"
then
   export Build="ProspectWeb"
   export wm_product="WEB"
   export WM_PRODUCT="WEB"
   #
   # check for e2e license
   #
sqlplus -s /NOLOG << !
set feed off
set lines 200
set serveroutput on size 1000000
connect $DB_CONNECT
VARIABLE return_status NUMBER;
DECLARE
BEGIN
   SELECT count(1)
     INTO :return_status
     FROM pe_feature f
    WHERE f.supported_feature = 'ENTERPRISE'; 
END;
/
EXIT :return_status
!
   export e2elicense=$?
fi

if test "${vendor}" = "Hydrogen"
then
   export Build="Colorado"
   export WM_PRODUCT="PROSPECT"
   export wm_product="PROSPECT"
   export e2elicense=0
fi

if [ $e2elicense -eq 0 ]; then
   if [[ -e /bin/less ]]; then
      /bin/less -P "(f forward, b back, q quit) " license.txt
   else
      more license.txt
   fi
else
   if [[ -e /bin/less ]]; then
      /bin/less -P "(f forward, b back, q quit) " licenseE2E.txt
   else
      more licenseE2E.txt
   fi
fi
    
echo ""
echo "Do you accept the license (y/n)? "

keeplooping=1
while [ $keeplooping -eq 1 ] 
do
  read ANSWER
  echo ""
  case $ANSWER in
       y|Y)
         keeplooping=0
           ;;
       n|N)
           exit 1
           ;;
       *) 
           echo "Please answer (y/n) "
           ;;
  esac
done

# Ensure default location of gtar is in path
PATH=$PATH:/usr/sfw/bin

# Ensure perl bin/libs are in path
if [ "x$PERL5LIB" = "x" ] ; then
    export PERL5LIB=$FLEXPM_HOME/sw/perl/lib
fi
if [ "x$PERL5BIN" = "x" ] ; then
    export PERL5BIN=/usr/perl5/5.6.1/bin
fi

export PATH=$PERL5BIN:$PATH
export LD_LIBRARY_PATH=$LD_LIBRARY_PATH:$PERL5LIB

export SESSION
    SESSION=/var/tmp/${release}

export START_DIR=`pwd`

test -d ${SESSION} ||
    mkdir ${SESSION}

cd /tmp

export uid
       uid=$DBUSER

if [[ -d ${uid} ]] ; then
   rm -rf ${uid}
fi 

if [[ ! -d ${uid} ]] ; then
   mkdir ${uid} 2>&1
fi

cd ${uid}

export SESSION_LOG
    SESSION_LOG=${SESSION}/untar_file_maint.log

if test "${vendor}" = "Hydrogen"
then
    gtar -xzvf ${START_DIR}/colorado80000-file_maint.tar.gz 2>&1|tee ${SESSION_LOG}
else
    gtar -xzvf ${START_DIR}/pweb-file_maint.tar.gz 2>&1|tee ${SESSION_LOG}
fi

if [ $? -ne 0 ]
then
   echo "Install failed"
   exit 1
fi

cp ${START_DIR}/revxml.txt .

if [[ -f wm_file_maint ]] ; then
  export SESSION_LOG
    SESSION_LOG=${SESSION}/wm_file_maint.log

  chmod 755 wm_file_maint
  echo "######################################" 
  echo "# Pre-upgrade file back up"
  echo "######################################"
  ./wm_file_maint 2>&1 | tee ${SESSION_LOG}
fi


cd ${FLEXPM_HOME}

if [[ -f "${START_DIR}/pweb.build" ]] ; then
   register START "${START_DIR}/pweb.build"
fi
     
if [[ ! -d ${FLEXPM_HOME}/Archive/${release}  ]]; then
        export NEW_DIR ; NEW_DIR=1
fi

export SESSION_LOG
    SESSION_LOG=${SESSION}/untar_bin.log

cd ${FLEXPM_HOME}

rm -rf ${FLEXPM_HOME}/pm/pas     2>&1 |tee ${SESSION_LOG}
rm -rf ${FLEXPM_HOME}/pm/bin     2>&1 |tee -a ${SESSION_LOG}
rm -rf ${FLEXPM_HOME}/pm/lib     2>&1 |tee -a ${SESSION_LOG}
rm -rf ${FLEXPM_HOME}/pm/adm/DiskUtil.jar 2>&1 |tee -a ${SESSION_LOG}
rm -rf ${FLEXPM_HOME}/pm/adm/Object* 2>&1 | tee -a ${SESSION_LOG}
rm -rf ${FLEXPM_HOME}/pm/adm/gtar 2>&1 |tee -a ${SESSION_LOG}
rm -rf ${FLEXPM_HOME}/pm/adm/g*zip  2>&1 |tee -a ${SESSION_LOG}
rm -rf ${FLEXPM_HOME}/pm/adm/pmon   2>&1 |tee -a ${SESSION_LOG}
rm -rf ${FLEXPM_HOME}/pm/adm/proc*  2>&1 |tee -a ${SESSION_LOG}
rm -rf ${FLEXPM_HOME}/pm/adm/templates/rpDeploy* 2>&1 |tee -a ${SESSION_LOG}
rm -rf ${FLEXPM_HOME}/pm/adm/top  2>&1 |tee -a ${SESSION_LOG}
rm -rf ${FLEXPM_HOME}/pm/adm/update_report_results.pl  2>&1 |tee -a ${SESSION_LOG}
rm -rf ${FLEXPM_HOME}/pm/run/taskSet.hdd  2>&1 |tee -a ${SESSION_LOG}
rm -rf ${FLEXPM_HOME}/licenses 2>&1 | tee -a ${SESSION_LOG}
rm -rf ${FLEXPM_HOME}/migrate 2>&1 | tee -a ${SESSION_LOG}
rm -rf ${FLEXPM_HOME}/sw/oracle/dbstart 2>&1 | tee -a ${SESSION_LOG}
rm -rf ${FLEXPM_HOME}/wm/run 2>&1 | tee -a ${SESSION_LOG}

if test "${vendor}" != "Hydrogen"
then
  ${START_DIR}/jboss.sh ${FLEXPM_HOME} ${jboss_zip_location} 2>&1 | tee -a ${SESSION_LOG}
  if [ $? -ne 0 ]
  then
    exit 1
  fi
fi

cd ${FLEXPM_HOME}

if test "${vendor}" = "Hydrogen"
then
    fileset=`gtar -tzf ${START_DIR}/colorado80000-fileset.tar.gz`
else
    fileset=`gtar -tzf ${START_DIR}/pweb-fileset.tar.gz`
fi

if [ $? -ne 0 ]
then
   echo "Install failed"
   exit 1
fi

for file in ${fileset}
do
  if [ -f ${FLEXPM_HOME}/${file} ] ; then
     chmod +w ${FLEXPM_HOME}/${file}
  fi
done

if test "${vendor}" = "Hydrogen"
then
    gtar -xzvf ${START_DIR}/colorado80000-fileset.tar.gz 2>&1|tee -a ${SESSION_LOG}
else
    gtar -xzvf ${START_DIR}/pweb-fileset.tar.gz 2>&1|tee -a ${SESSION_LOG}
fi

if [ $? -ne 0 ]
then
   echo "Install failed"
   exit 1
fi


chmod -R 755 ${FLEXPM_HOME}/pm/lib
chmod -R 755 ${FLEXPM_HOME}/pm/bin

if [[ ! -d ${FLEXPM_HOME}/.setup ]]; then
    mkdir -p ${FLEXPM_HOME}/.setup 
    touch ${FLEXPM_HOME}/.setup/FlexPM-0000.at
fi

export SESSION_LOG
    SESSION_LOG=${SESSION}/untar_migrate.log

if test "${vendor}" = "Hydrogen"
then
    fileset=`gtar -tzf ${START_DIR}/colorado80000-migrate.tar.gz`
else
    fileset=`gtar -tzf ${START_DIR}/pweb-migrate.tar.gz`
fi

if [ $? -ne 0 ]
then
   echo "Install failed"
   exit 1
fi

for file in ${fileset}
do
  if [ -f ${FLEXPM_HOME}/${file} ] ; then
     chmod +w ${FLEXPM_HOME}/${file}
  fi
done

if test "${vendor}" = "Hydrogen"
then
    gtar -xzvf ${START_DIR}/colorado80000-migrate.tar.gz 2>&1 |tee ${SESSION_LOG}
else
    gtar -xzvf ${START_DIR}/pweb-migrate.tar.gz 2>&1 |tee ${SESSION_LOG}
fi

if [ $? -ne 0 ]
then
   echo "Install failed"
   exit 1
fi

cd ${FLEXPM_HOME}

export SESSION_LOG
    SESSION_LOG=${SESSION}/exec-bits.log

export SQLPATH
    SQLPATH=${FLEXPM_HOME}/config

cp db/Oracle8i/scheduler/sched/schedule_maint pm/run/
chmod +x pm/adm/setup-exec-bits 2>&1 |tee ${SESSION_LOG}
pm/adm/setup-exec-bits -set 2>&1 |tee -a ${SESSION_LOG}

export  ORACLE_VERS   ;
    ORACLE_VERS=`basename ${ORACLE_HOME}`

MAKE=$FLEXPM_HOME/pm/adm/make
cd ${FLEXPM_HOME}
${MAKE} bldfix 2>&1 | tee -a ${SESSION_LOG}

if [ $? -ne 0 ]
then
   echo "Install failed"
   exit 1
fi

cd ${FLEXPM_HOME}/migrate/upgrades/bin

chmod 755 *

export SESSION_LOG
    SESSION_LOG=${SESSION}/upgrade-schema.log

./setup-upgrade -r ${release} -schema 2>&1  |tee ${SESSION_LOG}

if [ $? -ne 0 ]
then
   echo "Install failed"
   exit 1
fi

export SESSION_LOG
    SESSION_LOG=${SESSION}/upgrade-config.log

./setup-upgrade -r ${release} -config 2>&1 |tee ${SESSION_LOG}

if [ $? -ne 0 ]
then
   echo "Install failed"
   exit 1
fi

if [[ -f "${START_DIR}/pweb.build" ]] ; then
   register COMPLETE "${START_DIR}/pweb.build"
fi

if [[ -d /tmp/${uid} ]] ; then
   rm -rf /tmp/${uid}
fi

unset uid


