---------------------------------------------------------------------------
--
-- Licensed Materials - Property of IBM
-- 5724-T05,5724-T06
--
-- (C) Copyright IBM Corp. 2003,2010. All Rights Reserved.
--
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
--
---------------------------------------------------------------------------
-- (#) ./base/migrate/upgrades/sql/Generic/upgrade_misc_fixes.sql BL_core_schema_8.0.7_8.0.7.4.02_20100413  064938
-- (#) 
--

PROMPT START upgrade_misc_fixes.sql

-- Start of every upgrade code
-- The following should be done for every upgrade DO NOT REMOVE

-- @@ ensures script runs from the same path as this script
PROMPT Cleaning up the orphaned schedule entries...
@@ clean_orphaned_skeds.sql

COMMIT;

-- Fix non-report schedules (also fixes timezone stuff).  Keeps schedules running properly across upgrade
UPDATE schedule
   SET next_time = start_time, needs_msg_update = 'Y'
 WHERE period NOT IN ('I', 'O')
   AND NVL(end_time, sysdate) >= sysdate
   AND job_type NOT IN (1, 10);

-- Only change scheduled reports that will run in the future. Keeps schedules running properly across upgrade
UPDATE schedule
   SET next_time = start_time, needs_msg_update = 'Y'
 WHERE period NOT IN ('I', 'O')
   AND NVL(end_time, sysdate) >= sysdate
   AND job_type = 10
   AND next_time > sysdate;
    
COMMIT;

-- End of every upgrade code

-- Start 8.0.6 patches
PROMPT Create wm message log metadata...
@ $FLEXPM_HOME/db/Oracle8i/metadata/wmlib/wm_log_metadata.sql

PROMPT
PROMPT Re-aligning FA/LA dates in pm_busyhour...
UPDATE pm_busyhour
SET firstavail = wm_date.trunc_to_last_period( firstavail, span ),
    lastavail  = wm_date.trunc_to_last_period( lastavail, span );

COMMIT;

DELETE pm_scenario s
 WHERE s.folderid = -1
   AND NOT EXISTS
 (SELECT 1 FROM pm_report r WHERE r.scenarioid = s.id);

UPDATE pm_scenario s
   SET s.userid = (SELECT r.userid FROM pm_report r WHERE r.scenarioid = s.id)
 WHERE s.folderid = -1
   AND s.userid IS NULL;

DELETE pm_template t
 WHERE t.folderid = -1
   AND NOT EXISTS
 (SELECT 1 FROM pm_report r WHERE r.templateid = t.id);

UPDATE pm_template t
   SET t.userid = (SELECT r.userid FROM pm_report r WHERE r.templateid = t.id)
 WHERE t.folderid = -1
   AND t.userid IS NULL;

COMMIT;

exec dbms_aqadm.alter_queue(queue_name=>'SAEXT_Q', max_retries=>8, retry_delay=>3600);

COMMIT;

UPDATE active_job j
   SET cleanup_time = j.job_time + 1
 WHERE cleanup_time IS NULL
   AND NOT EXISTS
 (SELECT 1 FROM schedule s WHERE j.schedule_id = s.schedule_id);

COMMIT;

-- End 8.0.6 patches


-- BH SA Import Start


PROMPT Create metadata for BH/SA import-export core merge.
@ $FLEXPM_HOME/db/Oracle8i/export2/export2_meta.sql

COMMIT;

-- BH SA Import End

-- Action Logging Start

-- action logging
PROMPT Adding action logging metadata

BEGIN
  -- action.logging.level set to 5 or 6
  wm_sysval.newsysvalifnotexists( 'action.logging.level', '5' );
  -- number of days to retain logs
  wm_sysval.newsysvalifnotexists( 'action.logging.retain', '30' );
  -- location where the files created by action_log.ksh are created
  wm_sysval.newsysvalifnotexists( 'action.logging.folder', '$PM_LOGS' );
  -- turn action logging off 
  wm_sysval.newsysvalifnotexists( 'action.logging.on', 'FALSE'  );
  -- turn automatic logoug on error off
  wm_sysval.newsysvalifnotexists ( 'action.logging.autologout.on', 'FALSE'  );
END;
/

BEGIN
  INSERT INTO pm_action_logging_areas VALUES (1, 'System');
EXCEPTION
   WHEN dup_val_on_index THEN
      NULL;
END;
/

BEGIN
  INSERT INTO pm_action_logging_areas VALUES (2, 'Reporting');
EXCEPTION
   WHEN dup_val_on_index THEN
      NULL;
END;
/

BEGIN
  INSERT INTO pm_action_logging_areas VALUES (3, 'Scheduling');
EXCEPTION
   WHEN dup_val_on_index THEN
      NULL;
END;
/

BEGIN
  INSERT INTO pm_action_logging_areas VALUES (4, 'Tools');
EXCEPTION
   WHEN dup_val_on_index THEN
      NULL;
END;
/

BEGIN
  INSERT INTO part_tables(part_table_id,table_name, tablespace_name,period,future_part,past_part,Run_Daily,Needs_Analyze,Needs_Move,Needs_Purge)
    VALUES(part_table_seq.NEXTVAL,'PM_ACTION_LOGGING','TRAFFIC_SMALL','D',5,2,'Y','Y','Y','Y');
EXCEPTION
   WHEN dup_val_on_index THEN
      NULL;
END;
/

BEGIN
  INSERT INTO subclass_table (ID, class_id, NAME, past_part_func) 
    (SELECT subclass_table_seq.NEXTVAL,ID, 'PmActionLogging', NULL
      FROM class_table
      WHERE upper(NAME) = upper('Part Maint')
  );
EXCEPTION
   WHEN dup_val_on_index THEN
      NULL;
END;
/

BEGIN
  INSERT INTO subclass_map( subclass_id , object_id) 
            VALUES((select id as subclass_id from subclass_table where name='PmActionLogging'), (select PART_TABLE_ID as object_id from part_tables where table_name='PM_ACTION_LOGGING'));
EXCEPTION
   WHEN dup_val_on_index THEN
      NULL;
END;
/
 
COMMIT;

-- Action Logging End


-- Instance Exclusion Start

PROMPT Inserting Instance Exclusion Metadata...

BEGIN
  INSERT INTO WM_FEATURE (FEATURE_ID, FEATURE_NAME) 
  VALUES (1,'DataAvailability');
EXCEPTION
   WHEN dup_val_on_index THEN
      NULL;
END;
/

BEGIN
  INSERT INTO WM_FEATURE (FEATURE_ID, FEATURE_NAME) 
  VALUES (2,'Reporting');
EXCEPTION
   WHEN dup_val_on_index THEN
      NULL;
END;
/

BEGIN
  INSERT INTO WM_FEATURE (FEATURE_ID, FEATURE_NAME) 
  VALUES (3,'All');
EXCEPTION
   WHEN dup_val_on_index THEN
      NULL;
END;
/

COMMIT;

-- Instance Exclusion End

-- Rehoming Start (Ensure related rh events chain properly)
UPDATE rh_trend t
   SET t.started = (SELECT MAX(x.ended) + 1 / (24 * 60 * 60)
                      FROM rh_trend x
                     WHERE x.trend_id < t.trend_id
                       AND x.instanceid = t.instanceid)
 WHERE t.started IS NULL;

COMMIT;
-- Rehoming End

PROMPT Updating validate_add_and_rpt_params
@ $FLEXPM_HOME/db/Oracle8i/utility/validate_add_and_rpt_params.sql

-- ========================== --
-- Report Forecasting - START --
-- ========================== --
PROMPT Updating report forecasting functions ...
BEGIN
  -- ADD UDC FUNCTION TYPE: Trending
  INSERT INTO wme_function_type VALUES(-1,'Trending');
EXCEPTION
   WHEN dup_val_on_index THEN
      NULL;
END;
/

COMMIT;

BEGIN
  -- ADD UDC FUNCTION: getKCILimit()
  INSERT INTO wme_function(function_id, function_type_id,function_name,function_signature,function_desc)
  (SELECT -1, 
          fnt.function_type_id,
          'getKCILimit',
          'getKCILimit(STRING,STRING,STRING)',
          'FLOAT getKCILimit(STRING entity, STRING field, STRING limit_name) - Gets the value of the specified limit, defined on the specified field.'
     FROM wme_function_type fnt
    WHERE upper(fnt.function_type_name) = 'TRENDING');
EXCEPTION
   WHEN dup_val_on_index THEN
      NULL;
END;
/

COMMIT;

BEGIN
  -- ADD UDC FUNCTION: trend()
  INSERT INTO wme_function(function_id, function_type_id,function_name,function_signature,function_desc)
  (SELECT -1, 
          fnt.function_type_id,
          'trend',
          'trend(RELATION,STRING,STRING,STRING,INT,INT)',
          'FLOAT trend(RELATION kci_to_trend, STRING bh_cluster_entity, STRING stored_busy_hour_name, STRING regression_type, INT number_of_days_regression, INT min_datapoints) - Gets the best-fit line value of the kci_to_trend calculated for the particular timestamp. Instances must have at least min_datapoints days worth of data to be included in the resultset.'
     FROM wme_function_type fnt
    WHERE upper(fnt.function_type_name) = 'TRENDING');
EXCEPTION
   WHEN dup_val_on_index THEN
      NULL;
END;
/

COMMIT;

BEGIN
  -- ADD UDC FUNCTION: projectTime()
  INSERT INTO wme_function(function_id, function_type_id,function_name,function_signature,function_desc)
  (SELECT -1, 
          fnt.function_type_id,
          'projectTime',
          'projectTime(RELATION,STRING,STRING,STRING,INT,INT,INT)',
          'FLOAT projectTime(RELATION kci_to_project, STRING bh_cluster_entity, STRING stored_busy_hour_name, STRING regression_type, INT number_of_days_regression, FLOAT limit, INT min_datapoints) - Gets the number of days until the specified limit will be breached. Instances must have at least min_datapoints days worth of data to be included in the resultset.'
     FROM wme_function_type fnt
    WHERE upper(fnt.function_type_name) = 'TRENDING');
EXCEPTION
   WHEN dup_val_on_index THEN
      NULL;
END;
/

COMMIT;

BEGIN
    -- Sets the minimum number of SBH datapoints an instance must have in a forecasting report,
  -- in order for that instance to be included in the results.
  -- (having "web.*" at the start of the name is probably incorrect. Needs revising.)
  wm_sysval.newsysvalifnotexists( 'web.reporting.trending.min_datapoints',   '10' );

  -- Sets the smallest valid forecasting slope value for valid instances
  wm_sysval.newsysvalifnotexists( 'SmallestValidRegressionSlope',            '0.00000001' );
END;
/

COMMIT;
-- ========================== --
-- Report Forecasting - END --
-- ========================== --

-- Classic Client Merge begin
BEGIN
  
   wm_client_feature.new('ENABLE_SOFTALARM_ID', 'Show the AlarmId textbox on the SA Definiton form', wm_client_feature.CONST_ENABLED, 'IGNORE_DUPS');
   
END;
/

COMMIT;
-- Classic Client Merge end



-- 8.0.7 Patch1 ---------------------------------------------------------------------------
-- Check is only one partition for table SAEXT_KPI_TAB.
-- If more than 1 then do nothing
-- If only one partition then pm_daily has not run yet.
--    So Fix the First partition because high value = partitiion name which causes an issue 
--    on the first run of pm_daily.
--    Also Make t sits right on today. PART_MAINT then takes care of the rest
-- ---------------------------------------------------------------------------
DECLARE
  v_old_part_name VARCHAR2(35);
  v_new_part_name VARCHAR2(35);
  v_sql_stmt VARCHAR2(2000);
  v_part_DATE DATE;
  v_sysdate DATE := trunc(sysdate,'DDD');
  p_table_name VARCHAR2(30) := 'SAEXT_KPI_TAB';
BEGIN
  SELECT SUBOBJECT_NAME
    INTO v_old_part_name
    FROM user_objects
   WHERE object_name = upper(p_table_name)
     AND object_type = 'TABLE PARTITION';

  IF TO_DATE(substr(v_old_part_name,2),'YYYYMMDDHH24') < v_sysdate
  THEN
      v_new_part_name := 'p'||to_char(v_sysdate,'YYYYMMDDHH24');
      v_sql_stmt := 'alter table '||p_table_name||' add partition '||v_new_part_name
                 || ' values less than ('
                 ||'to_DATE('||to_char(v_sysdate+1,'YYYYMMDDHH24')||',''YYYYMMDDHH24''))';
--dbms_output.put_line(v_sql_stmt);
    execute immediate v_sql_stmt;
    v_sql_stmt := 'alter table '||p_table_name||' drop partition '||v_old_part_name;
--dbms_output.put_line(v_sql_stmt);
    execute immediate v_sql_stmt;
  END IF;
EXCEPTION
  WHEN TOO_MANY_ROWS THEN
    dbms_output.put_line('TABLE SAEXT_KPI_TAB : Has more than one partition pm_daily has been run at least once NO Change Required');
  WHEN OTHERS THEN
    raise_application_error('-20100', 'ERROR FIXING TABLE SAEXT_KPI_TAB PARTITIONS: ORA'||to_char(SQLCODE)||SQLERRM);
END;
/

-- begin valnt00097329 Add support for elemprotect

BEGIN
  INSERT INTO wme_function(function_type_id,function_name,function_signature,function_desc)
  (SELECT fnt.function_type_id,
          'elemprotect',
          'elemprotect(expression)',
          'ATTR elemprotect(EXPR E) - Force E to behave as an element protected expression when warped during report generation'
     FROM wme_function_type fnt
    WHERE upper(fnt.function_type_name) = 'MISCELLANEOUS');
EXCEPTION
   WHEN dup_val_on_index THEN
      NULL;
END;
/

COMMIT;

-- end valnt00097329 Add support for elemprotect

-- begin valnt00098261 extSoftAlarm class default
BEGIN
  -- Only set if this is moto oem.  Other versions should use system default
  IF (wm_sysval.getboolean(pname => 'is.moto.hybrid')) THEN
     wm_sysval.updateSysVal('SAEXT_MIN_STORAGE', 1);
  END IF;
END;
/

COMMIT;
-- end valnt00098261 extSoftAlarm class default

-- begin valnt00094524 default part_maint sessions

BEGIN
-- Only set if this is moto oem. Other versions should use system defaults
IF (wm_sysval.getboolean(pname => 'is.moto.hybrid')) THEN
   wm_sysval.updateSysVal('PartMaintSessions', 3);
END IF;
END;
/

COMMIT;

-- end valnt00094524 default part_maint sessions


-- Start 8.0.6 patches (Redefine tables)  MUST BE LAST IN FILE
PROMPT
PROMPT Starting traffic redefinition...

DECLARE
  v_errorcnt INTEGER := 0;
  v_tstamp DATE;
BEGIN

  v_tstamp := SYSDATE;

  wmd_traffic_redefinition.redefine_tables;
  commit;

  SELECT count(*)
    INTO v_errorcnt
    FROM WM_MESSAGE_LOG
   WHERE severity IS NOT NULL
     AND lower(component) like 'wmd_traffic_redefinition.%'
     AND tstamp > v_tstamp;

   IF v_errorcnt = 0 THEN
     DBMS_OUTPUT.put_line('Traffic redefinition successful.');
   ELSE
     DBMS_OUTPUT.put_line('Traffic redefinition failed.');
   END IF;
END;
/
-- End 8.0.6 patches  (Redefine tables)  MUST BE LAST IN FILE

PROMPT END upgrade_misc_fixes.sql DONE
