---------------------------------------------------------------------------
--
-- Licensed Materials - Property of IBM
-- 5724-T05,5724-T06
--
-- (C) Copyright IBM Corp. 2003,2009. All Rights Reserved.
--
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
--
---------------------------------------------------------------------------
-- (#) ./pweb/migrate/upgrades/sql/Pweb/upgrade_misc_fixes.sql BL_core_schema_8.0.7_8.0.7.4.02_20100413  064938
-- (#) 
--

PROMPT START PWEB upgrade_misc_fixes.sql
--
-- SEAde48956 - Always do every upgrade - Do not remove next two lines
-- They force the java system to run upgrade code
UPDATE pe_agent_types SET active = 'N';
UPDATE pe_system SET ldap_url = 'temp' WHERE ldap_url IS NOT NULL;

-- valnt00094111 - Core UnknownEnterpriseField is available in "Field Selection" area under define report
UPDATE pe_mv_field pmf
SET is_available = 'N'
WHERE pmf.field_name = 'UnknownEnterpriseField'
  AND pmf.is_available = 'Y';

-- valnt00100002  Ensure fullkey/localkey fields are available
UPDATE pe_mv_field pmf
   SET is_available = 'Y'
 WHERE UPPER(pmf.field_name) in ('FULLKEY', 'LOCALKEY')
   AND pmf.is_available = 'N';

-- Disable bh_summary so clean_iot runs 
-- pweb only since sched_job_types will have row for prospect/moto
UPDATE schedule
   SET is_suspended='Y'
 WHERE job_type = 30
   AND period NOT IN ('I','O')
   AND NOT EXISTS (SELECT 1
                     FROM sched_job_types
                    WHERE job_type = 30);

-- Update sched_license to raise to 500 since reporting is under
-- agent control if command is null.
UPDATE sched_license s
   SET s.maximum = 500
 WHERE s.job_type IN (SELECT job_type
                        FROM sched_job_types
                       WHERE command IS NULL
                         AND job_type IN (1, 10));
                         
-- This is to mark any immediate schedules in pweb with a cleanup time if one is missing
UPDATE schedule
   SET cleanup_time=sysdate+1, needs_msg_update ='N'
WHERE cleanup_time is null
  AND period = 'I'
  AND job_type in (1,10);


-- valnt00097612
-- Remove the REPORT agent type:
delete from pe_activity
where agent_type_id = (select agent_type_id from pe_agent_types where agent_type_name = 'REPORT');
delete from pe_agent_load
where agent_type_id = (select agent_type_id from pe_agent_types where agent_type_name = 'REPORT');
delete from pe_agent_depend
where agent_type_id = (select agent_type_id from pe_agent_types where agent_type_name = 'REPORT');
delete from pe_agent_datasource
where agent_type_id = (select agent_type_id from pe_agent_types where agent_type_name = 'REPORT');
delete from af_process
where agent_type_id = (select agent_type_id from pe_agent_types where agent_type_name = 'REPORT');
delete from pe_agent_types where agent_type_name = 'REPORT';


-- valnt00083183
-- AnalysisFramework needs a new type of agent - 'ANALYSIS'
INSERT INTO pe_agent_types (agent_type_id, agent_type_name, description,  max_pool_size, 
  max_retry_count, retry_delay, retry_delay_factor, agent_type, jndi_name, sched_period_minutes,
  modify_pool_size)
  SELECT pe_seq_agent_types.nextval, 'ANALYSIS', 'Analysis Framework Agent', 1, 5, 60, 1.1, 'L', 'AnalysisAgentSessionHome', 60, 'N'
  FROM DUAL
 WHERE NOT EXISTS(SELECT 1 
                    FROM pe_agent_types
                   WHERE agent_type_name = 'ANALYSIS');


-- Updates for the new report result export agent
INSERT INTO pe_agent_types (agent_type_id, agent_type_name, description, max_pool_size, 
   max_retry_count, retry_delay, retry_delay_factor, agent_type, jndi_name, sched_period_minutes, modify_pool_size)
SELECT pe_seq_agent_types.nextval, 'REPORT_EXPORT','Report Result Export Agent', 1, 5, 10, 1.1, 'L', 'ReportExportAgentHome', 10, 'N'
  FROM DUAL
 WHERE NOT EXISTS(SELECT 1 
                    FROM pe_agent_types
                   WHERE agent_type_name = 'REPORT_EXPORT');

--- When adding a new agent type rebuild agent dependencies
--- Clean old dependencies first
DELETE pe_agent_depend;

--- INSTANCE depends on the TRAFFIC, INSTANCESCHEMA and TRAFFICSCHEMA
INSERT INTO pe_agent_depend ( agent_type_id, dependent_agent_type_id )
SELECT a.agent_type_id,
       b.agent_type_id
  FROM pe_agent_types a,
       pe_agent_types b
 WHERE a.agent_type_name = 'INSTANCE'
   AND b.agent_type_name IN ('TRAFFIC', 'INSTANCESCHEMA', 'TRAFFICSCHEMA');
   
--- TRAFFIC depends on the INSTANCE, INSTANCESCHEMA and TRAFFICSCHEMA
INSERT INTO pe_agent_depend ( agent_type_id, dependent_agent_type_id )
SELECT a.agent_type_id,
       b.agent_type_id
  FROM pe_agent_types a,
       pe_agent_types b
 WHERE a.agent_type_name = 'TRAFFIC'
   AND b.agent_type_name IN ('INSTANCE', 'INSTANCESCHEMA', 'TRAFFICSCHEMA');
  
--- INSTANCESCHEMA depends on INSTANCE AND TRAFFIC
INSERT INTO pe_agent_depend ( agent_type_id, dependent_agent_type_id )
SELECT a.agent_type_id,
       b.agent_type_id
  FROM pe_agent_types a,
       pe_agent_types b
 WHERE a.agent_type_name = 'INSTANCESCHEMA'
   AND b.agent_type_name IN ('INSTANCE', 'TRAFFIC', 'TRAFFICSCHEMA');
   
--- TRAFFICSCHEMA depends on INSTANCE, TRAFFIC and INSTANCESCHEMA
INSERT INTO pe_agent_depend ( agent_type_id, dependent_agent_type_id )
SELECT a.agent_type_id,
       b.agent_type_id
  FROM pe_agent_types a,
       pe_agent_types b
 WHERE a.agent_type_name = 'TRAFFICSCHEMA'
   AND b.agent_type_name IN ('INSTANCE', 'TRAFFIC', 'INSTANCESCHEMA');
 
--- LDAP_SYNC depends on all agents
INSERT INTO pe_agent_depend ( agent_type_id, dependent_agent_type_id )
SELECT a.agent_type_id,
       b.agent_type_id
  FROM pe_agent_types a,
       pe_agent_types b
 WHERE a.agent_type_name = 'LDAP_SYNC'
   AND b.agent_type_name != 'LDAP_SYNC';

--- All agents depend on LDAP_SYNC
INSERT INTO pe_agent_depend ( agent_type_id, dependent_agent_type_id )
SELECT a.agent_type_id,
       b.agent_type_id
  FROM pe_agent_types a,
       pe_agent_types b
 WHERE a.agent_type_name != 'LDAP_SYNC'
   AND b.agent_type_name = 'LDAP_SYNC';

PROMPT
PROMPT Updating metadata.sql...
@ $FLEXPM_HOME/vendor/EnterpriseTrafficCache/analysis-framework/metadata.sql 


-- Report Forecasting - START
PROMPT Adding report forecasting metadata ...
BEGIN
    -- Sets the maximum X-Axis extention for forecasting charts  
  wm_sysval.newsysvalifnotexists( 'web.reporting.trending.max_chart_extend', '30' );
END;
/

COMMIT;
-- Report Forecasting - FINISH

-- AnalysisFramework 

INSERT INTO subclass_table st ( id, class_id, name )
  ( SELECT subclass_table_seq.NEXTVAL, id, 'kpiArchive'
      FROM class_table ct 
     WHERE LOWER( ct.name ) = 'part maint' 
     AND NOT EXISTS ( SELECT 1 FROM subclass_table st WHERE st.NAME = 'kpiArchive'));

-- Now register this puppy with part_maint
INSERT INTO part_tables(part_table_id, table_name, tablespace_name, 
period, run_hourly, run_daily,
run_weekly, run_monthly, needs_export, needs_analyze, needs_move, 
needs_purge,
future_part, past_part, add_sproc)
( SELECT PART_TABLE_SEQ.nextval, 'AF_KPI_ARCHIVE', 'TRAFFIC_JUMBO', 'D', 'N', 'Y', 
'N', 'N', 'N', 'Y', 'Y', 'Y', 5, 90, 'af_kpi_combiner.part_maint_add'
FROM dual
WHERE NOT EXISTS (SELECT 1 FROM part_tables pt WHERE pt.table_name = 'AF_KPI_ARCHIVE'));


INSERT INTO subclass_map ( subclass_id, object_id )
    SELECT ID, part_table_id FROM 
    ( SELECT id, part_table_id
        FROM subclass_table st, part_tables pt
       WHERE st.name = 'kpiArchive'
           AND pt.table_name = 'AF_KPI_ARCHIVE'
           AND NOT EXISTS (SELECT 1 FROM subclass_map sm WHERE sm.subclass_id = st.ID AND sm.object_id = pt.part_table_id));


INSERT INTO part_tables(part_table_id, table_name, tablespace_name, 
period, run_hourly, run_daily,
run_weekly, run_monthly, needs_export, needs_analyze, needs_move, 
needs_purge,
future_part, past_part)
( select PART_TABLE_SEQ.nextval, 'AF_KPI_BH_ARCHIVE', 'TRAFFIC_JUMBO', 'D', 'N', 'Y', 'N', 'N', 'N', 'Y', 'Y', 'Y', 5, 90
   FROM dual
    WHERE NOT EXISTS (SELECT 1 FROM part_tables pt WHERE pt.table_name = 'AF_KPI_BH_ARCHIVE'));


INSERT INTO subclass_map ( subclass_id, object_id )
    SELECT ID, part_table_id FROM 
       ( SELECT id, part_table_id
        FROM subclass_table st, part_tables pt
       WHERE st.name = 'kpiArchive'
           AND pt.table_name = 'AF_KPI_BH_ARCHIVE'
           AND NOT EXISTS (SELECT 1 FROM subclass_map sm WHERE sm.subclass_id = st.ID AND sm.object_id = pt.part_table_id));
         
-- AnalysisFramework END

-- Japanese Lite - START
PROMPT Japanese Lite Support - Add system values if necessary
BEGIN
    wm_sysval.newsysvalifnotexists('web.reporting.chart.display.fontname', 'Arial');
    wm_sysval.newsysvalifnotexists('web.reporting.results.download.encoding', 'UTF-8');
    wm_sysval.newsysvalifnotexists('web.reporting.results.store.encoding', 'UTF-16');
    wm_sysval.newsysvalifnotexists('web.myprospect.openpage.encoding', 'UTF-16');
END;
/

PROMPT Japanese Lite Support - Install Languages if necessary
DECLARE
  langcount INTEGER;

BEGIN
  -- firstly check to see if there are any languages in pm_language
  SELECT COUNT(*) INTO langcount FROM pm_language;
  -- if not then install the languages, English as default and update the users to use these langs
  IF (langcount = 0) THEN
    pm_language_api.add_update_language(p_code         => 'en',
                                        p_display_name => 'English',
                                        p_is_default   => 'Y');
    pm_language_api.add_update_language(p_code         => 'ja',
                                        p_display_name => 'Japanese',
                                        p_is_default   => 'N');
    pm_language_api.update_user_default_language;                                        
  END IF;

END;
/

COMMIT;
-- Japanese Lite FINISH - FINISH

--- LocalKey start
INSERT INTO pe_mv_field
  (mv_field_id, mv_entity_id, field_name, heading1, heading2, description, 
   field_group_id, column_type_id, aggr, is_dimension, is_virtual, is_available)
  SELECT pe_seq_mv_field.NEXTVAL, 
         e.mv_entity_id,
         'LocalKey',
         e.entity_name,
         'Local Key',
         'The local key for the entity',
         g.field_group_id,
         ct.column_type_id,
         'N',
         'Y',
         'Y',
         'Y'
    FROM pe_mv_entity e, pe_mv_field_group g, pe_mv_field_group_map gm, pe_column_type ct
   WHERE upper(g.field_group_short) = 'EXT'
     AND g.field_group_id = gm.field_group_id
     AND gm.module_version_id = e.module_version_id
     AND upper(ct.type_name) = 'STRING'
     AND NOT EXISTS (SELECT 1
                       FROM pe_mv_field f
                      WHERE f.mv_entity_id = e.mv_entity_id
                        AND upper(f.field_name) = 'LOCALKEY');

COMMIT;
--- LocalKey finish

--- Web 2.2.6 migrate START
update pe_remote_file set cleanup_time=sysdate;
commit;
--- Web 2.2.6 migrate FINISH


-- =====================================
-- valnt00093333: START
-- =====================================
BEGIN
      -- Need to clean up any zombie monitor tasks and jobs.      
      -- Temp report cleanup agent will have removed the temp reports from PM_REPORT,
      -- but will not have cleaned up the monitor items related to them. 
      -- This leads to invalid details appearing on the monitor tab. So, ...
      
      -- Clean up any zombie monitor job(s)
      UPDATE active_job j
         SET j.cleanup_time = SYSDATE
       WHERE j.cleanup_time IS NULL
         AND j.job_type IN (1,10)
         AND NOT EXISTS ( SELECT 1 
                            FROM rg_tasklist rgt, pe_reportspec rs
                           WHERE rgt.jobid = j.job_id
                             AND rgt.pe_reportspecid = rs.reportspec_id);

    
      -- Clean up any zombie monitor task(s)
      UPDATE active_task t
         SET t.cleanup_time = SYSDATE
       WHERE t.cleanup_time IS NULL
         AND EXISTS ( SELECT 1
                        FROM active_job j
                       WHERE j.job_id = t.job_id
                         AND j.job_type IN (1, 10) )
         AND NOT EXISTS ( SELECT 1
                            FROM rg_tasklist rgt, pe_reportspec rs
                           WHERE rgt.jobid = t.job_id
                             AND rgt.id = t.task_id
                             AND rgt.pe_reportspecid = rs.reportspec_id);

END;
/
-- =====================================
-- valnt00093333: END
-- =====================================


-- 8.0.7.1 Values
BEGIN
  -- Only set if this is moto oem.  Other versions should use system defaults
  IF (wm_sysval.getboolean(pname => 'is.moto.hybrid')) THEN
      wm_sysval.newsysvalifnotexists(pname  => 'PWebReportTimeout',
                                     pvalue => to_char(nvl(wm_sysval.getinteger('ReportBlockingTimeoutMinutes') * 60,14400)));
  
      wm_sysval.deletesysval('ReportBlockingTimeoutMinutes');
  
      wm_sysval.mergesysval(pname  => 'PE_ActivityAgentMaxRunTime',   pvalue => '14400');
      wm_sysval.mergesysval(pname  => 'PartMaintSessions',            pvalue => 3);

      wm_sysval.mergesysval(pname  => 'ReportResultsDecimalRounding', pvalue => 4); -- valnt00097874 (Decimal Rounding)
  END IF;

END;
/

-- 8.0.7.2 Tickets
-- force the removal of any file types in the pweb data availability
-- where the is_show flag has been set to N
-- Note: Moto OEM only.  Normally it is dangerous to reference prospect tables in pweb. 
--       However this table is empty so this delete does nothing in a pweb environment

DELETE FROM pe_mv_file_type pmft
 WHERE upper(pmft.mv_file_type_name) IN
       (SELECT upper(file_type) 
        FROM wm_file_control 
        WHERE is_show = 'N');
COMMIT;



PROMPT END PWEB upgrade_misc_fixes.sql DONE
