---------------------------------------------------------------------------
--
-- Licensed Materials - Property of IBM
-- 5724-T05,5724-T06
--
-- (C) Copyright IBM Corp. 2003,2010. All Rights Reserved.
--
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
--
---------------------------------------------------------------------------
-- (#) ./pweb/migrate/upgrades/sql/Pweb/upgrade_schema.sql BL_core_schema_8.0.7_8.0.7.4.02_20100413  064938
-- (#) 
--

PROMPT START PWEB upgrade_schema.sql

-- valnt00104254 DROP AF_TRAP_MESSAGE_QT if not in WM_QUEUES
DECLARE
   v_af_message_q_ts user_tables.tablespace_name%TYPE := NULL;
BEGIN
   -- This queue is likely not used, so don't bother saving messages
   BEGIN
      SELECT tablespace_name 
        INTO v_af_message_q_ts
        FROM user_tables
       WHERE table_name = 'AF_TRAP_MESSAGE_QT';

   EXCEPTION
      WHEN NO_DATA_FOUND THEN
         v_af_message_q_ts := NULL;
   END;

   IF (v_af_message_q_ts IS NULL) THEN
     dbms_output.put_line('AF_TRAP_MESSAGE_QT does not exist.  Skipping...');

   ELSIF (v_af_message_q_ts = 'WM_QUEUES') THEN
     dbms_output.put_line('AF_TRAP_MESSAGE_QT is ok.  Skipping...');

   ELSE
     dbms_output.put_line('AF_TRAP_MESSAGE_QT is not ok.  Dropping queue...');

     dbms_aqadm.stop_queue
     (  
        queue_name => 'AF_TRAP_MESSAGE_queue',
        wait       => TRUE
     );

     dbms_aqadm.drop_queue
     (
        queue_name => 'AF_TRAP_MESSAGE_queue'
     );

     dbms_aqadm.drop_queue_table
     (
        queue_table => 'AF_TRAP_MESSAGE_QT',
        force => TRUE
     );

     dbms_output.put_line('AF_TRAP_MESSAGE_QT dropped.');

   END IF;
END;
/

BEGIN
   -- valnt00104254 move pe_expression literal to WM_FLEXPM.  Needs to be early in upgrade
   run_sql ( 'ALTER TABLE pe_expression_literal MOVE TABLESPACE WM_FLEXPM ');
   run_sql ( 'ALTER INDEX pk_expression_literal REBUILD TABLESPACE WM_FLEXPM ');

   run_sql ( 'ALTER TABLE pe_field ADD IS_MAPPABLE CHAR(1) DEFAULT ''Y'' NOT NULL ENABLE ');
   run_sql ( 'ALTER TABLE pe_field ADD CONSTRAINT CK_FIELD_IMAP CHECK (is_mappable IN (''Y'', ''N'')) ENABLE ');
   run_sql ( 'ALTER TABLE PE_REPORT_RESULT MODIFY REPORT_ID NOT NULL ENABLE ');

   run_sql(' CREATE INDEX pe_idx_auto_dl_set_folder_id ON pe_auto_downloaded_settings(result_folder_id) ');
   run_sql(' CREATE INDEX pe_idx_section_page_id ON pe_section(page_id) ');
   run_sql(' CREATE INDEX pe_idx_section_doc_id ON pe_section(result_document_id) ');
   run_sql(' CREATE INDEX pw_idx_page_urls_docid ON pw_page_urls(report_doc_id) ');

   run_sql( ' CREATE TABLE pe_result_export ' 
        ||  ' ( '
        ||  '   report_result_id       INTEGER NOT NULL, '
        ||  '   email_addr             VARCHAR2(64), '
        ||  '   destination            VARCHAR2(4000), '
        ||  '   format_type            VARCHAR2(23), '
        ||  '   status                 VARCHAR2(20), '
        ||  '   email_enabled          CHAR(1) NOT NULL, '
        ||  '   auto_down_enabled      CHAR(1) NOT NULL, '
        ||  '   CONSTRAINT pk_result_export PRIMARY KEY (report_result_id), '
        ||  '   CONSTRAINT ck_result_export_status CHECK (status IN (''processed'', ''not processed'', ''email failure'', ''download failure'')), '
        ||  '   CONSTRAINT fk_result_export_result_id FOREIGN KEY ( report_result_id ) '
        ||  '   REFERENCES pe_report_result( report_result_id ) ON DELETE CASCADE '
        ||  ' ) ');

   run_sql( ' CREATE TABLE PE_EXPORTED_RESULT_FILES ' 
        ||  ' ( '
        ||  '   filename               VARCHAR2(4000) '
        ||  ' ) ');

   run_sql( ' CREATE TABLE pe_schedule_extension ' 
        ||  ' ( '
        ||  '   rg_schedule_id       INTEGER NOT NULL, '
        ||  '   user_mail_address    VARCHAR2(64), '
        ||  '   file_format          VARCHAR2(23), '
        ||  '   email_notif_enabled  CHAR(1) NOT NULL, '
        ||  '   autodownload_enabled CHAR(1) NOT NULL, '
        ||  '   destination_path      VARCHAR2(256), '
        ||  '   CONSTRAINT pk_pe_schedule_extension PRIMARY KEY (rg_schedule_id), '
        ||  '   CONSTRAINT ck_schedule_ext_email CHECK (email_notif_enabled IN (''Y'', ''N'')), '
        ||  '   CONSTRAINT ck_schedule_ext_download CHECK (autodownload_enabled IN (''Y'', ''N'')), '
        ||  '   CONSTRAINT ck_schedule_ext_format CHECK (file_format IN (''CSV (with rollups)'', ''CSV (without rollups)'', ''Excel (with rollups)'', ''Excel (without rollups)'', ''XML'')), '
        ||  '   CONSTRAINT fk_pe_schedule_ext_schedule_id FOREIGN KEY ( rg_schedule_id ) '
        ||  '   REFERENCES schedule ( schedule_id ) ON DELETE CASCADE '
        ||  ' ) ');

   -- Analysis Framework - START 

   run_sql(' ALTER TABLE pe_feature DROP CONSTRAINT chk_feature ');
   run_sql(' ALTER TABLE pe_feature ADD ( CONSTRAINT chk_feature check (supported_feature IN (''ENTERPRISE'',''RESULT_AUTOMATIC_DOWNLOAD'',''EMAIL_NOTIFICATION'', ''MOTOROLA_AEMS''))) ');
   run_sql(' ALTER TABLE pe_remote_file DROP CONSTRAINT ck_pe_remote_file_type ');
   run_sql(' ALTER TABLE pe_remote_file ADD ( CONSTRAINT ck_pe_remote_file_type check (file_type  IN (''LOG'', ''CSV'', ''TMP'', ''XLS''))) ');
   run_sql(' ALTER TABLE '
        || ' pe_activity '
        || ' ADD '
        || ' ( '
        || '   origin             VARCHAR2(100), '
        || '   report_result_id   INTEGER '
        || ' )');
    
   run_sql(' CREATE TABLE pe_entity_filetype '
        || ' ( '
        || '   datasource_id  INTEGER      NOT NULL, '
        || '   entity_id      INTEGER      NOT NULL, '
        || '   file_type_name VARCHAR2(30) NOT NULL, '
        || '   CONSTRAINT pk_pe_entity_filetype PRIMARY KEY (entity_id, datasource_id, file_type_name), '
        || '   CONSTRAINT fk_pe_entity_filetype_entid FOREIGN KEY (entity_id) '
        || '   REFERENCES pe_entity(entity_id) ON DELETE CASCADE, '
        || '   CONSTRAINT fk_pe_entity_filetype_dsid FOREIGN KEY (datasource_id) '
        || '   REFERENCES pe_datasource(datasource_id) ON DELETE CASCADE '
        || ' ) ORGANIZATION INDEX ');

  run_sql(' CREATE TABLE pe_datasource_filetype '
        || ' ( '
        || '   datasource_id  INTEGER      NOT NULL, '
        || '   file_type_id   INTEGER      NOT NULL, '
        || '   CONSTRAINT pk_pe_datasource_filetype PRIMARY KEY (datasource_id, file_type_id), '
        || '   CONSTRAINT fk_pe_datasource_filetype_dsid FOREIGN KEY (datasource_id) '
        || '   REFERENCES pe_datasource(datasource_id) ON DELETE CASCADE '
        || ' ) '
        || ' ORGANIZATION INDEX ');

END;
/

-- Creating AF_TRAP_MESSAGE_QT...
----------------------------------create_af_trap_message_queue.sql-----------------------

begin
run_sql(' create type AF_TRAP_MESSAGE as object ( '
     || '   objectClass    varchar2(255), '
     || '   objectInstance varchar2(255), '
     || '   eventType      varchar2(255), '
     || '     probableCause  varchar2(255), '
     || '   alarmSeverity  varchar2(64), '
     || '   alarmTime      date, '
     || '   additionalText varchar2(1024) ) ');
end;
/
     
DECLARE

   queue_table_exits EXCEPTION;
   PRAGMA EXCEPTION_INIT (queue_table_exits,-24001);

BEGIN
    dbms_output.put_line ('Creating Queue Table AF_TRAP_MESSAGE_QT...');

    dbms_aqadm.CREATE_queue_table(
        queue_table => 'AF_TRAP_MESSAGE_QT',
        storage_clause => 'TABLESPACE WM_QUEUES',
        multiple_consumers => FALSE,
        queue_payload_type => 'AF_TRAP_MESSAGE',
        compatible => '8.1.3',
        comment => 'Creating alarm queue table');


    dbms_output.put_line ('Created Queue Table AF_TRAP_MESSAGE_QT.');

EXCEPTION
    WHEN queue_table_exits THEN 
        dbms_output.put_line ('Queue Table AF_TRAP_MESSAGE_QT. Already exists');

END;
/

-- Creating AF_TRAP_MESSAGE_queue...

DECLARE

Create_queue_exits EXCEPTION;
PRAGMA EXCEPTION_INIT (Create_queue_exits,-24006);

BEGIN

    dbms_output.put_line ('Creating Queue AF_TRAP_MESSAGE_queue...');

    dbms_aqadm.CREATE_queue(
        queue_name => 'AF_TRAP_MESSAGE_queue',
        queue_table => 'AF_TRAP_MESSAGE_QT',
        comment => 'Queue for accepting alarms from prospect ');

    dbms_output.put_line ('Created Queue AF_TRAP_MESSAGE_queue.');

EXCEPTION
    WHEN Create_queue_exits THEN 
       dbms_output.put_line ('Queue AF_TRAP_MESSAGE_queue. already exists');

END;
/

-- Start AF_TRAP_MESSAGE_queue

DECLARE
BEGIN

    dbms_output.put_line('starting queue AF_TRAP_MESSAGE_queue...');

    dbms_aqadm.start_queue(
        queue_name => 'AF_TRAP_MESSAGE_queue');

    dbms_output.put_line ('Started Queue AF_TRAP_MESSAGE_queue.');

exception
    when others then
        dbms_output.put_line('Oracle Server Error = '|| to_char (SQLERRM));
        dbms_output.put_line('Oracle Server Message = Start Queue ' || substr(SQLERRM, 1, 256));

END;
/


BEGIN

----------------------------------af_row_types.sql-------------------------------

run_sql(' CREATE OR REPLACE TYPE traffic_row AS OBJECT '
     || ' ( ' 
     || '   tstamp      DATE,' 
     || '   instance_id INTEGER,' 
     || '   fullkey     VARCHAR2(900),' 
     || '   field1      FLOAT,' 
     || '   field2      FLOAT' 
     || ' ) ');

run_sql(' CREATE OR REPLACE TYPE traffic_row_tab IS TABLE OF traffic_row');

run_sql(' CREATE OR REPLACE TYPE instance_row AS OBJECT ' 
     || ' ( ' 
     || '   enterprise_instance_id INTEGER, ' 
     || '   core_instance_id       INTEGER ' 
     || ' ) ' );


run_sql(' CREATE OR REPLACE TYPE instance_row_tab IS TABLE OF instance_row ');

----------------------------------schema.sql-------------------------------------

run_sql(' CREATE SEQUENCE af_datasource_type_seq');

run_sql(' CREATE TABLE af_datasource_type '
     || '    ( '
     || '     datasource_type_id   INTEGER      NOT NULL, '
     || '     datasource_type_name VARCHAR2(64) NOT NULL, '
     || '     CONSTRAINT pk_af_datasource_type_id PRIMARY KEY (datasource_type_id) '
     || '    ) '
     || '    TABLESPACE wm_flexpm');
  

run_sql(' CREATE UNIQUE INDEX idx_af_datasource_type_name ON  '
     || ' af_datasource_type(datasource_type_name) '
     || ' TABLESPACE wm_flexpm');

run_sql(' CREATE SEQUENCE af_datasource_seq');

run_sql(' CREATE TABLE af_datasource '
     || '   ( '
     || '    datasource_id       INTEGER NOT NULL, '
     || '    datasource_name     VARCHAR2(64) NOT NULL, '
     || '    datasource_type_id  INTEGER NOT NULL, '
     || '    resource_descriptor VARCHAR2(256), '
     || '    resource_detail     XMLType, '
     || '    pe_table_id         INTEGER, '
     || '    CONSTRAINT pk_af_datasource PRIMARY KEY (datasource_id), '
     || '    CONSTRAINT fk_af_datasource_dstid FOREIGN KEY (datasource_type_id)  '
     || ' REFERENCES af_datasource_type(datasource_type_id), '
     || '    CONSTRAINT fk_af_datasource_ptid FOREIGN KEY (pe_table_id) REFERENCES ' 
     || ' pe_table(table_id) '
     || '   ) '
     || '   TABLESPACE wm_flexpm ');

run_sql(' CREATE UNIQUE INDEX idx_af_datasource_name ON  '
     || ' af_datasource(datasource_name) '
     || ' TABLESPACE wm_flexpm ');

run_sql(' CREATE SEQUENCE af_datasource_category_seq');

run_sql(' CREATE TABLE af_datasource_category '
     || ' ( '
     || '   datasource_category_id INTEGER NOT NULL, '
     || '   category_name          VARCHAR2(255) NOT NULL '
     || ' ) '
     || ' TABLESPACE wm_flexpm ');

run_sql(' ALTER TABLE af_datasource_category '
     || '   ADD CONSTRAINT pk_af_datasource_category PRIMARY KEY  '
     || ' (datasource_category_id) ');
  
run_sql(' ALTER TABLE af_datasource_category '
     || '   ADD CONSTRAINT uq_af_datasource_category_name UNIQUE (category_name) ');

run_sql(' CREATE SEQUENCE af_datasource_access_seq ');

run_sql(' CREATE TABLE af_datasource_access '
     || ' ( '
     || '   datasource_access_id    INTEGER NOT NULL, '
     || '   datasource_access_name  VARCHAR2(64) NOT NULL, '
     || '   jndi_name               VARCHAR2(64) NOT NULL, '
     || '   dao_class_name          VARCHAR2(256) NOT NULL, '
     || '   db_object_name          VARCHAR2(256) NOT NULL, '
     || '   db_object_type          CHAR(1), '
     || '   access_config           XMLType, '
     || '   chartable               CHAR(1) DEFAULT (''Y'') NOT NULL, '
     || '   datasource_category_id  INTEGER,  '
     || '   kpi_name                VARCHAR2(256), '
     || '   kpi_heading1            VARCHAR2(256), '
     || '   kpi_heading2            VARCHAR2(256),  '
     || '   CONSTRAINT pk_af_datasource_access PRIMARY KEY (datasource_access_id), '
     || '   CONSTRAINT ck_af_datasource_access_chrt CHECK (chartable IN (''Y'', ''N'')),  '
     || '   CONSTRAINT fk_af_datasource_category FOREIGN KEY (datasource_category_id) '
     || '     REFERENCES af_datasource_category (datasource_category_id) '
     || ' ) '
     || ' TABLESPACE wm_flexpm ');


run_sql(' CREATE UNIQUE INDEX idx_af_datasource_access_nm ON  '
     || ' af_datasource_access(datasource_access_name) '
     || ' TABLESPACE wm_flexpm ');

run_sql(' CREATE TABLE af_datasource_access_map '
     || ' ( '
     || '   datasource_access_id    INTEGER NOT NULL, '
     || '   datasource_id           INTEGER NOT NULL, '
     || '   CONSTRAINT pk_af_dsrc_acs_map PRIMARY KEY (datasource_access_id,  '
     || ' datasource_id), '
     || '   CONSTRAINT fk_af_dsrc_acs_map_aid FOREIGN KEY (datasource_access_id) '
     || '     REFERENCES af_datasource_access(datasource_access_id) ON DELETE  '
     || ' CASCADE, '
     || '   CONSTRAINT fk_af_dsrc_acs_map_did FOREIGN KEY (datasource_id) '
     || '     REFERENCES af_datasource(datasource_id) ON DELETE CASCADE '
     || ' ) '
     || ' TABLESPACE wm_flexpm ');


run_sql(' CREATE SEQUENCE af_process_seq ');

run_sql(' CREATE TABLE af_process '
     || ' ( '
     || '   process_id          INTEGER NOT NULL, '
     || '   process_name        VARCHAR2(30) NOT NULL, '
     || '   agent_type_id       INTEGER NOT NULL, '
     || '   jndi_name           VARCHAR2(256) NOT NULL, '
     || '   process_config      XMLType, '
     || '   CONSTRAINT pk_af_process_id PRIMARY KEY (process_id), '
     || '   CONSTRAINT fk_af_process_atid FOREIGN KEY (agent_type_id) REFERENCES  '
     || ' pe_agent_types(agent_type_id) '
     || ' ) '
     || ' TABLESPACE wm_flexpm ');

run_sql(' CREATE UNIQUE INDEX idx_af_datasource_process_name ON  '
     || ' af_process(process_name) '
     || ' TABLESPACE wm_flexpm ');

run_sql(' CREATE SEQUENCE af_process_input_seq ');
 
run_sql(' CREATE TABLE af_process_input '
     || ' ( '
     || '   process_input_id    INTEGER NOT NULL, '
     || '   process_id          INTEGER NOT NULL, '
     || '   af_datasource_id    INTEGER, '
     || '   CONSTRAINT pk_af_process_input_id PRIMARY KEY (process_input_id), '
     || '   CONSTRAINT fk_af_process_input_pid FOREIGN KEY (process_id) REFERENCES '
     || '     af_process(process_id) ON DELETE CASCADE, '
     || '   CONSTRAINT fk_af_process_input_tid FOREIGN KEY (af_datasource_id)  '
     || ' REFERENCES '
     || '     af_datasource(datasource_id) ON DELETE CASCADE '
     || ' ) '
     || ' TABLESPACE wm_flexpm ');

run_sql(' CREATE UNIQUE INDEX idx_af_process_input ON  '
     || ' af_process_input(process_id, af_datasource_id) '
     || ' TABLESPACE wm_flexpm ');

run_sql(' CREATE SEQUENCE af_process_output_seq ');

run_sql(' CREATE TABLE af_process_output '
     || ' ( '
     || '   process_output_id   INTEGER NOT NULL, '
     || '   process_id          INTEGER NOT NULL, '
     || '   af_datasource_id    INTEGER, '
     || '   CONSTRAINT pk_af_process_output_id PRIMARY KEY (process_output_id), '
     || '   CONSTRAINT fk_af_process_output_pid FOREIGN KEY (process_id) REFERENCES '
     || '     af_process(process_id) ON DELETE CASCADE, '
     || '   CONSTRAINT fk_af_process_output_tid FOREIGN KEY (af_datasource_id)  '
     || ' REFERENCES '
     || '     af_datasource(datasource_id) ON DELETE CASCADE '
     || ' ) '
     || ' TABLESPACE wm_flexpm ');

run_sql(' CREATE UNIQUE INDEX idx_af_process_output ON  '
     || ' af_process_output(process_id, af_datasource_id) '
     || ' TABLESPACE wm_flexpm ');

run_sql(' CREATE TABLE af_activity '
     || ' ( '
     || '   activity_id          INTEGER NOT NULL, '
     || '   process_id           INTEGER NOT NULL, '
     || '   table_id             INTEGER, '
     || '   start_key            VARCHAR2(100), '
     || '   end_key              VARCHAR2(100), '
     || '   start_instance_id    INTEGER, '
     || '   end_instance_id      INTEGER, '
     || '   CONSTRAINT pk_af_activity PRIMARY KEY (activity_id), '
     || '   CONSTRAINT fk_af_activity_actid FOREIGN KEY (activity_id) REFERENCES  '
     || ' pe_activity (activity_id) ON DELETE CASCADE, '
     || '   CONSTRAINT fk_af_activity_pid   FOREIGN KEY (process_id) REFERENCES  '
     || ' af_process (process_id) ON DELETE CASCADE, '
     || '   CONSTRAINT fk_af_activity_tid   FOREIGN KEY (table_id) REFERENCES  '
     || ' pe_table(table_id) ON DELETE CASCADE '
     || ' ) '
     || ' TABLESPACE wm_flexpm ');

run_sql(' CREATE INDEX idx_af_activity_actid ON af_activity (process_id) '
     || ' TABLESPACE wm_flexpm ');
  
run_sql(' CREATE INDEX idx_af_activity_tid ON af_activity (table_id) '
     || ' TABLESPACE wm_flexpm ');


run_sql(' CREATE TABLE wmd_kpi_load_stage '
     || ' ( '
     || '   entity_name    VARCHAR2(64), '
     || '   field_name     VARCHAR2(64), '
     || '   heading1       VARCHAR2(40), '
     || '   heading2       VARCHAR2(40), '
     || '   aggr_type      VARCHAR2(10), '
     || '   tech_types     VARCHAR2(256), '
     || '   calc_source    VARCHAR2(2000) '
     || ' ) '
     || ' TABLESPACE wm_flexpm ');


----------------------------------af_kpi_schema.sql---------------------------------


run_sql(' CREATE SEQUENCE af_kpi_seq ');

run_sql(' CREATE TABLE af_kpi '
     || ' ( '
     || '   kpi_id           INTEGER      NOT NULL, '
     || '   kpi_name         VARCHAR2(64) NOT NULL, '
     || '   aggr_type        CHAR(1)      NOT NULL, '
     || '   field_id         INTEGER, '
     || '   first_avail      DATE, '
     || '   last_avail       DATE, '
     || '   busyhour_period  CHAR(1), '
     || '   CONSTRAINT pk_af_kpi PRIMARY KEY (kpi_id), '
     || '   CONSTRAINT fk_af_kpi_fid FOREIGN KEY (field_id) REFERENCES  '
     || ' pe_field(field_id) ON DELETE CASCADE, '
     || '   CONSTRAINT chk_af_kpi_bh_prd CHECK (busyhour_period IN (''D'', ''W'', ''M'', ''Y'', ''A'')) '
     || ' ) '
     || ' TABLESPACE wm_client ');

run_sql(' CREATE UNIQUE INDEX idx_af_kpi_name ON af_kpi(kpi_name) ');

run_sql(' CREATE INDEX idx_af_kpi_fid ON af_kpi(field_id)');

run_sql(' CREATE GLOBAL TEMPORARY TABLE af_kpi_archive_tmp '
     || ' ( '
     || '   tstamp         DATE           NOT NULL, '
     || '   kpi_id         INTEGER        NOT NULL, '
     || '   instance_id    INTEGER        NOT NULL, '
     || '   fullkey        VARCHAR2(900)  NOT NULL, '
     || '   numerator      FLOAT, '
     || '   denominator    FLOAT '
     || ' ) '
     || ' ON COMMIT PRESERVE ROWS ');

run_sql(' CREATE TABLE af_kpi_archive '
     || ' ( '
     || '   tstamp         DATE           NOT NULL, '
     || '   kpi_id         INTEGER        NOT NULL, '
     || '   instance_id    INTEGER        NOT NULL, '
     || '   fullkey        VARCHAR2(900)  NOT NULL, '
     || '   numerator      FLOAT, '
     || '   denominator    FLOAT, '
     || '   CONSTRAINT pk_af_kpi_archive PRIMARY KEY (tstamp, kpi_id, instance_id) '
     || ' ) '
     || ' ORGANIZATION INDEX COMPRESS '
     || ' PCTFREE 5 '
     || ' PARTITION BY RANGE (tstamp) '
     || '( PARTITION ' || 'P' || TO_CHAR(trunc(sysdate+1), 'YYYYMMDDHH24')
     || ' VALUES LESS THAN (TO_DATE(''' || TO_CHAR(trunc(sysdate+2), 'YYYYMMDDHH24') || ''', ''YYYYMMDDHH24'')) ) '
     || ' TABLESPACE traffic_jumbo ');


run_sql(' ALTER TABLE af_kpi_archive MONITORING ');

run_sql(' CREATE TABLE af_kpi_bh_archive '
     || ' ( '
     || '   kpi_id         INTEGER        NOT NULL, '
     || '   tstamp         DATE           NOT NULL, '
     || '   instance_id    INTEGER        NOT NULL, '
     || '   fullkey        VARCHAR2(900)  NOT NULL, '
     || '   bh_tstamp      DATE           NOT NULL, '
     || '   numerator      FLOAT, '
     || '   denominator    FLOAT, '
     || '   CONSTRAINT pk_af_kpi_bh_archive PRIMARY KEY (kpi_id, tstamp, instance_id) '
     || ' ) '
     || ' ORGANIZATION INDEX COMPRESS '
     || ' PCTFREE 5 '
     || ' PARTITION BY RANGE (tstamp) '
     || '( PARTITION ' || 'P' || TO_CHAR(trunc(sysdate+1), 'YYYYMMDDHH24')
     || ' VALUES LESS THAN (TO_DATE(''' || TO_CHAR(trunc(sysdate+2), 'YYYYMMDDHH24') || ''', ''YYYYMMDDHH24'')) ) '
     || ' TABLESPACE traffic_jumbo ');

run_sql(' ALTER TABLE af_kpi_bh_archive MONITORING ');




   -- Analysis Framework - END    
   
   run_sql('ALTER TABLE pe_reportspec ADD (GROUPBY_10  char(1) DEFAULT ''N'' NOT NULL) ');    


   -- Report Forecasting - START
   run_sql(' ALTER TABLE pe_view_setting_chart ADD (show_limits CHAR(1) DEFAULT ''Y'') ');

   run_sql(' ALTER TABLE pe_view_setting_chart ADD CONSTRAINT pe_view_set_chart_show_lmt_ck '
        || ' CHECK ( show_limits IN ( ''Y'', ''N'' ) )');
   -- Report Forecasting - FINISH

   -- Japanese Lite START --
   run_sql ( 'ALTER TABLE pe_view_setting_entity DROP CONSTRAINT pe_view_setting_entity_pk ');  
   wm_patch.ALTER_COLUMN_TO_NCHAR('pe_view_setting_entity', 'entity_name',64);  
   run_sql ( 'ALTER TABLE pe_view_setting_entity ADD CONSTRAINT pe_view_setting_entity_pk PRIMARY KEY ( view_setting_id, entity_name )'); 
 
   wm_patch.ALTER_COLUMN_TO_NCLOB('pe_expression_literal', 'literal_value');

   run_sql( 'DROP VIEW pe_reportdetail_vw');

   run_sql( 'ALTER TABLE WB_PREFERENCES ADD ('
       || 'Default_Language VARCHAR2(40),'
       || 'Attribute_Preference VARCHAR2(100),'
       || 'Attribute_Preference_Language VARCHAR2(40))');

   --Japanese Lite FINISH--     

END;
/

-- Rehoming changes START --
DECLARE
   v_pe_rehome_exists INTEGER := 0;
BEGIN
  -- The following is pweb only and should only be done if hasn't been done
  -- before.  Basically copy info from pe_rehoming to pm_gen_report_attr
  BEGIN
     SELECT 1 INTO v_pe_rehome_exists
       FROM user_tables 
      WHERE table_name = 'PE_REHOMING';
        
  EXCEPTION
     WHEN NO_DATA_FOUND THEN
        v_pe_rehome_exists := 0;
  END;

  IF (v_pe_rehome_exists != 1) THEN
     dbms_output.put_line('pe_rehoming does not exist, skipping upgrade.');
  ELSE
     dbms_output.put_line('pe_rehoming does exist, performing upgrade.');

     run_sql( ' INSERT INTO pm_gen_report_attr(id, reportid, name) '
           || ' SELECT sq_pm_gen_report_attr.nextval, r.id, ''rehomeInstances'''
           || '   FROM pm_report r, pe_rehoming rh '
           || '  WHERE r.pe_reportspecid = rh.reportspec_id '
           || '    AND lower(rh.rehomeflag) = ''true''' );

     run_sql( ' INSERT INTO pm_gen_report_value(attrid, seq, value) '
           || ' SELECT ra.id, 100, ''Y''' 
           || '   FROM pm_gen_report_attr ra '
           || '  WHERE ra.name = ''rehomeInstances''' );

     COMMIT;

     run_sql(' DROP TABLE PE_REHOMING ');
  END IF;
END;
/
-- Rehoming changes FINISH --

--valnt00091852 DD Import IS_AVAILABLE START

BEGIN
  run_sql('ALTER TABLE pe_mv_field add is_available CHAR(1) DEFAULT ''Y'' NOT NULL');
  run_sql('ALTER TABLE pe_mv_field ADD CONSTRAINT ck_mv_field_iava CHECK (is_available IN (''Y'', ''N'')) ');
  run_sql('ALTER TABLE pe_mv_field_tmp add is_available CHAR(1) NOT NULL');
END;
/

--valnt00091852 DD Import IS_AVAILABLE FINISH

--  valnt00107540 start
BEGIN
run_sql('Drop trigger pe_module_instance_dsft_tr');
END;
/
--  valnt00107540 End



PROMPT END PWEB upgrade_schema.sql DONE
