---------------------------------------------------------------------------
--
-- Licensed Materials - Property of IBM
-- 5724-T05,5724-T06
--
-- (C) Copyright IBM Corp. 2003,2008. All Rights Reserved.
--
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
--
---------------------------------------------------------------------------
-- (#) ./base/migrate/upgrades/sql/Generic/upgrade_misc_fixes.sql BL_core_schema_8.0.6.0.13_20081104  180142
-- (#) 
--

PROMPT START upgrade_misc_fixes806.sql

-- Ensure all 'TRAFFIC' tables are in the subclass map
insert into subclass_map(object_id,subclass_id)
    select pt.part_table_id, sc.id
      from part_tables pt, subclass_table sc
     where pt.table_name like '%\_ST\_TAB' escape '\'
       and UPPER(sc.name) = 'TRAFFIC' 
       and pt.part_table_id not in 
       (select sm.object_id from subclass_map sm)
/

PROMPT Cleaning up the orphaned schedule entries...
@clean_orphaned_skeds806.sql

COMMIT;

-- Fix non-report schedules (also fixes timezone stuff).  Keeps schedules running properly across upgrade
UPDATE schedule
   SET next_time = start_time, needs_msg_update = 'Y'
 WHERE period NOT IN ('I', 'O')
   AND NVL(end_time, sysdate) >= sysdate
   AND job_type NOT IN (1, 10);

-- Only change scheduled reports that will run in the future. Keeps schedules running properly across upgrade
UPDATE schedule
   SET next_time = start_time, needs_msg_update = 'Y'
 WHERE period NOT IN ('I', 'O')
   AND NVL(end_time, sysdate) >= sysdate
   AND job_type = 10
   AND next_time > sysdate;
    
COMMIT;

PROMPT 
PROMPT Adding metadata for SAEXT...
@ $FLEXPM_HOME/db/Oracle8i/metadata/event/saext_eventType.sql
@ $FLEXPM_HOME/db/Oracle8i/metadata/saext/pop_part_table.sql
@ $FLEXPM_HOME/db/Oracle8i/metadata/saext/pop_system_val.sql

PROMPT
PROMPT Adding extSoftAlarm subclass...
DECLARE
   l_count PLS_INTEGER;
   l_saext VARCHAR2(20) := 'extSoftAlarm';
BEGIN
   
   SELECT count(*)
   INTO l_count
   FROM subclass_table
   WHERE lower(name)=lower(l_saext);
   
   -- SAEXT
   IF (l_count = 0) THEN
	 
      INSERT INTO subclass_table (id, class_id, name, past_part_func)
         SELECT subclass_table_seq.NEXTVAL, 
                id, 
                l_saext, 
                'saext_pm.past_part_func'
         FROM class_table ct
         WHERE LOWER(ct.name)='part maint';
    
      INSERT INTO subclass_map (subclass_id, object_id)
         SELECT id, part_table_id
         FROM subclass_table st, part_tables pt
         WHERE st.name=l_saext
         AND UPPER(pt.table_name) ='SAEXT_KPI_TAB';

      COMMIT;

   END IF;

END;
/

-- These used sqlldr and data files. So we call directly
-- sa_aggregator
BEGIN
   INSERT INTO sa_aggregator( id, class, name, description )
   VALUES( 4, 'E', 'STDDEV-I', 'External STDDEV-I' );
EXCEPTION
   WHEN dup_val_on_index THEN
      NULL;
END;
/

BEGIN
   INSERT INTO sa_aggregator( id, class, name, description )
   VALUES( 5, 'E', 'STDDEV-II', 'External STDDEV-II' );
EXCEPTION
   WHEN dup_val_on_index THEN
      NULL;
END;
/

-- sa_time_range
BEGIN
   INSERT INTO sa_time_range( id, class, description, time_range_key )
   VALUES( 6, 'E', 'External Evaluation Algorithm', 'External Evaluation Algorithm' );
EXCEPTION
   WHEN dup_val_on_index THEN
      NULL;
END;
/

-- java sentry/loader
BEGIN
   INSERT INTO part_tables(part_table_id, table_name, tablespace_name, period, run_hourly, run_daily,
                           run_weekly, run_monthly, needs_export, needs_analyze, needs_move, needs_purge,
                           future_part, past_part, drop_sproc)
   VALUES(PART_TABLE_SEQ.nextval, 'PM_SENTRY_FILE_HISTORY', 'WM_FLEXPM', 'D', 'N', 'Y', 'N', 'N', 'N', 'Y', 'N', 'Y', 5, 14,
          'pm_sentry_loader.cleanup');
EXCEPTION
   WHEN dup_val_on_index THEN
      NULL;
END;
/

COMMIT;

PROMPT END upgrade_misc_fixes806.sql DONE
