-- -------------------------------------
-- @(#) upgrade_summations.sql 1.4.0 08/01/23 20:23:29
-- @(#) 
-- -------------------------------------
PROMPT
PROMPT START upgrade_summations805.sql
PROMPT

PROMPT Generate new DXS and DXC schema objects
PROMPT ...this may take a few minutes...
PROMPT

-- For each TAB table that contains an AVG column
DECLARE
   l_table_id INTEGER;
   l_table_name VARCHAR2(30);
   l_dxs_name VARCHAR(30);
BEGIN

   FOR i IN ( SELECT DISTINCT t.table_name
              FROM wmd_dict_field f, wmd_dict_table t, wmd_aggregator_base agg
              WHERE f.table_id = t.table_id
                 AND f.field_type = 'C'
                 AND t.summary_id = 0
                 AND field_aggregator NOT IN ( 'a','d' )
                 AND f.field_aggregator=agg.aggr_id
                 AND agg.func_time = 'avg'
              ORDER BY t.table_name ) LOOP

      -- Do we have a DXS table?
      BEGIN

         SELECT object_name INTO l_dxs_name
           FROM user_objects
          WHERE object_name = summarize.GenDestName( i.table_name, 'XS' )
            AND object_type = 'TABLE'
            AND subobject_name IS NULL;

         EXCEPTION
            WHEN NO_DATA_FOUND THEN
               l_dxs_name := NULL;
      END;

      -- If tables do not exist, then build them
      IF ( l_dxs_name IS NULL) THEN     

         DBMS_OUTPUT.PUT_LINE('UPDATING TABLE ' || i.table_name);
         CreateSumTab.CreateSummaryTables( 'D', i.table_name );

         -- DSM table_name
         l_table_name := summarize.GenDestName( i.table_name, 'D' );

         --
         -- DXS
         --
         -- Now add table to part_tables using DSM info as a guide
         SELECT part_table_seq.NEXTVAL INTO l_table_id FROM DUAL;

         INSERT INTO part_tables (
            part_table_id, table_name, tablespace_name, period,
            run_hourly, run_daily, run_weekly, run_monthly,
            needs_export, needs_analyze, needs_move, needs_purge,
            future_part, past_part,
            add_sproc, drop_sproc, pre_drop_sproc,
            datatypeid, stat_mask, creation_date )
         SELECT
            l_table_id, summarize.GenDestName( i.table_name, 'XS' ), tablespace_name, period,
            run_hourly, run_daily, run_weekly, run_monthly,
            needs_export, needs_analyze, needs_move, needs_purge,
            future_part, past_part,
            NULL, NULL, NULL,
            datatypeid, stat_mask, wm_date.trunc_to_last_period(sysdate, 'W') 
         FROM part_tables
         WHERE table_name = l_table_name;
 
          -- subclass_map
          INSERT INTO subclass_map ( subclass_id, object_id )
          SELECT subclass_id, l_table_id
          FROM part_tables pt, subclass_map sc
          WHERE pt.table_name = l_table_name
            AND pt.part_table_id = sc.object_id;
 
         --
         -- DXC
         --

         -- Now add table to part_tables using DSM info as a guide
         SELECT part_table_seq.NEXTVAL INTO l_table_id FROM DUAL;

         INSERT INTO part_tables (
            part_table_id, table_name, tablespace_name, period,
            run_hourly, run_daily, run_weekly, run_monthly,
            needs_export, needs_analyze, needs_move, needs_purge,
            future_part, past_part,
            add_sproc, drop_sproc, pre_drop_sproc,
            datatypeid, stat_mask, creation_date )
         SELECT
            l_table_id, summarize.GenDestName( i.table_name, 'XC' ), tablespace_name, period,
            run_hourly, run_daily, run_weekly, run_monthly,
            needs_export, needs_analyze, needs_move, needs_purge,
            future_part, past_part,
            NULL, NULL, NULL,
            datatypeid, stat_mask, wm_date.trunc_to_last_period(sysdate, 'W')
         FROM part_tables
         WHERE table_name = l_table_name;

         -- subclass_map
         INSERT INTO subclass_map ( subclass_id, object_id )
         SELECT subclass_id, l_table_id
         FROM part_tables pt, subclass_map sc
         WHERE pt.table_name = l_table_name
           AND pt.part_table_id = sc.object_id;

         COMMIT;
      END IF;
   END LOOP;

END;
/

PROMPT
PROMPT END upgrade_summations805.sql DONE
PROMPT


