PROMPT START PWEB upgrade_perf_schema226.sql
---------------------------------------------------------------------------
--
-- Licensed Materials - Property of IBM
-- 5724-T05,5724-T06
--
-- (C) Copyright IBM Corp. 2003,2008. All Rights Reserved.
--
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
--
---------------------------------------------------------------------------
-- (#) ./pweb/migrate/upgrades/sql/Pweb/upgrade_perf_schema.sql BL_core_schema_8.0.6.0.13_20081104  180142
-- (#) 
--
DECLARE
   vTableExists INTEGER := 0;
BEGIN
   BEGIN
      SELECT 1
        INTO vTableExists
        FROM user_tables
       WHERE table_name = 'PE_PERF_REPORT_DB_STATS';
      EXCEPTION WHEN NO_DATA_FOUND THEN
         vTableExists := 0;
   END;
   IF vTableExists = 1 THEN
      dbms_output.put_line('PE_PERF tables up to date');
      RETURN;
   END IF;
   dbms_output.put_line('Upgrading PE_PERF tables');
   -- Drop old tables
   run_sql( 'DROP TABLE pe_perf_stats_general' );
   run_sql( 'DROP TABLE pe_perf_stats_report' );
   run_sql( 'DROP TABLE pe_perf_stats_report_strings' );
   run_sql( 'DROP TABLE pe_perf_stats_report_queue' );
   run_sql( 'DROP TABLE pe_perf_db_stat_name' );
   run_sql( 'DROP TABLE pe_perf_report_db_stats' );
   run_sql( 'DROP TABLE pe_perf_report_db_stats_tmp' );
   -- Create new tables
   run_sql( ' CREATE TABLE pe_perf_stats_general ' 
        ||  ' ( '
        ||  '   tstamp                        DATE NOT NULL, '
        ||  '   active_user_count             INTEGER NOT NULL, '
        ||  '   max_memory                    INTEGER NOT NULL, '
        ||  '   available_memory              INTEGER NOT NULL, '
        ||  '   report_started_count          INTEGER NOT NULL, '
        ||  '   report_completed_count        INTEGER NOT NULL, '
        ||  '   scheduled_report_queue_count  INTEGER NOT NULL, '
        ||  '   immediate_report_queue_count  INTEGER NOT NULL, '
        ||  '   CONSTRAINT pk_perf_stats_general PRIMARY KEY(tstamp) '
        ||  ' ) '
        ||  ' ORGANIZATION INDEX  '
        ||  ' PARTITION BY RANGE ( tstamp ) '
        ||  ' ( '
        ||  '   PARTITION p0 VALUES LESS THAN ( TO_DATE( ''2000-01-01 00'', ''YYYY-MM-DD HH24'' ) ) '
        ||  ' ) '
        ||  ' PCTFREE 0 '
        ||  ' TABLESPACE TRAFFIC_SMALL ' );
   run_sql( ' CREATE TABLE pe_perf_stats_report '
        ||  ' ( '
        ||  '   tstamp                  DATE NOT NULL, '
        ||  '   task_id                 INTEGER NOT NULL, '
        ||  '   report_id               INTEGER NOT NULL, '
        ||  '   datasource_id           INTEGER, '
        ||  '   user_id                 INTEGER, '
        ||  '   queue_time              DATE, '
        ||  '   start_time              DATE, '
        ||  '   end_time                DATE, '
        ||  '   job_type                INTEGER, '
        ||  '   report_attrs            INTEGER, '
        ||  '   status_code             INTEGER, '
        ||  '   table_count             INTEGER, '
        ||  '   column_count            INTEGER, '
        ||  '   CONSTRAINT pk_perf_stats_report PRIMARY KEY(tstamp, task_id) '
        ||  ' ) '
        ||  ' ORGANIZATION INDEX  '
        ||  ' PARTITION BY RANGE ( tstamp ) '
        ||  ' ( '
        ||  '   PARTITION p0 VALUES LESS THAN ( TO_DATE( ''2000-01-01 00'', ''YYYY-MM-DD HH24'' ) ) '
        ||  ' ) '
        ||  ' PCTFREE 0 '
        ||  ' TABLESPACE TRAFFIC_SMALL ' );
   run_sql( ' CREATE TABLE pe_perf_stats_report_strings '
        ||  ' ( '
        ||  '   tstamp                  DATE NOT NULL, '
        ||  '   task_id                 INTEGER NOT NULL, '
        ||  '   report_name             VARCHAR2(256), '
        ||  '   status_message          VARCHAR2(4000), '
        ||  '   CONSTRAINT pk_perf_stats_report_strings PRIMARY KEY(tstamp, task_id) '
        ||  ' ) '
        ||  ' ORGANIZATION INDEX  '
        ||  ' PARTITION BY RANGE ( tstamp ) '
        ||  ' ( '
        ||  '   PARTITION p0 VALUES LESS THAN ( TO_DATE( ''2000-01-01 00'', ''YYYY-MM-DD HH24'' ) ) '
        ||  ' ) '
        ||  ' PCTFREE 0 '
        ||  ' TABLESPACE TRAFFIC_SMALL ' );
   run_sql( ' CREATE TABLE pe_perf_stats_report_queue '
        ||  ' ( '
        ||  '   tstamp                  DATE NOT NULL, '
        ||  '   agent_type_id           INTEGER NOT NULL, '
        ||  '   datasource_id           INTEGER NOT NULL, '
        ||  '   avg_queue_length        FLOAT, '
        ||  '   max_queue_length        INTEGER, '
        ||  '   min_queue_length        INTEGER, '
        ||  '   CONSTRAINT pk_perf_stats_report_queue PRIMARY KEY(tstamp, agent_type_id, datasource_id) '
        ||  ' ) '
        ||  ' ORGANIZATION INDEX  '
        ||  ' PARTITION BY RANGE ( tstamp ) '
        ||  ' ( '
        ||  '   PARTITION p0 VALUES LESS THAN ( TO_DATE( ''2000-01-01 00'', ''YYYY-MM-DD HH24'' ) ) '
        ||  ' ) '
        ||  ' PCTFREE 0 '
        ||  ' TABLESPACE TRAFFIC_SMALL ' );
   run_sql( ' CREATE TABLE pe_perf_db_stat_name '
        ||  ' ( '
        ||  '    stat_id                INTEGER NOT NULL, '
        ||  '    stat_name              VARCHAR2(64) NOT NULL, '
        ||  '   CONSTRAINT pk_perf_db_stat_name PRIMARY KEY(stat_id) '
        ||  ' ) '
        ||  ' PCTFREE 0 '
        ||  ' TABLESPACE TRAFFIC_SMALL ' );
   run_sql( ' CREATE UNIQUE INDEX pe_idx_perf_db_stat_name ON pe_perf_db_stat_name(UPPER(stat_name)) ' );
   run_sql( ' CREATE SEQUENCE pe_seq_perf_db_stat ' );
   run_sql( ' CREATE TABLE pe_perf_report_db_stats '
        ||  ' ( '
        ||  '   tstamp                  DATE NOT NULL, '
        ||  '   task_id                 INTEGER NOT NULL, '
        ||  '   stat_id                 INTEGER NOT NULL,  '  
        ||  '   stat_value              NUMBER(22), '
        ||  '   CONSTRAINT pk_perf_report_db_stats PRIMARY KEY(tstamp, task_id, stat_id) '
        ||  ' ) '
        ||  ' ORGANIZATION INDEX  '
        ||  ' PARTITION BY RANGE ( tstamp ) '
        ||  ' ( '
        ||  '   PARTITION p0 VALUES LESS THAN ( TO_DATE( ''2000-01-01 00'', ''YYYY-MM-DD HH24'' ) ) '
        ||  ' ) '
        ||  ' PCTFREE 0 '
        ||  ' TABLESPACE TRAFFIC_SMALL ' );
   run_sql( ' CREATE GLOBAL TEMPORARY TABLE pe_perf_report_db_stats_tmp '
        ||  ' ( '
        ||  '      stat_name             VARCHAR(64), '
        ||  '      stat_value            NUMBER(22) '
        ||  ' ) '
        ||  ' ON COMMIT DELETE ROWS ' );
   -- ------------------------------------------------------------------------
   -- Update partition metadata in order to build partitions
   --
   INSERT INTO subclass_table ( id, class_id, name ) 
     ( SELECT subclass_table_seq.NEXTVAL, id, 'PerformanceStats'
         FROM class_table ct 
        WHERE LOWER( ct.name ) = 'part maint' 
          AND NOT EXISTS (SELECT 1 FROM subclass_table where name = 'PerformanceStats' ));
   INSERT INTO part_tables ( part_table_id, table_name, tablespace_name, period, needs_purge, future_part, past_part )
     ( SELECT part_table_seq.NEXTVAL, 'PE_PERF_STATS_GENERAL', 'TRAFFIC_SMALL', 'W', 'Y', 2, 13
         FROM dual
        WHERE NOT EXISTS (SELECT 1 FROM part_tables where table_name = 'PE_PERF_STATS_GENERAL' ));
   INSERT INTO subclass_map ( subclass_id, object_id )
     ( SELECT id, part_table_id
         FROM subclass_table st, part_tables pt
        WHERE st.name = 'PerformanceStats'
          AND pt.table_name = 'PE_PERF_STATS_GENERAL'
          AND NOT EXISTS (SELECT 1 FROM subclass_map 
                           WHERE subclass_id = st.id and object_id = pt.part_table_id ));
   INSERT INTO part_tables ( part_table_id, table_name, tablespace_name, period, needs_purge, future_part, past_part )
     ( SELECT part_table_seq.NEXTVAL, 'PE_PERF_STATS_REPORT', 'TRAFFIC_SMALL', 'W', 'Y', 2, 13
         FROM dual
        WHERE NOT EXISTS (SELECT 1 FROM part_tables where table_name = 'PE_PERF_STATS_REPORT' ));
   INSERT INTO subclass_map ( subclass_id, object_id )
     ( SELECT id, part_table_id
         FROM subclass_table st, part_tables pt
        WHERE st.name = 'PerformanceStats'
          AND pt.table_name = 'PE_PERF_STATS_REPORT'
          AND NOT EXISTS (SELECT 1 FROM subclass_map 
                           WHERE subclass_id = st.id and object_id = pt.part_table_id ));
          
   INSERT INTO part_tables ( part_table_id, table_name, tablespace_name, period, needs_purge, future_part, past_part )
     ( SELECT part_table_seq.NEXTVAL, 'PE_PERF_STATS_REPORT_STRINGS', 'TRAFFIC_SMALL', 'W', 'Y', 2, 13
         FROM dual
        WHERE NOT EXISTS (SELECT 1 FROM part_tables where table_name = 'PE_PERF_STATS_REPORT_STRINGS' ));
 
   INSERT INTO subclass_map ( subclass_id, object_id )
     ( SELECT id, part_table_id
         FROM subclass_table st, part_tables pt
        WHERE st.name = 'PerformanceStats'
          AND pt.table_name = 'PE_PERF_STATS_REPORT_STRINGS'
          AND NOT EXISTS (SELECT 1 FROM subclass_map 
                           WHERE subclass_id = st.id and object_id = pt.part_table_id ));
   INSERT INTO part_tables ( part_table_id, table_name, tablespace_name, period, needs_purge, future_part, past_part )
      ( SELECT part_table_seq.NEXTVAL, 'PE_PERF_STATS_REPORT_QUEUE', 'TRAFFIC_SMALL', 'W', 'Y', 2, 13
          FROM dual
         WHERE NOT EXISTS (SELECT 1 FROM part_tables where table_name = 'PE_PERF_STATS_REPORT_QUEUE' ));
   INSERT INTO subclass_map ( subclass_id, object_id )
     ( SELECT id, part_table_id
         FROM subclass_table st, part_tables pt
        WHERE st.name = 'PerformanceStats'
          AND pt.table_name = 'PE_PERF_STATS_REPORT_QUEUE'
          AND NOT EXISTS (SELECT 1 FROM subclass_map 
                           WHERE subclass_id = st.id and object_id = pt.part_table_id ));
   INSERT INTO part_tables ( part_table_id, table_name, tablespace_name, period, needs_purge, future_part, past_part )
      ( SELECT part_table_seq.NEXTVAL, 'PE_PERF_REPORT_DB_STATS', 'TRAFFIC_SMALL', 'W', 'Y', 2, 13
          FROM dual
         WHERE NOT EXISTS (SELECT 1 FROM part_tables where table_name = 'PE_PERF_REPORT_DB_STATS' ));
   INSERT INTO subclass_map ( subclass_id, object_id )
     ( SELECT id, part_table_id
         FROM subclass_table st, part_tables pt
        WHERE st.name = 'PerformanceStats'
          AND pt.table_name = 'PE_PERF_REPORT_DB_STATS'
          AND NOT EXISTS (SELECT 1 FROM subclass_map 
                           WHERE subclass_id = st.id and object_id = pt.part_table_id ));
   UPDATE part_tables
      SET period = 'W',
          run_daily = 'N',
          future_part = 2,
          past_part = 13
    WHERE table_name IN ('PE_PERF_STATS_GENERAL', 'PE_PERF_STATS_REPORT');
  COMMIT;
    init_part_tab ( 'PE_PERF_STATS_GENERAL' );
    init_part_tab ( 'PE_PERF_STATS_REPORT' );
    init_part_tab ( 'PE_PERF_STATS_REPORT_STRINGS' );
    init_part_tab ( 'PE_PERF_STATS_REPORT_QUEUE' );
    init_part_tab ( 'PE_PERF_REPORT_DB_STATS' );
END;
/
PROMPT END PWEB upgrade_perf_schema226.sql DONE
