#!/bin/sh
#
# @(#) mkdirs.sh = generate directories for sentry/commander/loader
# USAGE:  mkdirs.sh [ -v ][ -d directory ][ -Rxx ]
#   -v|-verbose  = show results of each step
#   -d directory = pathname alternative to ${PROSPECT_HOME}
#   -Rxx | -rxx  = release subdirectory (eg., -R17 | -R16 | ... )
# EXAMPLE:
#   $ sh db/Oracle8i/creation_scripts/mkdirs.sh		;# all by default
#   $ sh db/Oracle8i/creation_scripts/mkdirs.sh	-Rxx	;# build just one
# EXAMPLE:
#   $ cd db/Oracle8i/creation_scripts
#   $ sh mkdirs.sh ${FLEXPM_HOME}/vendor/Lucent/ECP/1.3 -R19,R18,R17,R16
# NOTES:
#   uses 'PROSPECT_HOME' for default directory
#   builds directories for each "Rxx" -- default = R19,R18,R17,R16,R15,R14,R13
# FILES:
#   ${PROSPECT_HOME}/../ftpIN/sentryLogs
#   ${PROSPECT_HOME}/../ftpIN/Rxx/in
#   ${PROSPECT_HOME}/../ftpIN/Rxx/ok
#   ${PROSPECT_HOME}/../ftpIN/Rxx/fail
#   ${PROSPECT_HOME}/../ftpIN/Rxx/logs
# SEE ALSO:
#   ${PROSPECT_HOME}/../ftpIN/omp-transfer
# 
# (#) ./base/peik/loaders/scripts/mkdirs.sh BL_core_schema_8.0.7_8.0.7.4.02_20100413  064938
# (#) 
#

#
##  give help if asked
#
    ToolName="`basename $0`"
    case $1 in
    -help|-usage)
	echo "?($ToolName) usage information -- " 1>&2
	grep "^# " $0 1>&2
	exit 2
	;;
    esac
#
##  set handler for Interrupt/Quit Signals
#
    trap 'echo ; echo "** Interrupt **" ; exit ' 1 2 3 15
##
    lx() {
	/bin/ls -l $@ | /bin/cut -c1-11,33-333 1>&2
    }
    create() {
	Directory="$1"

	test "${Option}" != "-v" && \
	    echo 1>&2 " Creating directory  \"${Directory}\""

	mkdir -p "${Directory}"

	test "${Option}" != "-v" || \
	    lx -ld   "${Directory}"
    }
#
##  scan command args
#
##  Subset=" R19 R18 R17 R16 R15 R14 R13 "
    Subset=" Rnn "
    select=""
    Option="--"

    while true
    do
	case $1 in
	'') break ;;

	-V  | -v  ) Option="-v" ; shift ;;
	-R* | -r* ) Rxx=` echo "$1" | sed 's/^-[Rr]/R/;s/,/ /g' ` ; shift
	    select="${select} ${Rxx}"
	    ;;

	-d) shift ; PROSPECT_HOME="$1" ; shift ;;

	-*) echo "?($ToolName) unknown option: \"$1\"" 1>&2 ; exit 1 ;;
	esac
    done
#
##  confirm environment setting, check directory
#
    if   test ! -n "${PROSPECT_HOME}"
    then echo "?($ToolName) variable not set: \"\$PROSPECT_HOME\"" 1>&2 ; exit 1
    fi

    if   test ! -d "${PROSPECT_HOME}"
    then echo "?($ToolName) missing directory: \"$PROSPECT_HOME\"" 1>&2 ; exit 1
    fi
#
##  construct basic framework
#
    echo ""

    create   ${PROSPECT_HOME}/../ftpIN
    cd       ${PROSPECT_HOME}/../ftpIN
#
##  generate directories for sentry/commander/loader
#
    for Rxx in ${select:=$Subset}
    do  #

    create   ../ftpIN/${Rxx}/in
    create   ../ftpIN/${Rxx}/ok
    create   ../ftpIN/${Rxx}/fail
    create   ../ftpIN/${Rxx}/logs
    create   ../ftpIN/${Rxx}/tmp

    done

    create   ../ftpIN/sentryLogs	;# see 'sentry' et.al
    create   ../ftpIN/rcp		;# see 'omp-transfer'

    echo ""
#.
