#!/bin/ksh
#
# @(#) sentry.sh = start script for 'sentry'
# USAGE:  sentry.sh [ option ... ]

# @(#) sentry.sh ; 1.9.0 01/10/22 17:53:33

    case ${PROSPECT_HOME} in
    '')
	echo "?(sentry.sh) PROSPECT_HOME undefined, check environment" 1>&2
	echo "?(sentry.sh) aborting ..." 1>&2
	exit 1 
    esac

##  Force data directory to be managed exernal to this workspace for neatness.
##  Allow multiple workspaces with one core data set

    if ! test -f ${PROSPECT_HOME}/scripts/.prospectrc
    then
	echo "?(sentry.sh) missing file: \".prospectrc\"" 1>&2
	echo "?(sentry.sh) aborting ..." 1>&2
	exit 2 
    fi

    cd ${PROSPECT_HOME}/scripts
    .  ${PROSPECT_HOME}/scripts/.prospectrc

##  parse command args -- allow local Oracle version, eg "-oracle 8.1.7"

    SENTRYARGS=""

    while true
    do
	case $1 in
	'') break ;;

	-oracle   ) shift

	    case $1 in
	    816   ) ORACLE_HOME=`dirname ${ORACLE_HOME}`/816	;;
	    8.1.6 ) ORACLE_HOME=`dirname ${ORACLE_HOME}`/8.1.6	;;
	    817   ) ORACLE_HOME=`dirname ${ORACLE_HOME}`/817	;;
	    8.1.7 ) ORACLE_HOME=`dirname ${ORACLE_HOME}`/8.1.7	;;
	    esac

	    export  ORACLE_HOME
	    ;;

	* ) SENTRYARGS="$SENTRYARGS $1"
	esac

	case $1 in
	'') break ;;
	* ) shift ;;
	esac
    done

##  Configure oracle with ORACLE_HOME

    if ! test -f ${PROSPECT_HOME}/scripts/.oracleEnv
    then
	echo "?(sentry.sh) missing file: \".oracleEnv\"" 1>&2
	echo "?(sentry.sh) aborting ..." 1>&2
	exit 3 
    fi

    . ${PROSPECT_HOME}/scripts/.oracleEnv

    if ! test -d ${ORACLE_HOME}
    then
	echo "?(sentry.sh) missing ORACLE_HOME: \"${ORACLE_HOME}\"" 1>&2
	echo "?(sentry.sh) aborting ..." 1>&2
	exit 3 
    fi

##  Invoke 'sentry' with control parameters

    unset ENV
    unset CDPATH

    echo 1>&2 + \
    ${SENTRYPROGRAM-sentry}	\
	${WMPM}         \
	${CONFIGSET}	\
	${VERBOSITY}	\
	${SENTRYARGS}	\
	-def ${GWDEF}	\
	-maxc ${MAX_COMMANDERS}	\
	-ld ${PROSPECT_HOME}/../ftpIN/sentryLogs \
	-cp commander.sh \
	;

    exec \
    ${SENTRYPROGRAM-sentry}	\
	${WMPM}         \
	${CONFIGSET}	\
	${VERBOSITY}	\
	${SENTRYARGS}	\
	-def ${GWDEF}	\
	-maxc ${MAX_COMMANDERS}	\
	-ld ${PROSPECT_HOME}/../ftpIN/sentryLogs \
	-cp commander.sh \
	;
#.
