#!/usr/bin/ksh
# ------------------------------------------------------------------------
#     COPYRIGHT WatchMark Corp 2003
# *** (#) ./base/pm/adm/AD_run.sh BL_core_schema_8.0.7_8.0.7.4.02_20100413  064938
# *** (#) 
# ------------------------------------------------------------------------
#Updated 10/02/2009 - valnt00077479
DB_CONNECT=`crypt_util.ksh -g ${DBUSER} -c`

SCRIPTNAME=`basename $0`
usage()
{
 echo 'Usage:'
 echo "$SCRIPTNAME  [ -d YYYYMMDD -D YYYYMMDD | -w days ] [ -s {true|false} ]"
 echo "-d : the start date of date range to activate instances"
 echo "-D : the end date of date range to activate instances"
 echo "-w : the number of days window to activate instances,"
 echo "     if days is 0, then the current window will be used"
 echo "-s : scanning tables, default is true"
 echo ""
 exit
}

START_DATE=NULL
END_DATE=NULL
SCAN_TABLES=TRUE
WINDOW=NULL

if [ $# -eq 0 ]
 then
   usage
fi

while [ $# -gt 0 ]
do

    case $1 in
      -d) 
          shift
          START_DATE=$1
          ;;
      -D) 
          shift
          END_DATE=$1
          ;;
      -w)
          shift
          WINDOW=$1
          WINDOW_TEMP=`echo ${WINDOW}|sed 's/[0123456789]//g'`
          if [ ! ${WINDOW_TEMP:=NULL} = "NULL"  -o ${WINDOW:=NULL} = "NULL" ]
           then
                echo
                echo 'Invalid character in window days input'
                echo "days' input is '${WINDOW}'"
                echo
                usage
          fi

          ;;
      -s) 
          shift
          SCAN_TABLES=$1
          ;;
      -v) 
          usage
          ;;
       *) echo "$SCRIPTNAME: Invalid parameter $1"
          usage
          ;;
     esac

     if [ $# -gt 0 ]
      then
       shift
     fi
done

if [ ${START_DATE:=NULL} = "NULL" -a ${END_DATE:=NULL} = "NULL" ]
 then
      if [ ${WINDOW:=NULL} = "NULL" ]
       then
         echo "Invalid days "
         usage
      else
         echo "using window option -w "
         OPTION=WINDOW; export OPTION
      fi
 else
   if [ ${START_DATE:=NULL} = "NULL" -o ${END_DATE:=NULL} = "NULL"\
         -o ${WINDOW} != "NULL" ]
    then
      echo "window option and range option are mutual exclusive"
      echo "range option is not complete"
      usage
   else
      echo " using range option -d/-D" 
      OPTION=RANGE; export OPTION
   fi
fi

sqlplus -s /NOLOG  <<!|grep -v Connected. |grep -v "PL/SQL procedure successfully completed."
connect $DB_CONNECT
set serveroutput on size 1000000
set termout off
DECLARE
 vFoo     VARCHAR2(10) := 'FALSE';
 vSchedID INTEGER;
 vOption VARCHAR2(30) :='${OPTION}';
 vWindow  PLS_INTEGER;
BEGIN

    vFoo := UPPER( wm_sysval.getString('ScenarioActivation') );

    IF vFoo IS NOT NULL AND vFoo = 'TRUE' THEN
      INSERT INTO SCHEDULE
       (schedule_id,
        job_type,
        start_time,
        end_time,
        period,
        frequency,
        sched_fk
        )
      VALUES
       (schedule_seq.nexTval,
        8,
        sysdate,
        null,
        'I',
        1,
        null
        );

      IF vOption = 'RANGE' THEN
          INSERT INTO sched_parameters(id, name,type,value,sched_id)
          VALUES(
             sched_para_seq.nexTval, 'startDate', 'DATE',
             '$START_DATE', schedule_seq.currVal);
          INSERT INTO sched_parameters(id, name,type,value,sched_id)
          VALUES(
             sched_para_seq.nexTval, 'endDate', 'DATE', 
             '$END_DATE', schedule_seq.currVal);
      ELSIF vOption = 'WINDOW' THEN
          IF ${WINDOW} = 0 THEN
              vWindow := wm_sysval.getInteger('ScenarioActivationWindow');
              DBMS_OUTPUT.PUT_LINE('The current window is '||to_char(vWindow));
          ELSE
              vWindow := ${WINDOW};
          END IF;

          INSERT INTO sched_parameters(id, name,type,value,sched_id)
          VALUES(
             sched_para_seq.nexTval, 'window', 'NUMBER',
             vWindow, schedule_seq.currVal);
      ELSE
          RAISE_APPLICATION_ERROR(-20101, 'Invalid option(${WINDOW})');
      END IF;
      
          INSERT INTO sched_parameters(id, name,type,value,sched_id)
          VALUES(
             sched_para_seq.nexTval, 'scanTable', 'CHAR',
             '$SCAN_TABLES', schedule_seq.currVal);
      COMMIT;
      DBMS_OUTPUT.PUT_LINE('The Scenario Activation job is scheduled.');
      DBMS_OUTPUT.PUT_LINE('Check the job type 8 log file.');
    ELSE
      DBMS_OUTPUT.PUT_LINE('The Scenario Activation feature is disabled.');
      DBMS_OUTPUT.PUT_LINE('You can''t schedule Scenario Activation job.');
    END IF;
END;
/
!

