#!/usr/bin/ksh
# ------------------------------------------------------------------------
#     COPYRIGHT WatchMark Corp 2003
# *** (#) ./base/pm/adm/SBH_dedup.sh BL_core_schema_8.0.7_8.0.7.4.02_20100413  064938
# *** (#) 
# ------------------------------------------------------------------------
#Updated 10/02/2009 - valnt00077479
DB_CONNECT=`crypt_util.ksh -g ${DBUSER} -c`

SCRIPTNAME=`basename $0`
usage()
{
 echo 'Usage:'
 echo "$SCRIPTNAME -d YYYYMMDD [ -D YYYYMMDD ] [ -r Max_rows_per_deleting ] [ -s max_seconds ]"
 echo '-d YYYYMMDD: The starting date to deduplicate, The week of the date is alway'
 echo '             being used'
 echo '-D YYYYMMDD: The ending date to deduplicate, The week of the date is alway'
 echo '             being used, the default is the starting date'
 echo '-r Max_rows_per_deleting: An integer to indicate max rows per deleting to avoid'
 echo '                          Oracle rollback segment problem. The min value is 1000' 
 echo '                          The default is 10000'
 echo '-s max_seconds: The max seconds this script is allowed to run, The default is 0,'
 echo '                means no limit'
 echo ''
 echo 'Example:'
 echo "$SCRIPTNAME -d 20030105 -D 20030119 -s 36000"
 echo 'deduplicate data from week of 20030105 to week of 20030119 with max run time'
 echo '36000 seconds(ten hours)'
 echo ''
 echo 'Note: This script deduplicate based on weekly period'
 echo '      The log file is under /var/tmp directory'
 exit
}

WORK_DIR=/var/tmp

START_DATE=NULL
END_DATE=NULL
DELTRKCNT=10000
MAX_SEC=0

if [ $# -eq 0 ]
 then
 usage
fi

while [ $# -gt 0 ]
do

    case $1 in
      -d) shift
          START_DATE=$1
          ;;
      -D) shift
          END_DATE=$1
          ;;
      -r) shift
          DELTRKCNT=$1
          ;;
      -s) shift
          MAX_SEC=$1
          ;;
      -v) 
          usage
          ;;
       *) echo "$SCRIPTNAME: Invalid parameter $1"
          usage
          ;;
     esac

     shift
done

#DELTRKCNT=${2:-10000}

if [ $DELTRKCNT -lt 1000 ]
 then
 DELTRKCNT=1000
fi

if [ $END_DATE = "NULL" ]
 then
 END_DATE=$START_DATE
fi

if [ -f ${WORK_DIR}/SBH_dedup_tmp$$.lst ]
 then
 rm -f ${WORK_DIR}/SBH_dedup_tmp$$.lst
fi

if [ -f ${WORK_DIR}/SBH_dedup_tmp$$.sql ]
 then
 rm -f ${WORK_DIR}/SBH_dedup_tmp$$.sql
fi

BEGINTIME=`date +%y%b%e%T|tr " " "0"`

sqlplus -s /NOLOG  <<!|grep -v Connected. >/dev/null
connect $DB_CONNECT
set serveroutput on size 1000000
set termout off
spool ${WORK_DIR}/SBH_dedup_tmp$$
begin
 SBH_Dedup.generate_cmd(to_date('$START_DATE','YYYYMMDD'),
                        to_date('$END_DATE','YYYYMMDD'),
                        to_date('$BEGINTIME','RRMONDDHH24:MI:SS'),
                        $MAX_SEC,
                        $DELTRKCNT
                       );
end;
/
spool off
!

STATUS_CODE=`grep "ORA-" ${WORK_DIR}/SBH_dedup_tmp$$.lst|wc -l`

if [ $STATUS_CODE -eq 0 ]
 then
   echo 'Deduplication process complete OK.'
 else
   echo 'Deduplication process failed.'
   exit 1
fi
#
grep -v "PL/SQL procedure successfully completed." \
${WORK_DIR}/SBH_dedup_tmp$$.lst >${WORK_DIR}/SBH_dedup_tmp$$.sql
rm -f ${WORK_DIR}/SBH_dedup_tmp$$.lst

sqlplus -s /NOLOG  <<!
connect $DB_CONNECT
set timing on
set serveroutput on size 1000000
WHENEVER SQLERROR EXIT FAILURE
spool ${WORK_DIR}/SBH_dedup$$.log
@${WORK_DIR}/SBH_dedup_tmp$$.sql
spool off
exit
!
#STATUS_CODE=$?
STATUS_CODE=`grep "ORA-" ${WORK_DIR}/SBH_dedup$$.log|wc -l`

if [ $STATUS_CODE -eq 0 ]
 then
   echo 'Deduplication process complete OK.'
 else
   echo 'Deduplication process failed.'
   exit 1
fi

#rm -f ${WORK_DIR}/SBH_dedup_tmp$$.sql
