#!/bin/ksh

SCRIPTNAME=`basename $0`
DB_CONNECT=`crypt_util.ksh -g ${DBUSER} -c`

Logpath=''
SystemId=''
MotoSystem='N'


lv_prop_log_level=action.logging.level
lv_prop_log_path=action.logging.folder
lv_prop_moto_hybrd=is.moto.hybrid


########################################################################################################

usage () { 
      echo "$SCRIPTNAME [-u <username> -m <minutes>] | [-u <username> -d <date>] | [-a <date>]"
      echo " "
      echo "-u <username>: given username to report on "
      echo "-m <minutes>: number of minutes ot report on"
      echo "-d <date>: date to Report on must be in the format of (YYYYMMDD)"
      echo "-a Report on all Users"
      echo " "
      echo "Examples:"
      echo "$SCRIPTNAME -u <username> -m 5          Generate the log file for the given user, only viewing the details for the last 5 minutes"
      echo "$SCRIPTNAME -u <username> -d <YYYYMMDD> Generate the log file for the given user, Reporting on details for an entire day"
      echo "$SCRIPTNAME -a <YYYYMMDD>               Generate the log files for all users, for an entire day"
      exit 1
}       

########################################################################################################
#
#function to generate the Report
#

CreateUserReport () { 
     
    
   #
   # build the dynamic where clause for the time
   #
   
   if [ "${MinuteReport}" = "Y" ] 
   then
   
      #
      # user entered number of minutes 
      #
     
      #
      #Save currant time
      #
      ToYear=`date "+%Y"`; 
      ToMonth=`date "+%m"`; 
      ToDay=`date "+%d"`; 
      ToHour=`date "+%H"`; 
      ToMinute=`date "+%M"`; 
      
      ToDate="${ToYear}${ToMonth}${ToDay}_${ToHour}${ToMinute}";
      #
      #get sysdate - number of minutes user entered
      #
      FromTime=`sqlplus -S /NOLOG <<EOF
        WHENEVER SQLERROR EXIT FAILURE ROLLBACK;
        
        
        CONNECT $DB_CONNECT
        
        SET FEEDBACK OFF;
        SET HEADING OFF;
        SET SERVEROUTPUT OFF;
        SET PAGESIZE 0; 
        SET VERIFY OFF; 
        SET ECHO OFF;	
      
        SELECT to_char(sysdate - '$UserMinute'*1/24/60,'yyyymmdd_hh24mi') FROM dual; 
        
        EXIT;
      EOF`
           
      
      if [[ ${#SystemId} > 0 ]] 
      then
            FilePathName="$Logpath/"${FromTime}"_"${ToDate}"_"${SystemId}"_"${UserName}"_IBM.log";
      else
            FilePathName="$Logpath/"${FromTime}"_"${ToDate}"_"${UserName}"_IBM.log";
      fi
      TimeWhereClause=" tstamp between to_date('$FromTime','YYYYMMDD_HH24MI') AND  to_date('$ToDate','YYYYMMDD_HH24MI') AND";
   else
      Toyear=`date "+%Y"`      
      if [[ ${#SystemId} > 0 ]] 
      then
            FilePathName="$Logpath/${ReportDate}_${SystemId}_${UserName}_IBM.log";          
      else
            FilePathName="$Logpath/${ReportDate}_${UserName}_IBM.log";          
      fi
      TimeWhereClause=" trunc(tstamp) = to_date('$ReportDate','YYYYMMDD') AND ";
   fi
     

   #
   # build the dynamic where clause for the user
   #
             
     
	if [ "$UserName" = "Unknown" ] 
	then 
    	UserWhereClause=" user_id NOT IN (SELECT DISTINCT ID FROM pm_user) AND ";  
	else
    	UserWhereClause=" user_id = (SELECT ID FROM pm_user WHERE UPPER(NAME) = Upper('$UserName')) AND ";  
	fi
    
   # 
   # Find the current value of the master severity system variables in the DB
   #   
   MasterSeverity=`sqlplus -S /NOLOG <<EOF
     WHENEVER SQLERROR EXIT FAILURE ROLLBACK;           
           
     CONNECT $DB_CONNECT
           
     SET FEEDBACK OFF;
     SET HEADING OFF;
     SET SERVEROUTPUT OFF;
     SET PAGESIZE 0; 
     SET VERIFY OFF; 
     SET ECHO OFF;	
         
     SELECT VALUE FROM wm_system_values_v WHERE upper(NAME) = upper('${lv_prop_log_level}'); 
           
     EXIT;
   EOF`

   #
   # Create the Report
   #
    echo "======================================================"
    echo "Generating log file for user: [$UserName]"
    echo "======================================================"
    echo " "
    echo "Writing to file: [$FilePathName] ..."
    echo " "
    echo "======================================================"
    echo "             --== LOG FILE CONTENTS ==--              "
    echo "======================================================"

    
    sqlplus -S /NOLOG <<EOF
      WHENEVER SQLERROR EXIT FAILURE ROLLBACK;
    
      CONNECT $DB_CONNECT
      SET SERVEROUTPUT OFF
      SET PAGESIZE 0
      SET LINESIZE 80
      SET WRAP OFF
      SET LONGCHUNKSIZE 2000000
      SET FEEDBACK OFF
      SET LONG 2000000
      SET TRIMSPOOL ON
      SET LINESIZE 32767
      SET TAB OFF
      SET HEADING OFF
                         
      
      SPOOL $FilePathName
      
      SELECT trim(to_char(a.priority)) || '|' || trim(a.Report_date) || '|' || trim(a.Report_time) || '|' || trim(b.Name) || '|' || trim(a.message)
            FROM ( SELECT priority,
                      to_char(tstamp,'yyyy-dd-mm') Report_date,
                      to_char(tstamp,'hh24:mi:ss') Report_time,
                      AREA_ID, 
                      message
                   From pm_action_logging    
                   WHERE 
                      $UserWhereClause
                      $TimeWhereClause
                      $MasterSeverity != 8 AND
                      Severity <= $MasterSeverity
                   ORDER BY tstamp ASC
                   ) a,
                 ( SELECT ID,NAME from pm_action_logging_areas) b     
       WHERE a.area_id = b.ID;
     
       SELECT 'EOF' from dual;
            
      SPOOL OFF
      EXIT;
EOF
    
   
echo "======================================================"
echo " "
echo " "
}       

########################################################################################################
#
# function to create a file with a list of user where a report is required 
#
CreateListOfUsers () { 
Toyear=`date "+%Y"`    
if [[ ${#SystemId} > 0 ]] 
then
      UserListFile="$Logpath/$Toyear`date "+%m%d"`_"${SystemId}"_UserList_IBM.log"; 
else
      UserListFile="$Logpath/$Toyear`date "+%m%d"`_UserList_IBM.log"; 
fi
echo "======================================================"
echo "Compiling list of users requiring log file generation ..."
echo "======================================================"  
echo " "
echo "Writing list to file: [$UserListFile] ..."
echo " "
echo "======================================================"
echo "             --== LIST FILE CONTENTS ==--             "
echo "======================================================"
    sqlplus -S /NOLOG <<EOF
      WHENEVER SQLERROR EXIT FAILURE ROLLBACK;
    
      CONNECT $DB_CONNECT
      SET SERVEROUTPUT OFF
      SET PAGESIZE 0
      SET LINESIZE 32767
      SET LONG 2000000
      SET LONGCHUNKSIZE 2000000
      SET WRAP OFF
      SET FEEDBACK OFF
      SET TRIMSPOOL ON
      SET TAB OFF
      SET HEADING OFF
                         
      
      SPOOL $UserListFile
      
      SELECT DISTINCT username FROM (SELECT nvl(pu.name, 'Unknown') AS username
			FROM pm_user pu, pm_action_logging pml 
			WHERE pu.id (+) =  pml.user_id );
            
      SPOOL OFF
      EXIT;
EOF

echo "======================================================"
echo " "
echo " "
}

########################################################################################################
#
# function to get the directory path to Write the logs
#
getDirectorypath () { 

  ##
  #select the directory path to save the file into.
  ##
  echo "======================================================"
  echo "Getting log output folder location ...                "
  echo "======================================================"
  Logpath=`sqlplus -S /NOLOG <<EOF
    WHENEVER SQLERROR EXIT FAILURE ROLLBACK;
  
  
    CONNECT $DB_CONNECT
   
    SET FEEDBACK OFF;
    SET HEADING OFF;
    SET SERVEROUTPUT OFF;
    SET PAGESIZE 0; 
    SET VERIFY OFF; 
    SET ECHO OFF;	

    SELECT VALUE FROM wm_system_values_v WHERE upper(NAME) = upper('${lv_prop_log_path}');
  
    EXIT;
EOF`

  # this substitutes and env variable that mat be stored in sys variable
  Logpath=$(echo $Logpath | perl -p -e 's/\$(\w+)/$ENV{$1}/g')

  echo " "
  echo "Outputting log files to location: [$Logpath]" 
  echo " "
  
  if [[ -d $Logpath ]]; then
      echo "Does directory already exist?: [YES]"
  else
      echo "Does directory already exist?: [NO]"
      echo "Attempting to create directory: [$Logpath]"
      
      mkdir -p $Logpath
      
      if [[ -d $Logpath ]]; then
          echo "Directory creation successful!"
      else
          echo "Directory creation failed, script will exit because output location is not accessible ..."
          echo " "
          echo "(Please verify specified log output directory is valid, and user has sufficient privileges to create it)"
          echo " "
          exit 1
      fi
  fi
  
  echo " "
  echo " "
  
}
########################################################################################################
#
# function to get the system Id
#
getsystemid () { 

  ##
  #select the system Id to save the file into.
  ##
  echo "======================================================" 
  echo "Getting System ID for Moto OEM"
  echo "======================================================" 
  SystemId=`sqlplus -S /NOLOG <<EOF
    WHENEVER SQLERROR EXIT FAILURE ROLLBACK;
    
    
    CONNECT $DB_CONNECT
    
    SET FEEDBACK OFF;
    SET HEADING OFF;
    SET SERVEROUTPUT OFF;
    SET PAGESIZE 0; 
    SET VERIFY OFF; 
    SET ECHO OFF;	
  
    SELECT trim(system_id) FROM gen_ent_ne_system WHERE ROWNUM = 1;
    
    EXIT;
  EOF`
  echo " "
  echo "Using system ID: [$SystemId]" 
  echo " "
  echo " "

}


########################################################################################################
#
# function to check of this is a Moto hybrid
#
checkIsMotoHybrid () { 

  ##
  #select the system Id to save the file into.
  ##
  MotoHybrid=`sqlplus -S /NOLOG <<EOF
    WHENEVER SQLERROR EXIT FAILURE ROLLBACK;
    
    
    CONNECT $DB_CONNECT
    
    SET FEEDBACK OFF;
    SET HEADING OFF;
    SET SERVEROUTPUT ON;
    SET PAGESIZE 0; 
    SET VERIFY OFF; 
    SET ECHO OFF; 

    SELECT upper(VALUE) FROM wm_system_values_v WHERE upper(NAME) = upper('${lv_prop_moto_hybrd}');    

    EXIT;
  EOF`

}

########################################################################################################
#
#Main code to validate user entry 
#
if [ $# -eq  0 ]
then
   usage;
   exit 1;
fi


USAGE="u:m:d:a:h"

while getopts "${USAGE}" opt
do
   case $opt in
      u) 
         UserName=${OPTARG}
         OneUser="Y"
         ;;
      m) 
         UserMinute=${OPTARG}
         MinuteReport="Y"
         ;;
      d) 
         ReportDate=${OPTARG}
         DateReport="Y"
         ;;
      a) 
         AllUsers="Y"
         ReportDate=${OPTARG}
         ;;
      h) 
         usage
         ;;
      *) 
         echo "$SCRIPTNAME: Invalid parameter $1"
         usage
         ;;
   esac
done


##
## Validate input - must cover 3 use cases -u and -m options, -u and -d options and -a and -d options
##


# need -m or -d with -u option
if [ "${OneUser}" = "Y" ] 
then
    if [[ ${#UserMinute} = 0 ]] && [[ ${#ReportDate} = 0 ]] 
    then 
         echo "$SCRIPTNAME: Invalid parameters: -u option must be used with -m or -d options"
         usage;
         exit 1;
    fi   
    
    # only one of these must be defined
    if [[ ${#UserMinute} != 0 ]] && [[ ${#ReportDate} != 0 ]] 
    then 
       echo "$SCRIPTNAME: Invalid parameters:  -m or -d options must be exclusive"
       usage;
       exit 1;
    fi 
fi   

# need a report date for -a option
if [ "${AllUsers}" = "Y" ] && [[ ${#ReportDate} != 8 ]] 
then
   echo "$SCRIPTNAME: Invalid parameters: -a option must specify valid date"
   usage;
   exit 1;
fi

# check that we do not have -u and -a 
# only one of these must be defined
if [ "${OneUser}" = "Y" ]  && [ "${AllUsers}" = "Y" ] 
then 
   echo "$SCRIPTNAME: Invalid parameters:  -u or -a options must be exclusive"
   usage;
   exit 1;
fi   

# check that we do not have -a and -m or -d 
# only one of these must be defined
if  [ "${AllUsers}" = "Y" ] && ( [ "${DateReport}" = "Y" ] || [ "${MinuteReport}" = "Y" ] )
then 
   echo "$SCRIPTNAME: Invalid parameters:  -a options cannot be used with -m or -d options"
   usage;
   exit 1;
fi   



# validate ReportDate - check date format YYYYMMDD

if [[ ${#ReportDate} != 0 ]]
then
  # sed the report date to root out any non numerical characters in it (ignoring leading - sign)
  NON_DIGITS="$(echo $ReportDate | sed 's/[0-9]//g')"
  # make sure the value passed is an int
  if [[ ! -z $NON_DIGITS ]] 
  then
    echo "The -d option must in numerical date format YYYYMMDD, e.g. 20090212." >&2
    usage
  fi
  # check length - should also add check to determine correct format
  if [[ ${#ReportDate} != 8 ]] 
  then
    echo "The -d option must in numerical date format YYYYMMDD, e.g. 20090212." >&2
    usage
  fi
fi

# validate UserMinute - check +ve Integer
if [[ ${#UserMinute} != 0 ]]
then
  NON_DIGITS="$(echo $UserMinute | sed 's/^-//g' | sed 's/[0-9]//g')"
  # now make sure the value passed is an int
  if [[ ! -z $NON_DIGITS ]] then
    echo "The -m option must be a positive integer." >&2
    usage
  # now make sure the value passed is +ve integer
  elif [[ $UserMinute -lt 1 ]] then
    echo "The -m option must be a positive integer." >&2
    usage
  fi
fi

#
#get Directory path
#
getDirectorypath


# check to see if this is a hybrid, if so then we need to get the system id here also
checkIsMotoHybrid
#
#get system id
#
# <TODO> Implement check for Motorola
if [ "${MotoHybrid}" = "TRUE" ] 
then
 getsystemid
fi

#
# Call the fucntion to generate the Report
# if user selects to run a report for all users then
# First need to create a list of users
# then call the function fto generate the report for each user.
#
if [ "${AllUsers}" = "Y" ] 
then
#
#Run Report for each user
#
  CreateListOfUsers
  if [ -e $UserListFile ]  
  then
    for lv_user_name in `cat $UserListFile`
    do
       UserName=$lv_user_name;
       CreateUserReport
    done;  
  fi
  if [ -e $UserListFile ]  
    then
    rm $UserListFile
  fi  
    
else  
#
#Run Report for one user
#
  CreateUserReport
fi


#
#End script
#
########################################################################################################
