#! /bin/ksh
#
# @action_log_config.ksh

SCRIPTNAME=`basename $0`


DB_CONNECT=`crypt_util.ksh -g ${DBUSER} -c`


lv_prop_log_level=action.logging.level
lv_prop_log_retention=action.logging.retain
lv_prop_log_path=action.logging.folder
lv_prop_log_on=action.logging.on
lv_prop_autologout=action.logging.autologout.on



lv_path_flag=0
lv_log_level_flag=0
lv_retention_flag=0
lv_print_flag=0
lv_logon_flag=0
lv_autologout_flag=0


usage() {
    echo "$SCRIPTNAME [-l <log_level> ] [ -r <retention>] [ -f <path>] [-o <logging on>] [-a <auto logout> [-p]"
    echo "-h Displays this usage message. "
    echo "-l <log_level>    The logging level($lv_prop_log_level), can be 5 (Notice: normal but significant condition), 6 (Informational: informational messages) or 8 (Disabled) only"
    echo "-r <retention>    Number of days to retain log files ($lv_prop_log_retention). Must be a positive integer"
    echo "-f <path>         Location at which the log files are stored ($lv_prop_log_path). Must be a valid path on the system"
    echo "-o <logging on>   Flag to turn logging on or off for all users. ($lv_prop_log_on).  can be set to either TRUE or FALSE"
    echo "-a <auto logout>  Flag to turn automatic logout of users on  or off if logging framework fails. ($lv_prop_autologout) can be TRUE or FALSE"
    echo "-p                Prints out current values for above parameters"
    exit 1
}


if [ $# -eq 0 ]
then
    usage
fi



while [ $# -gt 0 ]
do
    case $1 in
        -f)
            shift
            pv_path=$1
            lv_path_flag=1
            ;;

        -l)
            shift
            pv_log_level=$1
            lv_log_level_flag=1
            ;;

        -r)
            shift
            pv_retention=$1
            lv_retention_flag=1
            ;;
        -h)
           usage
           ;;
        -p)
            pv_print=1
            lv_print_flag=1
           ;;
        -o)
        	shift
            pv_logon=$1
            lv_logon_flag=1
           ;;
           
        -a)
        	shift
            pv_autologout=$1
            lv_autologout_flag=1
           ;;
      
        *)
            echo "$SCRIPTNAME: You entered an invalid parameter $1"
            usage
            ;;
    esac
    shift
done

# Validate arguments
# Log level
if  [ "$pv_log_level" ] && [ "$pv_log_level" != "5" ] &&  [ "$pv_log_level" != "6" ] &&  [ "$pv_log_level" != "8" ]
then
    echo "$SCRIPTNAME: Log level ($pv_log_level) is incorrect, must be 5,6, or 8." >&2
    usage
fi 


# Retention period
if  [ "$pv_retention" ] 
then
    # sed the string to root out any non numerical characters in it (ignoring leading - sign)
    NON_DIGITS="$(echo $pv_retention | sed 's/^-//g' | sed 's/[0-9]//g')"
    if [[ ! -z $NON_DIGITS ]] 
    then
        echo "$SCRIPTNAME: The retention value ($pv_retention) must be an integer." >&2
        usage
    fi
    if [[ $pv_retention -lt 1 ]] then
        echo "$SCRIPTNAME: The retention value ($pv_retention) must be a positive integer." >&2
        usage
    fi
fi 

# folder
if  [ "$pv_path" ] 
then
    if [[ ! -d $pv_path ]] 
    then
        echo "The path specified ($pv_path) does not exist." >&2
        usage
    fi

fi


if  [ "$pv_logon" ] 
then
	if  [ "$pv_logon" != "TRUE" ] &&  [ "$pv_logon" != "FALSE" ] 
    then
        echo "The logging on value supplied must be either TRUE or FALSE" >&2
        usage
    fi

fi



if  [ "$pv_autologout" ] 
then
	if  [ "$pv_autologout" != "TRUE" ] &&  [ "$pv_autologout" != "FALSE" ] 
    then
        echo "The automatic logout value supplied must be either TRUE or FALSE" >&2
        usage
    fi

fi


#  open up sqlplus session to update and/or print values
sqlplus -s $DB_CONNECT <<!
SET FEED OFF
SET LINES 200
SET SERVEROUTPUT ON SIZE 1000000
SET LINESIZE 128
VARIABLE return_status NUMBER;
DECLARE
   

   PROCEDURE printVal (pName in varchar2) IS
   BEGIN
      DBMS_OUTPUT.PUT_LINE( pName  || ' value set to ' || WM_SYSVAL.GETSTRING(pName));
   END;

   PROCEDURE updateVal (pName in varchar2, pValue in varchar2) IS
   BEGIN
      WM_SYSVAL.UPDATESYSVAL( pName, pValue );
      printVal(pName);
   END;
   
   
BEGIN

  :return_status := 0;

   IF ( $lv_log_level_flag = 1 ) THEN
      updateVal( '$lv_prop_log_level', '$pv_log_level' );
   END IF;

   IF ( $lv_retention_flag = 1 ) THEN
      updateVal( '$lv_prop_log_retention', '$pv_retention' );
   END IF;

   IF ( $lv_path_flag = 1) THEN
      updateVal( '$lv_prop_log_path', '$pv_path' );
   END IF;

	IF ( $lv_logon_flag = 1) THEN
        updateVal( '$lv_prop_log_on', '$pv_logon' );
   END IF;
   
   
   	IF ( $lv_autologout_flag = 1) THEN
        updateVal( '$lv_prop_autologout', '$pv_autologout' );
   END IF;
 

   IF ( $lv_print_flag = 1) THEN
      printVal('$lv_prop_log_level');
      printVal('$lv_prop_log_retention');
      printVal('$lv_prop_log_path');
      printVal('$lv_prop_log_on');
      printVal('$lv_prop_autologout');
   END IF;

   COMMIT;


EXCEPTION
   WHEN OTHERS THEN
      :return_status := 1;
      DBMS_OUTPUT.PUT_LINE('ERROR: Unable to set system value for the logging parameter');
      DBMS_OUTPUT.PUT_LINE( SQLERRM );

END;
/
EXIT :return_status
!
XRETURN=$?

exit $XRETURN
