#! /bin/ksh
#Updated 10/02/2009 - valnt00077479
DB_CONNECT=`crypt_util.ksh -g ${DBUSER} -c`

SCRIPTNAME=`basename $0`

usage() {
   echo " "
   echo " add_filetype_timeout.sh  [ [ -t -f |  -t -f -i | -f  | -i | all ] [ clean ] ] | -d |  -v |  -vdetailed"
   echo " "
   echo " -t          : timeout "
   echo " -f          : file type "
   echo " -i          : instance name "
   echo "all          : all instances of all file types "
   echo "clean        : removes specified filetype or instance groups from scheduler "
   echo "               and expectation tables "
   echo " -d          : Displays the File Type, Timeout, and Interval for existing entries "  
   echo " -v          : usage "
   echo " -vdetailed  : usage details"
 
   echo " " 

   exit 1
}

usage_detail() {
   echo " "
    echo "$SCRIPTNAME [ [ -t -f |  -t -f -i | -f  | -i | all ] [ clean ] ] | "
   echo "    -d | "
   echo "    -v |  "
   echo "    -vdetailed"
   echo " "
   echo "#1 Option -t -f :"
   echo "The above option is used to add the timeout value(in seconds) specified "
   echo "by -t option to filetype specified by -f option."
   echo "Example : add_filetype_timeout.sh -f smsmdump -t 3600"
   echo " "
   echo "#2 Option -t -f -i :"
   echo "The above option is used to add the timeout value(in seconds) specified by -t option to"
   echo "filetype specified by -f option to instance or molist name specified by -i option."
   echo "Example : add_filetype_timeout.sh  -t 3600 -f smsmdump -i Synth"
   echo " "
   echo "#3 Option -f only :"
   echo "The above option is used to add default timeout to filetype specified by -f option."
   echo "Example : add_filetype_timeout.sh  -f smsmdump"
   echo " "
   echo "#4 Option -i only :"
   echo "The above option is used to add default timeout to all filetypes that belongs to"
   echo "instance specified by -i."
   echo "Example : add_filetype_timeout.sh -i Synth"
   echo " "
   echo "#5 Option all :"
   echo "The above option is used to add default timeout to all filetypes and all instances."
   echo "Example : add_filetype_timeout.sh all"
   echo " "
   echo "#6 Option clean : "
   echo " Used in combination -t/-i/-f/all options, it removes filetype groups from scheduler/expectation process"
   echo  "  "
   echo "#7 Option -d :"
   echo "The above option is used to display timeout and interval for filetypes."
   echo "Example : add_filetype_timeout.sh -d"


   exit 1
}


timeout=0
filetype=none
instance=none
display=n
instance_id=none
i_clean=n


while [ $# -gt 0 ]
do
   case $1 in
      -t)
         shift
         timeout=$1
         ;;
      -f)
         shift
         filetype=$1
         ;;
      -i)
         shift
         instance=$1
         ;;
      -d)
         display=y
         ;;

      all)
         filetype=all
         instance=all
         instance_id=all
         ;;
      -v)
           usage
           ;;
      -vdetailed)
           usage_detail
           ;;

       clean)
           i_clean=y
           ;;
      
       *)
         echo "$SCRIPTNAME: Invalid parameter $1"
         usage
         ;;
   esac

   shift

done

  if [ "$filetype" != "none" -a "$instance" != "none" -a "$filetype" != "all" ]
  then
    instance_id=`$FILE_DECODE_SCRIPT -e $instance -t $filetype`
  elif [ "$filetype" == "none" -a "$instance" != "none" ]
  then
     instance_id=`$FILE_DECODE_SCRIPT -e $instance`
  fi



if [ "$filetype" == "none" -a "$instance" == "none" -a "$display" == "n" ]
then
   usage
elif [ "$filetype" == "none" -a "$instance" == "none" -a "$display" == "y" ]
then
   
   sqlplus -s /NOLOG <<EOF 
   connect ${DB_CONNECT} 
   set feed off
   set serveroutput on size 1000000 format wrapped
   exec xpt.display_groups;
EOF
else
   if [ "$filetype" != "none" -a "$instance" == "none" ]
   then
      instance_id=all
   elif [ "$filetype" == "none" -a "$instance" != "none" ]
   then
       filetype=all
   fi

   if [ "$i_clean" = "y" ]
   then
      echo "  "
      echo " Cleaning filetype/timeout groups . . ."
   else
      echo "  "
      echo " Adding filetype/timeout groups . . ."
   fi



   sqlplus -s /NOLOG <<EOF  
   set feed off
   set serveroutput on size 1000000 format wrapped
   connect ${DB_CONNECT}
   exec xpt.add_filetype_timeout('$timeout','$filetype','$instance_id','$i_clean');
EOF
fi


