#! /bin/ksh
#
# (#) ./base/pm/adm/dst_rule.sh BL_core_schema_8.0.7_8.0.7.4.02_20100413  064938
# (#) 
# COPYRIGHT WatchMark Corp 2004
#
#Updated 10/02/2009 - valnt00077479
DB_CONNECT=`crypt_util.ksh -g ${DBUSER} -c`

SCRIPTNAME=`basename $0`

usage() {
    echo "${SCRIPTNAME} [ [start] [end] -s minutes ] | [ -r [id] ] | [ -x id ]"
    echo "     [start] can be : "
    echo "        -m MM -a dayofweek -d DD -t HH:MI"
    echo "        -m MM -b dayofweek -d DD -t HH:MI"
    echo "        -m MM -f dayofweek -t HH:MI"
    echo "        -m MM -l dayofweek -t HH:MI"
    echo "        -e MMDD -t HH:MI"
    echo "     [end] can be : "
    echo "        -M MM -A dayofweek -D DD -T HH:MI"
    echo "        -M MM -B dayofweek -D DD -T HH:MI"
    echo "        -M MM -F dayofweek -T HH:MI"
    echo "        -M MM -L dayofweek -T HH:MI"
    echo "        -E MMDD -T HH:MI"
    echo " "
    echo "      a/A : First (1=Sun, ...) on or after"
    echo "      b/B : Last (1=Sun, ...) or before"
    echo "      d/D : Day of the month DD"
    echo "      f/F : First (1=Sun, ...)"
    echo "      l/L : Last (1=Sun, ...)"
    echo "      m/M : Month, 01-12"
    echo "      e/E : Exact day, specify month (MM) and day (DD)"
    echo "      t/T : Time, hours (HH) and minutes (MI)"
    echo "      s   : Savings, in minutes"
    echo " OR "
    echo "      r   : Dump the rule specified or all rules"
    echo " OR "
    echo "      x   : Delete the DST rule"
    exit 1
}

XFLAG=0

XAFTER=""
XBEFORE=""
XDAY=""
XEXACT=""
XFIRST=""
XLAST=""
XMONTH=""
XTIME=""

XAFTER2=""
XBEFORE2=""
XDAY2=""
XEXACT2=""
XFIRST2=""
XLAST2=""
XMONTH2=""
XTIME2=""

XRULE=""
RULEFLAG=0

XDELETE=""
DELETEFLAG=0

XSAVINGS=""

# Check for no options
if [[ $# -eq 0 ]] then
   usage
fi

while [ $# -gt 0 ]
do

    case ${1} in
        -a) 
            shift
            if [[ $# -gt 0 ]] then
               XAFTER=${1}
               shift
               XFLAG=1
            fi
            ;;

        -A) 
            shift
            if [[ $# -gt 0 ]] then
               XAFTER2=${1}
               shift
               XFLAG=1
            fi
            ;;

        -b)
            shift
            if [[ $# -gt 0 ]] then
               XBEFORE=${1}
               shift
               XFLAG=1
            fi
            ;;

        -d)
            shift
            if [[ $# -gt 0 ]] then
               XDAY=${1}
               shift
               XFLAG=1
            fi
            ;;

        -D)
            shift
            if [[ $# -gt 0 ]] then
               XDAY2=${1}
               shift
               XFLAG=1
            fi
            ;;

        -B)
            shift
            if [[ $# -gt 0 ]] then
               XBEFORE2=${1}
               shift
               XFLAG=1
            fi
            ;;

        -e)
            shift
            if [[ $# -gt 0 ]] then
               XEXACT=${1}
               shift
               XFLAG=1
            fi
            ;;

        -E)
            shift
            if [[ $# -gt 0 ]] then
               XEXACT2=${1}
               shift
               XFLAG=1
            fi
            ;;

        -f)
            shift
            if [[ $# -gt 0 ]] then
               XFIRST=${1}
               shift
               XFLAG=1
            fi
            ;;

        -F)
            shift
            if [[ $# -gt 0 ]] then
               XFIRST2=${1}
               shift
               XFLAG=1
            fi
            ;;

        -l)
            shift
            if [[ $# -gt 0 ]] then
               XLAST=${1}
               shift
               XFLAG=1
            fi
            ;;

        -L)
            shift
            if [[ $# -gt 0 ]] then
               XLAST2=${1}
               shift
               XFLAG=1
            fi
            ;;

        -m)
            shift
            if [[ $# -gt 0 ]] then
               XMONTH=${1}
               shift
               XFLAG=1
            fi
            ;;

        -M)
            shift
            if [[ $# -gt 0 ]] then
               XMONTH2=${1}
               shift
               XFLAG=1
            fi
            ;;

        -r)
            shift
            if [[ $# -gt 0 ]] then
               XRULE=${1}
               shift
            fi

            # rule id is optional
            RULEFLAG=1
            ;;

        -s)
            shift
            if [[ $# -gt 0 ]] then
               XSAVINGS=${1}
               shift
               XFLAG=1
            fi
            ;;

        -t)
            shift
            if [[ $# -gt 0 ]] then
               XTIME=${1}
               shift
               XFLAG=1
            fi
            ;;

        -T)
            shift
            if [[ $# -gt 0 ]] then
               XTIME2=${1}
               shift
               XFLAG=1
            fi
            ;;

        -x)
            shift
            if [[ $# -gt 0 ]] then
               XDELETE=${1}
               DELETEFLAG=1
               shift
            fi
            ;;

        *)
            echo "$0: Invalid parameter ${1}"
            usage
            ;;
    esac

done

# exclusivity
if [[ $(( $XFLAG + $RULEFLAG + $DELETEFLAG )) -ne 1 ]] then
   usage
fi

#
# Allow the database to handle the parameter verification
#
sqlplus -s /NOLOG << !
set feed off
set lines 200
set serveroutput on size 1000000
connect $DB_CONNECT
VARIABLE return_status NUMBER;
DECLARE
   p_id       INTEGER := 0;
   pErrorCode INTEGER := 0;
   pErrorMessage VARCHAR2(512);
BEGIN
   IF ( $DELETEFLAG = 1 ) THEN

      wm_time.delete_dst_rule( '$XDELETE',
                               pErrorCode,
                               pErrorMessage );
   ELSE

      wm_time.create_dst_rule( '$XAFTER',
                        '$XBEFORE',
                        '$XDAY',
                        '$XEXACT',
                        '$XFIRST',
                        '$XLAST',
                        '$XMONTH',
                        '$XTIME',
                        '$XAFTER2',
                        '$XBEFORE2',
                        '$XDAY2',
                        '$XEXACT2',
                        '$XFIRST2',
                        '$XLAST2',
                        '$XMONTH2',
                        '$XTIME2', 
                        '$XRULE',
                        $RULEFLAG,
                        '$XSAVINGS',
                        p_id, 
                        pErrorCode, 
                        pErrorMessage );
   END IF;

    IF ( pErrorCode != 0 ) THEN
       :return_status := 1;

       wm_print.print(pErrorMessage, LENGTH( pErrorMessage ) );
    ELSE
       :return_status := 0;

       IF ( p_id IS NOT NULL AND p_id != 0 ) THEN
          wm_print.print('DST rule: ' || TO_CHAR( p_id ) );
       END IF;

    END IF;

    COMMIT;


END;
/
EXIT :return_status
!
XRETURN=$?

exit $XRETURN
