#!/bin/ksh
#-- -------------------------------------
#-- (#) ./base/pm/adm/en_clean.sh BL_core_schema_8.0.7_8.0.7.4.02_20100413  064938
#-- (#) 
#-- -------------------------------------
#
#Updated 10/02/2009 - valnt00077479
DB_CONNECT=`crypt_util.ksh -g ${DBUSER} -c`

SCRIPTNAME=`basename $0`

SYSTEM_VARIABLE="EventRetention"

display_usage()
{
   (\
   echo "$SCRIPTNAME"
   echo $SCRIPTNAME | sed "s/./-/g"
   echo "This script will display or set the Retention time (in days) of"
   echo "Event data before they are cleaned up.  This script can also be"
   echo "used to run the Event cleanup immediately without going through"
   echo "the scheduler."
   echo
   echo "Note: Make sure DB_CONNECT is properly set."
   echo
   echo "Usage: $SCRIPTNAME [ -h | -d | -s <t> | -e]"
   echo "where:"
   echo "  -h    : show the usage information"
   echo "  -d    : display the current retention time of Events"
   echo "  -s <t>: set the retention time of Events to <t> days"
   echo "  -e    : execute event cleanup immediately"
   ) >&2
}

run_sql()
{
   sqlplus <<EOSQL
     $DB_CONNECT
     $1
EOSQL
}

display_retention()
{
   sqlplus -s <<EOSQL
      $DB_CONNECT
      colu name format a30
      colu value format a30
      select a.name, b.value || ' days' value
        from WM_SYSTEM_VARIABLE a, WM_SYSTEM_VALUE b
       where a.id=b.variable_id
         and a.name='$SYSTEM_VARIABLE';
     exit
EOSQL

}

set_retention()
{

   sqlplus -s <<EOSQL
      $DB_CONNECT
      exec register_system_value('$SYSTEM_VARIABLE', '$1')
      commit;
      exit
EOSQL

}

exec_cleanup()
{

   sqlplus -s <<EOSQL
      $DB_CONNECT
      set serveroutput on
      variable status number
      begin
      :status := event_clean(NULL);
      end;
/
      exit :status
EOSQL

}

DO_SET="N"
DO_EXEC="N"

while getopts heds: opts
do
   case $opts in
   s  )  RETENTION=$OPTARG
         DO_SET="Y" ;;
   e  )  DO_EXEC="Y" ;;
   d  )  display_retention
         exit 0 ;;
   h  )  display_usage
         exit 0 ;;
   \? )  display_usage
         exit 1 ;;
   esac
done
shift `expr $OPTIND - 1`

if [ -z "$DB_CONNECT" ]
then
   echo "$SCRIPTNAME: The environment variable DB_CONNECT is not set."
   exit 9
fi

if [ "$DO_SET" = "Y" ]
then
   expr $RETENTION + 9 > /dev/null 2>&1
   if [ $? -ne 0 ]
   then
      display_usage
      exit 2
   fi
   set_retention $RETENTION
fi

if [ "$DO_EXEC" = "Y" ]
then

   display_retention $SYSTEM_VARIABLE

   (\
   echo "You are about to clean up Events data (subject to"
   echo "the Retention constraint)."
   ) >&2
   echo "Do you wish to continue? \c"
   read response
   if [ "$respones" = "Y" -o "$response" = "y" ]
   then
      exec_cleanup
   fi

fi
  
if [ "${DO_SET}${DO_EXEC}" = "NN" ]
then
   display_usage
fi
