#!/bin/ksh
###########################################################################
#
# Licensed Materials - Property of IBM
# 5724-T05,5724-T06
#
# (C) Copyright IBM Corp. 2008,2009. All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
###########################################################################
# (#) ./base/pm/adm/excludeFromFeature.sh BL_core_schema_8.0.7_8.0.7.4.02_20100413  064938
# (#)  
#

SCRIPTNAME=`basename $0`

DB_CONNECT=`crypt_util.ksh -g ${DBUSER} -c`

# ---------------------
# How to use the script
# ---------------------
usage()
{
 echo 'Usage:'
  echo 'To Exclude a device from a feature'
  echo '=================================='
  echo "$SCRIPTNAME  -action add -feature <<feature_name>> -entity <<entity_name>> -fullkey <<full_key>>"
  echo '-action     : The action to perform in this case it will be add'
  echo '-feature    : The name of the feature e.g. DataAvailability'
  echo '-entity     : The name of the entity e.g. BSC'
  echo '-fullkey    : The full key name of the device e.g. 112-6-21'
  echo 
  echo 'To Exclude multiple devices from a feature'
  echo '=========================================='
  echo "$SCRIPTNAME  -action add -file <<filename>>"
  echo '-action     : The action to perform in this case it will be add'
  echo '-file       : The name of the file which contains the list of devices to be actioned'
  echo '              The file is a comma delimitd file (1 device per line)'
  echo '              For example DataAvailability,BTSs,112-6-23'
  echo  
  echo 'To Exclude all devices for an Entity'
  echo '===================================='
  echo "$SCRIPTNAME  -action addall -feature <<feature_name>> -entity <<entity_name>> "
  echo '-action     : The action to perform in this case it will be addall'
  echo '-feature    : The name of the feature e.g. DataAvailability'
  echo '-entity     : The name of the entity e.g. BSC'
  echo
  echo 'To Cancel previously excluded devices'
  echo '====================================='
  echo "$SCRIPTNAME  -action cancel -feature <<feature_name>> -entity <<entity_name>> -fullkey <<full_key>>"
  echo '-action     : The action to perform in this case it will be cancel'
  echo '-feature    : The name of the feature e.g. DataAvailability'
  echo '-entity     : The name of the entity e.g. BSC'
  echo '-fullkey    : The full key name of the device e.g. 112-6-21'
  echo
  echo 'To Cancel Many previously excluded devices'
  echo '=========================================='
  echo "$SCRIPTNAME  -action cancel -file <<filename>>"
  echo '-action     : The action to perform in this case it will be cancel'
  echo '-file       : The name of the file which contains the list of devices to be actioned'
  echo '              The file is a comma delimitd file (1 device per line)'
  echo '              For example DataAvailability,BTSs,112-6-23'
  echo  
  echo 'To Cancel all devices for an Entity'
  echo '==================================='
  echo "$SCRIPTNAME  -action cancelall -feature <<feature_name>> -entity <<entity_name>> "
  echo '-action     : The action to perform in this case it will be cancelall'
  echo '-feature    : The name of the feature e.g. DataAvailability'
  echo '-entity     : The name of the entity e.g. BSC'
  echo  
  echo 'To List Devices Excluded'
  echo '============================'
  echo "$SCRIPTNAME  -action list -feature <<feature_name>> "
  echo '-action     : The action to perform in this case it will be list'
  echo '-feature    : The name of the feature e.g. DataAvailability'  
  echo  
  echo 'To List All Devices Excluded (including sub tree)'
  echo '============================'
  echo "$SCRIPTNAME  -action listall -feature <<feature_name>> "
  echo '-action     : The action to perform in this case it will be listall'
  echo '-feature    : The name of the feature e.g. DataAvailability'  
  echo  
  echo 'To List Devices Excluded in csv format'
  echo '============================'
  echo "$SCRIPTNAME  -action listcsv -feature <<feature_name>> "
  echo '-action     : The action to perform in this case it will be listcsv'
  echo '-feature    : The name of the feature e.g. DataAvailability'  
  echo  
  echo ''
  exit 2
}

function runplsqlproc
{
  sqlplus -s ${DB_CONNECT} <<SQLPLUS 
  WHENEVER SQLERROR EXIT FAILURE
  set linesize 1000
  set pagesize 80
  set verify off
  set heading off
  set showmode off
  set feedback off
  set serveroutput on size unlimited
  DECLARE
  BEGIN
     $1;
  END;
  /
  EXIT
SQLPLUS

}


########################
# Parameter validation
########################
if [ $# -eq 0 ]
 then
 usage
 exit 2
fi

entityname=''
fullkey=''
featurename=''

list=''
remove=NULL

while [ $# -gt 0 ]
do
    case $1 in
      -action)
          shift
          actionname=\'$1\'
          ;;
      -feature)
          shift
          featurename=\'$1\'
          ;;
      -entity)
          shift
          entityname=\'$1\'
          ;;
      -fullkey) 
          shift
          fullkey=\'$1\'
          ;;
      -file)
          shift
          filename=$1
          ;;
       *) echo "$SCRIPTNAME: Invalid parameter $1"
          usage
          exit 2
          ;;
     esac

     if [ $# -gt 0 ]
      then
       shift
     fi
done
#################################
# Add 1 exclusion
#################################
if [[ ${actionname} = "'add'"
   && ${featurename} != "" 
   && ${entityname} != "" 
   && ${fullkey} != "" ]] 
 then    
    echo Adding the instance to the exclusion list: Entity type = ${entityname}, Full key =  ${fullkey}, Feature = ${featurename}
    echo ============================================
    # Connect to the Database and run the query
    runplsqlproc "WM_FEATURES_EXCLUDED.addExclusion("${featurename}","${entityname}","${fullkey}");WM_FEATURES_EXCLUDED.updateconfig"
    # Check exit code from sql process and exit accordingly
    if [ $? -ne 0 ] 
    then
       exit 1
    fi

#################################
# Add many exclusion from a file
#################################
elif [[ ${actionname} = "'add'"
   && ${filename} != "" ]] 
 then
    echo Adding the instances stored in the file ${filename} to the exclusion list
    dos2unix ${filename} ${filename}.tmp
    mv ${filename}.tmp ${filename}
    line_num=0
    echo ============================================
    while read line_by_line
    do
          line_num=$((line_num+1))
          # For each record in the file
          echo Processing line number ${line_num} from file
          # Connect to the Database and run the query
          runplsqlproc "WM_FEATURES_EXCLUDED.addExclusion('"${line_by_line}"')"  
          echo ============================================

    done < ${filename}
    
    # check to see if any data in file at all
    if [ ${line_num} -eq 0 ] 
    then
       echo File does not contain any data
       exit 1
    fi

    # update the config
    runplsqlproc "WM_FEATURES_EXCLUDED.updateconfig"

########################################
# Add All devices for a particular entity
########################################
elif [[ ${actionname} = "'addall'"
   && ${featurename} != "" 
   && ${entityname} != "" ]] 
 then
    echo Adding all instances for the entity ${entityname} to the exclusion list
    echo ============================================
    # Connect to the Database and run the query
    runplsqlproc "WM_FEATURES_EXCLUDED.addExclusion("${featurename}","${entityname}");WM_FEATURES_EXCLUDED.updateconfig"  
    # Check exit code from sql process and exit accordingly
    if [ $? -ne 0 ] 
    then
       exit 1
    fi

#################################
# Cancel 1 exclusion
#################################
elif [[ ${actionname} = "'cancel'"
   && ${featurename} != "" 
   && ${entityname} != "" 
   && ${fullkey} != "" ]] 
 then
    echo Cancelling the instance from the exclusion list: Entity type = ${entityname}, Full key =  ${fullkey}, Feature = ${featurename}
    echo ============================================
    # Connect to the Database and run the query
    runplsqlproc "WM_FEATURES_EXCLUDED.cancelExclusion("${featurename}","${entityname}","${fullkey}");WM_FEATURES_EXCLUDED.updateconfig"  
    # Check exit code from sql process and exit accordingly
    if [ $? -ne 0 ] 
    then
       exit 1
    fi

###################################
# Cancel many exclusion from a file
################################### 
elif [[ ${actionname} = "'cancel'"
   && ${filename} != "" ]] 
 then  
     echo Cancelling the instances stored in the file ${filename} to the exclusion list  
     dos2unix ${filename} ${filename}.tmp
     mv ${filename}.tmp ${filename}
     line_num=0
     echo ============================================
     while read line_by_line
     do
           line_num=$((line_num+1))
           # For each record in the file
           echo Processing line number ${line_num} from file
           # Connect to the Database and run the query
          runplsqlproc "WM_FEATURES_EXCLUDED.cancelExclusion('"${line_by_line}"')"      
           echo ============================================
 
     done < ${filename}
     # check to see if any data in file at all
     if [ ${line_num} -eq 0 ] 
     then
        echo File does not contain any data
        exit 1
     fi
    # update the config
    runplsqlproc "WM_FEATURES_EXCLUDED.updateconfig"

############################################
# Cancel All devices for a particular entity
############################################
elif [[ ${actionname} = "'cancelall'"
   && ${featurename} != "" 
   && ${entityname} != "" ]] 
 then

    echo Cancelling all the devices for the entity ${entityname} from the exclusion list
    echo ============================================
    # Connect to the Database and run the query
    runplsqlproc "WM_FEATURES_EXCLUDED.cancelExclusion("${featurename}","${entityname}");WM_FEATURES_EXCLUDED.updateconfig"     
    # Check exit code from sql process and exit accordingly
    if [ $? -ne 0 ] 
    then
       exit 1
    fi

###########################################
# List devices for a particular feature
###########################################
elif [[ ${actionname} = "'list'"
     && ${featurename} != "" ]]
 then
    # Connect to the Database and run the query
    runplsqlproc "WM_FEATURES_EXCLUDED.listDevicesForFeature(pFeatureName=>"${featurename}",pIncludeSubTree=>FALSE,pOutputCSV=>FALSE)"  

###########################################
# List all devices for a particular feature (incl. sub tree)
###########################################
elif [[ ${actionname} = "'listall'"
     && ${featurename} != "" ]]
 then
    # Connect to the Database and run the query
    runplsqlproc "WM_FEATURES_EXCLUDED.listDevicesForFeature(pFeatureName=>"${featurename}",pIncludeSubTree=>TRUE,pOutputCSV=>FALSE)"     

###########################################
# List all devices for a particular feature in csv format (excl. subtree)
###########################################
elif [[ ${actionname} = "'listcsv'"
     && ${featurename} != "" ]]
 then
    # Connect to the Database and run the query
    runplsqlproc "WM_FEATURES_EXCLUDED.listDevicesForFeature(pFeatureName=>"${featurename}",pIncludeSubTree=>FALSE,pOutputCSV=>TRUE)"      
else
   usage
   exit 2
fi

# Check exit code from sql process and exit accordingly
if [ $? -ne 0 ] 
then
   exit 1
else
   exit 0
fi
