#!/usr/bin/ksh
###########################################################################
#
# Licensed Materials - Property of IBM
# 5724-T05,5724-T06
#
# (C) Copyright IBM Corp. 2003,2008. All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
###########################################################################
# (#) ./base/pm/adm/export_soft_alarms.sh BL_core_schema_8.0.7_8.0.7.4.02_20100413  064938
#
SCRIPTNAME=`basename $0`
#Updated 12/02/2009 - valnt00077479
DB_CONNECT=`crypt_util.ksh -g ${DBUSER} -c`

show_title()
{
   echo Prospect User Document Export Soft Alarms Utility.
   echo ----------------------------------------------------------------------
   echo @(#) export_soft_alarms.sh 1.9.0 07/06/25 16:12:51
   echo @(#) 
   echo Copyright 2003 IBM Corp.
   echo ----------------------------------------------------------------------
   echo
}

usage() {
   show_title
   echo "USAGE: "
   echo
   echo "$SCRIPTNAME -f <data_filename> [-l <log_filename>] [-p | -path <path>]"
   echo
   echo "Where:"
   echo "-f | -file <data_filename> : The name of the file to export the data to. Mandatory. "
   echo "-l | -log <log_filename>   : The name of a log file to capture the logging information to. Optional. "
   echo "-p | -path <path>          : An existing path on the source system to export all Soft Alarm configuration data from. Optional. "
   echo "-h | -help                 : Displays a usage message. "

   exit 1
}
# for internal debugging only
#   echo     -da Actions.
#   echo     -dq Dynamic SQL
#   echo     -dc Procedure and Function calls.
#   echo     -dm Performance Metrics.
#   echo     -dn Actions SQL.
#   echo     -dd Debug.


# pv_bh_name=NULL
pv_log_file=NULL
pv_path="'NULL'"

# Version is 2 for soft alarms import/export
lv_version=2
# Default verbosity (2 - Warnings).
lv_verbosity=2 

# different levels of verbosity
lv_actions=0
lv_dyna_sql=0
lv_procs=0
lv_perfs=0
lv_act_sql=0
lv_debug=0

# set the criteria to default
lv_criteria="'1=1'"

if [ $# -eq 0 ]
then
    usage
fi



while [ $# -gt 0 ]
do
    case $1 in
        -f)
            shift
            pv_data_file=$1
            ;;

        -file)
            shift
            pv_data_file=$1
            ;;
        -l)
            shift
            pv_log_file=$1
            ;;

        -log)
            shift
            pv_log_file=$1
            ;;
        -p)
            shift
            pv_path="'"$1"'"
            ;;
        -path)
            shift
            pv_path="'"$1"'"
            ;;
            
        -h)
           usage
           ;;
        -help)
           usage
           ;;
         -da) 
               lv_actions=4
               ;;
         -dq) 
               lv_dyna_sql=8
               ;;
         -dc) 
               lv_procs=16
               ;;
         -dm) 
               lv_perfs=32
               ;;
         -dn) 
               lv_act_sql=64
               ;;            
         -dd) 
               lv_debug=128
               ;;                 
        *)
            echo "$SCRIPTNAME: Invalid parameter $1"
            usage
            ;;
    esac
    shift
done

# Check mandatory arguments
if [ ! "$pv_data_file" ] 
then
    echo "$SCRIPTNAME: Required arguments not passed" >&2
    usage
fi 

# output passed args

echo "$SCRIPTNAME: Arguments passed: FILE = $pv_data_file ; LOG = $pv_log_file ;"


# Log file writable?
> $pv_log_file
if [ $? -ne 0 ]
then
    echo "$SCRIPTNAME: Cannot write to $pv_log_file" >&2
    exit 2
fi

lv_logspool=${pv_log_file}_$$

# Datafile writable?
lv_datadir=$(dirname $pv_data_file)
> $pv_data_file
if [ $? -ne 0 ]
then
    echo "$SCRIPTNAME: Cannot write to $pv_data_file" >&2
    exit 2
fi
rm $pv_data_file



# need to allow for additional verbosity in command line

lv_verbosity=$(( $lv_verbosity + $lv_actions + $lv_dyna_sql + $lv_procs + $lv_perfs + $lv_act_sql + $lv_debug ))

#---------------------------------------------------------------------------
# STARTUP
#---------------------------------------------------------------------------
#
(

echo "Export Process STARTED: $(date)"
echo "COMMAND OPTIONS: $*"
echo "======================================================" 
) | tee -a $pv_log_file

#---------------------------------------------------------------------------
# EXPORT
#---------------------------------------------------------------------------
#
(
sqlplus -S /NOLOG <<EOF
  WHENEVER SQLERROR EXIT FAILURE ROLLBACK;

  PROMPT Connecting to Oracle...
  CONNECT $DB_CONNECT

  SET PAGESIZE 0
  SET LONG 2000000
  SET LONGCHUNKSIZE 2000000
  SET WRAP OFF
  SET FEEDBACK OFF
  SET COLSEP '	'
  SET TRIMSPOOL ON
  SET TAB OFF
  SET HEADING OFF
  SET SERVEROUTPUT ON SIZE 1000000
  SET LINESIZE 128

  begin
     dbms_output.put_line('***');
     dbms_output.put_line('*** Export Soft Alarms');
     dbms_output.put_line('***');
  end;
/

  PROMPT Configuring...
  exec export2.gv_version := $lv_version;


  PROMPT Setting verbosity..
  exec export2.gv_verbosity := $lv_verbosity;

  PROMPT Clearing old exports...
  TRUNCATE TABLE exp_des;
  TRUNCATE TABLE exp_msg;
  TRUNCATE TABLE exp_query_text;

  SET SERVEROUTPUT ON SIZE 1000000
  PROMPT Exporting...
  declare
     table_name varchar2(100);
     criteria   varchar2(512);
     path    varchar2(1000);
  begin
    table_name := EXP_CUSTOM.CONST_FOLDER_TABLE; -- PM_FOLDER
    path:=$pv_path;
    IF ( path = 'NULL' ) THEN
      exp_custom.export_sa_folders;
    ELSE
      criteria := 'ID = ' || TO_CHAR( exp_custom.GET_FOLDER_ID_BY_PATH( path ) );
      export2.export(table_name, criteria);
    END IF;

    exp_custom.export_sa_schedules;
  end;
/
  COMMIT;
  EXIT;
EOF
if [ $? -ne 0 ]
then
   echo "FAILURE"
else
   echo "OK"
fi
) | tee -a $lv_logspool
EXPORT_STATUS=$(tail -1 $lv_logspool)
cat $lv_logspool >> $pv_log_file

#---------------------------------------------------------------------------
# WRITE TO EXPORT FILE
#---------------------------------------------------------------------------
#
if [ $EXPORT_STATUS = "OK" ]
then

echo "Writing to $pv_data_file ..." >> $pv_log_file
sqlplus -S /NOLOG <<EOF
  WHENEVER SQLERROR EXIT FAILURE ROLLBACK;

  PROMPT Connecting to Oracle...
  CONNECT $DB_CONNECT

  COL TAB# NEW_VALUE TAB NOPRINT
  SELECT CHR(9) TAB# FROM DUAL;
  SET COLSEP "&TAB"

  SET SERVEROUTPUT OFF
  SET PAGESIZE 0
  SET LINESIZE 32767
  SET LONG 2000000
  SET LONGCHUNKSIZE 2000000
  SET WRAP OFF
  SET FEEDBACK OFF
  SET TRIMSPOOL ON
  SET TAB OFF
  SET HEADING OFF

  PROMPT Writing data file...

  COLUMN STUFF FORMAT a40
  SPOOL $pv_data_file
      SELECT 'R' || CHR(9) || TABLE_NAME || CHR(9) || COLUMN_NAME || CHR(9) || TO_CHAR( ORDINAL )
        FROM exp_col
        WHERE VERSION = $lv_version;
      SELECT 'D' || CHR(9) || ID || CHR(9) || P_ID || CHR(9) || RTRIM(TABLE_NAME) , DATA
        FROM exp_des;

  SPOOL OFF
  EXIT;
EOF

fi
echo "======================================================" | tee -a $pv_log_file

  
#---------------------------------------------------------------------------
# MESSAGES
#---------------------------------------------------------------------------
#
sqlplus -S /NOLOG <<EOF
  WHENEVER SQLERROR EXIT FAILURE ROLLBACK;

  PROMPT Connecting to Oracle...
  CONNECT $DB_CONNECT

  COL TAB# NEW_VALUE TAB NOPRINT
  SELECT CHR(9) TAB# FROM DUAL;
  SET COLSEP "&TAB"

  SET SERVEROUTPUT OFF
  SET PAGESIZE 0
  SET LINESIZE 32767
  SET LONG 2000000
  SET LONGCHUNKSIZE 2000000
  SET WRAP OFF
  SET FEEDBACK OFF
  SET TRIMSPOOL ON

  SPOOL $lv_logspool
    PROMPT MESSAGES:
    PROMPT 
    SELECT * FROM exp_msg ORDER BY id;
  SPOOL OFF

  ROLLBACK;
  EXIT;

EOF

cat $lv_logspool >> $pv_log_file
rm $lv_logspool 2>/dev/null
  
#---------------------------------------------------------------------------
# END PROCESS
#---------------------------------------------------------------------------
(
echo "======================================================"
echo "Export Process FINISHED: $(date)"
echo "STATUS: $EXPORT_STATUS"
) | tee -a $pv_log_file
echo Done.

if [ "$EXPORT_STATUS" = "FAILURE" ]
then
   exit 9
fi
