#!/usr/bin/ksh
###########################################################################
#
# Licensed Materials - Property of IBM
# 5724-T05,5724-T06
#
# (C) Copyright IBM Corp. 2003,2008. All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
###########################################################################
# (#) ./base/pm/adm/import_busy_hours.sh BL_core_schema_8.0.7_8.0.7.4.02_20100413  064938
#
SCRIPTNAME=`basename $0`
#Updated 12/02/2009 - valnt00077479
DB_CONNECT=`crypt_util.ksh -g ${DBUSER} -c`

show_title()
{
   echo Prospect User Document Import Busy Hours Utility.
   echo ----------------------------------------------------------------------
   echo @(#) import_busy_hours.sh 1.9.0 07/06/25 16:12:51
   echo @(#) 
   echo Copyright 2003 IBM Corp.
   echo ----------------------------------------------------------------------
   echo
}

usage() {
    show_title
    echo "USAGE: "
    echo
    echo "$SCRIPTNAME -f <data_filename> -a <FAIL | IGNORE | OVERWRITE >  [-l <log_filename> ] [ -sn <scenario_name>]  [-s or -d <First Needed Date> ] "
    echo "$SCRIPTNAME -h "
    echo 
    echo "Where:"
    echo "-f       | -file <data_filename>           : The name of the file to import the data from. Mandatory. " 
    echo "-a       | -action <switch>                : Allows FAIL, IGNORE or OVERWRITE actions to be specified on busy hour import. Mandatory. "
    echo "-l       | -log <log_filename>             : The name of a log file to capture the logging information to. Optional. "
    echo "-sn      | -scenario_name <name>           : The name of the existing scenario to associate the imported busy hour data with. Optional. "
    echo "-s or -d | -neededdate <First Needed Date> : -s sets NeededDate to be sysdate, -d set Needed date based on data in the system. Mandatory. "      
    echo "-h       | -help			     : Show usage"
    exit 1
}
# for internal debugging only
#   echo     -da Actions.
#   echo     -dq Dynamic SQL
#   echo     -dc Procedure and Function calls.
#   echo     -dm Performance Metrics.
#   echo     -dn Actions SQL.
#   echo     -dd Debug.



pv_log_file=NULL
pv_set_sysdate=NULL
pv_set_systemdate=NULL
pv_set_date=NULL

# Default version
lv_version=1
# Default verbosity (2 - Warnings).
lv_verbosity=2 

# different levels of verbosity
lv_actions=0
lv_dyna_sql=0
lv_procs=0
lv_perfs=0
lv_act_sql=0
lv_debug=0
# set the criteria to default
lv_criteria="'1=1'"

pv_scenario_name="NULL"
pv_action="NULL"

if [ $# -eq 0 ]
then
    usage
fi

while [ $# -gt 0 ]
do

    case $1 in
        -f)
            shift
            pv_data_file=$1
            ;;

        -file)
            shift
            pv_data_file=$1
            ;;
        -l)
            shift
            pv_log_file=$1
            ;;

        -log)
            shift
            pv_log_file=$1
            ;;
        -sn)
            shift
            pv_scenario_name="'"$1"'"
            ;;
        -scenario_name)
            shift
            pv_scenario_name="'"$1"'"
            ;;
        -a)
            shift
            pv_action="'"$1"'"
            ;;
        -action)
            shift
            pv_action="'"$1"'"
            ;;
        -s)                     
	   pv_set_sysdate="'S'"            
            ;;
        -d)                     
	   pv_set_systemdate="'D'"            
	   ;;        
        -h)
           usage
           ;;
        -help)
           usage
           ;;
		-da) 
				lv_actions=4
				;;
    		-dq) 
    				lv_dyna_sql=8
    				;;
    		-dc) 
    				lv_procs=16
    				;;
    		-dm) 
    				lv_perfs=32
    				;;
    		-dn) 
    				lv_act_sql=64
    				;;              
        -dd) 
            lv_debug=128
            ;;  
        *)
            echo "$SCRIPTNAME: Invalid parameter $1"
            usage
            ;;
    esac
    shift
done

# Check mandatory arguments: File & Action
if [ ! "$pv_data_file" ] || [ ! "$pv_action" ] 
then
    echo "$SCRIPTNAME: Required arguments not passed" >&2
    usage
fi 

# Check mandatory arguments: First Need Date.
if [ $pv_set_sysdate = "NULL" ] && [ $pv_set_systemdate = "NULL" ] 
then
    echo "$SCRIPTNAME: Required arguments not passed" >&2
    usage
fi 

# Check that only one mandatory arguments: is set for First Need Date.
if [ $pv_set_sysdate = "'S'" ] && [ $pv_set_systemdate = "'D'" ]
then
    echo "$SCRIPTNAME: Only Allowed to select either -s or -d NOT both" >&2
    usage
fi

#Set-up pv_set_date for first needed date
if [ $pv_set_sysdate = "'S'" ]
then
   pv_set_date="'S'"
fi

if [ $pv_set_systemdate = "'D'" ]
then
   pv_set_date="'D'"
fi

# Check Action is a valid
if  [ "$pv_action" != "'FAIL'" ] &&  [ "$pv_action" != "'IGNORE'" ] &&  [ "$pv_action" != "'OVERWRITE'" ] 
then
    echo "$SCRIPTNAME: Required action arguments not passed" >&2
    usage
fi 

# output passed args

echo "$SCRIPTNAME: Arguments passed: FILE = $pv_data_file ; LOG = $pv_log_file ; SCENARIO NAME = $pv_scenario_name ; ACTION = $pv_action DATE = $pv_set_date"

# Log file writable?
> $pv_log_file
if [ $? -ne 0 ]
then
    echo "$SCRIPTNAME: Cannot write to $pv_log_file" >&2
    exit 2
fi
lv_logdir=`dirname $pv_log_file`

lv_logspool=${pv_log_file}_$$

# Datafile readable?
if [ ! -r "$pv_data_file" ]
then
    echo "$SCRIPTNAME: Cannot read $pv_data_file" >&2
    exit 2
fi

# Default verbosity (2).
lv_verbosity=$(( $lv_verbosity + $lv_actions + $lv_dyna_sql + $lv_procs + $lv_perfs + $lv_act_sql + $lv_debug ))

#---------------------------------------------------------------------------
# STARTUP
#---------------------------------------------------------------------------
#
(
echo "Import Process STARTED: $(date)"
echo "COMMAND OPTIONS: $*"
echo "======================================================"
) | tee -a $pv_log_file

#---------------------------------------------------------------------------
# SQL LOADER
#---------------------------------------------------------------------------
#
echo "Reading data file..." | tee -a $pv_log_file

sqlldr \
    silent=\(HEADER, FEEDBACK\) \
    userid=$DB_CONNECT \
    data=$pv_data_file \
    control=$FLEXPM_HOME/db/Oracle8i/export2/export2.ctl \
    log=$lv_logdir/loader.log \
    bad=$lv_logdir/loader.bad \
    discard=$lv_logdir/loader.dsc

LOADER_STATUS=$?

if [ -f $lv_logdir/loader.log ]
then
  echo # Loader log ######### >> $pv_log_file
  cat $lv_logdir/loader.log >> $pv_log_file
  rm $lv_logdir/loader.log 2> /dev/null
fi

if [ -f $lv_logdir/loader.bad ]
then
  echo # Bad records ######### >> $pv_log_file
  cat $lv_logdir/loader.bad >> $pv_log_file
  rm $lv_logdir/loader.bad 2> /dev/null
fi

if [ -f $lv_logdir/loader.dsc ]
then
  echo # Disarded records ######### >> $pv_log_file
  cat $lv_logdir/loader.dsc >> $pv_log_file
  rm $lv_logdir/loader.dsc 2> /dev/null
fi

case $LOADER_STATUS in
    1 | 3) echo "SQL*Loader: Fatal error reading data file." >&2 | tee -a $pv_log_file
	exit 1;;
    2) echo "SQL*Loader: All/some rows discarded/rejected." >&2 | tee -a $pv_log_file
        exit 1;;
    0) echo "SQL*Loader: All data files rows read." | tee -a $pv_log_file
esac
echo "======================================================" | tee -a $pv_log_file

#---------------------------------------------------------------------------
# IMPORT
#---------------------------------------------------------------------------
#
(
sqlplus -S /NOLOG <<EOF 
  WHENEVER SQLERROR EXIT FAILURE ROLLBACK

  PROMPT Connecting to Oracle...
  CONNECT $DB_CONNECT;

  SET FEEDBACK OFF
  SET SERVEROUTPUT ON SIZE 1000000
  SET LINESIZE 128
  begin
     dbms_output.put_line('***');
     dbms_output.put_line('*** Import Busy Hours');
     dbms_output.put_line('*** Import Package        : ' || export2.version());
     dbms_output.put_line('*** Custom Import Package : ' || exp_custom.version());
     dbms_output.put_line('***');
  end;
/

  PROMPT Clearing old exports...
  TRUNCATE TABLE exp_query_text;
  TRUNCATE TABLE exp_msg;

  PROMPT Configuring environment...
  exec export2.gv_version := $lv_version;

  PROMPT Setting scenario name...
  exec  exp_custom.gv_scenario_name := $pv_scenario_name

  PROMPT Setting action...
  exec exp_custom.gv_action := $pv_action  
  
  PROMPT Setting action...
  exec exp_custom.gv_set_FirstNeeded := $pv_set_date


  PROMPT Checking compatibility...
  exec exp_custom.compatibility_fixes;

  PROMPT Setting verbosity..
  exec export2.gv_verbosity := $lv_verbosity;


  PROMPT Importing...
  declare
     table_name varchar2(100);
     criteria   varchar2(512);
  begin
				table_name := 'PM_BUSYHOUR';
				criteria := $lv_criteria;
        export2.import(table_name, criteria);
  end;
/
  PROMPT Saving changes...
  COMMIT;
  EXIT;
EOF
if [ $? -ne 0 ]
then
   echo "FAILURE"
else
   echo "OK"
fi
) | tee -a $lv_logspool
IMPORT_STATUS=$(tail -1 $lv_logspool)
cat $lv_logspool >> $pv_log_file
echo "======================================================" | tee -a $pv_log_file

#---------------------------------------------------------------------------
# MESSAGES
#---------------------------------------------------------------------------
#
sqlplus -S /NOLOG <<EOF
  WHENEVER SQLERROR EXIT FAILURE ROLLBACK

  PROMPT Connecting to Oracle...
  CONNECT $DB_CONNECT;

  COL TAB# NEW_VALUE TAB NOPRINT
  SELECT CHR(9) TAB# FROM DUAL;
  SET COLSEP "&TAB"

  SET SERVEROUTPUT OFF
  SET PAGESIZE 0
  SET LINESIZE 32767
  SET LONG 2000000
  SET LONGCHUNKSIZE 2000000
  SET WRAP OFF
  SET FEEDBACK OFF  
  SET TRIMSPOOL ON

  SPOOL $lv_logspool
    PROMPT MESSAGES:
    PROMPT 
    SELECT * FROM exp_msg ORDER BY id;
  SPOOL OFF

  COMMIT;
  EXIT;
EOF

cat $lv_logspool >> $pv_log_file
rm $lv_logspool 2> /dev/null


#---------------------------------------------------------------------------
# END PROCESS
#---------------------------------------------------------------------------
#
(
echo "======================================================"
echo "Import Process FINISHED: $(date)"
echo "STATUS: $IMPORT_STATUS"
) | tee -a $pv_log_file
echo Done.

if [ "$IMPORT_STATUS" = "FAILURE" ]
then
   exit 9
fi
