#!/usr/bin/ksh
###########################################################################
#
# Licensed Materials - Property of IBM
# 5724-T05,5724-T06
#
# (C) Copyright IBM Corp. 2009,2010. All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
###########################################################################
# (#) ./base/pm/adm/listScenario.sh BL_core_schema_8.0.7_8.0.7.4.02_20100413  064938
# (#) 
#
DB_CONNECT=`crypt_util.ksh -g ${DBUSER} -c`
SCRIPTNAME=`basename $0`

usage()
{
 echo 'Usage:'
 echo "$SCRIPTNAME  -e entity_name -s scenario_name -f folder_name "
 echo '-e : The entity name of the instances in the scenario to list'
 echo '-f : The name of the folder where the scenario resides'
 echo '-s : The name of the scenario'
 echo ''
 echo "Example:"
 echo $SCRIPTNAME ' -e BSC -f "/Scenarios" -s "MY GSM SCENARIO"'
 echo $SCRIPTNAME ' -e UtranCell -f "/Scenarios" -s "MY UTRAN SCENARIO"'
 echo ''
 exit 2
}

function runplsqlproc
{
  sqlplus -s ${DB_CONNECT} <<SQLPLUS   
  WHENEVER SQLERROR EXIT FAILURE
  set pagesize 800
  set linesize 1000
  set verify off
  set heading off
  set showmode off
  set feedback off
  set serveroutput on size unlimited
  variable returnstatus number
  DECLARE
  BEGIN
     $1;  
     COMMIT;
     :returnstatus := 0;
  EXCEPTION
     WHEN OTHERS THEN
        ROLLBACK;
        :returnstatus := 1;
        DBMS_OUTPUT.PUT_LINE(SQLERRM);
        IF SQLCODE NOT BETWEEN -21000 AND -20000 THEN
           DBMS_OUTPUT.PUT_LINE(DBMS_UTILITY.FORMAT_ERROR_BACKTRACE);
        END IF;
  END;
  /
      
  EXIT :returnstatus
SQLPLUS
}

if [ $# -eq 0 ]
 then
 usage
 exit 2
fi

ENTITY=NULL
SCENARIO=NULL
FOLDER=NULL

while [ $# -gt 0 ]
do

    case $1 in
      -e)
          shift
          ENTITY=\'$1\'
          ;;
      -s)
          shift
          SCENARIO=\'$1\'
          ;;
      -f)
          shift
          FOLDER=\'$1\'
          ;;
      -v|-help)
          usage
          ;;
       *) echo "$SCRIPTNAME: Invalid parameter "
          usage
          ;;
     esac

     if [ $# -gt 0 ]
      then
       shift
     fi
done

if [ "${ENTITY:=NULL}" = "NULL" ]
 then
        usage
fi

if [ "${SCENARIO:=NULL}" = "NULL" ]
 then
        usage
fi

if [ "${FOLDER}" = "NULL" ]
 then
       usage
fi



COMMAND="wm_scenarioupdate.listscenario("${ENTITY}","${SCENARIO}","${FOLDER}")"
runplsqlproc "${COMMAND}"

retcode=$?
#Check exit code from sql process and exit accordingly
if [ $retcode -eq 0 ]
then
   echo "PL/SQL procedure wm_scenarioupdate.listscenario completed for Entity = ${ENTITY} Scenario = ${SCENARIO} Folder ${FOLDER}"
   exit 0
else
   echo "Error calling PL/SQL procedure wm_scenarioupdate.listscenario for Entity = ${ENTITY} Scenario = ${SCENARIO} Folder ${FOLDER}"
   exit 1
fi