#!/usr/bin/ksh
#
#-----------------------------------------------------------------------
# COPYRIGHT IBM Corp. 2007
#
# (#) ./base/pm/adm/part_mask.sh BL_core_schema_8.0.7_8.0.7.4.02_20100413  064938
# (#) 
#-----------------------------------------------------------------------
#
SCRIPTNAME=`basename $0`
#Updated 10/02/2009 - valnt00077479
DB_CONNECT=`crypt_util.ksh -g ${DBUSER} -c`

show_usage()
{
   (
   echo "USAGE: " 
   echo "$SCRIPTNAME -O [ -A | -T <tablespace> | -t <table> ]"
   echo "$SCRIPTNAME -S [ -A | -T <tablespace> | -t <table> ] [ -R | -p '<pattern>' | -a '<alt_pattern>']"
   echo "$SCRIPTNAME -h "
   echo
   echo "Where:"
   echo "-O                 : output"
   echo "-S                 : set"
   echo "-A                 : all tables"
   echo "-T <tablespace>    : all tables in the tablespace"
   echo "-t <table>         : for the specified table"
   echo "-R                 : round-robin"
   echo "-p '<pattern>'     : using pattern"
   echo "                   : a pattern is composed of 0/1 and has 7 digits"
   echo "                   : example: '0000000' or '0101010'"
   echo "-a '<alt_pattern>' : alternating between patterns"
   echo "                   : an alternating pattern is composed of 2 patterns separated by a single space"
   echo "                   :    enclosed within single quotes. Example: '0000000 0101010'"
   echo "-h                 : help, show usage"
   ) >&2
    echo
}

if [[ $# -eq 0 ]]
then
   show_usage
   exit 0
fi

if [ "${DB_CONNECT:+SET}" != "SET" ]
then
    echo "Error: DB_CONNECT not set" >&2
    exit 2
fi

# Set default values.
lv_operation=""
lv_dataset=""
lv_dataset_option=""
lv_style=""
lv_style_option=""

# Process the arguments.
while getopts hOSAT:t:Rp:a: arg
do
    case $arg in
    O) if [[ -n $lv_operation ]]
       then
          echo "$SCRIPTNAME: Options -O and -S are mutually exclusive" >&2
          show_usage
          exit 2;
       fi
       lv_operation='O'
       ;;

    S) if [[ -n $lv_operation ]]
       then
          echo "$SCRIPTNAME: Options -O and -S are mutually exclusive" >&2
          show_usage
          exit 2;
       fi
       lv_operation='S'
       ;;

    A) if [[ -n $lv_dataset ]]
       then
          echo "$SCRIPTNAME: Options -A, -T and -t are mutually exclusive" >&2
          show_usage
          exit 2;
       fi
       lv_dataset='A'
       ;;

    T) if [[ -n $lv_dataset ]]
       then
          echo "$SCRIPTNAME: Options -A, -T and -t are mutually exclusive" >&2
          show_usage
          exit 2;
       fi
       lv_dataset='T'
       lv_dataset_option="$OPTARG"
       ;;

    t) if [[ -n $lv_dataset ]]
       then
          echo "$SCRIPTNAME: Options -A, -T and -t are mutually exclusive" >&2
          show_usage
          exit 2;
       fi
       lv_dataset='t'
       lv_dataset_option="$OPTARG"
       ;;

    R) if [[ -n $lv_style ]]
       then
          echo "$SCRIPTNAME: Options -R, -p and -a are mutually exclusive" >&2
          show_usage
          exit 2;
       fi
       lv_style='R'
       ;;

    p) if [[ -n $lv_style ]]
       then
          echo "$SCRIPTNAME: Options -R, -p and -a are mutually exclusive" >&2
          show_usage
          exit 2;
       fi
       lv_style='p'
       lv_style_option="$OPTARG"
       ;;

    a) if [[ -n $lv_style ]]
       then
          echo "$SCRIPTNAME: Options -R, -p and -a are mutually exclusive" >&2
          show_usage
          exit 2;
       fi
       lv_style='a'
       lv_style_option="$OPTARG"
       ;;

    h) show_usage
       exit 0
       ;;
    \? | \:)
       show_usage
       exit 2
       ;;
   esac
done

# Must have specified an operation
if [[ -z $lv_operation ]]
then
   echo "$SCRIPTNAME: An option -O or -S must be specified" >&2
   # show_usage
   exit 2;
fi

# Must have specified a dataset
if [[ -z $lv_dataset ]]
then
   echo "$SCRIPTNAME: An option -A, -T or -t must be specified" >&2
   # show_usage
   exit 2;
fi

# Must have specified a style, if the opertion is "S"
if [[ -z $lv_style && $lv_operation == "S" ]]
then
   echo "$SCRIPTNAME: An option -R, -p or -a must be specified" >&2
   # show_usage
   exit 2;
fi
   
# Can't use style options with -O operation
if [[ -z $lv_style && $lv_operation == "S" ]]
then
   echo "$SCRIPTNAME: Options -R, -p or -a are exclusive to the -S option" >&2
   # show_usage
   exit 2;
fi
   
# Check for pattern
if [[ $lv_style == "p" ]]
then
   if [[ $lv_style_option != @([0|1][0|1][0|1][0|1][0|1][0|1][0|1]&(*[1]*)) ]]
   then 
      echo "$SCRIPTNAME: The pattern \"$lv_style_option\" is invalid"
      echo "$SCRIPTNAME: A pattern must be composed of 0/1 and contain 7 digits"
      echo "$SCRIPTNAME: The pattern 0000000 is invalid"
      # show_usage
      exit 2;
   fi
fi

# Check for alternating pattern
if [[ $lv_style == "a" ]]
then
   if [[ $lv_style_option != @([0|1][0|1][0|1][0|1][0|1][0|1][0|1] [0|1][0|1][0|1][0|1][0|1][0|1][0|1]&(*[1]* *[1]*)) ]]
   then 
      echo "$SCRIPTNAME: The pattern \"$lv_style_option\" is invalid"
      echo "$SCRIPTNAME: A pattern must be composed of 0/1 and contain 7 digits"
      echo "$SCRIPTNAME: An alternating pattern must be composed of 2 patterns separated by a single space"
      echo "$SCRIPTNAME:    enclosed in single quotes"
      echo "$SCRIPTNAME: The pattern 0000000 is invalid"
      # show_usage
      exit 2;
   fi
fi

sqlplus -S /NOLOG <<EOF
   WHENEVER SQLERROR EXIT FAILURE ROLLBACK;

   SET FEEDBACK OFF
   CONNECT $DB_CONNECT

   SET SERVEROUTPUT ON SIZE 1000000
   begin
      part_maint.part_mask_api('$lv_operation', 
                               '$lv_dataset', 
                               '$lv_dataset_option', 
                               '$lv_style', 
                               '$lv_style_option');
   end;
/
   EXIT;
EOF
