#!/usr/bin/ksh
###########################################################################
#
# Licensed Materials - Property of IBM
# 5724-T05,5724-T06
#
# (C) Copyright IBM Corp. 2003,2008. All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
###########################################################################
# (#) ./base/pm/adm/part_tablespaces.sh BL_core_schema_8.0.7_8.0.7.4.02_20100413  064938
#
SCRIPTNAME=`basename $0`
#Updated 10/02/2009 - valnt00077479
DB_CONNECT=`crypt_util.ksh -g ${DBUSER} -c`

show_usage()
{
   (
   echo "USAGE: " 
   echo "$SCRIPTNAME -O "
   echo "$SCRIPTNAME -S [ -T <tablespace> | -t <table> ] [ -m <degree> | -s <degree> ]"
   echo "$SCRIPTNAME -h "
   echo
   echo "Where:"
   echo "-O               : output"
   echo "-S               : set"
   echo "-T <tablespace>  : for the specified tablespace"
   echo "-t <table>       : for the specified table"
   echo "-m <degree>      : move parallelism degree during part_maint activity"
   echo "-s <degree>      : analyze parallelism degree during part_maint activity"
   echo "                 : <degree> = 0: reset value (use the upper hierarchy level)" 
   echo "                 : <degree> = 1: disable parallelism for specified tablespace/table" 
   echo "                 : <degree> = >1 && <99: apply specified parallelism" 
   echo "-h               : help, show usage"
   ) >&2
    echo
}

if [[ $# -eq 0 ]]
then
   show_usage
   exit 0
fi

if [ "${DB_CONNECT:+SET}" != "SET" ]
then
    echo "Error: DB_CONNECT not set" >&2
    exit 2
fi

# Set default values.
lv_operation=""
lv_dataset=""
lv_dataset_option=""
lv_attribute=""
lv_value=""

# Process the arguments.
while getopts hOST:t:m:s: arg
do
    case $arg in
    O) if [[ -n $lv_operation ]]
       then
          echo "$SCRIPTNAME: Options -O and -S are mutually exclusive" >&2
          show_usage
          exit 2;
       fi
       lv_operation='O'
       ;;

    S) if [[ -n $lv_operation ]]
       then
          echo "$SCRIPTNAME: Options -O and -S are mutually exclusive" >&2
          show_usage
          exit 2;
       fi
       lv_operation='S'
       ;;

    T) if [[ -n $lv_dataset ]]
       then
          echo "$SCRIPTNAME: Options -T and -t are mutually exclusive" >&2
          show_usage
          exit 2;
       fi
       lv_dataset='T'
       lv_dataset_option="$OPTARG"
       ;;

    t) if [[ -n $lv_dataset ]]
       then
          echo "$SCRIPTNAME: Options -T and -t are mutually exclusive" >&2
          show_usage
          exit 2;
       fi
       lv_dataset='t'
       lv_dataset_option="$OPTARG"
       ;;

    m) if [[ -n $lv_attribute ]]
       then
          echo "$SCRIPTNAME: Options -m and -s are mutually exclusive" >&2
          show_usage
          exit 2;
       fi
       lv_attribute='m'
       lv_value="$OPTARG"
       ;;

    s) if [[ -n $lv_attribute ]]
       then
          echo "$SCRIPTNAME: Options -m and -s are mutually exclusive" >&2
          show_usage
          exit 2;
       fi
       lv_attribute='s'
       lv_value="$OPTARG"
       ;;
       
    h) show_usage
       exit 0
       ;;
    \? | \:)
       show_usage
       exit 2
       ;;
   esac
done

# Must have specified an operation
if [[ -z $lv_operation ]]
then
   echo "$SCRIPTNAME: An option -O or -S must be specified" >&2
   # show_usage
   exit 2;
fi

# Must have specified a dataset, if the opertion is "S"
if [[ -z $lv_dataset && $lv_operation == "S" ]]
then
   echo "$SCRIPTNAME: An option -T or -t must be specified" >&2
   # show_usage
   exit 2;
fi

# Must have specified a style, if the opertion is "S"
if [[ -z $lv_attribute && $lv_operation == "S" ]]
then
   echo "$SCRIPTNAME: An option -m or -s must be specified" >&2
   # show_usage
   exit 2;
fi
   
# Can't use style options with -O operation
if [[ (-n $lv_dataset || -n $lv_attribute) && $lv_operation == "O" ]]
then
   echo "$SCRIPTNAME: Options -T, -t, -m or -s are exclusive to the -S option" >&2
   # show_usage
   exit 2;
fi
   
# Check for pattern
if [[ $lv_attribute == "m" || $lv_attribute == "s" ]]
then
   if [[ $lv_value -lt 0 || $lv_value -gt 99 ]]
   then 
      echo "$SCRIPTNAME: The degree \"$lv_value\" is invalid"
      echo "$SCRIPTNAME: A degree must be a number between 0 and 99"
      # show_usage
      exit 2;
   fi
fi

sqlplus -S /NOLOG <<EOF | grep -v Connected.
   WHENEVER SQLERROR EXIT FAILURE ROLLBACK;

   SET FEEDBACK OFF
   CONNECT $DB_CONNECT

   SET SERVEROUTPUT ON SIZE 1000000
   begin
      part_maint.part_tablespaces_api('$lv_operation', 
                                      '$lv_dataset', 
                                      '$lv_dataset_option', 
                                      '$lv_attribute', 
                                      '$lv_value');
   end;
/
   EXIT;
EOF
