#!/bin/ksh
###########################################################################
#
# Licensed Materials - Property of IBM
# 5724-T05,5724-T06
#
# (C) Copyright IBM Corp. 2009,2009. All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
###########################################################################
# (#) ./base/pm/adm/pswddb.sh BL_core_schema_8.0.7_8.0.7.4.02_20100413  064938
# (#) 
#
# Eoghan Shields  12/03/09
#
APPLICATION=`basename $0`
EXISTING_PASSWD="";
NEW_PASSWD="";
DUP_NEW_PASSWD="";
export EXIT_STATE=1
function logPasswordStoreUpdate
{
	CRYPT_UPDATE_TEST=`echo $1|grep -i "Updated value"|wc -l`
	if [ $CRYPT_UPDATE_TEST -gt 0 ]; then
		echo "`date` [INFO] - Password Store successfully ${2}d." #update or restore
	else
		echo "`date` [ERROR] - Failure to ${2} Password Store - Reason - [${1}]"
		exit 1;
	fi	
}
function logDatabaseUpdate
{
	UPDATE_OUTPUT_TEST=`echo $1|grep -i "User altered."|wc -l`
	if [ $UPDATE_OUTPUT_TEST -gt 0  ]; then
		echo "`date` [INFO] - Database password successfully ${2}d."
	else
		echo "`date` [ERROR] - Failure to ${2} database password - Rolling back Password Store"
		CRYPT_ROLLBACK=`crypt_util.ksh -p $DBUSER $EXISTING_PASSWD`
		logPasswordStoreUpdate "${CRYPT_ROLLBACK}" restore
		exit 1;
	fi
}
function exitStatus
{
	EXIT_STATE_MSG="";
	EXIT_STATE=$1;
	if [ $1 -eq 0 ]; then
		if [ ! -z $2 ]; then
			EXIT_STATE_MSG=$2
		fi
    else
		if [ ! -z $3 ]; then
			EXIT_STATE_MSG=$3
		fi
	fi
}
function testCryptDBSync
{
	#Check to see can we log in with given password
	TEST_USER_PASSWD=`sqlplus -S ${DBUSER}/${NEW_PASSWD}\@${DBSID} <<EOF
	exit
	EOF`

	#Check to see can we log in with gnew crypt util password
	NEW_CRYPT_PASSWD=`crypt_util.ksh -g $DBUSER`
	TEST_CRYPT_PASSWD=`sqlplus -S ${DBUSER}/${NEW_CRYPT_PASSWD}\@${DBSID} <<EOF
	exit
	EOF`

	#Check what happened on login attempts
	export TEST_RESULT_1=`echo $TEST_USER_PASSWD|grep -i "ERROR: ORA-01017: invalid username/password; logon denied"|wc -l`
	export TEST_RESULT_2=`echo $TEST_CRYPT_PASSWD|grep -i "ERROR: ORA-01017: invalid username/password; logon denied"|wc -l`
}
function doSyncCheck
{
	if [ ! -z $1 ] && [ $1 = "-c" ]; then
		
		testCryptDBSync
		if [ $TEST_RESULT_2 -gt 0 ]; then 
			echo "`date` [ERROR] - Password Store is out of sync with Database"
		else
			echo "`date` [INFO] - Password Store is in sync with Database"
		fi
		exit 0;
	fi
	
	
	if [ !$# -eq 0 ];then
	 	echo "The arguement entered  is incorrect"
		userhelp -h
		exit -1;
    	fi
	
	
}
function userhelp
{
	if [ ! -z $1 ]; then
		if [ $1 = "--help" ] || [ $1 = "-h" ]; then
			echo "`date` [HELP] - To change your existing password, run $APPLICATION with no arguments "
			echo "`date` [HELP] - To check if the password store is in sync with the database password, run $APPLICATION -c "
			exit;
		fi
	fi
}
#Make sure we get all  profiles environment variables
userhelp $@
trap "echo" 2
echo "\n\n`date` [INFO] - Checking system status - please wait....\n\n"
. $FLEXPM_HOME/.profile
#Middlware state
MW_STATE=`ps-mgr watch once 2>&1|grep -v "Connection failed"|grep -v "Next, try 'ps-mgr status' or 'ps-mgr init'"|wc -l;exitStatus $?`
#is DBPASSWD in env
DBPASSWD_EXISTS=`env|grep -i DBPASSWD|wc -l`

#if dbpasswd  exists we are assuming that password encryption hasnt been switched on, so we arent going any further
if [ ${DBPASSWD_EXISTS} -gt 0 ]; then
	echo "`date` [ERROR] - Password encryption is not enabled, please refer to the Prospect Documentation on changing the database password using ${APPLICATION}"
	exit 1;
fi

#If the -c flag has been provided we are going to check if crypt_util is in sync with database, basically can we log in using crypt password
#We dont need the  if the middleware is up here, were only logging in.
doSyncCheck $@

#if either of these fail that implies that the middleware is running, this is also a no go. 
if [ ${MW_STATE} -ne 0 ] && [ ${EXIT_STATE} -ne 0 ]; then
	echo "`date` [ERROR] - Prospect is currently running, please shutdown before executing ${APPLICATION}"
	exit 1;
fi
#if we are here, middleware is down and password encryption is enabled

echo "Please enter your existing password: "
stty -echo
read EXISTING_PASSWD
stty echo
echo "Please enter your new password: "
stty -echo
read NEW_PASSWD
stty echo
echo "Please re-enter your new password: "
stty -echo
read DUP_NEW_PASSWD
stty echo

EXISTING_CRYPT_PASSWD=`crypt_util.ksh -g $DBUSER`
TEST_EXISTING_CRYPT_PASSWD=`echo $EXISTING_CRYPT_PASSWD|grep -i "Password not found"|wc -l`

if [ $TEST_EXISTING_CRYPT_PASSWD -gt 0 ]; then
	echo "`date` [ERROR] - Problem retrieving password from password store for $DBUSER - Reason - ${EXISTING_CRYPT_PASSWD}"
	exit 1;
fi
if [ $EXISTING_PASSWD != $EXISTING_CRYPT_PASSWD ]; then
	echo "`date` [ERROR] - Your entered your existing password incorrectly"
	exit 1;
fi
if [ $NEW_PASSWD != $DUP_NEW_PASSWD ];then
	echo "`date` [ERROR] - Your new password entries did not match"
	exit 1;
fi

#Update Password Store
CRYPT_UPDATE=`crypt_util.ksh -p $DBUSER $NEW_PASSWD`
logPasswordStoreUpdate "${CRYPT_UPDATE}" update

#Update database password
CONNECTION_STRING=${DBUSER}/${EXISTING_PASSWD}@${DBSID}
UPDATE_OUTPUT=`sqlplus -S $CONNECTION_STRING <<EOF
alter user $DBUSER identified by $NEW_PASSWD;
commit;
exit;
EOF`
logDatabaseUpdate "${UPDATE_OUTPUT}" update

testCryptDBSync

#If password wasnt updated correctly
if [ $TEST_RESULT_1 -gt 0 ] || [ $TEST_RESULT_2 -gt 0 ] ; then
	#No harm in trying to reset password to original value
	UPDATE_ROLLBACK=`sqlplus -S $CONNECTION_STRING <<EOF
	alter user $DBUSER identified by $EXISTING_PASSWD;
	commit;
	exit;
	EOF`
	#Reset 
	CRYPT_ROLLBACK=`crypt_util.ksh -p $DBUSER $EXISTING_PASSWD`
	logPasswordStoreUpdate "${CRYPT_ROLLBACK}" restore
else
	echo "`date` [INFO] - Your password has been updated successfully"
fi