#!/usr/bin/ksh
###########################################################################
#
# Licensed Materials - Property of IBM
# 5724-T05,5724-T06
#
# (C) Copyright IBM Corp. 2008,2009. All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
###########################################################################
# (#) ./base/pm/adm/setSoftAlarmId.sh BL_core_schema_8.0.7_8.0.7.4.02_20100413  064938
# (#) 
#
# ------------------------------------------------------------------------
# History
# 10-JUN-2009  Core Merge BLavin 
#              Changed so that script would not update PM_FEATURE_CHANGES
#              table anymore but instead would tun on/off range checking in 
#              WM_SYSTEM_VALUES table


DB_CONNECT=`crypt_util.ksh -g DB_CONNECT`;

echo "Set SoftAlarm ID Range"

# ------------------------------------------------------------------------

function usage {
  echo "usage: "
  echo "  $0 [-enable -min <value> -max <value>|-disable] [-min <value>] [-max <value>] "
  echo ""
  echo "    -enable|-disable     Enable or disable the soft alarm id feature."
  echo "    -min <value>         Set the minimum allowable value of a soft alarm id"
  echo "    -max <value>         Set the maximum allowable value of a soft alarm id"
  echo ""
}

# ------------------------------------------------------------------------

eflag=
dflag=
mflag=
xflag=

# ------------------------------------------------------------------------

while [ $# -gt 0 ]
do
  case "$1" in
    -enable)  eflag=1;;
    -disable) dflag=1;;
    -min)     mflag=1; mval="$2"; shift;;
    -max)     xflag=1; xval="$2"; shift;;
    -*)       usage
              exit 1;;
    *)        break;;		# terminate while loop
  esac
  shift
done

# ------------------------------------------------------------------------

if [ ! -z "$eflag"  -a  ! -z "$dflag" ];
then
  echo "Mutually exclusive options may not be specified together."
  exit 2
fi

# ------------------------------------------------------------------------

if [ ! -z "$eflag" ];
then
echo "Enabling SoftAlarm ID Range Feature..."

	# Core merge change - when enabling need to also supply Min and Max args
	if [ -z "$mflag" -o -z "$xflag" ];then
		echo "Must supply both Min and Max range values when enabling"
		echo ""
		usage
		exit 2	
	fi
	#end Core merge change
fi

# ------------------------------------------------------------------------

if [ ! -z "$dflag" ];
then
echo "Disabling SoftAlarm ID Range Feature..."

# Core merge change - remove the range rows from the WM_SYSTEM_VALUES table now
sqlplus -S /nolog <<EOF
  CONNECT $DB_CONNECT
  BEGIN
	DELETE wm_system_values_v where NAME in ('MIN_SOFTALARM_ID', 'MAX_SOFTALARM_ID');
	COMMIT;	
  END;
/
  EXIT
EOF
# end Core merge change
fi

# ------------------------------------------------------------------------

if [ ! -z "$mflag" ];then
echo "Setting the minimum allowable value of a SoftAlarm ID..."

#<!-- SEAde57649 Description:setSoftAlarmId.sh script is allowing us to  give even alphabets as the input value
#Date:24/11/2005 
#Perot Systems Change start-->

# the grep is checking , is there exist any character in $mval whose value 
# is not in between 0 to 9.if its true then it will assign into "result"
# otherwise "result" will be empty.


result=`echo $mval | grep [^0-9]`
if [ ! -z "$result" ]; then
    echo "Fail, min value is not an integer"
else
  # The grep found only 0-9, so it's an integer. We can safely do a test on it.
  
sqlplus -S /nolog <<EOF
  CONNECT $DB_CONNECT
  BEGIN
    UPDATE wm_system_values_v SET value ='$mval'  WHERE name = 'MIN_SOFTALARM_ID';
    IF ( SQL%NOTFOUND ) THEN
      INSERT INTO wm_system_values_v ( name, value )
        VALUES ( 'MIN_SOFTALARM_ID', '$mval' );
    END IF;
    COMMIT;
  END;
/
  EXIT
EOF
fi
#<!-- SEAde57649 Change End-->
fi

# ------------------------------------------------------------------------

if [ ! -z "$xflag" ];
then
echo "Setting the maximum allowable value of a SoftAlarm ID..."

#<!-- SEAde57649 Description:setSoftAlarmId.sh script is allowing us to  give even alphabets as the input value
#Date:24/11/2005 
#Perot Systems Change start-->

# the grep is checking , is there exist any character in $xval whose value 
# is not in between 0 to 9.if its true then it will assign into "result"
# otherwise "result" will be empty.



result=`echo $xval | grep [^0-9]`
if [ ! -z "$result" ]; then
  # If the grep found something other than 0-9, then it's not an integer.
  echo "Fail, max value is not an integer"
else
  # The grep found only 0-9, so it's an integer. We can safely do a test on it.
  
sqlplus -S /nolog <<EOF
  CONNECT $DB_CONNECT
  BEGIN
    UPDATE wm_system_values_v SET value ='$xval'  WHERE name = 'MAX_SOFTALARM_ID';
    IF ( SQL%NOTFOUND ) THEN
      INSERT INTO wm_system_values_v ( name, value )
        VALUES ( 'MAX_SOFTALARM_ID', '$xval' );
    END IF;
    COMMIT;
  END;
/
  EXIT
EOF
fi   
#<!-- SEAde57649 Change End-->
fi

# ------------------------------------------------------------------------

echo ""

# Core merge change - remove need to check PM_FEATURE_CHANGES table

sqlplus -S /nolog <<EOF
  CONNECT $DB_CONNECT

  col feature   format a30
  col parameter format a30
  col status    format a10 
  col value     format a10

  SELECT name parameter, value
    FROM wm_system_values_v
   WHERE name IN ( 'MIN_SOFTALARM_ID', 'MAX_SOFTALARM_ID');

  EXIT
EOF

# ------------------------------------------------------------------------

echo ""




