#! /bin/ksh
#
# (#) ./base/pm/adm/set_tzr.sh BL_core_schema_8.0.7_8.0.7.4.02_20100413  064938
# (#) 
# COPYRIGHT WatchMark Corp 2004
#
#Updated 10/02/2009 - valnt00077479
DB_CONNECT=`crypt_util.ksh -g ${DBUSER} -c`

SCRIPTNAME=`basename $0`

usage() {
    echo "${SCRIPTNAME} [ -n 'name' | -t ]"
    echo "   -n name : Name of the time zone region"
    echo "OR "
    echo "   -t : Display the current time zone region"
    
    exit 1
}

# Create options
XNAME=""
XFLAG=0

# TZR list options
XTZRFLAG=0

# Check for no options
if [[ $# -eq 0 ]] then
   usage
fi

while [ $# -gt 0 ]
do

    case ${1} in
        -n) 
            shift
            if [[ $# -gt 0 ]] then
               XNAME=${1}
               XFLAG=1
               shift
            fi
            ;;

        -t)
            shift
            XTZRFLAG=1
            ;;

        *)
            echo "$0: Invalid parameter ${1}"
            usage
            ;;
    esac

done

# exclusivity
if [[ $(( $XFLAG + $XTZRFLAG )) -ne 1 ]] then
   usage
fi

#
# Allow the database to handle the parameter verification
#
sqlplus -s /NOLOG << !
set feed off
set lines 200
set serveroutput on size 1000000
connect $DB_CONNECT
VARIABLE return_status NUMBER;
DECLARE
   l_return VARCHAR2(512);
BEGIN

  :return_status := 0;

   IF ( $XFLAG = 1 ) THEN

      l_return := wm_time.set_database_tzr( '$XNAME' );
      wm_print.print( l_return );

      COMMIT;

   ELSE

      l_return := wm_sysval.getstring('TimeZoneRegion');

      IF ( l_return IS NULL ) THEN
         wm_print.print('TimeZoneRegion has not been set to a value');
      ELSE
         wm_print.print( l_return );
      END IF;

   END IF;

EXCEPTION
   WHEN OTHERS THEN
      :return_status := 1;
      wm_print.print('ERROR: Unable to set the database TZR');
      wm_print.print( SQLERRM );

END;
/
EXIT :return_status
!
XRETURN=$?

exit $XRETURN
