#! /bin/ksh
###########################################################################
#
# Licensed Materials - Property of IBM
# 5724-T05,5724-T06
#
# (C) Copyright IBM Corp. 2003,2008. All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
###########################################################################
# @(#) trending_admin.sh
# @(#)
#

SCRIPTNAME=`basename $0`

DB_CONNECT=`crypt_util.ksh -g $DBUSER -c`;

usage() {
    echo "${SCRIPTNAME} [ -m | -c ] [ -s <value> | -d ]"
    echo "   -m : Perform action for the trending report minimum datapoints system variable value"
    echo "  [OR] "
    echo "   -c : Perform action for the trending chart axis extend system variable value"
    echo "[AND] "
    echo "   -s <value> : Set the system variable value to <value>"
    echo "  [OR] "
    echo "   -d : Display the current value of the system variable value"

    exit 1
}


# Variables
SET_VALUE_FLAG=0
SHOW_VALUE_FLAG=0

CHART_VARIABLE="web.reporting.trending.max_chart_extend"
DATAPOINTS_VARIABLE="web.reporting.trending.min_datapoints"

VARIABLE_NAME=""
NEW_VALUE="10"

VAR_SET=0
ACTION_SET=0

# Display usage message if no options selected
if [[ $# -eq 0 ]] then
   usage
fi

# Display usage message if too few options selected
if [[ $# -lt 2 ]] then
   echo "Too few arguments found."
   usage
fi



# We have options... decisions, decisions
while [ $# -gt 0 ]
do
   case ${1} in
      -h) 
         usage
         ;;
      -m)
         VARIABLE_NAME=$DATAPOINTS_VARIABLE
         if [[ $VAR_SET -gt 0 ]] then
             echo "Must specify either -m OR -c, but not both"
             usage
         fi
         VAR_SET=1
         shift
         ;;
      -c)
         VARIABLE_NAME=$CHART_VARIABLE
         if [[ $VAR_SET -gt 0 ]] then
	     echo "Must specify either -m OR -c, but not both"
	     usage
	 fi
         VAR_SET=1
	 shift
         ;;
      -d) 
         # show value flag is set
         SHOW_VALUE_FLAG=1
         if [[ $ACTION_SET -gt 0 ]] then
	     echo "Must specify either -d OR -s, but not both"
	     usage
	 fi
         ACTION_SET=1
         shift
         ;;
      -s)
         shift
         if [[ $# -gt 0 ]] then
               NEW_VALUE=${1}
         else
            echo "Option -s must have a value." >&2
            usage
         fi
         if [[ $ACTION_SET -gt 0 ]] then
	     echo "Must specify either -d OR -s, but not both"
	     usage
	 fi
         ACTION_SET=1
         # sed the string to root out any non numerical characters in it (ignoring leading - sign)
         NON_DIGITS="$(echo $NEW_VALUE | sed 's/^-//g' | sed 's/[0-9]//g')"
         # check it is not the other option
         if [[ $NEW_VALUE == "-d" ]] then
            echo "You must specify either -s and -d, not both." >&2
            usage
         # now make sure the value passed is an int
         elif [[ ! -z $NON_DIGITS ]] then
            echo "The new value must be an integer." >&2
            usage
         # now make sure the value passed is >=2
         elif [[ $NEW_VALUE -lt 2 ]] then
            
            if [[ $VARIABLE_NAME == "$DATAPOINTS_VARIABLE" ]] then 
            	echo "The new value must be greater than or equal to 2." >&2
            	usage
            fi
            
         fi
         # now set the flag
         SET_VALUE_FLAG=1
         shift
         ;;
      *)
         echo "Invalid parameter ${1}." >&2
         usage
         ;;
    esac
done

#
# additional validations
#
# Make sure EITHER set OR display option is selected, not both
if [[ $(( $SET_VALUE_FLAG + $SHOW_VALUE_FLAG )) -ne 1 ]] then
   echo "You must specify either -s and -d, not both." >&2
   usage
fi

if [[ $(( $VAR_SET + $ACTION_SET )) -ne 2 ]] then
   echo "You must specify [-m OR -c] AND [-s OR -d]" >&2
   usage
fi 

#
# Allow the database to handle the parameter verification
#
sqlplus -s $DB_CONNECT <<!
set feed off
set lines 200
set serveroutput on size 1000000
VARIABLE return_status NUMBER;
DECLARE
   l_return INTEGER;
BEGIN

  :return_status := 0;

   IF ( $SET_VALUE_FLAG = 1 ) THEN
      wm_sysval.updateSysVal( '$VARIABLE_NAME', '$NEW_VALUE' );
      wm_print.print( 'New value set.' );
      COMMIT;
   END IF;


   l_return := wm_sysval.getInteger( '$VARIABLE_NAME' );

   IF ( l_return IS NULL ) THEN
      wm_print.print( '$VARIABLE_NAME has not been set to a value');
   ELSE
      wm_print.print( '$VARIABLE_NAME value from DB = ' || to_char( l_return ));
   END IF;



EXCEPTION
   WHEN OTHERS THEN
      :return_status := 1;
      wm_print.print('ERROR: Unable to set the trending report system value');
      wm_print.print( SQLERRM );

END;
/
EXIT :return_status
!
XRETURN=$?

exit $XRETURN
