#!/usr/bin/env perl
###########################################################################
#
# Licensed Materials - Property of IBM
# 5724-T05,5724-T06
#
# (C) Copyright IBM Corp. 2003,2010. All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
###########################################################################
# (#) ./base/pm/adm/update_bridge_properties.pl BL_core_schema_8.0.7_8.0.7.4.02_20100413  064938
# (#) 
#
###################################################################
# Module : update_bridge_properties.pl                            #
#                                                                 #
# Function : Read in the pm/adm/templates/bridge_properties.tpl   #
#            file and replace all of the __envars__ with their    #
#            actual values                                        #
###################################################################

use Env;
use File::Copy;
use IO::Handle;

###################################################################
#                                                                 #
###################################################################

my ( $flexpm_home )          = $ENV{'FLEXPM_HOME'};
my ( $jboss_version )        = $ENV{'JBOSS_VERSION'};
my ( $hostname )             = `/usr/bin/hostname`;   chomp ($hostname);
my ( $dbsid )                = $ENV{'DBSID'};
my ( $domain   )             = ""; # /usr/bin/domainname does not always work
my ( $fqsn )                 = "localhost"; # change to localhost SEAde46916
my ( $memsize )              = `prtconf | grep 'Memory'` ;
my ( $oracle_home )          = $ENV{'ORACLE_HOME'};
my ( $owned_by_init )        = 0;   
my ( $pas_log_dir )          = $ENV{'PM_LOGS'};

my ( $ldap_server )          = $ENV{'LDAP_SERVER'} || 'localhost';
my ( $ldap_port )            = $ENV{'LDAP_PORT'}   || '389';
my ( $ldap_suffix )          = $ENV{'LDAP_SUFFIX'} || 'watchmark.com';
my ( $ldap_admin_prefix )    = $ENV{'LDAP_ADMIN_PREFIX'} || 'cn=';
my ( $ldap_admin_suffix )    = $ENV{'LDAP_ADMIN_SUFFIX'} || 'cn=Administrators,cn=config';

my @system_memory            = split(/ /,$memsize);



sub get_date_time {
###################################################################
#                                                                 #
###################################################################

    ( $sec, $min, $hour, $mday, $mon, $year, $wday, $yday, $isdat ) =
      localtime(time);

    if ( length($hour) < 2 ) { $hour = "0" . $hour; }
    if ( length($min)  < 2 ) { $min  = "0" . $min;  }
    if ( length($sec)  < 2 ) { $sec  = "0" . $sec;  }

    $curr_time = $hour . ":" . $min . ":" . $sec;

    if ( length($mon  ) < 2 )  { $mon  = "0" . $mon;  }
    if ( length($mday ) < 2 )  { $mday = "0" . $mday; }

    $date = join "-", ( $year + 1900 ), ( ++$mon ), ( $mday );

    $curr_time = $hour . ":" . $min . ":" . $sec;

    return (join " ", $date, $curr_time );

}    ### end of get_date_time

sub print_report {
###################################################################
#                                                                 #
###################################################################

     local ( $print_line ) = @_;
     chomp $print_line;
     $date_time_string = &get_date_time;
     $print_literal    = join "|", $date_time_string, $print_line;
     print RPT_FILE "$print_literal\n";
}

sub update_WmLdapApi_properties {
###################################################################
# update_WmLdapApi_properties :                                   #
#      1) copy pm/pas/etc/WmLdapApi.properties to                 #
#         WmLdapApi.properties.bak                                #
#      2) Remove WmLdapApi_properties file                        #
#      3) Read WmLdapApi_properties.bak and update lines with :   #
#         $LDAP_SERVER, $LDAP_PORT, and $LDAP_SUFFIX.             #
#      4) Write results to WmLdapApi_properties                   #
###################################################################

  $pas_etc = join "/", $flexpm_home, "pm/pas/etc";

  $ldap_properties = 'WmLdapApi.properties';

  $ldap_properties_template = $ldap_properties . ".template";

  $dc_line = "";
  
  &print_report("LDAP_SUFFIX ($ldap_suffix)");

  @dc_parts = split('\.',$ldap_suffix);

  for ( $i=0; $i<=$#dc_parts; $i++ ) {
      $dc_line .= 'dc=';
      $dc_line .= $dc_parts[$i];
      if ( $i != $#dc_parts ) {
         $dc_line .= ',';
       }
    }

  &print_report("Updating WmLdapApi.properties ");
  &print_report("LDAP_SERVER ($ldap_server)");
  &print_report("LDAP_PORT   ($ldap_port)");
  &print_report("LDAP_SUFFIX ($ldap_suffix)");
  &print_report("LDAP_ADMIN_PREFIX ($ldap_admin_prefix)");
  &print_report("LDAP_ADMIN_SUFFIX ($ldap_admin_suffix)");

  chdir ($pas_etc);

  unlink ($ldap_properties);

  open TEMPLATE,   "<$ldap_properties_template" or die "Unable to open $ldap_properties_template : $!";

  open NEW_LDAP, ">$ldap_properties"        or die "Unable to create $ldap_properties : $!";

  while (<TEMPLATE>) {
       $line = $_;
       chomp($line);
       if ( $line =~ /^java.naming.provider.url/ ) {
           @split_line = split ( '\=',$line);
           $line = $split_line[0] . '= ldap://' . $ldap_server . ':' . $ldap_port;
       }
       elsif ( $line =~ /WmLdapApi.adminUserDNPrefix/ ) {
           @split_line = split ( '\=',$line);
           $line = $split_line[0] . '= ' . $ldap_admin_prefix;
       }
       elsif ( $line =~ /WmLdapApi.adminUserDNSuffix/ ) {
           @split_line = split ( '\=',$line);
           $line = $split_line[0] . '= ' . $ldap_admin_suffix;
       }       
       if ( $line =~ /dc\=/ ) {
           @dc_parts = split('dc\=',$line);
           $line = $dc_parts[0] . $dc_line;
	 }
       print NEW_LDAP "$line\n";
     }

   close TEMPLATE   or die "Unable to close $ldap_properties_template : $!";
   close NEW_LDAP or die "Unable to close $ldap_properties : $!";

}


sub update_template {
###################################################################
# update_template : Uses two input parameters to create an xml    #
#                   file based on a template and the ports        #
#                   specified                                     # 
#                       $_[0] is the input template               #
#                       $_[1] is the output xml file              #
###################################################################


  open TEMPLATE, "<$_[0]" or die
       "Unable to open $_[0] : $!";

  chmod 0755, "$_[1]";

  open NEW_TEMPLATE, ">$_[1]" or die
       "Unable to open $_[1] : $!";

###
# Replace all occurrences of __envar__ with the associated envar.  For instance,
# the template has an occurrence of __PAS_WEB_PORT__.  This regex replaces 
# ___PAS_WEB_PORT__ with $PAS_WEB_PORT.
###

  while (<TEMPLATE>)
    {
      chomp($_);
      s/__(\w+)__/$ENV{"$1"}/g;
      print NEW_TEMPLATE "$_\n";
    }

  close TEMPLATE     or die "Couldn't close template : $!";
  close NEW_TEMPLATE or die "Couldn't close $_[1] : $!";

  &print_report("Updated $_[1]");

}

sub update_properties_file {
###################################################################
# update_properties_file :  Set envars to match the template      #
#         (bridge.properties.tpl) file.  After all have been set, #
#         run them thru a regex to update the template for jddsql.#
###################################################################

  $ENV{'FQSN'}    = $fqsn;
  $ENV{'MEMSIZE'} = $system_memory[2];

  if( length($ENV{'REP_HASH_AREA_SIZE'}) <= 0)
  {
	$ENV{'REP_HASH_AREA_SIZE'} = 600;
  }
  if( length($ENV{'REP_SORT_AREA_SIZE'}) <= 0) 
  {
	$ENV{'REP_SORT_AREA_SIZE'} = '600';
  }
  if( length($ENV{'REP_SORT_AREA_RETAINED_SIZE'}) <= 0)
  {
	$ENV{'REP_SORT_AREA_RETAINED_SIZE'} = 500;
  }
  if( length($ENV{'REP_PARALLEL_DEGREE'}) <= 0)
  {
	$ENV{'REP_PARALLEL_DEGREE'} = 2;
  }
  if( length($ENV{'REP_TIMEOUT'}) <= 0) 
  {
    $ENV{'REP_TIMEOUT'} = '82800';
  }
  if( length($ENV{'USE_GROUPBY_HINT_CURSOR_SHARING_EXACT'}) <= 0)
  {
       $ENV{'USE_GROUPBY_HINT_CURSOR_SHARING_EXACT'}='true';
  }
  
  chdir ($flexpm_home);

###
# Get the oracle sid for this installation
###
  open TNSPING, "$oracle_home/bin/tnsping $dbsid 2>&1 |"
       or die "Unable to exec $oracle_home/bin/tnsping : $!";

  while ( <TNSPING> ) {
         chomp;
	 my $input_line = $_;
	 next if ( $input_line !~ 'HOST' );
	 local ( $dummy, $part2 ) = split ( 'HOST', $input_line );
         local ( $save_part2 ) = $part2;
         ( $part2, $dummy ) = split('\)',$save_part2);
         $save_part2 = $part2;
         local ( $dummy, $part2 ) = split ( '\=',$save_part2 );
         $_= $part2;
         tr/ //d;
         $part2 = $_;
	 local ( $dbhost,@dummy ) = split ('\)',$part2);
     # Use gethostbyname to retrieve full name SEAde46917
     local ($name, $aliases, $addrtype, $length, @addrs) = gethostbyname($dbhost);
     if ($name ne "")
     {
        $ENV{'DBSERVER'} = $name;
     }
     else 
     {
        $ENV{'DBSERVER'} = $dbhost;
     }
     
  }

  close TNSPING or die "Unable to close tnsping pipe : $!";

  my $input;
  my $output;

  $input =  "$flexpm_home/pm/adm/templates/bridge.properties.tpl";
  $output = "$flexpm_home/pm/pas/etc/bridge.properties";
  &update_template($input,$output);

  # Also copy to bridge properties to report properties 
  $output = "$flexpm_home/pm/pas/$jboss_version/server/default/conf/report.properties";
  &update_template($input,$output);
  
  $input = "$flexpm_home/pm/adm/templates/prospectDS-DefaultProspectDS-ds.xml";
  $output = "$flexpm_home/pm/pas/$jboss_version/server/default/deploy/prospectDS-DefaultProspectDS-ds.xml";
  &update_template($input,$output);

  &update_WmLdapApi_properties;

}


sub get_parent_pid {
###################################################################
# Get the parent id (ppid).  If it is a one (then we are owned    #
# by init), set $owned_by_init to 1 so later processing will      #
# be bypassed                                                     #
###################################################################

  my ($x) = getppid();

  if ( $x eq 1 ) {
      $owned_by_init = 1;
      &print_report("Process owned by init ..... terminating");
    }
}


sub wait_for_jboss {
###################################################################
#                                                                 #
###################################################################

    my ( $boot_log )   = join "/", $flexpm_home, "pm/pas/$jboss_version/server/default/log/boot.log";
    my ( $server_log ) = join "/", $pas_log_dir, "jboss-server.log";

###
# jboss creates two log files on start up.  A boot.log (first) and then a server.log.
# We wait until both are available
###

    &get_parent_pid;

    if ( ! $owned_by_init ) {
        while ( ( ! -f "$boot_log") || ( ! -f "$server_log" ) ) {
             &print_report("Waiting for boot.log ($boot_log) and server.log ($server_log) ");
             &get_parent_pid;
             if ( ! $owned_by_init ) {
                sleep 5;
	      }
             else
	       {
                 return(-1);
	       }
	   }
    }

    my ($boot_epoch)   = 0;
    my ($server_epoch) = -1;

###
# Wait until a new server log is created.  On restart, an old server log file may
# exist and is not overwritten until jboss has completed it's boot.log
###

    &get_parent_pid;

    if ( ! $owned_by_init ) {
        while ( $boot_epoch > $server_epoch ) {

             ($dev, $ino, $mode,$nlink,$uid,$gid,$rdev,$size,
              $atime, $boot_epoch, $ctime, $blksize,$blocks)   = stat "$boot_log";
             ($dev, $ino, $mode,$nlink,$uid,$gid,$rdev,$size,
              $atime, $server_epoch, $ctime, $blksize,$blocks) = stat "$server_log";
              &print_report("Waiting for a new server log ($server_log)");
              &get_parent_pid;
	      if ( ! $owned_by_init ) {
                   sleep 5;
	   	 }
              else
	         {
                  return(-1);
	         }
        }
        &print_report("Boot.log ($boot_log) wait completed ... ");
      }

###
# Now we wait until the "MX MicroKernel" string is found in the server.log
# It only appears once so, when we find it, we can stop waiting.
###

    &get_parent_pid;

    if ( ! $owned_by_init) {
       my ( $break_switch )= 1;
       while ($break_switch) {
           open SERVER_LOG,"<$server_log" or die "Unable to open server log : $!";
           while (<SERVER_LOG>) {
               if ($_ =~ /MX MicroKernel/ ){
                   $break_switch = 0;
               }
           }
           close SERVER_LOG;
           if ( $break_switch ) {
                &print_report("Waiting for full jboss deployment ");
                &get_parent_pid;
                if ( ! $owned_by_init ) {
                    sleep 5;
		  }
                else
		  {
                    return(-1);
		  }
           }
       }
       &print_report("All waits completed");
     }
}


###################################################################
# Pseudo Main                                                     #
###################################################################

my ( $report_file ) = join "/", $flexpm_home, "pm/log", "bridge_update.log";

open RPT_FILE, ">>$report_file" or die "Unable to open $report_file : $!";
RPT_FILE->autoflush(1);

&print_report("Start- $0");

&update_properties_file;

&wait_for_jboss;

&get_parent_pid;

&print_report("End- $0");

close RPT_FILE or die "Unable to close $report_file : $!";

