#!/usr/bin/env perl
###########################################################################
#
# Licensed Materials - Property of IBM
# 5724-T05,5724-T06
#
# (C) Copyright IBM Corp. 2003,2009. All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
###########################################################################
# (#) ./base/pm/adm/update_jboss_ports.pl BL_core_schema_8.0.7_8.0.7.4.02_20100413  064938
# (#) 
#

use Env;
use File::Find;
use File::Copy;
use strict;
use Utils::StartUpEnv;
use FileHandle;




###################################################################
#                                                                 #
###################################################################

# read environment and set jboss and temaplate base accordingly
my $flexpm_home  = $ENV{'FLEXPM_HOME'};
my $jboss_version = $ENV{'JBOSS_VERSION'};
my $vendor_jboss_prestart       = $ENV{'VENDOR_JBOSS_PRESTART'};
my $template_base   = "$flexpm_home/pm/pas/etc/jboss-templates";
my $jboss_base      = "$flexpm_home/pm/pas/$jboss_version";
my $deploy_dir      = "$jboss_base/server/default/deploy";


my %default_ports = (

    'PAS_WEB_PORT'              =>    '8083',
    'PAS_NAME_PORT'             =>    '1099',
    'PAS_INVOKER_PORT'          =>    '4444',
    'PAS_JNDI_NAME_PORT'        =>    '1100',
    'PAS_JNDI_SVC_PORT'         =>    '9000',
    'PAS_OIL_PORT'              =>    '8090',
    'PAS_OIL2_PORT'             =>    '8091',
    'PAS_HSQL_PORT'             =>    '1476',
    'PAS_JETTY_PORT'            =>    '8080',
    'PAS_LISTENER_PORT'         =>    '8009',
    'PAS_SECURE_PORT'           =>    '8443',
    'PAS_RMI_PORT'              =>    '9001',
    'PAS_UIL2_PORT'             =>    '8092',
    'PAS_POOLED_INVOKER_PORT'   =>    '4445',
    'PAS_SNMPAGENT_PORT'        =>    '4445',
    'PAS_SSO_PORT'              =>    '8443'
    );



# This sub takes each of the template file and then substitutes any env variable place holders in it,
# and copies it to the appropriate location in JBoss
sub process_template_file
{
  my $source_file = $File::Find::name;
  my $dest_file = $source_file;
  unless (-d $source_file)
  {
    print " The template file found is: $source_file\n";
    $dest_file =~ s/$template_base/$jboss_base/;
    print " The destination file for the template is: $dest_file\n";
    # now process the file
    update_xml_file($source_file,$dest_file);

  }

}

###################################################################
# update_xml_file : Uses two input parameters to create an xml    #
#                   file based on a template and the ports        #
#                   specified                                     #
#                       $input is the input template              #
#                       $output is the output xml file            #
###################################################################
sub update_xml_file {

  my ($input, $output) = @_;


  # open input for reading
  my $input_fh = FileHandle->new($input, "r") or die "Unable to open $input : $!";

  # make sure we can write to output
  chmod 0755, "$output";
  my $output_fh = FileHandle->new($output, "w") or die "Unable to open $output : $!";


###
# Replace all occurrences of __envar__ with the associated envar.  For instance,
# the template has an occurrence of __PAS_WEB_PORT__.  This regex replaces
# ___PAS_WEB_PORT__ with $PAS_WEB_PORT.
###

  while (my $line = $input_fh->getline())
    {
      chomp($line);
      $line =~ s/__(\w+)__/$ENV{"$1"}/g;
      $output_fh->print("$line\n");
    }

  $input_fh->close() or die "Couldn't close $input : $!";
  $output_fh->close() or die "Couldn't close $output : $!";
}

sub remove_rg_spool_locks {

   my ($rg_dir) = join "/", $flexpm_home, "rg/spool";

   opendir RG_DIR, "$rg_dir" or die "Unable to open $rg_dir directory for read : $!";

   my @allfiles = grep /\.lck$/, readdir RG_DIR;

   closedir RG_DIR or die "Unable to close $rg_dir directory : $!";

   for (my $i=0;$i<= $#allfiles;$i++) {
       my ($unlink_file) = join "/",$rg_dir,$allfiles[$i];
       print STDERR "Removing $unlink_file\n";
       unlink ($unlink_file);
     }
}

# This opens up pweb.war and sets the Auth method and trasnport guarantee in WEB-INF/web.xml accordingly depending on whether we usee SSO or not

sub process_war_file
{
  
  my ($sso_enabled) = @_;
  my $auth_method = ($sso_enabled ? "CLIENT-CERT" : "FORM");
  my $transport_guarantee = ($sso_enabled ? "CONFIDENTIAL" : "NONE");
  my $temp_dir = "$ENV{FLEXPM_HOME}/tempwar";
  my $web_xml_orig = "$temp_dir/WEB-INF/web.xml";
  my $web_xml_tmp = "$web_xml_orig.tmp";

  chdir $ENV{'FLEXPM_HOME'};
  mkdir $temp_dir;
  chdir $temp_dir;
  print "Expanding jar file to temp location: $temp_dir\n";
  system("jar -xf $deploy_dir/pweb.war WEB-INF/web.xml");
  open ORIG, "<$web_xml_orig" or die
         "Unable to open $web_xml_orig : $!";

  open TMP, ">$web_xml_tmp" or die
         "Unable to open $web_xml_tmp : $!";

  # run through the file looking for the auth-method tag and substitute accordingly
  while (<ORIG>)
  {
      my $line = $_;
      chomp($line);
      # substitutute in the correct auth-method here
      $line =~ s/\<auth-method\>(.*?)\<\/auth-method\>/\<auth-method\>$auth_method\<\/auth-method\>/ ;
      # substitutute in the correct transport-guarantee here
      $line =~ s/\<transport-guarantee\>(.*?)\<\/transport-guarantee\>/\<transport-guarantee\>$transport_guarantee\<\/transport-guarantee\>/ ;
      print TMP "$line\n";
  }

  close ORIG or die "Couldn't close $web_xml_orig : $!";
  close TMP or die "Couldn't close $web_xml_tmp : $!";
  
  copy($web_xml_tmp,$web_xml_orig);
  unlink($web_xml_tmp);
  print "Re-creating jar file : $deploy_dir/pweb.war\n";
  chdir $temp_dir;
  system("jar -uf $deploy_dir/pweb.war WEB-INF");
  chdir $ENV{'FLEXPM_HOME'};
  system("rm -fR tempwar");
  
}












###################################################################
# Pseudo Main                                                     #
###################################################################

# firstly - ensure all port values are populated
foreach my $default_port (keys %default_ports)
{
  if (! exists($ENV{$default_port}))
  {
     print STDERR ("$default_port not found .. Default (". $default_ports{$default_port} . ")\n");
     $ENV{$default_port} = "$default_ports{$default_port}";
     print "$default_port = $ENV{$default_port} \n";
  }
}


my $startup = new Utils::StartUpEnv();

# set the connector xml appropriately (for SSL if needed)
print "Setting Tomcat related configuration:\n";
if ($startup->checkSSLEnabled())
{
  $startup->setStartupEnvironmentSSL($ENV{'PAS_JETTY_PORT'}, $ENV{'PAS_SECURE_PORT'}, $jboss_base);
}
# note that SSO will only be invoked if we have the vendor_jboss
elsif (defined($ENV{SSO_STORES_DIR}) ? $startup->checkSSOEnabled() : 0)
{
  $startup->setStartupEnvironmentSSO($ENV{'PAS_JETTY_PORT'}, $ENV{'PAS_SECURE_PORT'}, $jboss_base);
}
else
{
  $startup->setStartupEnvironment($ENV{'PAS_JETTY_PORT'}, $ENV{'PAS_SECURE_PORT'}, $jboss_base);
}

# finds all the template files and processes them to the appropriate dir in jboss
print "Processing Templates:\n";
find(\&process_template_file, $template_base);

# only do this step is SSO has been set up in the system (i.e. by the oem component)
if (defined($ENV{'SSO_STORES_DIR'}) ? $startup->checkSSOSet() : 0)
{
  print "Processing pweb war file:\n";
  process_war_file($startup->checkSSOEnabled() && $startup->ssoConfiguredOK());
}





# finally if $VENDOR_JBOSS_PRESTART env variable is set make a call to this script
# Note: $VENDOR_JBOSS_PRESTART gets set in .profile.oem if such exists

if( -e $vendor_jboss_prestart )
{
    print "Make a call to $vendor_jboss_prestart\n";
    system($vendor_jboss_prestart);
   }
else{
    print "VENDOR_JBOSS_PRESTART not set. No call to vendor_update_jboss_ports...\n";
}




&remove_rg_spool_locks
