/*
 *=============================================================================
 *                      COPYRIGHT WatchMark Inc 2004
 *=============================================================================
 * 
 * Created on Mar 19, 2004
 * 
 * An Adapter encapsulates an object that is being configured from an XML
 * document. The adapter translates the elements as they are streamed in
 * converting them to setFoo calls on the target object, or create
 * sub-adapters that handle sub-classes.
 */
package com.watchmark.loader.processor.flarion;

import com.watchmark.loader.xml.model.*;

import java.io.IOException;
import java.io.StringReader;

import java.text.ParseException;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;
import org.apache.log4j.Logger;

import org.xml.sax.Attributes;
import org.xml.sax.InputSource;
import org.xml.sax.SAXException;
import org.xml.sax.XMLReader;
import org.xml.sax.helpers.DefaultHandler;
import org.xml.sax.helpers.XMLReaderFactory;

import java.util.List;
import java.sql.Connection;

/**
 * @author robin
 * @version 1.0 2004/03/19
 * 
 * 
 */

public class MessageAdapter extends XMLBaseAdapter
{
  public static final String ADAPTER_NAME = "message";

  private String _id;
  private String _name;
  private MessagesAdapter _messagesAdapter;
  private Map _fieldValueMap = new HashMap();
  
  public MessageAdapter(MessagesAdapter ma)
  {
    super(null, null);
    _messagesAdapter = ma;
  }
  
  public void setAttributes(Attributes list)
  {
    for (int i=0; i<list.getLength(); i++)
    {
      String name = list.getQName(i);
      String value = list.getValue(i);
      
      if (name.equals("id"))
        _id = value;
      else if (name.equals("name"))
        _name = value;
    }
  }
  
  public String getName()
  {
    return ADAPTER_NAME;
  }
  
  
  
  public Adapter create(String tag, Attributes list)
    throws Exception
  {
    Adapter result = this;
    
    if (tag.equals("field"))
    {
      // This is so simple, we can handle it here.
      // <field name='ActUserHist_index_119' level='info' format='number' value='0'/>
      //
      String fieldName = null;
      String fieldValue = null;
      for (int i=0; i<list.getLength(); i++)
      {
        String name = list.getQName(i);
        String value = list.getValue(i);
        
        if (name.equals("name"))
          fieldName = value;
        else if (name.equals("value"))
          fieldValue = value;
      }
      
      if (fieldName != null && fieldValue != null)
      {
        // Stash the value, so when we close we can pull out and write a
        // line of fields in a reasonable order (at least, an order that
        // is well-known to the loader).
        _fieldValueMap.put(fieldName, fieldValue);
      }
    }
    return result;
  }
  

  public void text(String tag, String data) throws Exception
  {
  }
  
  
  public void writeHeader(List types) throws IOException
  {
    _messagesAdapter.writeHeader();
    
    // these are the addition headings that come from the first <moid> tag
    // we see.
    writeList(types); 
  }
  
  public void writeList(List types) throws IOException
  {
    _messagesAdapter.writeList(types);
  }
  
  public void endLine() throws IOException
  {
    _messagesAdapter.endLine();
  }
  
  public void writeKeys(List ids) throws IOException
  {
    _messagesAdapter.writeKeys();
    writeList(ids); // these need to go out before the time columns
  }

  public void close() throws Exception
  {
    // Awesome. Dump out a line of attributes, including all the keys we need
    // to make the row unique.
    _messagesAdapter.writeFields(_name, _id, _fieldValueMap);
  }
}