/*
 *=============================================================================
 *                      COPYRIGHT WatchMark Inc 2004
 *=============================================================================
 * 
 * Created on Mar 19, 2004
 * 
 * An Adapter encapsulates an object that is being configured from an XML
 * document. The adapter translates the elements as they are streamed in
 * converting them to setFoo calls on the target object, or create
 * sub-adapters that handle sub-classes.
 */
package com.watchmark.loader.xml.model;

import com.watchmark.loader.framework.Message;
import com.watchmark.loader.framework.MessageField;
import com.watchmark.loader.framework.MessageName;
import com.watchmark.loader.framework.MessageTypeMap;
import java.io.IOException;
import java.io.StringReader;

import java.text.ParseException;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;
import java.util.StringTokenizer;
import org.apache.log4j.Logger;

import org.xml.sax.Attributes;
import org.xml.sax.InputSource;
import org.xml.sax.SAXException;
import org.xml.sax.XMLReader;
import org.xml.sax.helpers.DefaultHandler;
import org.xml.sax.helpers.XMLReaderFactory;

import java.util.List;
import java.sql.Connection;

/**
 * @author robin
 * @version 1.0 2004/03/19
 * 
 * 
 */

public class MeasurementDataAdapter extends XMLBaseAdapter
{
  public static final String ADAPTER_NAME = "md";
  public static final String SEP = ",";
 
  private MessageTypeMap _messageTypeMap = null;
  private SimpleDateFormat _from = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
  private SimpleDateFormat _to = new SimpleDateFormat("MM/dd/yy HH:mm");
  
  private Map _attributeMap = new HashMap();
  
  public MeasurementDataAdapter(XMLController c, Connection conn)
  {
    super(c, conn);
  }
  
  public String getName()
  {
    return ADAPTER_NAME;
  }
  
  public Adapter create(String tag, Attributes attributes)
    throws Exception
  {
    Adapter result = this;
        
    if (tag.equals(MeasurementInfoAdapter.ADAPTER_NAME))
    {
      // <mi>
      result = new MeasurementInfoAdapter(_controller, _connection, this);
    }
    return result;
  }

  public void text(String tag, String data) throws Exception
  {
    if (tag.equals("nedn"))
      extractDN(data);
  }
  
  private void extractDN(String data)
  {
    List types = new ArrayList();
    List values = new ArrayList();
    
    extractDN(types, values, data);
    Iterator it = types.iterator();
    Iterator vit = values.iterator();
    while (it.hasNext() && vit.hasNext())
    {
      String type = (String)it.next();
      String value = (String)vit.next();
      
      // Just stick the DN components straight into the value map.
      _attributeMap.put(type, value);
    }

  }
  
  public static void extractDN(List types, List values, String data)
  {
    // subNetwork=WTC1AccessOAM,subNetwork=utran,ManagedElement=RNC-WTCRUR02
    StringTokenizer st = new StringTokenizer(data, ",=", true);
    String element = null;
    while (st.hasMoreElements())
    {
      String token = st.nextToken();

      if (token.equals(","))
        element = null;
      else if (!token.equals("="))
      {
        if (element == null)
          element = token;
        else
        {
          // we've got a pair
          if (element.length() > 0 && token != null && token.length() > 0)
          {
            types.add(element);
            values.add(token);
          }
          element = null;
        }
      }
    }
  }

  
  public void writeMap(MessageName messageName, Map attributes) throws IOException
  {
    Message message = getMessage(messageName);
    if (message != null)
    {
      // What about the tstamp? Where do we get that from?
      
      String tstamp = (String)attributes.get("tstamp");
      if (tstamp != null)
      {
        try
        {
          getController().write(message.getMessageNameString());
          Date d = _from.parse(tstamp);
    
          // Horrible Loader requires this nasty date format. I'm not
          // impressed.
          String tstampString = _to.format(d);
          
          Iterator it = message.getFieldIterator();
          while (it.hasNext())
          {
            MessageField mf = (MessageField)it.next();
            String value;
            if (mf.getFieldName().equals("tstamp"))
              value = tstampString;
            else
              value = (String)attributes.get(mf.getFieldName());
  
            getController().write(SEP); // always write a separator.
            if (value != null)
              getController().write(value);
          }
      
          endLine();      
        }
        catch (ParseException pe)
        {
        }
      }
    }
  }
  
  public void endLine() throws IOException
  {
    getController().endLine();
  }
  
  
  public void setMessageTypeMap(MessageTypeMap mtm)
  {
    _messageTypeMap = mtm;
  }
  
  public Map getAttributeMap()
  {
    return _attributeMap;
  }
  
  public Message getMessage(MessageName n)
  {
    Message result = null;
    
    if (_messageTypeMap != null)
      result = _messageTypeMap.getMessage(n);
      
    return result;
  }
  
  public Iterator getMessageNameIterator()
  {
    List result = new ArrayList();
    
    Iterator it =_messageTypeMap.getMessageIterator();
    while (it.hasNext())
    {
      Message m = (Message)it.next();
      result.add(m.getMessageName());
    }
    
    return result.iterator();
  }
}