/*
 *=============================================================================
 *                      COPYRIGHT WatchMark Inc 2004
 *=============================================================================
 * 
 * Created on Mar 19, 2004
 * 
 * An Adapter encapsulates an object that is being configured from an XML
 * document. The adapter translates the elements as they are streamed in
 * converting them to setFoo calls on the target object, or create
 * sub-adapters that handle sub-classes.
 */
package com.watchmark.loader.xml.model;

import com.watchmark.loader.framework.MessageName;
import java.io.IOException;
import java.io.StringReader;

import java.text.ParseException;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;
import java.util.Vector;
import org.apache.log4j.Logger;

import org.xml.sax.Attributes;
import org.xml.sax.InputSource;
import org.xml.sax.SAXException;
import org.xml.sax.XMLReader;
import org.xml.sax.helpers.DefaultHandler;
import org.xml.sax.helpers.XMLReaderFactory;

import java.util.List;
import java.sql.Connection;

/**
 * @author robin
 * @version 1.0 2004/03/19
 * 
 * 
 */

public class MeasurementInfoAdapter extends XMLBaseAdapter
{
  public static final String ADAPTER_NAME = "mi";
 
  private Vector _measurementTypes = new Vector();
  private Date   _tstamp;
  private int    _granularityPeriod = 0;
  private MeasurementDataAdapter _measurementDataAdapter;
  private Map     _attributeMap;
  private final SimpleDateFormat _to = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
  private MessageName _messageName = null;
      
  public MeasurementInfoAdapter(XMLController c, Connection conn, MeasurementDataAdapter mda)
  {
    super(c, conn);
    _measurementDataAdapter = mda;
    _attributeMap = new HashMap(_measurementDataAdapter.getAttributeMap());
  }
  
  public String getName()
  {
    return ADAPTER_NAME;
  }
    
  public int getGranularityPeriod()
  {
    return _granularityPeriod;
  }
    
  public Adapter create(String tag, Attributes attributes)
    throws Exception
  {
    Adapter result = this;
    
    if (tag.equals(MeasurementValueAdapter.ADAPTER_NAME))
    {
      result = new MeasurementValueAdapter(_controller, _connection, this, _attributeMap);
    }
    else if (tag.equals(MeasurementTypeAdapter.ADAPTER_NAME))
    {
      result = new MeasurementTypeAdapter(_controller, _connection, this);
      result.setAttributes(attributes);
    }
    
    return result;
  }
  
  private void extractTstamp(String data) throws Exception
  {
    SimpleDateFormat from = new SimpleDateFormat("yyyyMMddHHmmss");
    
    // Shameful old loader date format. Ick.

    _tstamp = from.parse(data);
    
    if (_granularityPeriod > 0)
    {
      // we've already got this, so we can slide the date back to represent
      // the beginning of the period.
      _tstamp.setTime(_tstamp.getTime() - (_granularityPeriod*1000));
      String tstampString = _to.format(_tstamp);

      // Update the tstamp value we hold in our attribute map.      
      _attributeMap.put("tstamp", tstampString);
    }
  }

  public void text(String tag, String data) throws Exception
  {
    if (tag.equals("mts"))
      extractTstamp(data);
    else if (tag.equals("gp"))
      setGranularityPeriod(Integer.parseInt(data));
  }
  
  private void setGranularityPeriod(int gp)
  {
    _granularityPeriod = gp;
    
    if (_tstamp != null)
    {
      // We're quite often given the granularity period <gp> after the 
      // tstamp <mts>, so now it's time to adjust to the beginning of the
      // period.
      _tstamp.setTime(_tstamp.getTime() - (_granularityPeriod*1000));

      // Update these attributes in the map.
      String tstampString = _to.format(_tstamp);
      _attributeMap.put("tstamp", tstampString);
    }
    _attributeMap.put("granularityPeriod", "" +_granularityPeriod);
  }
      
  public void endLine() throws IOException
  {
    _measurementDataAdapter.endLine();
  }
  
  public void writeMap(Map attributes) throws IOException
  {
    // Now. The big question here. How on earth do we come up with a
    // map-name? Perhaps we should just iterate over the list of available
    // map names, and use the first one that we have all the values for.
    // Seems reasonable...
    if (_messageName == null)
    {
      _messageName = determineMessageName(attributes);
    }
    
    if (_messageName != null)
      _measurementDataAdapter.writeMap(_messageName, attributes);
  }

  public void close() throws Exception
  {
  }
  
  public String getMeasurementName(int measurementIndex)
  {
    // Remember that measurementIndex goes from 1..n, so we have to offset into
    // our array.
    String result = "";

    MeasurementType mt = (MeasurementType)_measurementTypes.get(measurementIndex-1);
    if (mt != null)
      result = mt.getName();
    
    return result;
  }
  
  protected void addMeasurementType(String name, int measurementIndex)
  {
    int index;
    
    if (measurementIndex >= 0)
      index = measurementIndex-1;
    else
      index = _measurementTypes.size();

    MeasurementType mt = new MeasurementType(name, index);

    if (index >= _measurementTypes.size())
    {
      _measurementTypes.setSize(index+1);
    }
      
    _measurementTypes.set(index, mt);
  }
  
  private MessageName determineMessageName(Map attributes)
  {
    // Find the first <message> entry for which all its parts can be found in
    // the attributes Map parameter.
    MessageName result = null;
    Iterator it = _measurementDataAdapter.getMessageNameIterator();
    while (result == null && it.hasNext())
    {
      result = (MessageName)it.next();
      Iterator parts = result.getParts().iterator();

      while (result != null && parts.hasNext())
      {
        String part = (String)parts.next();
        if (attributes.get(part) == null)
          result = null; // mismatch, so try another one
      }
    }
    
    return result;
  }
}
