/*
 *=============================================================================
 *                      COPYRIGHT WatchMark Inc 2004
 *=============================================================================
 * 
 * Created on Mar 19, 2004
 * 
 * An Adapter encapsulates an object that is being configured from an XML
 * document. The adapter translates the elements as they are streamed in
 * converting them to setFoo calls on the target object, or create
 * sub-adapters that handle sub-classes.
 */
package com.watchmark.loader.xml.model;

import java.io.IOException;
import java.io.StringReader;

import java.text.ParseException;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;
import org.apache.log4j.Logger;

import org.xml.sax.Attributes;
import org.xml.sax.InputSource;
import org.xml.sax.SAXException;
import org.xml.sax.XMLReader;
import org.xml.sax.helpers.DefaultHandler;
import org.xml.sax.helpers.XMLReaderFactory;

import java.util.List;
import java.sql.Connection;

/**
 * @author robin
 * @version 1.0 2004/03/19
 * 
 * 
 */

public class MeasurementValueAdapter extends XMLBaseAdapter
{
  public static final String ADAPTER_NAME = "mv";

  private MeasurementInfoAdapter _measurementInfoAdapter; 
  private Map _valueMap;
  int _attributeCount = 0;
  String _value;
  String _moid;
  int _currentMeasurementIndex = -1;

  
  public MeasurementValueAdapter(XMLController c, Connection conn, 
    MeasurementInfoAdapter mia, Map infoMap)
  {
    super(c, conn);
    _measurementInfoAdapter = mia;
    
    // Copy the info fields into the map we're building.
    _valueMap = new HashMap(infoMap);
  }
  
  public String getName()
  {
    return ADAPTER_NAME;
  }
  
  public Adapter create(String tag, Attributes attributes)
    throws Exception
  {
    Adapter result = this;
    
    if (tag.equals("r"))
      _currentMeasurementIndex = extractMeasurementIndex(attributes);
    
    return result;
  }

  public void text(String tag, String data) throws Exception
  {
    if (tag.equals("r"))
    {
      // OK. So let's find out what measurement this refers to and stick it in
      // our map.
      String measurementName = _measurementInfoAdapter.getMeasurementName(_currentMeasurementIndex);
      if (measurementName != null)
      {
        _valueMap.put(measurementName, data);
      }
    }
    else if (tag.equals("moid"))
      extractMOID(data);
  }

  public void close() throws Exception
  {
    // Now how do we know we're the last one of our kind on the stack? Hopefully
    // close only gets called the once.
    _measurementInfoAdapter.writeMap(_valueMap);
  }
  
  private void extractMOID(String m) throws IOException
  {
    List types = new ArrayList();
    List values = new ArrayList();
    MeasurementDataAdapter.extractDN(types, values, m);
    
    Iterator it = types.iterator();
    Iterator vit = values.iterator();
    while (it.hasNext() && vit.hasNext())
    {
      String type = (String)it.next();
      String value = (String)vit.next();
      
      // Just stick the DN components straight into the value map.
      _valueMap.put(type, value);
    }
  }

  public int extractMeasurementIndex(Attributes list)
  {
    int result = -1;
    for (int i=0; result == -1 && i<list.getLength(); i++)
    {
      String name = list.getQName(i);
      String value = list.getValue(i);
      
      if (name.equals("p") && value != null && value.length() > 0)
        result = Integer.parseInt(value);
    }
    
    // they're not using the p="2" position references
    if (result == -1)
      result = ++_attributeCount;
    
    return result;
  }

}
