/*
 *=============================================================================
 *                      COPYRIGHT WatchMark Inc 2004
 *=============================================================================
 * 
 * Created on Feb 23, 2004
 * 
 */
package com.watchmark.loader.zipstream;

import com.watchmark.loader.framework.ArchiveReader;
import com.watchmark.loader.framework.Controller;
import com.watchmark.loader.framework.FileReader;
import com.watchmark.loader.framework.Processor;

import java.io.BufferedInputStream;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.zip.GZIPInputStream;
import org.w3c.dom.Element;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;

public class CpioFileReader extends ArchiveReader
{
  boolean _compressed = false;
  
  public CpioFileReader(String name)
  {
    super(name);
  }

  /**
   * Configure the Processor using data it finds under this element. Usually only
   * things specific to this instance.
   * @param e
   */
  public void configure(Element e)
  {
    super.configure(e);
    
    // Hmm, now are we compressed? If so, we probably need to read through
    // a GZIPInputStream.
    _compressed = "true".equalsIgnoreCase(ConfigHandler.getValueByName(e, "compressed"));
  }

  /**
   * Open the file as a ZIP.
   * @param is
   */
  public void process(String filename, Controller controller)
    throws FileNotFoundException, IOException
  {
    FileInputStream fis = new FileInputStream(filename);
    CpioInputStream cis = null;
    GZIPInputStream gz = null;
    
    try
    {
      if (_compressed)
      {
        gz = new GZIPInputStream(new BufferedInputStream(fis));
        cis = new CpioInputStream(gz);
      }
      else
      {
        cis = new CpioInputStream(new BufferedInputStream(fis));
      }
      
      CpioEntry entry;
      while((entry = cis.getNextEntry()) != null)
      {
        processEntry(cis, entry.getName());
      }
    }
    finally
    {
      if (gz != null)
        gz.close();
      cis.close();
    }
  }
}
