package com.watchmark.loader.zipstream;
// -f flarionMessageMap.xml -d loader -t Flarion -lid LID_Flarion -tlid TLID_Flarion
// -f lucentUMTSMessageMap.xml -d lumts -t 3GPP -lid LID_LUCUMTS -tlid TLID_LUCUMTS
import com.watchmark.loader.framework.*;

import java.io.BufferedOutputStream;
import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.FileWriter;
import java.io.IOException;
import java.io.OutputStream;
import java.io.OutputStreamWriter;
import java.io.PrintWriter;
import java.io.Writer;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;
import org.apache.log4j.BasicConfigurator;
import org.apache.log4j.Logger;
import org.xml.sax.SAXException;

import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.parsers.FactoryConfigurationError;
import javax.xml.parsers.ParserConfigurationException;
import org.w3c.dom.Document;

public class LoaderGen
{
	private Logger _logger = Logger.getLogger(getClass());
  Map _messageTypeMaps = new HashMap();
  String _targetDirName = "";
  String _typeMapName = "";
  String _loaderId = "";
  String _tableLoadId = "";
  
  public LoaderGen()
  {
  }
    
  public void readConfigFile(String filename)
  {
    ZipStreamUtil.readMessageTypeMap("LoaderGen", filename, _messageTypeMaps);
  }
  
  public void processArgs(String args[])
  {
    try
    {
      for (int i=0; i<args.length; i++)
      {
        if (args[i].equals("-f") && i+1 < args.length)
        {
          readConfigFile(args[++i]);
        }
        else if (args[i].equals("-d") && i+1 < args.length)
        {
          _targetDirName = args[++i];
        }
        else if (args[i].equals("-t") && i+1 < args.length)
        {
          _typeMapName = args[++i];
        }
        else if (args[i].equals("-lid") && i+1 < args.length)
        {
          _loaderId = args[++i];
        }
        else if (args[i].equals("-tlid") && i+1 < args.length)
        {
          _tableLoadId = args[++i];
        }
        else
        {
          System.err.println("Unrecognized or invalid argument: " + args[i]);
          printUsage();
        }
      }
    }
    catch (Exception e)
    {
      System.out.println(e.getMessage());
      e.printStackTrace();
    }
  }
  
  public void printUsage()
  {
    System.err.println("Usage: " +
    "java -classpath ${LOADER_HOME} com.watchmark.loader.zipstream.LoaderGen " +
      "-f <mapfile.xml> -d <target-dir> -t <type-map-name> -lid <loader-id>");
  }
  
  public void process()
  {
    // Read the map entry, and build as much of the loader config as we can.
    MessageTypeMap map = (MessageTypeMap)_messageTypeMaps.get(_typeMapName);
    if (map != null)
    {
      try
      {
        buildConfig(map);
      }
      catch (IOException e)
      {
        System.err.println("Error writing configuration: " + e.getMessage());
      }
    }
    else
    {
      System.err.println("Type-map-name \"" + _typeMapName + "\" not found in " +
        " map file(s).");
    }
  }
  
  public void buildConfig(MessageTypeMap map) throws IOException
  {
    File base = new File(_targetDirName);
    File data = new File(base, "data");
    File gateway = new File(base, "GATEWAY");
    
    if (!data.exists())
      data.mkdirs();
    
    if (!gateway.exists())
      gateway.mkdirs();
    
    // The 3 primary configuration files that we can construct automatically
    // from the information in the MessageTypeMap.
    File parserState   = new File(data, "ParserState.txt");
    File loaderControl = new File(data, "LoaderControl.txt");
    File loadAction    = new File(data, "LoadAction.txt");
    File dataGateway   = new File(gateway, "dataGateway.hdd");
    
    generateDataGateway(dataGateway, map);
    generateParserState(parserState, map);
    generateLoaderControl(loaderControl, map);
    generateLoadAction(loadAction, map);
  }
  
  private void generateDataGateway(File f, MessageTypeMap m) throws IOException
  {
    PrintWriter w = new PrintWriter(new FileWriter(f));
    try
    {
      w.println("(dataGateway");
      w.println("  (package SYSTEM 1 STRING");
      w.println("    (package Key " + m.getMaxKeyCount() + " STRING");
      
      Iterator it = m.getMessageIterator();
      while (it.hasNext())
      {
        Message message = (Message)it.next();
        w.println("      (package " + message.getMessageNameString() + " " +
          message.getPackageFieldCount() + ")");
      }
      w.println("    )");
      w.println("  )");
      w.println(")");
    }
    finally
    {
      w.close();
    }
    
  }
  
  private void generateParserState(File f, MessageTypeMap m) throws IOException
  {
    PrintWriter w = new PrintWriter(new FileWriter(f));
    try
    {
      String action = "delimiters ,; enableEmptyFields; push SYSTEM; setAttribute $SYSTEM_ID";
      w.println(new ParserLine(_loaderId, "start", "<default>", "RUN", 1, action).toString());
      
      // A final state to pop the 1 SYSTEM object off the stack. This ends the parser's
      // ability to accept any new data.
      w.println(new ParserLine(_loaderId, "RUN", "END_OF_STREAM__", "END", 1, "pop").toString());
      w.println(new ParserLine(_loaderId, "END", "<default>", "END", 1, 
        "say Token found after END_OF_STREAM__ $$").toString());
      
      Iterator it = m.getMessageIterator();
      while (it.hasNext())
      {
        Message message = (Message)it.next();
        
        // We have to grab the TSTAMP many times. We only remember the last one,
        // but hopefully that's enough for now. What we really need is the min
        // and max tstamp, which we could probably do through a gateway
        // expression: min(Key.SYSTEM.Key, F0), max(Key.SYSTEM.Key, F0) - but
        // this is rather expensive. We should be loading into tmp tables
        // and doing a MERGE anyway, so this probably doesn't matter.
        action = 
          "push Key; skip; collect 1; setArg TSTAMP $$; skip; collect " + message.getKeyCount() +
          "; push " + message.getMessageNameString() + 
          "; skip; next; collect " + message.getPackageFieldCount() + // fields start F1...Fn
          "; pop; pop";
        ParserLine pl = new ParserLine(_loaderId, 
          "RUN", "\""+message.getMessageNameString()+"\"", "RUN", 1, action);
        w.println(pl.toString());
      }
    }
    finally
    {
      w.close();
    }
    
  }

  private void generateLoaderControl(File f, MessageTypeMap m) throws IOException
  {
    PrintWriter w = new PrintWriter(new FileWriter(f));
    try
    {
      int loadIndex = 0;
      Iterator it = m.getMessageIterator();
      while (it.hasNext())
      {
        Message message = (Message)it.next();
        
        Iterator tables = message.getTableIterator();
        while (tables.hasNext())
        {
          MessageTable mt = (MessageTable)tables.next();
          Iterator cols = mt.getColumnIterator();
          while (cols.hasNext())
          {
            MessageTableColumn mtc = (MessageTableColumn)cols.next();
            
            String exp = message.translate(mtc);
            
            LoaderControlLine lcl = new LoaderControlLine(_tableLoadId,
              loadIndex, mtc.getColumnName(), mt.getTableName(), 
              message.getMessageNameString(),
              mtc.getColumnType(), exp);
              
            w.println(lcl.toString());
          }
          
          // Each table we output must have its own unique loader sequence
          // number.
          loadIndex++;
        }
      }
    }
    finally
    {
      w.close();
    }
    
  }

  private void generateLoadAction(File f, MessageTypeMap m) throws IOException
  {
    PrintWriter w = new PrintWriter(new FileWriter(f));
    try
    {
      int loadIndex = 0;
      Iterator it = m.getMessageIterator();
      while (it.hasNext())
      {
        Message message = (Message)it.next();
        
        Iterator tables = message.getTableIterator();
        while (tables.hasNext())
        {
          MessageTable mt = (MessageTable)tables.next();
          Iterator actions = mt.getActionIterator();
          while (actions.hasNext())
          {
            MessageTableAction mta = (MessageTableAction)actions.next();
                        
            LoadActionLine lal = new LoadActionLine(_tableLoadId,
              mt.getTableName(), loadIndex, mta.getPrePost(),
              mta.getActionType(), mta.getAction(), mta.getArguments());
              
            w.println(lal.toString());
          }
          
          // Each table we output must have its own unique loader sequence
          // number.
          loadIndex++;
        }
      }
    }
    finally
    {
      w.close();
    }
  }
  
  /**
   * 
   * @param args
   */
  public static void main(String[] args)
  {
    Logger rootLogger = Logger.getRootLogger();
    BasicConfigurator.configure();
    
    long startTime = System.currentTimeMillis();
    LoaderGen lg = new LoaderGen();
    
    lg.processArgs(args);
    lg.process();
     
    long endTime = System.currentTimeMillis();

    double delta = (endTime - startTime)/1000.0;

    System.err.println("=====================================================");
    System.err.println("Test took " + delta + "s");
    System.err.println("=====================================================");
  }
}
