/*
 *=============================================================================
 *                      COPYRIGHT WatchMark Inc 2004
 *=============================================================================
 * 
 * Created on Feb 23, 2004
 * 
 */
package com.watchmark.loader.framework;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.Reader;

public class NoCloseBufferedReader extends BufferedReader
{
  public NoCloseBufferedReader(Reader r)
  {
    super(r);
  }
  
  public void close()
  {
    // do nothing...we're stopping a SAX parser from closing the input stream
    // on us.
  }

   /**
     * Read characters into a portion of an array.
     * 
     * <p> This subclass removes zero bytes (0x0) values in the stream using
     * a rolling algorithm to compact data in the array.
     * 
     * The stream should never really have these bytes in there in the 
     * first place (it's not valid XML).
     *
     * @param      cbuf  Destination buffer
     * @param      off   Offset at which to start storing characters
     * @param      len   Maximum number of characters to read
     *
     * @return     The number of characters read, or -1 if the end of the
     *             stream has been reached
     *
     * @exception  IOException  If an I/O error occurs
     */
    public int read(char cbuf[], int off, int len) throws IOException 
    {
      int result = super.read(cbuf, off, len);
      int skip = 0;
      
      if (result >= 0)
      {
        for (int i=off; i<off+result; i++)
        {
          if (cbuf[i] == 0)
          {
            ++skip;
          }
          else if (skip > 0)
            cbuf[i-skip] = cbuf[i];
        }
      }
      
      result = result - skip;
      
      return result;
    }
  
}