/*
 *=============================================================================
 *                      COPYRIGHT WatchMark Inc 2004
 *=============================================================================
 * 
 * Created on Mar 19, 2004
 * 
 * An Adapter encapsulates an object that is being configured from an XML
 * document. The adapter translates the elements as they are streamed in
 * converting them to setFoo calls on the target object, or create
 * sub-adapters that handle sub-classes.
 */
package com.watchmark.loader.processor.flarion;

import com.watchmark.loader.framework.*;
import com.watchmark.loader.xml.model.*;

import java.io.IOException;
import java.io.StringReader;

import java.text.ParseException;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.Iterator;
import java.util.Map;
import java.util.StringTokenizer;
import org.apache.log4j.Logger;

import org.xml.sax.Attributes;
import org.xml.sax.InputSource;
import org.xml.sax.SAXException;
import org.xml.sax.XMLReader;
import org.xml.sax.helpers.DefaultHandler;
import org.xml.sax.helpers.XMLReaderFactory;

import java.util.List;
import java.sql.Connection;

/**
 * @author robin
 * @version 1.0 2004/03/19
 * 
 * 
 */

public class MessagesAdapter extends XMLBaseAdapter
{
  public static final String ADAPTER_NAME = "messages";
  public static final String SEP = ",";
 
  private List _keyHeaders = new ArrayList(); //
  private List _keyValues  = new ArrayList(); //
  private MessageTypeMap _messageTypeMap;
  
  public MessagesAdapter(XMLController c, MessageTypeMap messageTypeMap)
  {
    super(c, null);
    _messageTypeMap = messageTypeMap;
  }
  
  public String getName()
  {
    return ADAPTER_NAME;
  }
  
  public Adapter create(String tag, Attributes attributes)
    throws Exception
  {
    Adapter result = this;
    
    if (tag.equals(MessageAdapter.ADAPTER_NAME))
    {
      // <messages id='m0' name='HISTOGRAM_USER_LOAD'>
      result = new MessageAdapter(this);
      result.setAttributes(attributes);
    }
    return result;
  }

  public void text(String tag, String data) throws Exception
  {
  }
  
  

  public void writeHeader() throws IOException
  {
    getController().write("H");
    writeList(_keyHeaders);
  }
  
  public void writeList(List types) throws IOException
  {
    Iterator it = types.iterator();
    while (it.hasNext())
    {
      getController().write(SEP);
        
      String elementType = (String)it.next();
      getController().write(elementType);
    }
  }
  
  public void endLine() throws IOException
  {
    getController().write("\n");
  }
  
  public void writeKeys() throws IOException
  {
    getController().write("M");
    writeList(_keyValues);
  }
  
  public void writeFields(String messageName, String id, Map fieldValueMap)
    throws IOException
  {
    if (_messageTypeMap != null)
    {
      MessageName mn = new MessageName(messageName);
      Message message = (Message)_messageTypeMap.getMessage(mn);
      if (message != null)
      {
        
        // What about the tstamp? Where do we get that from?
        String secondString = (String)fieldValueMap.get("seconds");
        if (secondString != null)
        {
          getController().write(message.getMessageNameString());
          long seconds = Long.parseLong(secondString);
          Date d = new Date(seconds*1000);
    
          // Push the tstamp string into the attributes map (so any Translators
          // can get their sticky paws on it).
          String tstampString = Message.timeToISO(d);
          fieldValueMap.put("tstamp", tstampString);

          // Before we go any further, run any translators we have on the attribute
          // map.
          message.runTranslators(fieldValueMap);
          
          Iterator it = message.getFieldIterator();
          while (it.hasNext())
          {
            MessageField mf = (MessageField)it.next();
            String value = null;
            
            if (mf.getFieldName().equals("id"))
              value = id;
            else if (mf.getFieldName().equals("tstamp"))
            {
              // Horrible Loader requires this nasty date format. I'm not
              // impressed.
              String iso = (String)fieldValueMap.get(mf.getFieldName());
              value = Message.timeToGateway(iso);
            }
            else
              value = (String)fieldValueMap.get(mf.getFieldName());

            getController().write(SEP); // always write a separator.
            if (value != null)
              getController().write(value);
          }
      
          endLine();      
        }
      }
    }
  }
}