/*
 *=============================================================================
 *                      COPYRIGHT WatchMark Inc 2004
 *=============================================================================
 * 
 * Created on Feb 23, 2004
 * 
 */
package com.watchmark.loader.processor.xml3GPP;
import com.watchmark.loader.framework.*;

import com.watchmark.loader.translator.Substring;
import com.watchmark.loader.translator.TranslatorFactory;
import com.watchmark.loader.xml.model.MeasurementDataAdapter;
import com.watchmark.loader.xml.model.XMLController;
import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.PrintWriter;
import java.io.Reader;
import java.io.Writer;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import org.w3c.dom.Element;
import org.xml.sax.SAXException;

import org.apache.regexp.*;

public class XML3GPPProcessor implements Processor
{
  private String _name;
  private Map _nameMap;
  
  // Map of MessageName -> MessageTypeMap
  private Map _messageMap;
  private List _patterns = new ArrayList();
  private PrintWriter _writer = null;

  public XML3GPPProcessor(String name)
  {
    _name = name;
  }

  /**
   * Configure the Processor using data it finds under this element.
   * @param e
   */
  public void configure(Element e)
  {
    // This should be the "properties" element from the zipstream.xml
    // file <processor> section. In it, we should find a reference to
    // a message-map URL that we can use to load a message type map.
    _messageMap = new HashMap();
    
    ZipStreamUtil.loadMessageTypeMap("3GPP", e, _messageMap, 
      TranslatorFactory.getTranslators());
  }
    
  public void setWriter(PrintWriter w)
  {
    _writer = w;
  }
  
  public void addPattern(String ptn)
  {
    try
    {
      RE r = new RE(ptn);
      _patterns.add(r);
    }
    catch (RESyntaxException e)
    {
      System.err.println("Invalid pattern for processor " + _name + ": \"" + ptn
        + "\", " + e.getMessage());
    }
  }

  /**
   * The name map is a name/value pairing, built up from parsing the
   * archive name and the current filename in the archive.
   * @param m
   */
  public void setNameMap(Map m)
  {
    _nameMap = m;
  }

  /**
   * 
   * @param filename
   * @param readerName
   * @return true if this Processor should handle the given file. The name of
   * the current reader is also passed in, as some configurations may restrict
   * processing of certain files to certain readers.
   */
  public boolean accept(String filename, String readerName)
  {
    boolean result = false;

    Iterator it = _patterns.iterator();
    while (!result && it.hasNext())
    {
      RE r = (RE)it.next();
      result = r.match(filename);
    }
    
    return result;
  }
  
  /**
   * Read this input stream and process the data in it.
   * @param is
   */
  public void process(InputStream is, String entryName)
    throws IOException
  {
    XMLController c = new XMLController(null);
    MeasurementDataAdapter mda = new MeasurementDataAdapter(c, null);
    MessageTypeMap typeMap = (MessageTypeMap)_messageMap.get("3GPP");
    mda.setMessageTypeMap(typeMap);

    // Seed adapter stack with our top level adapter.
    c.push(mda);

    try
    {
      Reader in = new InputStreamReader(is);

      // Note that we use a NoCloseBufferedReader to stop the naughty SAX
      // parser from closing the stream on us.
      c.parse(new NoCloseBufferedReader(in), _writer);
    }
    catch (SAXException s)
    {
      throw new IllegalArgumentException("Error processing data: " + entryName
       + ": " + s.getMessage());
    }
  }
}