/*
 *=============================================================================
 *                      COPYRIGHT WatchMark Inc 2004
 *=============================================================================
 * 
 * Created on Mar 19, 2004
 * 
 * An Adapter encapsulates an object that is being configured from an XML
 * document. The adapter translates the elements as they are streamed in
 * converting them to setFoo calls on the target object, or create
 * sub-adapters that handle sub-classes.
 */
package com.watchmark.loader.xml.model;

import java.io.IOException;
import java.io.StringReader;

import java.text.ParseException;

import org.apache.log4j.Logger;

import org.xml.sax.Attributes;
import org.xml.sax.InputSource;
import org.xml.sax.SAXException;
import org.xml.sax.XMLReader;
import org.xml.sax.helpers.DefaultHandler;
import org.xml.sax.helpers.XMLReaderFactory;

import java.util.List;

public interface Adapter
{
  /**
   * Adapters know how to make their own child adapters
   * @see #aaa
   * @param paramName comments
   * @exception XxxxxxException if ...
   * @return comments
   */
  public Adapter create(String adapterName, Attributes attributes) 
      throws Exception;

  public String getName();

  /**
   * Absorb the attributes passed in.
   * @param a
   */
  public void setAttributes(Attributes a);

  /**
   * Every Adapter must know about its parent Controller
   * @see #aaa
   * @param paramName comments
   * @exception XxxxxxException if ...
   * @return comments
   */
  public Controller getController();

  /**
   * Each adapter must process its own element data
   * @see #aaa
   * @param paramName comments
   * @exception XxxxxxException if ...
   * @return comments
   */
   public void text(String elementName, String data) throws Exception;

  /**
   * Close is called just as this Adapter gets popped of the stack. It means
   * that its payload should now be fully configured.
   * @see #aaa
   * @param paramName comments
   * @exception XxxxxxException if ...
   * @return comments
   */
   public void close() throws Exception;
}