/*
 *=============================================================================
 *                      COPYRIGHT WatchMark Inc 2004
 *=============================================================================
 * 
 * Created on Feb 23, 2004
 * 
 */
package com.watchmark.loader.zipstream;

import com.watchmark.loader.framework.ArchiveReader;
import com.watchmark.loader.framework.Controller;
import com.watchmark.loader.framework.FileReader;
import com.watchmark.loader.framework.Processor;

import java.io.BufferedInputStream;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.zip.GZIPInputStream;
import org.w3c.dom.Element;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;

public class CpioFileReader extends ArchiveReader
{
  String _compression = "";
  
  public CpioFileReader(String name)
  {
    super(name);
  }

  /**
   * Configure the Processor using data it finds under this element. Usually only
   * things specific to this instance.
   * @param e
   */
  public void configure(Element e)
  {
    super.configure(e);
    
    // Hmm, now are we compressed? If so, we probably need to read through
    // a GZIPInputStream.
    String compressor = ConfigHandler.getValueByName(e, "compressed");
    if (compressor != null)
    {
      if ("Z".equalsIgnoreCase(compressor))
        _compression = "Z";
      else if ("GZ".equalsIgnoreCase(compressor))
        _compression = "GZ";
      else
      {
        if (compressor.length() > 0)
        {
          System.err.println("Unrecognized compression type \"" + compressor +
            "\" for " + getName() + ". Use \"Z\" or \"GZ\".");
        }
      }
    }
  }

  /**
   * Need to find a better abstraction for reading different types of compressed
   * files.
   * @param is
   */
  public void process(String filename, Controller controller)
    throws FileNotFoundException, IOException
  {
    FileInputStream fis = null;
    CpioInputStream cis = null;
    GZIPInputStream gz = null;
    Process p = null;
    
    try
    {
      if (_compression.equals("GZ"))
      {
        fis = new FileInputStream(filename);
        gz = new GZIPInputStream(new BufferedInputStream(fis));
        cis = new CpioInputStream(gz);
      }
      else if (_compression.equals("Z"))
      {
        // Yuk. Don't have a Z decompressor in Java...need to do this as
        // a child process.
        String cmd = "zcat " + filename;
        p = Runtime.getRuntime().exec(cmd);
        cis = new CpioInputStream(new BufferedInputStream(p.getInputStream()));
      }
      else
      {
        fis = new FileInputStream(filename);
        cis = new CpioInputStream(new BufferedInputStream(fis));
      }
      
      CpioEntry entry;
      while((entry = cis.getNextEntry()) != null)
      {
        processEntry(cis, entry.getName());
      }
    }
    finally
    {
      if (gz != null)
        gz.close();
      if (cis != null)
        cis.close();
        
      // Wait for our child process to terminate.
      if (p != null)
      {
        boolean waited = false;
        while (!waited)
        {
          try
          {
            p.waitFor();
            waited = true;
          }
          catch (InterruptedException e)
          {
          }
        }
      }
    }
  }
}
