#!/bin/sh
###########################################################################
#
# Licensed Materials - Property of IBM
# 5724-T05,5724-T06
#
# (C) Copyright IBM Corp. 2003,2008. All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
###########################################################################

DIRNAME=`dirname $0`
PROGNAME=`basename $0`

ROOT_DIR=${FLEXPM_HOME}/pm/pas
MODULE_DIR=$ROOT_DIR/modules
LIB_DIR=$ROOT_DIR/lib
ETC_DIR=${ROOT_DIR}/etc
JBOSS_HOME=${ROOT_DIR}/jboss-4.0.5.GA
JBOSS_CONF=${JBOSS_HOME}/server/default/conf
JBOSS_DEPLOY=${JBOSS_HOME}/server/default/deploy
JBOSS_TMP=${JBOSS_HOME}/server/default/tmp
JBOSS_HSDB=${JBOSS_HOME}/server/default/data/hypersonic
JBOSS_AXIS_INF=${JBOSS_DEPLOY}/axis.war/WEB-INF

### Start with a clean CLASSPATH
CLASSPATH=""

# OS specific support (must be 'true' or 'false').
cygwin=false;
darwin=false;
case "`uname`" in
    CYGWIN*)
        cygwin=true
        ;;

    Darwin*)
        darwin=true
        ;;
esac

# For Cygwin, ensure paths are in UNIX format before anything is touched
if $cygwin ; then
    [ -n "$JBOSS_HOME" ] &&
        JBOSS_HOME=`cygpath --unix "$JBOSS_HOME"`
    [ -n "$JAVA_HOME" ] &&
        JAVA_HOME=`cygpath --unix "$JAVA_HOME"`
    [ -n "$JAVAC_JAR" ] &&
        JAVAC_JAR=`cygpath --unix "$JAVAC_JAR"`
fi

# Setup the JVM
if [ "x$JAVA_HOME" != "x" ]; then
    JAVA="$JAVA_HOME/bin/java"
else
    JAVA="java"
fi

# Set the minimum Java VM size.  We usually want the min = max
if [ "x$JAVA_MIN_VM_SIZE" = "x" ]; then
    JAVA_MIN_VM_SIZE="512m"
fi

# Set the maximum Java VM size
if [ "x$JAVA_MAX_VM_SIZE" = "x" ]; then
    JAVA_MAX_VM_SIZE="512m"
fi

# For Cygwin, switch paths to Windows format before running java
if $cygwin; then
    JBOSS_HOME=`cygpath --path --windows "$JBOSS_HOME"`
    JAVA_HOME=`cygpath --path --windows "$JAVA_HOME"`
    CLASSPATH=`cygpath --path --windows "$CLASSPATH"`
    ROOT_DIR=`cygpath --path --windows "$ROOT_DIR"`
fi

# Display our environment
echo "================================================================================"
echo ""
echo "  Prospect Java"
echo ""
echo "  ROOT_DIR: $ROOT_DIR"
echo ""
echo "  JAVA: $JAVA"
echo ""
echo "  JAVA_OPTS: $JAVA_OPTS"
echo ""
echo "  CLASSPATH: $CLASSPATH"
echo ""
echo "================================================================================"
echo ""

# SEAde36010. Need to update ports so we can run multiple instances of JBoss on one
# machine
${FLEXPM_HOME}/pm/adm/update_jboss_ports.pl

# Deploy wsdd 

# Setup NAME_PORT
if [ "x$PAS_NAME_PORT" != "x" ]; then
   NAME_PORT="$PAS_NAME_PORT"
else
   NAME_PORT="1099"
fi

# build the deploy.wsdd file
`sed "s/_PAS_NAME_PORT_/$NAME_PORT/" ${ETC_DIR}/server-config.wsdd.template > ${ETC_DIR}/server-config.wsdd`

# copy it
echo "Installing server-config.wsdd file"
cp ${ETC_DIR}/server-config.wsdd ${JBOSS_AXIS_INF}/server-config.wsdd

# preserve current jboss-server.log
TODAY=`date +"%Y-%m-%d"`
mv -f ${PM_LOGS}/jboss-server.log ${PM_LOGS}/jboss-server.log.${TODAY}.$$

# clean temp directory and hypersonic database
rm -rf ${JBOSS_TMP}/*
rm -rf ${JBOSS_HSDB}/*

# setup java options
JAVA_OPTS="-server -Dprospectj.home.dir=$ROOT_DIR -Djboss.log.dir=$PM_LOGS"
JAVA_OPTS="${JAVA_OPTS} -Drg.spool.dir=${RG_SPOOLDIR} -Drg.log.dir=${RG_LOGS} -Djava.awt.headless=true"
JAVA_OPTS="${JAVA_OPTS} -DFxDsPort=localhost:$FX_DS_PORT"
JAVA_OPTS="${JAVA_OPTS} -Dweb.http.port=${PAS_JETTY_PORT}"
JAVA_OPTS="${JAVA_OPTS} -Dsun.rmi.dgc.client.gcInterval=3600000 -Dsun.rmi.dgc.server.gcInterval=3600000"
JAVA_OPTS="${JAVA_OPTS} -Xms${JAVA_MIN_VM_SIZE} -Xmx${JAVA_MAX_VM_SIZE} -XX:+AggressiveHeap ${JAVA_OTHER_VM_OPTIONS}"

# Note : JAVA_OEM_OPTIONS gets set in .profile.oem_
JAVA_OPTS="${JAVA_OPTS} ${JAVA_OEM_OPTIONS}"


export JAVA_OPTS

#
# This part copied from /bin/run.sh
# Next time we upgrade jboss, examine the diffs in run.sh to see if anything below needs to change
#
cd $JBOSS_HOME
PROGNAME=`basename $0`

# Use the maximum available, or set MAX_FD != -1 to use that
MAX_FD="maximum"


# For Cygwin, ensure paths are in UNIX format before anything is touched
if $cygwin ; then
    [ -n "$JBOSS_HOME" ] &&
        JBOSS_HOME=`cygpath --unix "$JBOSS_HOME"`
    [ -n "$JAVA_HOME" ] &&
        JAVA_HOME=`cygpath --unix "$JAVA_HOME"`
    [ -n "$JAVAC_JAR" ] &&
        JAVAC_JAR=`cygpath --unix "$JAVAC_JAR"`
fi

# Increase the maximum file descriptors if we can
if [ "$cygwin" = "false" ]; then
    MAX_FD_LIMIT=`ulimit -H -n`
    if [ $? -eq 0 ]; then
	if [ "$MAX_FD" = "maximum" -o "$MAX_FD" = "max" ]; then
	    # use the system max
	    MAX_FD="$MAX_FD_LIMIT"
	fi

	ulimit -n $MAX_FD
	if [ $? -ne 0 ]; then
	    warn "Could not set maximum file descriptor limit: $MAX_FD"
	fi
    else
	warn "Could not query system maximum file descriptor limit: $MAX_FD_LIMIT"
    fi
fi

# Setup the classpath
runjar="$JBOSS_HOME/bin/run.jar"
if [ ! -f $runjar ]; then
    die "Missing required file: $runjar"
fi
JBOSS_BOOT_CLASSPATH="$runjar"

# Include the JDK javac compiler for JSP pages. The default is for a Sun JDK
# compatible distribution which JAVA_HOME points to
if [ "x$JAVAC_JAR" = "x" ]; then
    JAVAC_JAR="$JAVA_HOME/lib/tools.jar"
fi
if [ ! -f "$JAVAC_JAR" ]; then
   # MacOSX does not have a seperate tools.jar
   if [ "$darwin" != "true" ]; then
      warn "Missing file: $JAVAC_JAR"
      warn "Unexpected results may occur.  Make sure JAVA_HOME points to a JDK and not a JRE."
   fi
fi

if [ "x$JBOSS_CLASSPATH" = "x" ]; then
    JBOSS_CLASSPATH="$JBOSS_BOOT_CLASSPATH:$JAVAC_JAR"
else
    JBOSS_CLASSPATH="$JBOSS_CLASSPATH:$JBOSS_BOOT_CLASSPATH:$JAVAC_JAR"
fi

# Setup JBoss sepecific properties
JAVA_OPTS="$JAVA_OPTS -Dprogram.name=$PROGNAME"

# For Cygwin, switch paths to Windows format before running java
if $cygwin; then
    JBOSS_HOME=`cygpath --path --windows "$JBOSS_HOME"`
    JAVA_HOME=`cygpath --path --windows "$JAVA_HOME"`
    JBOSS_CLASSPATH=`cygpath --path --windows "$JBOSS_CLASSPATH"`
fi

now=`date`
java_version=`$JAVA -version 2>&1 | head -1`

# Display our environment
echo "================================================================================="
echo ""
echo "  JBoss Bootstrap Environment, $now"
echo ""
echo "  JBOSS_HOME: $JBOSS_HOME"
echo ""
echo "  JAVA: $JAVA ($java_version)"
echo ""
echo "  JAVA_OPTS: $JAVA_OPTS"
echo ""
echo "  CLASSPATH: $JBOSS_CLASSPATH"
echo ""
echo "================================================================================="
echo ""

#Prospect Core AS depends on some jars and property files
#which reside on Motorola AS.They must be loaded by Core
#Jboss.This is for dual server configuration
#
#
#OEM_RESOURCES is enviromental variable which gets set in
#_profile.oem. Motorola must set it to correct value.




OEM_RESOURCES=${OEM_RESOURCES}
OEM_CLASSPATH=""
if [ "x$OEM_RESOURCES" != "x" ]; then

for i in `ls $OEM_RESOURCES`; do
      RBAC=`echo $i|grep -i "rbac-service.sar"|wc -l`
      MOT_LOC=`echo $i|grep -i "MotorolaLocalizedMessages.properties"|wc -l`
      MOT_SSO=`echo $i|grep -i "moto-prospect-sso.jar"|wc -l`
      JARS=`echo $i|grep -i ".jar"|wc -l`
      if [ $RBAC -eq 1 ]; then
        cp -f $OEM_RESOURCES/$i $JBOSS_DEPLOY
        echo "Will be deployed in next iteration"
      elif [ $MOT_LOC -eq 1 ]; then
        echo Copying $OEM_RESOURCES/$i to $JBOSS_CONF/localization
        cp -f $OEM_RESOURCES/$i $JBOSS_CONF/localization
      elif [ $MOT_SSO -eq 1 ]; then
        echo Copying $OEM_RESOURCES/$i to $JBOSS_DEPLOY/jbossweb-tomcat55.sar
        cp -f $OEM_RESOURCES/$i $JBOSS_DEPLOY/jbossweb-tomcat55.sar
      elif [ $JARS -eq 1 ]; then
        echo Copying $OEM_RESOURCES/$i to $JBOSS_HOME/server/default/lib
       cp -f $OEM_RESOURCES/$i $JBOSS_HOME/server/default/lib
      else
		echo Copying $OEM_RESOURCES/$i to $JBOSS_CONF
        cp -f $OEM_RESOURCES/$i $JBOSS_CONF
      fi
done
fi




    STATUS=10
    while [ $STATUS -eq 10 ]
    do
    # Execute the JVM
       exec "$JAVA" $JAVA_OPTS \
               -classpath "$JBOSS_CLASSPATH" \
               org.jboss.Main "$@"        
       STATUS=$?
       # if it doesn't work, you may want to take a look at this:
       #    http://developer.java.sun.com/developer/bugParade/bugs/4465334.html
    done
