<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
				xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
				version="2.0">
	
	<xsl:output method="xml" 
				indent="yes"
				omit-xml-declaration="no" />


	<!--
		######################################### 
		               CONSTANTS
		#########################################
	-->
	<xsl:variable name="newline">
		<xsl:text>
		</xsl:text>
	</xsl:variable>
	
	<xsl:template match="@*|node()">
		<xsl:copy>
			<xsl:apply-templates select="@*|node()" />
		</xsl:copy>
	</xsl:template>

	<xsl:template match="/import-export-data-set">
		<xsl:copy>
			<xsl:attribute name="xml-version">
				<xsl:value-of select="'2.2.7'" />
			</xsl:attribute>
			<xsl:apply-templates />
		</xsl:copy>
	</xsl:template>

	<!--
		######################################### 
		                 UDCs
		#########################################
	-->

	<!-- Ignore the following Moto-specific UDC elements -->
	<xsl:template match="report-definition/udc/forecasting">
		<xsl:comment>XSL: Removed [forecasting] element from here ...</xsl:comment>
	</xsl:template>
	
	<xsl:template match="report-definition/udc/available">
		<xsl:comment>XSL: Removed [available] element from here ...</xsl:comment>
	</xsl:template>


	<!--
		######################################## 
		                REPORTS
		#######################################
	-->
	<xsl:template match="report-definition/report">
		<xsl:copy>
			<xsl:attribute name="xsi:type">
				<xsl:value-of select="'java:com.watchmark.prospect.enterprise.api.reportDefClient.WmReportDefValue'" />
			</xsl:attribute>
			
			<xsl:value-of select="$newline" />
			<xsl:comment>XSL: [scenario-id], [filtering-active-instances] and [rehoming-instances] are set to default values if not available ...</xsl:comment>			
			<xsl:value-of select="$newline" />
			
			<xsl:if test="not(scenario-id)">
				<xsl:element name="scenario-id">
					<xsl:value-of select="'0'" />
				</xsl:element>
			</xsl:if>
			
			<xsl:value-of select="$newline" />
			<xsl:if test="not(filtering-active-instances)">
				<xsl:element name="filtering-active-instances">
					<xsl:value-of select="'false'" />
				</xsl:element>
			</xsl:if>

			<!--
				These match boolean values _isRehomingInstances, _isForecasting in
				CORE WmReportDefValue.java
			-->
			<xsl:value-of select="$newline" />
			<xsl:if test="not(rehoming-instances)">
				<xsl:choose>
					<xsl:when test="rehoming">
						<xsl:element name="rehoming-instances">
							<xsl:value-of select="rehoming/use-rehoming" />
						</xsl:element>
					</xsl:when>
					<xsl:otherwise>
						<xsl:element name="rehoming-instances">
							<xsl:value-of select="'false'" />
						</xsl:element>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:if>


			<!--
				Are rehoming and forecasting treated the same?? No rehoming example
				in CORE_report_results, no forecasting example in
				CORE_exported_report to compare Forecasting in CORE_results
				<def-forecasting> <use-forecasting>false</use-forecasting>
				</def-forecasting> Rehoming in CORE_exported_report
				<rehoming-instances>false</rehoming-instances>
			-->
			<xsl:value-of select="$newline" />			
			<xsl:choose>
				<xsl:when test="forecasting">
					<xsl:element name="forecasting">
						<xsl:value-of select="forecasting/use-forecasting" />
					</xsl:element>
				</xsl:when>
				<xsl:otherwise>
					<xsl:element name="forecasting">
						<xsl:value-of select="'false'" />
					</xsl:element>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:apply-templates />
		</xsl:copy>
	</xsl:template>

	<xsl:template match="report-definition/report/date-time-scope">
		<xsl:copy>
			<xsl:if test="not(dt-scope-id)">
				<xsl:value-of select="$newline" />
				<xsl:comment>XSL: [dt-scope-id] not available; Setting to 0 by default ...</xsl:comment>
				<xsl:value-of select="$newline" />
				<xsl:element name="dt-scope-id">
					<xsl:value-of select="'0'" />
				</xsl:element>
			</xsl:if>
			<xsl:apply-templates />
		</xsl:copy>
	</xsl:template>

	<xsl:template match="report-definition/report/report-spec">
		<xsl:copy>
			<xsl:if test="not(histogram-report-type)">
				<xsl:value-of select="$newline" />
				<xsl:comment>XSL: [histogram-report-type] not available in R23; Setting to 'FALSE' by default ...</xsl:comment>
				<xsl:value-of select="$newline" />
				<xsl:element name="histogram-report-type">
					<xsl:value-of select="'false'" />
				</xsl:element>
			</xsl:if>
			<xsl:apply-templates />
		</xsl:copy>
	</xsl:template>
	
	<!--
		Ignore the following Motorola-specific report elements; 
		(their values are used elsewhere but elements themselves are discarded)
	-->
	<xsl:template match="report-definition/report/rehoming" >
		<xsl:value-of select="$newline" />
		<xsl:comment>XSL: Removed [rehoming] element from here ...</xsl:comment>
	</xsl:template>
	
	<xsl:template match="report-definition/report/forecasting">
		<xsl:value-of select="$newline" />
		<xsl:comment>XSL: Removed [forecasting] element from here ...</xsl:comment>
	</xsl:template>

	<!-- 
		Remove duplicate expression row elements. 
		These values have no meaning (the corresponding [value] element is used instead) so they need to be removed.
		The check for 'filter-exp' is done because the filter type can be attribute ('filter-exp') or traffic ('traffic-filter-exp')
	-->
	<xsl:template match="report-definition/report/*[contains(name(), 'filter-exp')]/expression-rows/string">
		<xsl:comment>XSL: Removed [string] element from here (see [value] element for proper value)...</xsl:comment>
	</xsl:template>
	
	<xsl:template match="report-definition/report/*[contains(name(), 'filter-exp')]/expression-rows/_int">
		<xsl:comment>XSL: Removed [_int] element from here (see [value] element for proper value) ...</xsl:comment>
	</xsl:template>
	
	<xsl:template match="report-definition/report/*[contains(name(), 'filter-exp')]/expression-rows/_float">
		<xsl:comment>XSL: Removed [_float] element from here (see [value] element for proper value) ...</xsl:comment>
	</xsl:template>


	<!--
		######################################## 
		              SCHEDULES
		########################################
	-->
	<xsl:template match="Schedules">
		<xsl:element name="{name()}">
			<xsl:attribute name="xsi:type">
				<xsl:value-of select="'marshallable-schedule'" />
			</xsl:attribute>
			<xsl:apply-templates />
		</xsl:element>
	</xsl:template>

	<xsl:template match="Schedules/schedule">
		<xsl:element name="{name()}">
			<xsl:attribute name="xsi:type">
				<xsl:value-of select="'java:com.watchmark.prospect.enterprise.api.reportDefClient.WmScheduleValue'" />
			</xsl:attribute>

			<xsl:if test="not(export-conf)">
				<xsl:value-of select="$newline" />
				<xsl:comment>XSL: [export-conf] created, default values set ...</xsl:comment>
				<xsl:value-of select="$newline" />
				<xsl:element name="export-conf">
					<xsl:value-of select="$newline" />
					<xsl:element name="auto-download-enabled">
						<xsl:value-of select="'false'" />
					</xsl:element>
					<xsl:value-of select="$newline" />
					<xsl:element name="email-notif-enabled">
						<xsl:value-of select="'false'" />
					</xsl:element>
				</xsl:element>
			</xsl:if>

			<xsl:if test="report-def-pk">
				<xsl:value-of select="$newline" />
				<xsl:comment>XSL: Replacing [report-def-pk] with [scheduled-document-key] element ...</xsl:comment>
				<xsl:value-of select="$newline" />
				<xsl:element name="scheduled-document-key">
					<xsl:attribute name="xsi:type">
						<xsl:value-of select="'java:com.watchmark.prospect.enterprise.api.reportDefClient.WmReportDefPk'" />
					</xsl:attribute>
					<xsl:value-of select="$newline" />
					<xsl:element name="id">
						<xsl:value-of select="report-def-pk/id" />
					</xsl:element>
					<document-type>
						<xsl:value-of select="report-def-pk/document-type" />
					</document-type>
				</xsl:element>
			</xsl:if>

			<xsl:apply-templates />
		</xsl:element>
	</xsl:template>

	<xsl:template match="schedule/options">
		<xsl:copy>
			<xsl:value-of select="$newline" />
			<xsl:element name="active">
				<xsl:value-of select="is-active" />
			</xsl:element>
			<xsl:apply-templates />
		</xsl:copy>
	</xsl:template>

	<!-- Ignore the following Motorola-specific schedule elements -->
	<xsl:template match="schedule/report-def-pk">
		<xsl:comment>XSL: Removed [report-def-pk] element from here ...</xsl:comment>
	</xsl:template>
	
	<xsl:template match="schedule/options/report-folder-path">
		<xsl:comment>XSL: Removed [report-folder-path] element from here ...</xsl:comment>
	</xsl:template>
	
	<xsl:template match="schedule/options/report-name">
		<xsl:comment>XSL: Removed [report-name] element from here ...</xsl:comment>
	</xsl:template>
	
	<xsl:template match="schedule/options/is-active">
		<xsl:comment>XSL: Removed [is-active] element from here ...</xsl:comment>
	</xsl:template>



	<!--
		######################################### 
		              FOLDERS
		#########################################
	-->
	<xsl:template match="//Folders">
		<xsl:element name="{name()}">
			<xsl:attribute name="xsi:type">
				<xsl:value-of select="'marshallable-folder'" />
			</xsl:attribute>
			<xsl:comment>XSL: Added [@xsi:type] manually ...</xsl:comment>
			<xsl:apply-templates />
		</xsl:element>
	</xsl:template>
	
	<xsl:template match="Folders/folder">
		<xsl:element name="{name()}">
			<xsl:if test="not(@xsi:type)">
     			<xsl:attribute name="xsi:type">
					<xsl:value-of select="'java:com.watchmark.prospect.enterprise.api.folderClient.Folder'" />
				</xsl:attribute>
				<xsl:comment>XSL: Added [@xsi:type] manually ...</xsl:comment>
      		</xsl:if>			
			<xsl:apply-templates />
		</xsl:element>
	</xsl:template>
	
	<xsl:template match="Folders/folder/folder-pk">
		<xsl:element name="{name()}">
			<xsl:if test="not(@xsi:type)">
     			<xsl:attribute name="xsi:type">
					<xsl:value-of select="'com.watchmark.prospect.enterprise.folder.impl.wrapper.WmFolderKey'" />
				</xsl:attribute>
				<xsl:comment>XSL: Added [@xsi:type] manually ...</xsl:comment>
      		</xsl:if>	
			<xsl:apply-templates />
		</xsl:element>
	</xsl:template>
	
</xsl:stylesheet> 