#! /bin/ksh
###########################################################################
#
# Licensed Materials - Property of IBM
# 5724-T05,5724-T06
#
# (C) Copyright IBM Corp. 2000, 2008. All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
###########################################################################
# (#) ./base/pm/run/add_datafiles.sh BL_core_schema_8.0.7_8.0.7.4.02_20100413  064938
# (#) 
#


SCRIPTNAME=`basename $0`
DB_CONNECT=`crypt_util.ksh -g DB_CONNECT`;

usage() {
    echo "$SCRIPTNAME [-t tablespace -s max size [-i initial size] [-n next size] [-l location of datafile]] [-u]"
    echo " -t : Tablespace name"
    echo " -s : Maximum size of datafile in Megabytes"
    echo " -i : Initial size of datafile in Megabytes"
    echo " -n : Next size of datafile in Megabytes"
    echo " -l : file name path; default location is /u04/flexpm"
    echo " -u : Print the tablespace usage "
    exit 1
}

PRINT_USAGE=N
TABLESPACE_NAME=N
LOCATION=N
SIZE=0
INITIALSIZE=0
NEXTSIZE=0

if [ $# -eq 0 ] 
then
    usage
fi

while [ $# -gt 0 ]
do

    case $1 in
	-t) 
	    shift
	    TABLESPACE_NAME="$1"
            if [ "${TABLESPACE_NAME}" == "N" ] 
            then
                echo " Enter a tablespace name with -t argument "
                usage
            fi
            ;;

        -s)
            shift
            SIZE=$1
            if [ "${SIZE}" -eq 0 ] 
            then
                echo " Enter maximum data file size with -s argument "
                usage
            fi
            ;;
        -i)
            shift
            INITIALSIZE=$1
            if [ "${INITIALSIZE}" -eq 0 ] 
            then
                echo " Enter initial data file size with -i argument "
                usage
            fi
            ;;
        -n)
            shift
            NEXTSIZE=$1
            if [ "${NEXTSIZE}" -eq 0 ] 
            then
                echo " Enter next data file size with -n argument "
                usage
            fi
            ;;
        -l)
            shift
            LOCATION="$1"
            if [ "${LOCATION}" == "N" ] 
            then
                echo " Enter a location with -l argument "
                usage
            fi
            ;;
            
	-u)
	    PRINT_USAGE=Y
            ;;
        -v)
           usage
           ;;

	*)
	    echo "Error : *****Invalid parameter ****** "
            echo " Usage as follows :"
	    usage
	    ;;
    esac

    shift
done


  if [ "$TABLESPACE_NAME" == "N" -a $SIZE -gt 0 ] 
  then
      echo "Error : *** Specify a tablespace name with size *** "
      usage
  fi

  if [ "$TABLESPACE_NAME" != "N" -a $SIZE -eq 0 ] 
  then
      echo "Error : *** Specify size with the tablespace name *** "
      echo " Usage as follows :"
      usage
  fi
  if [ "$TABLESPACE_NAME" == "N" -a $SIZE -eq 0 -a "$LOCATION" != "N" ] 
  then
      echo "Error : *** Location cannot be specified without tablespace and size ***"
      echo " Usage as follows :"
      usage
  fi

  if  [ "$PRINT_USAGE" != "Y" -a  $INITIALSIZE -gt $SIZE ] 
  then
      echo "Error : *** Initial size must be less than or equal to the size of the file ***"
      echo " Usage as follows :"
      usage
  fi

  if  [ "$PRINT_USAGE" != "Y" -a  $NEXTSIZE -gt $SIZE ] 
  then
      echo "Error : *** Next size must be less than or equal to the size of the file ***"
      echo " Usage as follows :"
      usage
  fi


sqlplus -s /NOLOG << !
connect ${DB_CONNECT}
set feed off
set serveroutput on
set linesize 200
variable status_sh NUMBER
DECLARE
    status_sql NUMBER;
BEGIN
validate_add_and_rpt_params('$TABLESPACE_NAME',$SIZE,'$LOCATION',$INITIALSIZE,$NEXTSIZE,status_sql);
:status_sh := status_sql;
END;
/
EXIT :status_sh
!
status=$?
PREV_PWD=$PWD
cd $FLEXPM_HOME/pm/run

monitor="${FLEXPM_HOME}/sw/oracle/monitor-sizes.sql"

if [ "$status" -eq 1 -o "$PRINT_USAGE" == "Y" ] 
then
    echo "*** Printing Tablespace Usage ***"
    sqlplus -s /NOLOG << !
    set feed off
    set serveroutput on 
    connect ${DB_CONNECT}
    @ ${monitor}
!
fi
cd $PREV_PWD


