set serveroutput on size 1000000

PROMPT Add updated aggregation columns to DXS and DXC
---------------------------------------------------------------------------
--
-- Licensed Materials - Property of IBM
-- 5724-T05,5724-T06
--
-- (C) Copyright IBM Corp. 2009. All Rights Reserved.
--
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
--
---------------------------------------------------------------------------
-- (#) ./base/post-vendor/summarize/add_changed_agg_columns.sql BL_core_schema_8.0.7_8.0.7.4.02_20100413  064938
-- (#) 
--
-- This script adds columns to DXS and DXC tables where the aggregation type 
-- has been updated to an AVG aggregation type (A, F, R, G, T). This will
-- create DXS and DXC tables when needed.
--
--
DECLARE

   -- Find the AVG columns that are NOT in the DXS/DXC tables
   CURSOR clist IS
      SELECT wt.table_name table_name, wcd.col_name column_name
      FROM wmd_col_def wcd, wmd_dict_table wt, wmd_dict_field wf
         WHERE wt.table_name like '%\_TAB' escape '\'
            AND wcd.table_id = wt.table_id
            AND wf.field_id = wcd.field_id
            AND wf.field_aggregator in ('A','F','R','G','T')
      MINUS
      SELECT DISTINCT SUBSTR(table_name, 1, LENGTH(table_name)-4) || '_TAB' table_name, column_name
      FROM user_tab_columns
         WHERE ( table_name like '%\_DXS' escape '\'
            OR table_name like '%\_DXC' escape '\' )
            AND column_name NOT IN ('SUMMARY_ID', 'INSTANCE_ID', 'TSTAMP')
      ORDER BY table_name, column_name;

   vUpdated INTEGER := 0;
BEGIN

   -- Get the list of missing tables and columns
   FOR rec IN clist LOOP

      DBMS_OUTPUT.PUT_LINE( rec.table_name  || '  ' || rec.column_name);

      BEGIN
         create_schema_objects.update_shadow_tables( rec.table_name, rec.column_name );
         vUpdated := 1;
      EXCEPTION
         WHEN OTHERS THEN
            -- Dump the error but keep processing
            DBMS_OUTPUT.PUT_LINE('ERROR: ' || SUBSTR( SQLERRM, 1, 256 ) );
      END;

   END LOOP;

   IF vUpdated = 1 THEN
      DBMS_OUTPUT.PUT_LINE('Updating views');
      wmd_traffic_redefinition.rebuild_traffic_views;
   END IF;

END;
/
