set serveroutput on size 1000000

PROMPT DROP UNUSED columns in DXS and DXC tables
---------------------------------------------------------------------------
--
-- Licensed Materials - Property of IBM
-- 5724-T05,5724-T06
--
-- (C) Copyright IBM Corp. 2009. All Rights Reserved.
--
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
--
---------------------------------------------------------------------------
-- (#) ./base/post-vendor/summarize/mark_unused_agg_columns.sql BL_core_schema_8.0.7_8.0.7.4.02_20100413  064938
-- (#) 
--

--
-- This script DROPs columns in DXS and DXC tables
-- when the aggregation type has changed to something other
-- than 'avg'. The column must have been 'avg' before.
--
-- Marking the columns as UNUSED prevents us from moving the partition during PartMaint.
--
--
DECLARE

   -- Columns from DXS and DXC that are NOT avg columns in the dictionary
   CURSOR clist IS
      SELECT DISTINCT SUBSTR(table_name, 1, LENGTH(table_name)-4) || '_TAB' table_name, 
             column_name
      FROM user_tab_columns
      WHERE ( table_name like '%\_DXS' escape '\'
         OR table_name like '%\_DXC' escape '\' )
         AND column_name NOT IN ('SUMMARY_ID', 'INSTANCE_ID', 'TSTAMP')
         AND (SUBSTR(table_name, 1, LENGTH(table_name)-4) || '_TAB', column_name) NOT IN 
         ( SELECT wt.table_name tab_name, wcd.col_name column_name
           FROM wmd_col_def wcd, wmd_dict_table wt, wmd_dict_field wf
           WHERE wcd.table_id = wt.table_id
              AND wf.field_id = wcd.field_id
              AND wf.field_aggregator in ('A','F','R','G','T')
         )
      ORDER BY table_name, column_name;

   vUpdated INTEGER := 0;

   invalid_identifier EXCEPTION;
   PRAGMA EXCEPTION_INIT ( invalid_identifier, -904 );
BEGIN

   -- Get the list of missing tables and columns
   FOR rec IN clist LOOP
      DBMS_OUTPUT.PUT_LINE( rec.table_name  || '  ' || rec.column_name);

      -- DXS
      BEGIN
         EXECUTE IMMEDIATE 'ALTER TABLE ' 
                           || summarize.genDestName(rec.table_name, 'XS')
                           || ' DROP COLUMN ' 
                           || rec.column_name;
      EXCEPTION
         WHEN invalid_identifier THEN
            NULL;
      END;

      -- DXC
      BEGIN

         EXECUTE IMMEDIATE 'ALTER TABLE ' 
                           || summarize.genDestName(rec.table_name, 'XC')
                           || ' DROP COLUMN ' 
                           || rec.column_name;
      EXCEPTION
         WHEN invalid_identifier THEN
            NULL;
      END;
      
      vUpdated := 1;

   END LOOP;

   IF vUpdated = 1 THEN
      DBMS_OUTPUT.PUT_LINE('Updating views');
      wmd_traffic_redefinition.rebuild_traffic_views;
   END IF;

END;
/
