#!/usr/bin/env perl

use Env;
use File::Basename;

@valid_dirs ;
@valid_releases ;
@valid_db_connect ;
@valid_ports ;
@valid_status ;
@valid_descriptions;

sub get_date_time {

    ( $sec, $min, $hour, $mday, $mon, $year, $wday, $yday, $isdst ) =
	  localtime(time);

    $global_hour  = $hour;
    $global_min   = $min;
    $global_month = $mon;
    $global_day   = $mday;
    $global_year  = $year;

    if ( length($global_hour)  < 2 ) { $global_hour  = "0" . $global_hour; }
    if ( length($global_min)   < 2 ) { $global_min   = "0" . $global_min; }
    if ( length($global_month) < 2 ) { $global_month = "0" . $global_month; }
    if ( length($global_day)   < 2 ) { $global_day   = "0" . $global_day; }

    ++$global_month;
    $global_year += 1900;

    $return_date_time = join("-",$global_year, $global_month, $global_day);
    $return_date_time = $return_date_time . "@" . $global_hour . ":" . $global_min;

    return($return_date_time);

}


sub print_menu {

   print "\n";
   print "+----------------------------------------------------------------------------+\n";
   print "| Number | Directory |            DESCRIPTION          | PORT_GROUP | Status |\n";
   print "|----------------------------------------------------------------------------|\n";

   for ($i = 0;$i <= $#valid_dirs ; $i++ ) {
       $dir = $valid_dirs[$i];
       printf "%-2s %-5s %s %-09s %s %-31s %s %-10s %s %-6s %s \n", "|", $i + 1, "|", $dir, "|", $valid_descriptions[$i], "|", $valid_ports[$i], "|", $valid_status[$i],"|" ;
   }

   print "+----------------------------------------------------------------------------+\n";
   print "\n";
}

sub get_status {

    for ( $i=0;$i <= $#valid_dirs;$i++) {
	$valid_status[$i] = "Down";
    }

    $cmd = 'ps -ef | grep "wmpm -service" | grep -v grep ';

    open STATUS, "$cmd |" or die "Unable to open status pipe : $!";

    while (<STATUS>) {
	chomp;
	$literal = $_;
	for ( $i=0;$i <= $#valid_dirs;$i++) {
	    if ($literal =~  $valid_dirs[$i] ) {
	       $valid_status[$i] = "Up";
	    }
        }
    }
}



sub fill_in_other_parts {

    local ($dir_to_check) = @_;

    $dir_to_check = "/u01/apps/WatchMark/FlexPM/" . $dir_to_check;

    local ( $description ) = "";

    $cmd = "/u01/apps/WatchMark/FlexPM/bin/readenv.ksh $dir_to_check";

    open FILL_IN, "$cmd |" or die
         "Unable to process readenv.ksh : $!";

    while ( <FILL_IN> ) {
          chomp;
          @parts = split(/\=/,$_);
          if ( $parts[0] = /DB_CONNECT/ ) {
             push @valid_db_connect, $parts[1];
	   }
          if ( $parts[0] = /PORT_GROUP/ ) {
              push @valid_ports, $parts[1];
	    }
          if ( $parts[0] = /release/ ) {
              push @valid_releases, $parts[1];
	    }
	}
    close FILL_IN or die "Unable to close ./readenv.ksh pipe : $!";

         if ( -e "$dir_to_check/.description") {
              $description=`cat $dir_to_check/.description`;
	    }
          else
	    {
              $description="";
	    }
          chomp($description);
          push @valid_descriptions, $description;
  }

sub check_valid {
    my ($dir_to_check) = @_;
    my ($test_dir) = $dir_to_check . "/sw";
    my ($profile_connect_file) = $dir_to_check . "/.profile.connect";
    next if ! -d $test_dir;
    next if ! -f $profile_connect_file;
    push @valid_dirs, $dir_to_check;
    &fill_in_other_parts($dir_to_check);

}

sub listdir {

   chdir("/u01/apps/WatchMark/FlexPM") or die 
	"Unable to chdir to /u01/apps/WatchMark/FlexPM : $!";

   $menu_file = ".menu_schema.txt";

   open MENUFILE, ">$menu_file" or die "Unable to open ($menu_file) : $!";

   open DIR_LIST, "ls -1 |"
	or die "ls command died with : $!";

   while (<DIR_LIST>) {
      chomp;
      next if -l $_;
      next if ! -d $_;
      &check_valid($_);
   }

   close DIR_LIST or die "Unable to close ls pipe : $!";
  
   &get_status;
   &print_menu;

   do 
     { 
       print "Select schema number : ";
       $i_MenuCnt = <STDIN>;
       }
   until $i_MenuCnt > 0 && $i_MenuCnt  <= ( $#valid_dirs + 1);

   print MENUFILE "$valid_dirs[$i_MenuCnt -1]";

   close MENUFILE;
}


############################################################
# Pseudo Main                                              #
############################################################

&listdir;
