#! /bin/ksh
# @(#) ./base/sw/peik_tools/pop_inst.sh ; BL_core_schema_8.0.7_8.0.7.4.02_20100413  064938
############################################################################
# The following script populates the traffic table(s) with simulation data
############################################################################
#Updated 10/02/2009 - valnt00077479
DBPASSWD=`crypt_util.ksh -g ${DBUSER}`

SCRIPTNAME=`basename $0`
usage() {
    echo "$SCRIPTNAME -f fullkey [(-e entity_name n)*]"
    echo " -f: instance fullkey for system entity"
    echo " -e: entity name and n is number of instance for"
    echo "     this entity to the same parent instance. The "
    echo "     default is 1 "
    echo " example:"
    echo "  $ pop_inst.sh -f 88 -e ECP 1 -e Cell 3 -e Antenna 7"
    exit 1
}

if  [  $# -lt 2 ]
then
  usage 
  exit 1
fi

CONTEXT=ALL
i=0

while [ $# -gt 0 ]
do
case $1 in
   -e)
        shift;
        ENTITY_NAME[${i}]="'$1'"
        shift
        RATIO[${i}]=$1
        i=$(($i+1));
        ;;
   -f)
        shift;
        FULLKEY="'$1'"
        ;;
   -c)
        shift;
        CONTEXT="'$1'"
        ;;
   *)
        usage
        ;;
esac
shift
done

date
################################################
# create temp table
################################################
sqlplus -s /NOLOG << !
whenever sqlerror exit sql.sqlcode
set feed off
set serveroutput on size 1000000
connect $DBUSER/$DBPASSWD@$DBSID
declare
 vSQL varchar2(400);
 table_not_exists exception;
 object_exists exception;
 seq_not_exists exception;
 PRAGMA EXCEPTION_INIT(table_not_exists, -942);
 PRAGMA EXCEPTION_INIT(object_exists, -955);
 PRAGMA EXCEPTION_INIT(seq_not_exists, -2289);
begin
 begin -- drop table pop_ent_ratio_tmp
   vSQL := 'drop table pop_ent_ratio_tmp';
   execute immediate vSQL;
 exception
   when table_not_exists then
    null;
   when others then
    dbms_output.put_line(SQLERRM);
 end; -- drop table pop_ent_ratio_tmp

 begin -- create table pop_ent_ratio_tmp
   vSQL := 'create table pop_ent_ratio_tmp '||
           '(entity_id integer,'||
           ' ratio integer)';
   execute immediate vSQL;
 exception
   when object_exists then
    null;
   when others then
    dbms_output.put_line(SQLERRM);
 end; -- create table pop_ent_ratio_tmp

end;
/
EXIT 0
!

ret=$?
if [ !$ret -eq 0 ]
then
 exit $ret
fi

################################################
# create package
################################################
# create package
sqlplus -s /NOLOG << !
whenever sqlerror exit sql.sqlcode
set feed off
set serveroutput on size 1000000
connect $DBUSER/$DBPASSWD@$DBSID
@popIns_pkg.sql
!

ret=$?
if [ !$ret -eq 0 ]
then
 exit $ret
fi

################################################
# create package body
################################################
# create package body
sqlplus -s /NOLOG << !
whenever sqlerror exit sql.sqlcode
set feed off
set serveroutput on size 1000000
connect $DBUSER/$DBPASSWD@$DBSID
@popIns_pkgb.sql
!

ret=$?
if [ !$ret -eq 0 ]
then
 exit $ret
fi

################################################
# populating temp table
################################################
count=${i}
i=0
while [ ${i} -lt ${count} ]
do
sqlplus -s /NOLOG << !
whenever sqlerror exit sql.sqlcode
set feed off
set serveroutput on size 1000000
connect $DBUSER/$DBPASSWD@$DBSID
begin
POPULATE_INST.set_Ratio(${ENTITY_NAME[${i}]}, ${RATIO[${i}]});
end;
/
EXIT 0
!
i=$(($i+1))
done

ret=$?
if [ !$ret -eq 0 ]
then
 exit $ret
fi

  ################################################
  # populating generic and scenario instances
  ################################################
  sqlplus -s /NOLOG << !
  whenever sqlerror exit sql.sqlcode
  set feed off
  set serveroutput on size 1000000
  connect $DBUSER/$DBPASSWD@$DBSID
  begin
  POPULATE_INST.pop_gen_inst($FULLKEY);
  POPULATE_INST.pop_Scenario_inst($FULLKEY);
  end;
/
EXIT 0
!

ret=$?
if [ !$ret -eq 0 ]
then
 exit $ret
fi

################################################
# clean up package and temp table
################################################
sqlplus -s /NOLOG << !
whenever sqlerror exit sql.sqlcode
set feed off
set serveroutput on size 1000000
connect $DBUSER/$DBPASSWD@$DBSID
declare
 vSQL varchar2(400);
 table_not_exists exception;
 object_exists exception;
 seq_not_exists exception;
 PRAGMA EXCEPTION_INIT(table_not_exists, -942);
 PRAGMA EXCEPTION_INIT(seq_not_exists, -2289);
begin

 begin -- drop table pop_ent_ratio_tmp
   vSQL := 'drop table pop_ent_ratio_tmp';
   execute immediate vSQL;
 exception
   when table_not_exists then
    null;
   when others then
    dbms_output.put_line(SQLERRM);
 end; -- drop table pop_ent_ratio_tmp

 begin -- drop package populate_inst
   vSQL := 'drop package populate_inst';
   execute immediate vSQL;
 exception
   when others then
    dbms_output.put_line(SQLERRM);
 end; -- drop package populate_inst
end;
/
EXIT 0
!
date
ret=$?
if [ !$ret -eq 0 ]
then
 exit $ret
fi

