###########################################################################
#
# Licensed Materials - Property of IBM
# 5724-T05,5724-T06
#
# (C) Copyright IBM Corp. 2008,2009. All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
###########################################################################
# (#) ./base/sw/perl/lib/Properties.pm BL_core_schema_8.0.7_8.0.7.4.02_20100413  064938
# (#) 
#

###################################################################
# Module : Properties.pm                                          #
#                                                                 #
# This module allows for getting and setting properties           #
# in props file                                                   #
#                                                                 #
###################################################################
package Properties;

use Env;
use Fcntl;
use File::Copy;
use SDBM_File;
use strict;


###################################################################
# update_property : Takes the filename, property name             #
# and new value as parameters                                     #
###################################################################


sub set_property {


  my ($filename, $property_name, $new_value) =@_;
 
  my $property_found = 0;
 
  # use a tmp file for processing
  my $tmp_filename = $filename.".tmp";
  
 
  open ORIG, "<$filename" or die
       "Unable to open $filename : $!";
       
  open TMP, ">$tmp_filename" or die
       "Unable to open $tmp_filename : $!";




  # run through the props file looking for the property @ the start of a line
  
  while (<ORIG>)
    {
      my $line = $_;
      chomp($line);
      
      if ($line =~ /^$property_name\=/)
      {
        $property_found = 1;
        $line = $property_name. "=" .  $new_value;
      }
      print TMP "$line\n";
    }

  close ORIG     or die "Couldn't close $filename : $!";
  close TMP or die "Couldn't close $tmp_filename : $!";
  
  # check to see if prop was found 
  if($property_found == 1)
  {
    copy ($tmp_filename, $filename);
  }
  else
  {
    print "Property: $property_name not found in file: $filename \n";
  }
  # remove the temp file
  unlink($tmp_filename);
  
  return $property_found;
  
}


###################################################################
# get_property : Takes the filename, property name as params      #             
# returns the property value if found or undef if not             #
###################################################################


sub get_property {


  my ($filename, $property_name) =@_;
 
  my $property_found = 0;
  my $property_value;
 
  open ORIG, "<$filename" or die
       "Unable to open $filename : $!";
       
  # run through the props file looking for the property @ the start of a line
  
  while (<ORIG>)
    {
      my $line = $_;
      chomp($line);
      if ($line =~ /^$property_name\=(.*)$/)
      {
        $property_found = 1;
        $property_value = $1;
        
      }
    }

  close ORIG     or die "Couldn't close $filename : $!";
  
  # check to see if prop was found 
  unless($property_found == 1)
  {
    print "Property: $property_name not found in file: $filename \n";
  }
  
  return $property_value;
  
}


1; 