###########################################################################
#
# Licensed Materials - Property of IBM
# 5724-T05,5724-T06
#
# (C) Copyright IBM Corp. 2009. All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
###########################################################################
# (#) ./base/sw/perl/lib/Utils/SysVal.pm BL_core_schema_8.0.7_8.0.7.4.02_20100413  064938
# (#) 
#
###################################################################
# Module   : Utils/SysVal.pm                                      # 
# Function : This module allows for access and reading of         #
#            system variables using the wm_sysval package api     #
#                                                                 #
###################################################################
package Utils::SysVal;

use strict;
use DBI;
use pass_crypt;
use Env;


sub new 
{
   my $class = shift;
   my ($name) = @_;


   my $db_connect = pass_crypt::getConnectForUser($ENV{DBUSER});

   my $self = {
                 'DB_CONNECT'   =>    $db_connect, 
                 'NAME'         =>    $name
              };

   bless $self, $class;
   return $self;
}

sub dbConnect 
{
    my $self = shift;
    if (@_) { $self->{'DB_CONNECT'} = shift }
    return $self->{'DB_CONNECT'};
}

sub name 
{
    my $self = shift;
    if (@_) { $self->{'NAME'} = shift }
    return $self->{'NAME'};
}


sub connectToDB 
{
  my $self = shift;
  my $dbh = DBI->connect( 'dbi:Oracle:', $self->dbConnect ) or die( $DBI::errstr . "\n" );
  
  $dbh->{AutoCommit}    = 0;
  $dbh->{RaiseError}    = 1;
  $dbh->{ora_check_sql} = 0;
  $dbh->{RowCacheSize}  = 16;
  
  return ($dbh);
}


sub getVal
{
  my $self = shift;
  
  return $self->{'VALUE'} if defined($self->{'VALUE'});

  my $ret_val = undef;
  
  my $dbh = $self->connectToDB();
  
  my $sth = $dbh->prepare(" SELECT sv.value FROM wm_system_values_v sv WHERE sv.NAME = :NAME");
  
  $sth->bind_param(":NAME",$self->name());
  
  $sth->execute();

  if (my @row = $sth->fetchrow_array())
  {

    $ret_val = $row[0];
  }
  else
  {
    $ret_val = undef; 
  }

  $sth->finish();
  $dbh->disconnect();

  $self->{'VALUE'} = $ret_val;

  return $self->{'VALUE'};
}


sub setVal
{
  my $self = shift;

  my ($value) = @_;
  my $name = $self->name();
  
  my $dbh = $self->connectToDB();

  my $sth = $dbh->prepare(<<SQL);
  BEGIN
      wm_sysval.mergesysval(pName => :NAME, pValue => :VALUE);
  END;    
SQL

  

  $sth->bind_param_inout(":NAME", \$name, 64);
  $sth->bind_param_inout(":VALUE", \$value, 64);
  
  $sth->execute() or die "Error: Cannot execute SQL: $DBI::errstr\n";

  $dbh->commit();

  $sth->finish();
  $dbh->disconnect();
  
  $self->{'VALUE'} = $value;

}



1; # to allow module compilation