#!/usr/bin/env perl -w
#---------------------------------------------------------
# (#) ./base/sw/wm_monitor/monitors/wmon_switch.pl BL_core_schema_8.0.7_8.0.7.4.02_20100413  064938
# (#) 
# COPYRIGHT 2003 WatchMark Corp.
#---------------------------------------------------------
#

use Env;
use Time::localtime;
use File::Basename;

my $SCRIPT_ID       = basename($0);
my $COMMENT_TAG     = "#";
my $DELIMITER       = "|";

my $MONITOR_HOME    = $ENV{"WM_MONITOR_HOME"} || ".";
my $MONITOR_SQLDIR  = $ENV{"WM_MONITOR_SQLDIR"} || "$MONITOR_HOME/sql";
my $MONITOR_LOGDIR  = $ENV{"WM_MONITOR_LOGDIR"} || "$MONITOR_HOME/logs";
my $MONITOR_SCRIPTS = $ENV{"WM_MONITOR_SCRIPTS"} || "$MONITOR_HOME/monitors";

my $MONITOR_EXECUTOR = "cat";
my $MONITOR_COMMAND  = "Not-Set"; #<-- TBD by choose_switch()
my $MONITOR_OPTIONS  = "";

my $STOP_FILE     = "$MONITOR_HOME/stop";
my $PROSPECT_HOME = $ENV{"PROSPECT_HOME"} || '';

#----------------------------------------------------------------------
sub process_line($$$)
#----------------------------------------------------------------------
{
   my $Outfile = shift;
   my $line_no = shift;
   my $xline   = shift;

   $xline =~ s/^[ \t]+//g;
   $xline =~ s/[ \t]*$//g;
   $xline =~ s/[ \t][ \t]*/ /g;
   $xline =~ s/ /|/g;

   print $Outfile "$xline\n";
}

#----------------------------------------------------------------------
sub choose_switch
#----------------------------------------------------------------------
{

   if (-r "$PROSPECT_HOME/ne_list")
   {
      $MONITOR_COMMAND = "$PROSPECT_HOME/ne_list";
   }
   elsif (-r "$PROSPECT_HOME/msc_list")
   {
      $MONITOR_COMMAND = "$PROSPECT_HOME/msc_list";
   }
   elsif (-r "$PROSPECT_HOME/element_list")
   {
      $MONITOR_COMMAND = "$PROSPECT_HOME/element_list";
   }
   elsif (-r "$PROSPECT_HOME/ecp_list")
   {
      $MONITOR_COMMAND = "$PROSPECT_HOME/ecp_list";
   }

}

#----------------------------------------------------------------------
sub format_date
#----------------------------------------------------------------------
{

   my ( $day, $month, $year, $hour, $min, $sec );
   my $date_str;

   my $tm = localtime;
   ( $day, $month, $year, $hour, $min, $sec ) = ( $tm->mday, $tm->mon, $tm->year, $tm->hour, $tm->min, $tm->sec );
   $date_str = sprintf( "%04d%02d%02d:%02d:%02d:%02d", $year+1900, $month+1, $day, $hour, $min, $sec );

   return $date_str;
}

#----------------------------------------------------------------------
sub createLogDir
#----------------------------------------------------------------------
{
   if ( ! -e $MONITOR_LOGDIR )
   {
      mkdir($MONITOR_LOGDIR,"500") or die "Cannot create $MONITOR_LOGDIR: $!\n";
   }
}


#----------------------------------------------------------------------
sub header
#----------------------------------------------------------------------
{

   my ( $fh, $name, $date, $monitor, $options ) = @_;

   printf $fh "$COMMENT_TAG StartHeader\n";
   printf $fh "$COMMENT_TAG Name: %s\n", $name;
   printf $fh "$COMMENT_TAG Date: %s\n", $date;
   printf $fh "$COMMENT_TAG Monitor: %s\n", $monitor;
   printf $fh "$COMMENT_TAG Options: %s\n", $options;
   printf $fh "$COMMENT_TAG EndHeader\n";
}

#----------------------------------------------------------------------
sub error_out
#----------------------------------------------------------------------
{
   my ( $name, $date, $monitor, $options, $error_message ) = @_;
   my $log_str;

   $log_str = sprintf( "%s/%s.%s.err", $MONITOR_LOGDIR, $name, $date );
   open( LOGFILE, ( "> " . $log_str ) ) or die "Can't write $log_str: $!\n";
   $fh = *LOGFILE;
   header( $fh, $name, $date, $monitor, $options );

   print $fh "$error_message\n";
   die $error_message;
}

#----------------------------------------------------------------------
sub new_log
#----------------------------------------------------------------------
{

   my ( $name, $date, $monitor, $options ) = @_;
   my $log_str;

   error_out( $name, $date, $monitor, $options, "Process is blocked. File $STOP_FILE found" )
      if ( -e $STOP_FILE );
   
   $log_str = sprintf( "%s/%s.%s.log", $MONITOR_LOGDIR, $name, $date );
   open( LOGFILE, ( "> " . $log_str ) ) or die "Can't write $log_str: $!\n";

   $fh = *LOGFILE;

   header( $fh, $name, $date, $monitor, $options );

   return $fh;

}

#----------------------------------------------------------------------
sub main
#----------------------------------------------------------------------
{

   createLogDir;

   my $FormattedDate = format_date;

   error_out($SCRIPT_ID, $FormattedDate, $MONITOR_COMMAND, $MONITOR_OPTIONS, "PROSPECT_HOME is not set.")
      if ($PROSPECT_HOME eq '');

   choose_switch;
   error_out($SCRIPT_ID, $FormattedDate, $MONITOR_COMMAND, $MONITOR_OPTIONS, "Switch list not found.")
      if ($MONITOR_COMMAND eq 'Not-Set');

   my $LogFile = new_log($SCRIPT_ID, $FormattedDate, $MONITOR_COMMAND, $MONITOR_OPTIONS);
   my $lineNum = 0;

   open ( MONITOR, "$MONITOR_EXECUTOR $MONITOR_COMMAND $MONITOR_OPTIONS|");
   while ( <MONITOR> )
   {
      chomp;
      $lineNum++;
      process_line($LogFile, $lineNum, $_);
   
   }

   close MONITOR;
   close $LogFile;
}

exit main;
