---------------------------------------------------------------------------
--
-- Licensed Materials - Property of IBM
-- 5724-T05,5724-T06
--
-- (C) Copyright IBM Corp. 2003,2008. All Rights Reserved.
--
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
--
---------------------------------------------------------------------------
-- (#) ./pweb/vendor/EnterpriseTrafficCache/agentSchemaViews.sql BL_core_schema_8.0.7_8.0.7.4.02_20100413  064938
-- (#) 
--
-- Agent schema views
--
-- ------------------------------------------------------------------------

-- ------------------------------------------------------------------------
PROMPT
PROMPT Creating view pe_agent_datasource_vw...

CREATE OR REPLACE VIEW pe_agent_datasource_vw AS
SELECT agt.AGENT_TYPE_NAME, 
       ds.DATASOURCE_NAME, 
       ads.MAX_AGENT_COUNT,
       ads.blackout1_start, 
       ads.blackout1_end, 
       ads.blackout2_start,
       ads.blackout2_end, 
       ads.active
  FROM pe_agent_types agt, 
       pe_datasource ds, 
       pe_agent_datasource ads
 WHERE ads.agent_type_id = agt.agent_type_id
   AND ads.datasource_id = ds.datasource_id;

show errors view pe_agent_datasource_vw;

-- ------------------------------------------------------------------------
-- This view shows the number of running activities in the system grouped
-- by different values: 
-- agent type, datasource, and (agent type and datasource)
-- ------------------------------------------------------------------------
PROMPT
PROMPT Creating view pe_activity_running_vw...

CREATE OR REPLACE VIEW pe_activity_running_vw AS
SELECT ads.agent_type_id,
       ads.datasource_id,
       NVL(a.agent_type_running, 0) agent_type_running,
       NVL(b.datasource_running, 0) datasource_running,
       NVL(b.agent_datasource_running, 0) agent_datasource_running
  FROM ( SELECT agent_type_id,
                SUM ( COUNT ( agent_type_id ) )
                      OVER ( PARTITION BY agent_type_id ) agent_type_running
           FROM pe_activity
          WHERE state = 'RUNNING'
          GROUP BY agent_type_id ) a,
       ( SELECT agent_type_id,
                NVL ( datasource_id, - 1 ) datasource_id,
                SUM ( NVL2 ( datasource_id, COUNT ( datasource_id ), 0 ) )
                      OVER ( PARTITION BY datasource_id ) datasource_running,
                SUM ( NVL2 ( agent_type_id, NVL2 ( datasource_id, COUNT ( datasource_id ), 0 ), 0 ) )
                      OVER ( PARTITION BY agent_type_id, datasource_id ) agent_datasource_running
           FROM pe_activity
          WHERE state = 'RUNNING'
          GROUP BY agent_type_id,
                   datasource_id ) b,
       ( SELECT t.agent_type_id,
                d.datasource_id
           FROM pe_agent_types t,
                pe_datasource d
          WHERE t.agent_type = 'R'
          UNION ALL 
         SELECT n.agent_type_id,
                -1 datasource_id
           FROM pe_agent_types n
          WHERE agent_type = 'L') ads
 WHERE ads.agent_type_id = a.agent_type_id ( + )
   AND ads.agent_type_id = b.agent_type_id ( + )
   AND ads.datasource_id = b.datasource_id ( + );

show errors view pe_activity_running_vw;

-- ------------------------------------------------------------------------
-- This view lets us look at the number of activities that are currently
-- runnable if only some resource were available. We can use this to
-- sample to queue periodically to determine where and what our peak load
-- is, and do we need to tune the system for better throughput.
-- ------------------------------------------------------------------------
PROMPT
PROMPT Creating view pe_activity_sample_vw...

CREATE OR REPLACE VIEW pe_activity_sample_vw AS
SELECT a.activity_id, 
       a.agent_type_id, 
       t.agent_type_name,
       NVL(a.datasource_id, -1) datasource_id, 
       ds.datasource_name,
       a.entity_id,
       a.active_time,
       t.jndi_name jndi,
       t.max_pool_size max_agents_type,
       NVL(ads.max_agent_count, t.max_pool_size) max_agents_per_agent_ds,
       NVL(ds.max_allowed_agents, t.max_pool_size) max_agents_per_ds,
       NVL(ads.blackout1_start, 0) blackout1_start,
       NVL(ads.blackout1_end, 0) blackout1_end,
       NVL(ads.blackout2_start, 0) blackout2_start,
       NVL(ads.blackout2_end, 0) blackout2_end,
       t.active   agent_active,
       NVL ( ds.active, 'Y' ) ds_active,
       NVL ( ads.active, 'Y' ) agent_ds_active
  FROM pe_activity         a, 
       pe_datasource       ds,
       pe_agent_datasource ads,
       pe_agent_types      t,
       pe_activity_group   g,
       pe_system           s
 WHERE a.agent_type_id = t.agent_type_id
   AND a.activity_group_id = g.activity_group_id
   AND a.datasource_id = ds.datasource_id ( + )
   AND a.agent_type_id = ads.agent_type_id ( + )
   AND a.datasource_id = ads.datasource_id ( + )
   AND s.quiesce = 'N'
   AND a.state = 'RUNNABLE'
   AND a.active_time <= SYSDATE
   AND a.CANCEL = 'N'
   AND g.fired = 'Y';
  
show errors view pe_activity_sample_vw;

-- ------------------------------------------------------------------------
-- This is the main view the AgentManager reads from to see what the next activity is
-- to schedule. We actually use a stored procedure with a staging table to pull this
-- information out. This allows us to update the state of the objects we are pulling
-- out and allows us to schedule many activities in one round-trip (actually, two) 
-- to the database. If all the agents are busy, then this query should return no rows.
-- It only returns rows for activities for which there are available agents, and those
-- activities do not have any incomplete dependent activities. We support a whole bunch
-- of other rules too, which allow us to easily limit the number of activities hitting
-- a particular server, or restrict running activities on servers during certain blackout
-- periods etc.
--
-- * The pe_activity_running_vw allows us to throttle the number of activities running on
-- one particular datasource, agents of a particular type and/or agents of a particular
-- type running on each datasource
-- * The asv subquery supports 2 blackout periods (more are easy) per datasource.
-- ------------------------------------------------------------------------
PROMPT
PROMPT Creating view pe_activity_vw...

CREATE OR REPLACE VIEW pe_activity_vw AS
SELECT asv.activity_id,
       asv.agent_type_name,
       asv.jndi,
       asv.datasource_name
  FROM pe_activity_sample_vw asv,
       pe_activity_running_vw arv,
       ( SELECT a.agent_type_id,
                ar.depend_count
           FROM pe_agent_types a,
                pe_agent_depend ad,
                (SELECT agent_type_id,
                        SUM ( COUNT ( agent_type_id ) )
                        OVER ( PARTITION BY agent_type_id ) depend_count
                   FROM pe_activity a
                  WHERE state = 'RUNNING'
                  GROUP BY agent_type_id ) ar
          WHERE a.agent_type_id = ad.agent_type_id
            AND ar.agent_type_id = ad.dependent_agent_type_id ) d
 WHERE asv.agent_type_id = d.agent_type_id ( + )
   AND asv.agent_type_id = arv.agent_type_id ( + )
   AND asv.datasource_id = arv.datasource_id ( + )
   AND asv.agent_active = 'Y'
   AND asv.ds_active = 'Y'
   AND asv.agent_ds_active = 'Y'
   AND NVL ( d.depend_count, 0 ) = 0
   AND ( SYSDATE NOT BETWEEN TRUNC ( SYSDATE ) + asv.blackout1_start / 86400
	     AND TRUNC ( SYSDATE ) + asv.blackout1_end / 86400 )
   AND ( SYSDATE NOT BETWEEN TRUNC ( SYSDATE ) + asv.blackout2_start / 86400
	     AND TRUNC ( SYSDATE ) + asv.blackout2_end / 86400 )
   AND NVL ( arv.agent_type_running, 0 ) < asv.max_agents_type
   AND NVL ( arv.datasource_running, 0 ) < asv.max_agents_per_ds
   AND NVL ( arv.agent_datasource_running, 0 ) < asv.max_agents_per_agent_ds
 ORDER BY asv.active_time, asv.activity_id ASC;
 
show errors view pe_activity_vw;

-- ------------------------------------------------------------------------
-- Reveal any activities that have been canceled and are not yet 
-- in a terminal state (completed, canceled or failed).
-- ------------------------------------------------------------------------
PROMPT
PROMPT Creating view pe_activity_cancel_vw...

CREATE OR REPLACE VIEW pe_activity_cancel_vw AS
SELECT a.activity_id, t.agent_type_name, t.jndi_name jndi
  FROM pe_activity          a, 
       pe_agent_types       t,
       pe_activity_states   st
 WHERE t.agent_type_id = a.agent_type_id
   AND a.cancel = 'Y'
   AND a.state = st.state
   AND st.terminal = 'N'
   AND a.state = 'RUNNING';

show errors view pe_activity_cancel_vw;

-- ----------------------------------------------------------------------------
-- This is the main view used to provide agents data about what tasks need
-- to be performed.
PROMPT
PROMPT Creating view pe_activity_detail_vw...

CREATE OR REPLACE VIEW pe_activity_detail_vw AS 
SELECT a.activity_id,
       a.datasource_id,
       d.datasource_name,
       a.entity_id,
       e.entity_name,
       a.data_start,
       a.data_end,
       a.procedure_name,
       a.current_attempt,
       a.current_run
  FROM pe_activity a,
       pe_entity e,
       pe_datasource d
 WHERE a.entity_id = e.entity_id ( + )
   AND a.datasource_id = d.datasource_id ( + );

show errors view pe_activity_detail_vw;

-- ----------------------------------------------------------------------------
-- This is the main schedule view for scheduled activities
PROMPT
PROMPT Creating view pe_activity_schedule_vw...

CREATE OR REPLACE VIEW pe_activity_schedule_vw AS 
SELECT a.activity_id,
       t.agent_type_name,
       t.agent_type_id,
       d.datasource_name,
       e.entity_name,
       a.active_time,
       a.procedure_name,
       s.next_time scheduled_time
  FROM pe_activity a,
       pe_agent_types t,
       pe_entity e,
       pe_datasource d,
       schedule s
 WHERE a.entity_id = e.entity_id ( + )
   AND a.datasource_id = d.datasource_id ( + )
   AND a.agent_type_id = t.agent_type_id
   AND a.state != 'DELETED'
   AND a.activity_group_id = s.sched_fk
   AND s.job_type = 7;
   
show errors view pe_activity_schedule_vw;

-- ----------------------------------------------------------------------------
--
-- Local Variables:
-- mode: pls
-- End:
