---------------------------------------------------------------------------
--
-- Licensed Materials - Property of IBM
-- 5724-T05,5724-T06
--
-- (C) Copyright IBM Corp. 2004,2008. All Rights Reserved.
--
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
--
---------------------------------------------------------------------------
-- (#) ./pweb/vendor/EnterpriseTrafficCache/analysis-framework/af_kpi_schema.sql BL_core_schema_8.0.7_8.0.7.4.02_20100413  064938
-- (#) 
--


INSERT INTO subclass_table ( id, class_id, name )
  ( SELECT subclass_table_seq.NEXTVAL, id, 'kpiArchive'
      FROM class_table ct 
     WHERE LOWER( ct.name ) = 'part maint' );



CREATE SEQUENCE af_kpi_seq;
CREATE TABLE af_kpi
(
  kpi_id           INTEGER      NOT NULL,
  kpi_name         VARCHAR2(64) NOT NULL,
  aggr_type        CHAR(1)      NOT NULL,
  field_id         INTEGER,
  first_avail      DATE,
  last_avail       DATE,
  busyhour_period  CHAR(1),
  CONSTRAINT pk_af_kpi PRIMARY KEY (kpi_id),
  CONSTRAINT fk_af_kpi_fid FOREIGN KEY (field_id) REFERENCES pe_field(field_id) ON DELETE CASCADE,
  CONSTRAINT chk_af_kpi_bh_prd CHECK (busyhour_period IN ('D', 'W', 'M', 'Y', 'A'))
)
TABLESPACE wm_client;

CREATE UNIQUE INDEX idx_af_kpi_name ON af_kpi(kpi_name);

CREATE INDEX idx_af_kpi_fid ON af_kpi(field_id);

-- -----------------------------------------------------------------------------------
-- New temp table for supporting merges into af_kpi_archive
-- -----------------------------------------------------------------------------------
CREATE GLOBAL TEMPORARY TABLE af_kpi_archive_tmp
(
  tstamp         DATE           NOT NULL,
  kpi_id         INTEGER        NOT NULL,
  instance_id    INTEGER        NOT NULL,
  fullkey        VARCHAR2(900)  NOT NULL,
  numerator      FLOAT,
  denominator    FLOAT
)
ON COMMIT PRESERVE ROWS;

-- ---------------------------------------------------------------------------
-- KPI table is structured to make it very efficient to compute the average and
-- standard deviation over the last n weeks for the same day of week and same
-- time of day.
-- ---------------------------------------------------------------------------
CREATE TABLE af_kpi_archive
(
  tstamp         DATE           NOT NULL,
  kpi_id         INTEGER        NOT NULL,
  instance_id    INTEGER        NOT NULL,
  fullkey        VARCHAR2(900)  NOT NULL,
  numerator      FLOAT,
  denominator    FLOAT,
  CONSTRAINT pk_af_kpi_archive PRIMARY KEY (tstamp, kpi_id, instance_id)
)
ORGANIZATION INDEX COMPRESS
PCTFREE 5
PARTITION BY RANGE (tstamp)
(
  PARTITION  p2001010100 VALUES less than (TO_DATE('2001-01-02 00','YYYY-MM-DD HH24'))
)
TABLESPACE traffic_jumbo;

-- So part-maint gets a crack at it.
ALTER TABLE af_kpi_archive MONITORING;

-- ---------------------------------------------------------------------------
-- Jiggle the partition so it sits right on today. PART_MAINT then takes care
-- of the rest
-- ---------------------------------------------------------------------------
DECLARE
  v_old_part_name VARCHAR2(35);
  v_new_part_name VARCHAR2(35);
  v_sql_stmt VARCHAR2(2000);
  v_part_DATE DATE;
  v_sysdate DATE := trunc(sysdate,'DDD');
  p_table_name VARCHAR2(30) := 'af_kpi_archive';
BEGIN
  dbms_output.enable(1000000);

  SELECT SUBOBJECT_NAME
    INTO v_old_part_name
    FROM user_objects
   WHERE object_name = upper(p_table_name)
     AND object_type = 'TABLE PARTITION';

  IF TO_DATE(substr(v_old_part_name,2),'YYYYMMDDHH24') < v_sysdate
  THEN
      v_new_part_name := 'p'||to_char(v_sysdate,'YYYYMMDDHH24');
      v_sql_stmt := 'alter table '||p_table_name||' add partition '||v_new_part_name
                 || ' values less than ('
                 ||'to_DATE('||to_char(v_sysdate+1,'YYYYMMDDHH24')||',''YYYYMMDDHH24''))';
--dbms_output.put_line(v_sql_stmt);
    execute immediate v_sql_stmt;
    v_sql_stmt := 'alter table '||p_table_name||' drop partition '||v_old_part_name;
--dbms_output.put_line(v_sql_stmt);
    execute immediate v_sql_stmt;
  END IF;
EXCEPTION
  WHEN TOO_MANY_ROWS THEN
    raise_application_error('-20100', 'ERROR: the table should have only one partition CREATEd');
  WHEN OTHERS THEN
    raise_application_error('-20100', 'ERROR: ORA'||to_char(SQLCODE)||SQLERRM);
END;
/
show error

-- Now register this puppy with part_maint
INSERT INTO part_tables(part_table_id, table_name, tablespace_name, period, run_hourly, run_daily,
run_weekly, run_monthly, needs_export, needs_analyze, needs_move, needs_purge,
future_part, past_part, add_sproc)
VALUES
(PART_TABLE_SEQ.nextval, 'AF_KPI_ARCHIVE', 'TRAFFIC_JUMBO', 'D', 'N', 'Y', 'N', 'N', 'N', 'Y', 'Y', 'Y', 5, 90,
'af_kpi_combiner.part_maint_add');
COMMIT;

INSERT INTO subclass_map ( subclass_id, object_id )
    ( SELECT id, part_table_id
        FROM subclass_table st, part_tables pt
       WHERE st.name = 'kpiArchive'
         AND pt.table_name = 'AF_KPI_ARCHIVE');


CREATE TABLE af_kpi_bh_archive
(
  kpi_id         INTEGER        NOT NULL,
  tstamp         DATE           NOT NULL,
  instance_id    INTEGER        NOT NULL,
  fullkey        VARCHAR2(900)  NOT NULL,
  bh_tstamp      DATE           NOT NULL,
  numerator      FLOAT,
  denominator    FLOAT,
  CONSTRAINT pk_af_kpi_bh_archive PRIMARY KEY (kpi_id, tstamp, instance_id)
)
ORGANIZATION INDEX COMPRESS
PCTFREE 5
PARTITION BY RANGE (tstamp)
(
  PARTITION  p2001010100 VALUES less than (TO_DATE('2001-01-02 00','YYYY-MM-DD HH24'))
)
TABLESPACE traffic_jumbo;


DECLARE
  v_old_part_name VARCHAR2(35);
  v_new_part_name VARCHAR2(35);
  v_sql_stmt VARCHAR2(2000);
  v_part_DATE DATE;
  v_sysdate DATE := trunc(sysdate,'DDD');
  p_table_name VARCHAR2(30) := 'af_kpi_bh_archive';
BEGIN
  dbms_output.enable(1000000);

  SELECT SUBOBJECT_NAME
    INTO v_old_part_name
    FROM user_objects
   WHERE object_name = upper(p_table_name)
     AND object_type = 'TABLE PARTITION';

  IF TO_DATE(substr(v_old_part_name,2),'YYYYMMDDHH24') < v_sysdate
  THEN
      v_new_part_name := 'p'||to_char(v_sysdate,'YYYYMMDDHH24');
      v_sql_stmt := 'alter table '||p_table_name||' add partition '||v_new_part_name
                 || ' values less than ('
                 ||'to_DATE('||to_char(v_sysdate+1,'YYYYMMDDHH24')||',''YYYYMMDDHH24''))';
--dbms_output.put_line(v_sql_stmt);
    execute immediate v_sql_stmt;
    v_sql_stmt := 'alter table '||p_table_name||' drop partition '||v_old_part_name;
--dbms_output.put_line(v_sql_stmt);
    execute immediate v_sql_stmt;
  END IF;
EXCEPTION
  WHEN TOO_MANY_ROWS THEN
    raise_application_error('-20100', 'ERROR: the table should have only one partition CREATEd');
  WHEN OTHERS THEN
    raise_application_error('-20100', 'ERROR: ORA'||to_char(SQLCODE)||SQLERRM);
END;
/
show error

ALTER TABLE af_kpi_bh_archive MONITORING;

INSERT INTO part_tables(part_table_id, table_name, tablespace_name, period, run_hourly, run_daily,
run_weekly, run_monthly, needs_export, needs_analyze, needs_move, needs_purge,
future_part, past_part)
VALUES
(PART_TABLE_SEQ.nextval, 'AF_KPI_BH_ARCHIVE', 'TRAFFIC_JUMBO', 'D', 'N', 'Y', 'N', 'N', 'N', 'Y', 'Y',
'Y', 5, 90);


INSERT INTO subclass_map ( subclass_id, object_id )
    ( SELECT id, part_table_id
        FROM subclass_table st, part_tables pt
       WHERE st.name = 'kpiArchive'
         AND pt.table_name = 'AF_KPI_BH_ARCHIVE');
COMMIT;


