DECLARE
   gid INTEGER;
BEGIN
   
-- Create a basic mapping so we have something to work with.
enterprise_mapping.create_entity('Switch', NULL, 'System', 15);
enterprise_mapping.create_entity('Cell', NULL, 'Switch', 15);
enterprise_mapping.create_entity('Sector', NULL, 'Cell', 15);

enterprise_mapping.create_tableNames('Switch');
enterprise_mapping.create_tableNames('Cell');
enterprise_mapping.create_tableNames('Sector');

enterprise_mapping.create_dimension_field('Switch', 'system_id', 0, 'N', 'Integer', 'System', 'Id', 'sysid');
enterprise_mapping.create_dimension_field('Switch', 'switch_id', 1, 'N', 'Integer', 'Switch', 'Id', 'swid');
-- 2 local dimension fields:
enterprise_mapping.create_dimension_field('Switch', 'market', NULL, 'Y', 'String', 'Switch', 'Market', 'swmkt');
enterprise_mapping.create_dimension_field('Switch', 'region', NULL, 'Y', 'String', 'Switch', 'Region', 'swregion');

-- Cell and everything below it needs two extra key fields to cover 
-- Motorola keys.
-- It may need more extra keys until it covers all possible vendors
enterprise_mapping.create_dimension_field('Cell', 'system_id', 0, 'N', 'Integer', 'System', 'Id', 'sysid');
enterprise_mapping.create_dimension_field('Cell', 'switch_id', 1, 'N', 'Integer', 'Switch', 'Id', 'swid');
enterprise_mapping.create_dimension_field('Cell', 'vs_bsc_id', 2, 'N', 'Integer', 'Bsc', 'Id', 'bscid');
enterprise_mapping.create_dimension_field('Cell', 'vs_bts_id', 3, 'N', 'Integer', 'Bts', 'Id', 'btsid');
enterprise_mapping.create_dimension_field('Cell', 'cell_id',   4, 'N', 'Integer', 'Cell',   'Id', 'cellid');
-- 1 local dimension field:
enterprise_mapping.create_dimension_field('Cell', 'engineer', NULL, 'Y', 'String', 'Cell', 'Engineer', 'celleng');


enterprise_mapping.create_dimension_field('Sector', 'system_id', 0, 'N', 'Integer', 'System', 'Id', 'sysid');
enterprise_mapping.create_dimension_field('Sector', 'switch_id', 1, 'N', 'Integer', 'Switch', 'Id', 'swid');
enterprise_mapping.create_dimension_field('Sector', 'vs_bsc_id', 2, 'N', 'Integer', 'Bsc', 'Id', 'bscid');
enterprise_mapping.create_dimension_field('Sector', 'vs_bts_id', 3, 'N', 'Integer', 'Bts', 'Id', 'btsid');
enterprise_mapping.create_dimension_field('Sector', 'cell_id',   4, 'N', 'Integer', 'Cell',   'Id', 'cellid');
enterprise_mapping.create_dimension_field('Sector', 'sector_id', 5, 'N', 'Integer', 'Sector', 'Id', 'sectorid');
-- 1 non-local dimension field:
enterprise_mapping.create_dimension_field('Sector', 'updates', NULL, 'N', 'Integer', 'Sector', 'UpdateCount', 'sectorupd');

enterprise_mapping.update_entityDefinedState('Switch', 'Y');
enterprise_mapping.update_entityDefinedState('Cell', 'Y');
enterprise_mapping.update_entityDefinedState('Sector', 'Y');

enterprise_mapping.update_fieldEnabledState('Switch', 'market',   'Y');
enterprise_mapping.update_fieldEnabledState('Switch', 'region',   'Y');
enterprise_mapping.update_fieldEnabledState('Cell',   'engineer', 'Y');
enterprise_mapping.update_fieldEnabledState('Sector', 'updates',  'Y');

enterprise_mapping.map_mv_entity('Hydrogen', 'Release 7.2', 'ECP', 'Switch');
enterprise_mapping.map_mv_entity('Hydrogen', 'Release 7.2', 'Cell', 'Cell');
enterprise_mapping.map_mv_entity('Hydrogen', 'Release 7.2', 'Antenna', 'Sector');

enterprise_mapping.map_mv_entity('Motorola', 'S17.0', 'MSC', 'Switch');
enterprise_mapping.map_mv_entity('Motorola', 'S17.0', 'BTS_Cell', 'Cell');
enterprise_mapping.map_mv_entity('Motorola', 'S17.0', 'Cell_Sector', 'Sector');


enterprise_mapping.create_mv_field_map('Hydrogen', 'Release 7.2', 'ECP',     'sys_id',     'Switch', 'system_id');
enterprise_mapping.create_mv_field_map('Hydrogen', 'Release 7.2', 'ECP',     'ecp_id',     'Switch', 'switch_id');

enterprise_mapping.create_mv_field_map('Hydrogen', 'Release 7.2', 'Cell',    'sys_id',     'Cell',   'system_id');
enterprise_mapping.create_mv_field_map('Hydrogen', 'Release 7.2', 'Cell',    'ecp_id',     'Cell',   'switch_id');
enterprise_mapping.create_mv_field_map('Hydrogen', 'Release 7.2', 'Cell',    'cell_id',    'Cell',   'vs_bsc_id'); -- hack #1
enterprise_mapping.create_mv_field_map('Hydrogen', 'Release 7.2', 'Cell',    'cell_id',    'Cell',   'vs_bts_id'); -- hack #2
enterprise_mapping.create_mv_field_map('Hydrogen', 'Release 7.2', 'Cell',    'cell_id',    'Cell',   'cell_id');

enterprise_mapping.create_mv_field_map('Hydrogen', 'Release 7.2', 'Antenna', 'sys_id',     'Sector', 'system_id');
enterprise_mapping.create_mv_field_map('Hydrogen', 'Release 7.2', 'Antenna', 'ecp_id',     'Sector', 'switch_id');
enterprise_mapping.create_mv_field_map('Hydrogen', 'Release 7.2', 'Antenna', 'cell_id',    'Sector', 'vs_bsc_id'); -- hack #3
enterprise_mapping.create_mv_field_map('Hydrogen', 'Release 7.2', 'Antenna', 'cell_id',    'Sector', 'vs_bts_id'); -- hack #4
enterprise_mapping.create_mv_field_map('Hydrogen', 'Release 7.2', 'Antenna', 'cell_id',    'Sector', 'cell_id');
enterprise_mapping.create_mv_field_map('Hydrogen', 'Release 7.2', 'Antenna', 'antenna_id', 'Sector', 'sector_id');
enterprise_mapping.create_mv_field_map('Hydrogen', 'Release 7.2', 'Antenna', 'update_count', 'Sector', 'updates');



-- Motorola keys are tricky because in order to get to a Sector 
-- we need to go through a BSC and a BTS mapping:
--
-- Mot: System -> MSC    -> BSC -> BTS -> BTS_Cell -> Cell_Sector
-- Ent: System -> Switch -> [     Cell           ] -> Sector
--
-- Thus, an Enterprise Cell maps to a (BSC, BTS, BTS_Cell) combo in Motorola.
-- Everything at or below Cell will then have to include mappings for the
-- keys of BSC and BTS (see Sector below).
--
enterprise_mapping.create_mv_field_map('Motorola', 'S17.0', 'MSC',     'sys_id',     'Switch', 'system_id');
enterprise_mapping.create_mv_field_map('Motorola', 'S17.0', 'MSC',     'MSC_id',     'Switch', 'switch_id');

enterprise_mapping.create_mv_field_map('Motorola', 'S17.0', 'BTS_Cell', 'sys_id',     'Cell',   'system_id');
enterprise_mapping.create_mv_field_map('Motorola', 'S17.0', 'BTS_Cell', 'MSC_id',     'Cell',   'switch_id');
enterprise_mapping.create_mv_field_map('Motorola', 'S17.0', 'BTS_Cell', 'BSC_id',     'Cell',   'vs_bsc_id'); -- hack #5
enterprise_mapping.create_mv_field_map('Motorola', 'S17.0', 'BTS_Cell', 'BTS_id',     'Cell',   'vs_bts_id'); -- hack #6
enterprise_mapping.create_mv_field_map('Motorola', 'S17.0', 'BTS_Cell', 'BTS_Cell_id',    'Cell',   'cell_id');

enterprise_mapping.create_mv_field_map('Motorola', 'S17.0', 'Cell_Sector', 'sys_id',     'Sector', 'system_id');
enterprise_mapping.create_mv_field_map('Motorola', 'S17.0', 'Cell_Sector', 'MSC_id',     'Sector', 'switch_id');
enterprise_mapping.create_mv_field_map('Motorola', 'S17.0', 'Cell_Sector', 'BSC_id',     'Sector', 'vs_bsc_id'); -- hack #7
enterprise_mapping.create_mv_field_map('Motorola', 'S17.0', 'Cell_Sector', 'BTS_id',     'Sector', 'vs_bts_id'); -- hack #8
enterprise_mapping.create_mv_field_map('Motorola', 'S17.0', 'Cell_Sector', 'BTS_Cell_id',     'Sector', 'cell_id');
enterprise_mapping.create_mv_field_map('Motorola', 'S17.0', 'Cell_Sector', 'Cell_Sector_id', 'Sector', 'sector_id');
enterprise_mapping.create_mv_field_map('Motorola', 'S17.0', 'Cell_Sector', 'update_count', 'Sector', 'updates');



-- now for some traffic fields
enterprise_mapping.create_field('Switch', 'attempts', 'Sum', 'Integer', 'switch', 'attempts', 'switch attempts');
enterprise_mapping.create_mv_field_map('Hydrogen', 'Release 7.2', 'ECP', 'OrigAtte', 'Switch', 'attempts');
enterprise_mapping.create_mv_field_map('Motorola', 'S17.0', 'MSC', 'OrgAccAtt', 'Switch', 'attempts');

enterprise_mapping.create_field('Cell', 'attempts', 'Sum', 'Integer', 'cell', 'attempts', 'cell attempts');
enterprise_mapping.create_mv_field_map('Hydrogen', 'Release 7.2', 'Cell', 'OrigAtte', 'Cell', 'attempts');
enterprise_mapping.create_mv_field_map('Motorola', 'S17.0', 'BTS_Cell', 'RvsSCH_ReSrcReq', 'Cell', 'attempts');


-- uncomment if you need some more hoakey traffic fields.
--enterprise_mapping.create_field('Cell', 'generic_c1', 'Sum', 'Integer', 'generic', 'c1', 'generic c1');
--enterprise_mapping.create_mv_field_map('Hydrogen', 'Release 7.2', 'Cell', 'OrigDrop', 'Cell', 'generic_c1');
--enterprise_mapping.create_field('Cell', 'generic_c2', 'Sum', 'Integer', 'generic', 'c2', 'generic c2');
--enterprise_mapping.create_mv_field_map('Hydrogen', 'Release 7.2', 'Cell', 'AOrigSup', 'Cell', 'generic_c2');
--enterprise_mapping.create_field('Cell', 'generic_c3', 'Sum', 'Integer', 'generic', 'c3', 'generic c3');
--enterprise_mapping.create_mv_field_map('Hydrogen', 'Release 7.2', 'Cell', 'AOrigSup', 'Cell', 'generic_c3');

--enterprise_mapping.create_mv_field_map('Motorola', 'S17.0', 'BTS_Cell', 'SoHoAddReqTrgtBTS', 'Cell', 'generic_c1');
--enterprise_mapping.create_mv_field_map('Motorola', 'S17.0', 'BTS_Cell', 'SoHoAddCompTrgtBTS', 'Cell', 'generic_c2');
--enterprise_mapping.create_mv_field_map('Motorola', 'S17.0', 'BTS_Cell', 'SoHoAddFailTrgtBTS', 'Cell', 'generic_c3');



-- get data for the last 14 days for each entity (first-needed)
INSERT INTO pe_data_range (data_range_id, entity_id, start_time, required)
SELECT pe_seq_data_range.nextval, e.entity_id, trunc(sysdate)-14, 'Y'
FROM pe_entity e;

-- Pick a reasonable end-point. This needs to move forward as time moves forward.
INSERT INTO pe_data_range (data_range_id, entity_id, start_time, required)
SELECT pe_seq_data_range.nextval, e.entity_id, trunc(sysdate, 'HH24'), 'N'
FROM pe_entity e
WHERE e.is_enabled = 'Y';


-- Use a Cartesian product to populate our datasource_data_range table
-- with a row for every datasource/data_range pair.
INSERT INTO pe_datasource_data_range(data_range_id, datasource_id)
SELECT dr.data_range_id, ds.datasource_id
FROM pe_data_range dr, pe_datasource ds
WHERE ds.deleted = 'N';

-- Launch instance schema agents
gid := pe_agent.createActivityGroup('Y');
pe_agent.addEntityActivity(gid, 'INSTANCESCHEMA', 'create Switch table', NULL, 'Switch');
pe_agent.addEntityActivity(gid, 'INSTANCESCHEMA', 'create Cell table', NULL, 'Cell');
pe_agent.addEntityActivity(gid, 'INSTANCESCHEMA', 'create Sector table', NULL, 'Sector');

-- instance data agents should automatically be launched
END;
/
-- ----------------------------------------------------------------------------
--
-- Local Variables:
-- mode: pls
-- End:
