-- ------------------------------------------------------------------------
--
-- Licensed Materials - Property of IBM
-- 5724-T05,5724-T06
--
-- (C) Copyright IBM Corp. 2003,2009. All Rights Reserved.
--
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
--
-- ------------------------------------------------------------------------
-- (#) ./pweb/vendor/EnterpriseTrafficCache/cacheSchemaViews.sql BL_core_schema_8.0.7_8.0.7.4.02_20100413  064938
-- (#) 
--
-- ------------------------------------------------------------------------
-- Draft schema for WatchMark Prospect Enterprise.
--
-- Robin Arnold, 2003-06-17.
--
-- ------------------------------------------------------------------------

CREATE OR REPLACE VIEW pe_module_version_vw AS
SELECT mv.module_version_id,
       m.module_name,
       mv.version_name,
       m.module_prefix || '_' || mv.version_prefix version_tag,
       mv.version_number,
       pmv.version_name parent_version_name,
       mv.root_entity_name
  FROM pe_module_version mv,
       pe_module_version pmv,
       pe_module m
 WHERE mv.parent_version_id = pmv.module_version_id ( + )
   AND m.module_id = mv.module_id;

-- ------------------------------------------------------------------------
-- ------------------------------------------------------------------------

CREATE OR REPLACE VIEW pe_mv_entity_vw AS
SELECT mve.mv_entity_id,
       mve.entity_name mv_entity_name,
       mve.image_key mv_image_key,
       mv.module_version_id,
       m.module_name,
       mv.version_name,
       mve.can_report,
       pe.entity_id,
       pe.entity_name,
       mvg.group_name,
       parent_mve.entity_name parent_mv_entity_name,
       mve.parent_mv_entity_id
  FROM pe_mv_entity mve,
       pe_mv_entity parent_mve,
       pe_module_version mv,
       pe_module m,
       pe_entity pe,
       pe_module_version_group mvg
 WHERE mve.module_version_id = mv.module_version_id
   AND mv.module_id = m.module_id
   AND mve.entity_id = pe.entity_id ( + )
   AND mve.parent_mv_entity_id = parent_mve.mv_entity_id ( + )
   AND mve.mv_group_id = mvg.module_version_group_id ( + );

-- ------------------------------------------------------------------------
-- ------------------------------------------------------------------------

CREATE OR REPLACE VIEW pe_mv_entity_small_vw AS
SELECT mve.mv_entity_id,
       mve.entity_name mv_entity_name,
       mve.image_key mv_image_key,
       mv.module_version_id,
       m.module_name,
       mv.version_name,
       mve.can_report,
       mve.parent_mv_entity_id
  FROM pe_mv_entity mve,
       pe_module_version mv,
       pe_module m
 WHERE mve.module_version_id = mv.module_version_id
   AND mv.module_id = m.module_id;

-- ------------------------------------------------------------------------
-- ------------------------------------------------------------------------

CREATE OR REPLACE VIEW pe_mv_field_vw AS
SELECT f.mv_field_id,
       e.mv_entity_id,
       e.entity_name mv_entity_name,
       f.field_name mv_field_name,
       m.module_name,
       mv.version_name,
       mv.module_version_id,
       f.heading1,
       f.heading2,
       f.description,
       grp.field_group_name,
       f.is_dimension,
       f.is_virtual,
       ct.type_name field_type,
       a.aggr_name,
       a.aggr_bh_ok bh_ok,
       ( SELECT pe_concat_all( pe_concat_expr_obj( ft.tech_name, ',' ))
         FROM pe_mv_field_tech_map fm,
            pe_field_technology ft
        WHERE fm.tech_id = ft.tech_id
          AND f.mv_field_id = fm.mv_field_id
         GROUP BY fm.mv_field_id ) tech_types,
       f.is_available
  FROM pe_mv_field f,
       pe_mv_entity e,
       pe_module_version mv,
       pe_module m,
       pe_mv_field_group grp,
       pe_column_type ct,
       wmd_aggregator_base a
 WHERE f.mv_entity_id = e.mv_entity_id
   AND e.module_version_id = mv.module_version_id
   AND mv.module_id = m.module_id
   AND f.field_group_id = grp.field_group_id
   AND f.aggr = a.aggr_id
   AND f.column_type_id  = ct.column_type_id
   AND UPPER(grp.field_group_name) NOT LIKE 'UDC%';

-- ------------------------------------------------------------------------
-- ------------------------------------------------------------------------

CREATE OR REPLACE VIEW pe_mv_udc_field_vw AS
SELECT u.mv_field_id,
       f.field_name mv_field_name,
       e.entity_name mv_entity_name,
       m.module_name,
       mv.version_name,
       u.heading1,
       u.heading2,
       u.description,
       grp.field_group_name,
       ct.type_name field_type,
       a.aggr_name,
       a.aggr_bh_ok bh_ok,
       f.is_dimension,
       f.is_virtual,
       d.datasource_name,
       u.datasource_id,
       d.local,
       u.udc_source,
       u.calc_source,
       u.modified,
       od.datasource_name  original_datasource_name,
       u.original_datasource_id,
       u.is_valid,
       u.is_complex,
       u.owner,
       ( SELECT pe_concat_all( pe_concat_expr_obj( ft.tech_name, ',' ))
         FROM pe_mv_udc_field_tech_map fm,
            pe_field_technology ft
        WHERE fm.tech_id = ft.tech_id
          AND u.mv_field_id = fm.mv_field_id
            AND u.datasource_id = fm.datasource_id
         GROUP BY fm.mv_field_id ) tech_types,
        f.is_available
  FROM pe_mv_udc_field u,
       pe_mv_field f,
       pe_mv_entity e,
       pe_module_version mv,
       pe_module m,
       pe_mv_field_group grp,
       pe_column_type ct,
       pe_datasource d,
       pe_datasource od,
       wmd_aggregator_base a
 WHERE f.mv_field_id = u.mv_field_id
   AND ct.column_type_id = u.column_type_id
   AND d.datasource_id = u.datasource_id
   AND d.deleted = 'N'
   AND u.original_datasource_id = od.datasource_id ( + )
   AND f.mv_entity_id = e.mv_entity_id
   AND e.module_version_id = mv.module_version_id
   AND mv.module_id = m.module_id
   AND f.field_group_id = grp.field_group_id
   AND u.aggr = a.aggr_id
   AND u.is_deleted = 'N';
      
-- ------------------------------------------------------------------------
-- ------------------------------------------------------------------------
CREATE OR REPLACE VIEW pe_mv_udc_dependency_vw AS
SELECT m.module_name,
       mv.version_name, 
       pe.entity_name parent_mv_entity_name,
       pf.field_name  parent_mv_field_name,
       ce.entity_name child_mv_entity_name,
       cf.field_name  child_mv_field_name
  FROM pe_mv_udc_field_depend fd,
       pe_module m,
       pe_module_version mv,
       pe_mv_entity pe,
       pe_mv_field  pf,
       pe_mv_entity ce,
       pe_mv_field cf
 WHERE fd.module_version_id = mv.module_version_id
   AND m.module_id = mv.module_id
   AND fd.parent_mv_field_id = pf.mv_field_id
   AND pf.mv_entity_id = pe.mv_entity_id
   AND mv.module_version_id = pe.module_version_id
   AND fd.child_mv_field_id = cf.mv_field_id
   AND cf.mv_entity_id = ce.mv_entity_id
   AND mv.module_version_id = ce.module_version_id;
   
-- ------------------------------------------------------------------------
-- ------------------------------------------------------------------------

CREATE OR REPLACE VIEW pe_ds_udc_dependency_vw AS
SELECT DISTINCT
       pe.entity_name     parent_entity_name,
       pf.field_name      parent_field_name,
       ce.entity_name     child_entity_name,
       cf.field_name      child_field_name,
       ds.datasource_name original_datasource_name
  FROM pe_mv_udc_field_depend fd,
       pe_mv_entity           pe,
       pe_mv_field            pf,
       pe_mv_entity           ce,
       pe_mv_field            cf,
       pe_mv_udc_field        uf,
       pe_datasource          ds
 WHERE fd.parent_mv_field_id = pf.mv_field_id
   AND pf.mv_entity_id = pe.mv_entity_id
   AND fd.child_mv_field_id = cf.mv_field_id
   AND cf.mv_entity_id = ce.mv_entity_id
   AND uf.mv_field_id = pf.mv_field_id
   AND ds.datasource_id = uf.original_datasource_id;

-- ------------------------------------------------------------------------
-- ------------------------------------------------------------------------

CREATE OR REPLACE VIEW pe_mv_field_map_vw AS
  SELECT e.entity_name, 
         f.field_name, 
         mve.entity_name       mv_entity_name, 
         mvf.field_name        mv_field_name,
         m.module_name, 
         mv.version_name, 
         f.aggr, 
         DECODE ( df.local_data,
              NULL,
              'N',
              'Y' ) is_dimension,
         fm.numerator, 
         fm.denominator, 
         t.table_name,
         mv.module_version_id, 
         e.entity_id           entity_id,
         mvg.group_name
    FROM pe_mv_field_map fm,
         pe_field f, 
         pe_entity e,
         pe_dimension_field df,
         pe_module_version mv,
         pe_module m,
         pe_mv_entity mve,
         pe_mv_field  mvf,
         pe_table t,
         pe_module_version_group mvg
   WHERE f.field_id = fm.field_id
     AND f.field_id = df.field_id ( + )
     AND e.entity_id = f.entity_id
     AND mv.module_version_id = fm.module_version_id
     AND m.module_id = mv.module_id
     AND mvf.mv_field_id = fm.mv_field_id
     AND mve.mv_entity_id = mvf.mv_entity_id
     AND fm.table_id = t.table_id ( + )
     AND fm.mv_group_id = mvg.module_version_group_id ( + );
   
-- ------------------------------------------------------------------------
-- ------------------------------------------------------------------------

CREATE OR REPLACE VIEW pe_field_vw AS
SELECT e.entity_name,
       f.field_name,
       f.field_id,
       ct.type_name field_type,
       df.key_ordinal,
       DECODE ( df.local_data,
                NULL,
                'N',
                df.local_data ) local_data,
       DECODE ( df.local_data,
                NULL,
                'N',
                'Y' ) is_dimension,
       f.ordinal field_ordinal,
       f.heading1,
       f.heading2,
       f.description,
       'Peg Count' field_group_name,
       f.is_enabled,
       a.aggr_name,
       a.aggr_bh_ok bh_ok,
       DECODE ( parent_field.key_ordinal,
                NULL,
                'N',
                'Y' ) is_parentkey,
       f.is_deleted,
       t.table_name,
       s.name column_status,
       f.is_mappable
  FROM pe_field f,
       pe_udc_field u,
       pe_entity e,
       pe_dimension_field df,
       pe_table t,
       pe_db_status s,
       pe_column_type ct,
       wmd_aggregator_base a,
       ( SELECT f.field_id,
                df.key_ordinal
           FROM pe_entity e,
                pe_field f,
                pe_field fp,
                pe_dimension_field df
          WHERE e.entity_id = f.entity_id
            AND fp.field_id = df.field_id
            AND f.field_name = fp.field_name
            AND e.parententity_id = fp.entity_id ) parent_field
 WHERE e.entity_id = f.entity_id
   AND f.aggr = a.aggr_id
   AND f.column_type_id = ct.column_type_id
   AND f.field_id = df.field_id ( + )
   AND df.table_id = t.table_id ( + )
   AND df.status = s.status ( + )
   AND f.field_id = parent_field.field_id ( + )
   AND f.field_id = u.field_id ( + )
   AND u.udc_source IS NULL;
      
-- ------------------------------------------------------------------------
-- ------------------------------------------------------------------------

CREATE OR REPLACE VIEW pe_udc_field_vw AS
SELECT e.entity_name,
       f.field_name,
       f.field_id,
       ct.type_name field_type,
       NULL key_ordinal,
       'N' local_data,
       'N' is_dimension,
       f.ordinal field_ordinal,
       f.heading1,
       f.heading2,
       f.description,
       'UDC' field_group_name,
       f.is_enabled,
       a.aggr_name,
       a.aggr_bh_ok bh_ok,
       'N' is_parentkey,
       f.is_deleted,
       NULL table_name,
       NULL column_status,
       u.udc_source,
       u.calc_source,
       u.error_msg,
       u.owner,
       u.modified,
       u.is_valid,
       u.is_complex
  FROM pe_field f,
       pe_udc_field u,
       pe_entity e,
       pe_column_type ct,
       wmd_aggregator_base a
 WHERE e.entity_id = f.entity_id
   AND f.field_id = u.field_id
   AND f.aggr = a.aggr_id
   AND f.column_type_id = ct.column_type_id;
      
-- ------------------------------------------------------------------------
-- ------------------------------------------------------------------------

CREATE OR REPLACE VIEW pe_entity_vw AS 
SELECT e.entity_id,
       e.entity_name entity_name,
       e.image_key,
       e.is_defined,
       e.is_enabled,
       (SELECT p.entity_name FROM pe_entity p WHERE e.parententity_id = p.entity_id) parent_entity_name,
       e.retention_days,
       e.parententity_id,
       (SELECT f.seconds FROM wm_frequency f WHERE e.data_frequency_id = f.frequency_id) data_frequency_sec
  FROM pe_entity e;
 
-- ------------------------------------------------------------------------
-- ------------------------------------------------------------------------
-- 
-- -> brings together datasource and module version information. 
-- -> used at least by the instance/traffic/schema agents.
--
CREATE OR REPLACE VIEW pe_mv_datasource_vw AS 
SELECT ds.datasource_id,
       ds.datasource_name,
       ds.active,
       ds.deleted,
       mv.module_version_id,
       mv.module_name,
       mv.version_name,
       mv.version_tag,
       mv.parent_version_name
  FROM pe_datasource ds,
       pe_module_deployments md,
       pe_module_instance mi,
       pe_module_version_vw mv
 WHERE ds.datasource_id = md.datasource_id
   AND md.module_instance_id = mi.module_instance_id
   AND mv.module_version_id = mi.module_version_id;

-- ------------------------------------------------------------------------
-- ------------------------------------------------------------------------

CREATE OR REPLACE VIEW pe_stored_field_vw AS
SELECT e.entity_name,
       f.field_name,
       mve.entity_name mv_entity_name,
       mvf.field_name mv_field_name,
       m.module_name,
       mv.version_name,
       m.module_prefix || '_' || mv.version_prefix version_tag,
       mve.mv_entity_id,
       mvf.mv_field_id,
       sf.table_id,
       sf.column_name,
       sf.component
  FROM pe_mv_field_map mfm,
       pe_entity e,
       pe_field f,
       pe_module_version mv,
       pe_module m,
       pe_mv_entity mve,
       pe_mv_field mvf,
       pe_stored_field sf,
       pe_stored_field_map sfm
 WHERE f.field_id = mfm.field_id
   AND NOT EXISTS ( SELECT 1
                      FROM pe_dimension_field df
                     WHERE df.field_id = f.field_id )
   AND e.entity_id = f.entity_id
   AND mv.module_version_id = mfm.module_version_id
   AND m.module_id = mv.module_id
   AND mvf.mv_field_id = mfm.mv_field_id
   AND mve.mv_entity_id = mvf.mv_entity_id
   AND mfm.mv_field_map_id = sfm.mv_field_map_id ( + )
   AND sfm.stored_field_id = sf.stored_field_id ( + );

-- ------------------------------------------------------------------------
-- ------------------------------------------------------------------------
--
-- Shows the complete mappings for the dimension fields of entities.
-- Note that only the implemented valid fields are selected by this
-- view. 
-- Also note that entities with incompletely mapped fields
-- mapped will show null values where the field mappings are missing.
-- The Instance and Traffic Agents rely on the view to only pull 
-- in the proper remote fields. Data Availability also looks at it,
-- because it has to show availability information only for fully
-- mapped entities.
--
CREATE OR REPLACE VIEW pe_mv_dimension_field_map_vw AS
SELECT dim.module_version_id,
       dim.module_name,
       dim.version_name,
       dim.entity_name,
       dim.entity_id,
       dim.field_name,
       dim.field_id,
       dim.field_ordinal,
       dim.key_ordinal,    -- if it's not null, it's a key
       dim.local_data,
       mvfm.mv_field_name,
       mvfm.mv_entity_name,
       mvfm.mv_group_id
  FROM ( -- find all the enabled and implemented dimension fields
         SELECT e.entity_name,
                e.entity_id,
                f.field_name,
                f.field_id,
                f.ordinal field_ordinal,
                df.key_ordinal,
                df.local_data,
                mve.module_version_id,
                m.module_name,
                mv.version_name,
                mve.entity_name mv_entity_name,
                mve.mv_entity_id mv_entity_id
           FROM pe_entity e,
                pe_field f,
                pe_dimension_field df,
                pe_mv_entity mve,
                pe_module m,
                pe_module_version mv
          WHERE e.entity_id = f.entity_id
            AND e.is_enabled = 'Y'
            AND f.is_enabled = 'Y'
            AND f.field_id = df.field_id
            AND df.table_id IS NOT NULL
            AND df.status = 'I'
            AND e.entity_id = mve.entity_id
            AND mve.module_version_id = mv.module_version_id
            AND mv.module_id = m.module_id ) dim,
       ( -- Join field name to mapped module version field
         SELECT mvfm.field_id, mvfm.module_version_id, mvf.mv_entity_id, 
                mvf.field_name mv_field_name, mvfm.mv_group_id,
                mve.entity_name mv_entity_name
           FROM pe_mv_field_map mvfm,
                pe_mv_field mvf,
                pe_mv_entity mve
          WHERE mvfm.mv_field_id = mvf.mv_field_id
            AND mvf.is_dimension = 'Y'
            AND mvf.mv_entity_id = mve.mv_entity_id ) mvfm
 WHERE dim.field_id = mvfm.field_id ( + )
   AND dim.module_version_id = mvfm.module_version_id ( + );


-- ------------------------------------------------------------------------
-- Shows entity and table relationships including current table status
-- ------------------------------------------------------------------------

CREATE OR REPLACE VIEW pe_entity_table_vw AS 
SELECT e.entity_id,
       t.table_id,
       e.entity_name,
       t.table_name,
       t.temp_table_name,
       t.table_type,
       s.name table_status
  FROM pe_entity e,
       pe_table t,
       pe_db_status s
 WHERE e.entity_id = t.entity_id
   AND s.status = t.status;
   
-- ------------------------------------------------------------------------

CREATE OR REPLACE VIEW pe_remote_system_vw AS
SELECT d.datasource_name, 
       rs.system_id, 
       d.deleted,
       d.active
  FROM pe_remote_system rs, 
       pe_datasource d
 WHERE rs.datasource_id = d.datasource_id;
 
-- ------------------------------------------------------------------------

CREATE OR REPLACE VIEW pe_module_version_group_vw AS
SELECT m.module_name,
       mv.version_name,
       mvg.group_name,
       mvg.is_default
  FROM pe_module m,
       pe_module_version mv,
       pe_module_version_group mvg
 WHERE mvg.module_version_id = mv.module_version_id
   AND m.module_id = mv.module_id;

-- ------------------------------------------------------------------------
CREATE OR REPLACE VIEW pe_datasource_attribute_vw AS
SELECT ds.datasource_name,
       at.attr_name,
       at.attr_value
  FROM pe_datasource ds,
       pe_datasource_attribute at
 WHERE ds.datasource_id = at.datasource_id;
 
-- ------------------------------------------------------------------------
CREATE OR REPLACE VIEW pe_datasource_aggregation_vw AS
SELECT ds.datasource_name,
       a.aggr_name,
       a.aggr_visible
  FROM wmd_aggregator_base a,
       pe_mv_aggregation_map mam,
       pe_datasource ds,
       ( SELECT md.datasource_id,
            mi.module_version_id
         FROM pe_module_instance mi,
                ( SELECT datasource_id,
                   MIN ( module_instance_id ) module_instance_id
                FROM pe_module_deployments
               GROUP BY datasource_id ) md
        WHERE md.module_instance_id = mi.module_instance_id ) mv
 WHERE ds.datasource_id = mv.datasource_id
   AND mam.module_version_id = mv.module_version_id
   AND a.aggr_id = mam.aggr_id; 
   
-- ------------------------------------------------------------------------
CREATE OR REPLACE VIEW pe_datasource_technology_vw AS
SELECT ds.datasource_name,
       t.tech_name,
       t.tech_char,
       t.tech_desc
  FROM pe_field_technology t,
       pe_mv_technology_map mtm,
       pe_datasource ds,
       ( SELECT md.datasource_id,
            mi.module_version_id
         FROM pe_module_instance mi,
            ( SELECT datasource_id,
               MIN ( module_instance_id ) module_instance_id
                FROM pe_module_deployments
               GROUP BY datasource_id ) md
        WHERE md.module_instance_id = mi.module_instance_id ) mv
 WHERE ds.datasource_id = mv.datasource_id
   AND mtm.module_version_id = mv.module_version_id
   AND t.tech_id = mtm.tech_id;
   
-- ------------------------------------------------------------------------
CREATE OR REPLACE VIEW pe_datasource_field_attr_vw AS
SELECT ds.datasource_name,
       a.attribute_name,
       mam.editable
  FROM pe_field_attribute a,
       pe_mv_field_attribute_map mam,
       pe_datasource ds,
       ( SELECT md.datasource_id,
                mi.module_version_id
         FROM pe_module_instance mi,
            ( SELECT datasource_id,
               MIN ( module_instance_id ) module_instance_id
                FROM pe_module_deployments
               GROUP BY datasource_id ) md
        WHERE md.module_instance_id = mi.module_instance_id ) mv
 WHERE ds.datasource_id = mv.datasource_id
   AND mam.module_version_id = mv.module_version_id
   AND a.attribute_id = mam.attribute_id;
      
-- ------------------------------------------------------------------------
CREATE OR REPLACE VIEW pe_datasource_field_group_vw AS
SELECT ds.datasource_name,
       g.field_group_name
  FROM pe_mv_field_group g,
       pe_mv_field_group_map mgm,
       pe_datasource ds,
       ( SELECT md.datasource_id,
                mi.module_version_id
           FROM pe_module_instance mi,
                ( SELECT datasource_id,
                         MIN ( module_instance_id ) module_instance_id
                    FROM pe_module_deployments
                   GROUP BY datasource_id ) md
          WHERE md.module_instance_id = mi.module_instance_id ) mv
 WHERE ds.datasource_id = mv.datasource_id
   AND mgm.module_version_id = mv.module_version_id
   AND g.field_group_id = mgm.field_group_id;
  
-- ------------------------------------------------------------------------
CREATE OR REPLACE VIEW pe_mv_field_attrval_vw AS              
SELECT m.module_name,
       mv.version_name,
     mve.entity_name mv_entity_name,
       mvf.field_name mv_field_name,
       fa.attribute_name,
       av.field_attribute_value attribute_value,
     aggr.aggr_bh_ok bh_ok
  FROM PE_MV_ENTITY mve,
       PE_MV_FIELD mvf,
     PE_FIELD_ATTRIBUTE fa,
     PE_MV_FIELD_ATTRIBUTE_VAL av,
     WMD_AGGREGATOR_BASE aggr,
     PE_MODULE_VERSION mv,
       PE_MODULE m
 WHERE av.mv_field_id = mvf.mv_field_id
   AND av.field_attribute_id = fa.attribute_id
   AND mvf.mv_entity_id = mve.mv_entity_id
   AND mvf.aggr = aggr.aggr_id
   AND mve.module_version_id = mv.module_version_id
   AND mv.module_id = m.module_id;
   
-- ------------------------------------------------------------------------
CREATE OR REPLACE VIEW pe_mv_udc_field_attrval_vw AS
SELECT ds.datasource_name,
       m.module_name,
       mv.version_name,
       mve.entity_name mv_entity_name,
       mvf.field_name mv_field_name,
       fa.attribute_name,
       av.field_attribute_value attribute_value,
       aggr.aggr_bh_ok bh_ok
  FROM PE_MV_ENTITY mve,
       PE_MV_UDC_FIELD mvuf,
       PE_MV_FIELD mvf,
       PE_FIELD_ATTRIBUTE fa,
       PE_MV_UDC_FIELD_ATTRIBUTE_VAL av,
       WMD_AGGREGATOR_BASE aggr,
       PE_MODULE_VERSION mv,
       PE_MODULE m,
       PE_DATASOURCE ds
 WHERE mvf.mv_field_id = mvuf.mv_field_id
   AND mvf.mv_entity_id = mve.mv_entity_id
   AND mve.module_version_id = mv.module_version_id
   AND mv.module_id = m.module_id
   AND mvuf.datasource_id = ds.datasource_id
   AND mvf.aggr = aggr.aggr_id
   AND mvuf.mv_field_id = av.mv_field_id
   AND mvuf.datasource_id = av.datasource_id
   AND av.field_attribute_id = fa.attribute_id;
  
-- ------------------------------------------------------------------------
CREATE OR REPLACE VIEW pe_entity_relation_vw AS
SELECT er.primary_field_id,
       ep.entity_name primary_entity_name,
       fp.field_name primary_field_name,
       ep.is_defined primary_entity_defined,
       er.secondary_field_id,
       es.entity_name secondary_entity_name,
       fs.field_name secondary_field_name,
       es.is_defined secondary_entity_defined
  FROM pe_entity_relation er,
       pe_field fp,
       pe_entity ep,
       pe_field fs,
       pe_entity es
 WHERE er.primary_field_id = fp.field_id
   AND fp.entity_id = ep.entity_id
   AND er.secondary_field_id = fs.field_id
   AND fs.entity_id = es.entity_id;

-- ----------------------------------------------------------------------------
--
-- Local Variables:
-- mode: pls
-- End:
