-- ---------------------------------------------------------------
-- (#) ./pweb/vendor/EnterpriseTrafficCache/create_extdoc_schema.sql BL_core_schema_8.0.7_8.0.7.4.02_20100413  064938
-- (#) 
-- ---------------------------------------------------------------

PROMPT CREATING External Documents Schema...

CREATE TABLE pe_extdoc (
    extdoc_id INTEGER,
    user_id   INTEGER,
    folder_id INTEGER,    
    name      VARCHAR2(255),
    file_id   INTEGER,
    CONSTRAINT pk_pe_extdoc PRIMARY KEY (extdoc_id),
    CONSTRAINT fk_pe_extdoc_user FOREIGN KEY (user_id) REFERENCES pm_user(id),
    CONSTRAINT ck_pe_extdoc_user_nn CHECK (user_id IS NOT NULL),
    CONSTRAINT fk_pe_extdoc_folder FOREIGN KEY (folder_id) REFERENCES pm_folder(id),
    CONSTRAINT ck_pe_extdoc_folder_nn CHECK (folder_id IS NOT NULL),
    CONSTRAINT fk_pe_extdoc_file_id FOREIGN KEY (file_id) REFERENCES pm_file(file_id)
) TABLESPACE wm_flexpm;

CREATE UNIQUE INDEX pe_extdoc_unq ON pe_extdoc (folder_id, UPPER(name));
CREATE SEQUENCE pe_extdoc_seq;    

PROMPT CREATING Staging Tables...

CREATE TABLE pe_extdoc_stage (
      temp_id    INTEGER NOT NULL,
      folder_id  INTEGER NOT NULL,
      user_id    INTEGER NOT NULL,
      name       VARCHAR2(255) NOT NULL,
      expiry     DATE    DEFAULT SYSDATE + 1/24 NOT NULL,
    CONSTRAINT pk_extdoc_stage PRIMARY KEY(temp_id),
    CONSTRAINT fk_extdoc_stage_fldr FOREIGN KEY (folder_id) REFERENCES pm_folder(id) ON DELETE CASCADE,
    CONSTRAINT fk_extdoc_stage_uid FOREIGN KEY (user_id) REFERENCES pm_user(id) ON DELETE CASCADE
) TABLESPACE wm_flexpm;	

CREATE UNIQUE INDEX pe_extdoc_stage_unq ON pe_extdoc_stage(folder_id, UPPER(name));

CREATE SEQUENCE pe_extdoc_stage_seq;

INSERT INTO pm_document_type 
(document_type_id, document_type_name, document_table, document_id_col,
 document_name_col, document_user_col, localhome, local, jndi)
VALUES
(seq_document_type.nextval, 'External Document', 'PE_EXTDOC', 'EXTDOC_ID', 
 'NAME', 'USER_ID', NULL, NULL, NULL);
COMMIT;

PROMPT CREATING payload TRIGGER for pe_extdoc...
      
CREATE OR REPLACE TRIGGER pe_extdoc_to_pm_doc
BEFORE INSERT OR UPDATE OR DELETE ON pe_extdoc
FOR EACH ROW
DECLARE
    extdoc_integrity_constraint EXCEPTION;
    PRAGMA exception_init(extdoc_integrity_constraint, -2292);        
BEGIN
           
    IF INSERTING THEN
       PM_Doc.add_document(:new.name,
                           :new.folder_id,
                           :new.user_id,
                           'External Document',
                           :new.extdoc_id);
              
    ELSIF UPDATING THEN
       -- since this is update, the :old.id and :new.id should be same
       pm_doc.update_document(:new.extdoc_id,
                              :new.folder_id,
                              :new.name,
                              :new.user_id,
                              'External Document');
              
    ELSIF DELETING THEN

       pm_doc.delete_document(:old.extdoc_id, 'External Document');
            
       BEGIN
          DELETE FROM pm_file WHERE file_id = :old.file_id;
       EXCEPTION
          WHEN extdoc_integrity_constraint THEN
            NULL;
       END;
              
    END IF;
           
END pe_extdoc_to_pm_doc;
/
SHOW ERRORS TRIGGER pe_extdoc_to_pm_doc;

    
-- ----------------------------------------------------------------------------
--
-- Local Variables:
-- mode: pls
-- End:
