---------------------------------------------------------------------------
--
-- Licensed Materials - Property of IBM
-- 5724-T05,5724-T06
--
-- (C) Copyright IBM Corp. 2003,2008. All Rights Reserved.
--
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
--
---------------------------------------------------------------------------
-- (#) ./pweb/vendor/EnterpriseTrafficCache/create_my_prospect_schema.sql BL_core_schema_8.0.7_8.0.7.4.02_20100413  064938
-- (#) 
--

PROMPT CREATE TABLE pe_page...
CREATE TABLE pe_page (
  page_id          NUMBER,
  user_id          NUMBER,
  folder_id        NUMBER,
  name             VARCHAR2(64),
  page_text        CLOB,           -- SEAde44185
  refresh_interval NUMBER,
  changed          DATE,
    CONSTRAINT pe_page_pk PRIMARY KEY ( page_id ),
    CONSTRAINT pe_page_user_id_fk FOREIGN KEY ( user_id ) REFERENCES pm_user( id ),
    CONSTRAINT pe_page_user_id_nn CHECK ( user_id IS NOT NULL ),
    CONSTRAINT pe_page_folder_id_fk FOREIGN KEY ( folder_id ) REFERENCES pm_folder( id ),
    CONSTRAINT pe_page_folder_id_nn CHECK ( folder_id IS NOT NULL ),
    CONSTRAINT pe_page_changed_nn CHECK ( changed IS NOT NULL )
) TABLESPACE wm_flexpm;

-- ---------------------------------------------------------------

PROMPT CREATE UNIQUE INDEX pe_page_unq...
CREATE UNIQUE INDEX pe_page_unq ON pe_page ( folder_id, UPPER( name ) );

-- ---------------------------------------------------------------

PROMPT CREATE SEQUENCE pe_page_seq...
CREATE SEQUENCE pe_page_seq START WITH 1000;

-- ---------------------------------------------------------------

PROMPT CREATE TABLE pe_section...
CREATE TABLE pe_section (
  section_id         NUMBER,
  page_id            NUMBER,
  result_document_id NUMBER,
  name               VARCHAR2(256),
  keep_updated       CHAR(1) DEFAULT 'Y',
  ordinal            NUMBER,
  override_results   CHAR(1) DEFAULT 'N',
  changed            DATE,
    CONSTRAINT pe_section_pk PRIMARY KEY ( section_id ),
    CONSTRAINT pe_section_page_id_fk FOREIGN KEY ( page_id ) REFERENCES pe_page( page_id ) ON DELETE CASCADE,
    CONSTRAINT pe_section_page_id_nn CHECK ( page_id IS NOT NULL ),
    CONSTRAINT pe_section_result_doc_id_fk FOREIGN KEY ( result_document_id ) REFERENCES pm_document( document_id ),
    CONSTRAINT pe_section_result_doc_id_nn CHECK ( result_document_id IS NOT NULL ),
    CONSTRAINT pe_section_keep_updated_ck CHECK ( keep_updated IN ( 'Y', 'N' ) ),
    CONSTRAINT pe_section_override_rts_ck CHECK ( override_results IN ( 'Y', 'N' ) ),
    CONSTRAINT pe_section_ordinal_nn CHECK ( ordinal IS NOT NULL )
);

-- ---------------------------------------------------------------

PROMPT CREATE SEQUENCE pe_section_seq...
CREATE SEQUENCE pe_section_seq START WITH 1000;

CREATE INDEX pe_idx_section_page_id ON pe_section(page_id);
CREATE INDEX pe_idx_section_doc_id ON pe_section(result_document_id);

-- ---------------------------------------------------------------

PROMPT CREATE TABLE pe_section_file...
CREATE TABLE pe_section_file (
  section_file_id NUMBER,
  section_id      NUMBER,
  file_id         INTEGER,
  changed         DATE DEFAULT SYSDATE,
    CONSTRAINT pe_section_file_pk PRIMARY KEY ( section_file_id ),
    CONSTRAINT pe_section_file_section_id_fk FOREIGN KEY ( section_id ) REFERENCES pe_section( section_id ) ON DELETE CASCADE,
    CONSTRAINT pe_section_file_section_id_nn CHECK ( section_id IS NOT NULL ),
    CONSTRAINT pe_section_file_file_id_fk FOREIGN KEY ( file_id ) REFERENCES pm_file( file_id )
);


-- ---------------------------------------------------------------

PROMPT CREATE SEQUENCE pe_section_file_seq...
CREATE SEQUENCE pe_section_file_seq START WITH 1000;

-- ---------------------------------------------------------------

PROMPT CREATE TRIGGER pe_section_tr...
CREATE OR REPLACE TRIGGER pe_section_tr
  BEFORE UPDATE OR INSERT ON pe_section FOR EACH ROW
BEGIN
  IF ( :new.changed IS NULL ) THEN
    SELECT sysdate INTO :new.changed FROM dual;
  END IF;
END pe_section_tr;
/
SHOW ERRORS TRIGGER pe_section_tr

-- ---------------------------------------------------------------

PROMPT CREATE TRIGGER pe_section_file_tr...
CREATE OR REPLACE TRIGGER pe_section_file_tr
  BEFORE UPDATE OR INSERT ON pe_section_file FOR EACH ROW
BEGIN
  IF ( :new.changed IS NULL ) THEN
    SELECT sysdate INTO :new.changed FROM dual;
  END IF;
END pe_section_file_tr;
/
SHOW ERRORS TRIGGER pe_section_file_tr

-- ---------------------------------------------------------------

PROMPT CREATE TRIGGER pe_section_file_del_tr...
CREATE OR REPLACE TRIGGER pe_section_file_del_tr 
  BEFORE DELETE ON pe_section_file FOR EACH ROW
DECLARE
 integrity_constraint exception;
 pragma exception_init( integrity_constraint, -2292 );
BEGIN
  DELETE FROM pm_file WHERE file_id = :old.file_id;
EXCEPTION
  WHEN integrity_constraint THEN
    NULL;
END pe_section_file_del_tr;
/
SHOW ERRORS TRIGGER pe_section_file_del_tr

-- ---------------------------------------------------------------

PROMPT INSERT Prospect Page document type
INSERT INTO pm_document_type
(document_type_id, document_type_name, document_table,
 document_id_col, document_name_col, document_user_col,
 localhome, local, jndi
)
VALUES
(seq_document_type.nextval,
'Prospect Page', 'PE_PAGE', 'PAGE_ID', 'NAME', 'USER_ID',
'com.watchmark.prospect.enterprise.api.ProspectPageHome',
'com.watchmark.prospect.enterprise.api.ProspectPageHome',
NULL);

-- ---------------------------------------------------------------

PROMPT CREATE payload TRIGGER for pe_page
CREATE OR REPLACE TRIGGER
pe_page_to_pm_doc
 BEFORE INSERT OR UPDATE OR DELETE
 ON pe_page
FOR EACH ROW
DECLARE
BEGIN
   IF INSERTING THEN
     PM_Doc.add_document(:new.name,
                         :new.folder_Id,
                         :new.user_ID,
                         'Prospect Page',
                         :new.page_id);
   ELSIF DELETING then
     pm_doc.delete_document(:old.page_id, 'Prospect Page');
   ELSIF UPDATING then
     -- since this is update, the :old.id and :new.id should be same
     pm_doc.update_document(:new.page_id,
                            :new.folder_ID,
                            :new.name,
                            :new.user_id,
                            'Prospect Page');

   END IF;
END pe_page_to_pm_doc;
/
SHOW ERRORS TRIGGER pe_page_to_pm_doc;

-- ---------------------------------------------------------------

