-- --------------------------------------------------------------
-- (#) ./pweb/vendor/EnterpriseTrafficCache/create_view_settings_schema.sql BL_core_schema_8.0.7_8.0.7.4.02_20100413  064938
-- (#) 
-- --------------------------------------------------------------
--       1         2         3         4         5         6
-- 45678901234567890123456789012345678901234567890123456789012345
-- --------------------------------------------------------------

PROMPT CREATE TABLE pe_view_setting...
CREATE TABLE pe_view_setting (
  view_setting_id    INTEGER,
  report_result_id   INTEGER,
  section_id         INTEGER,
  rollup_level       VARCHAR2(64),
  output_format      VARCHAR2(5)  DEFAULT 'HTML',
  expanded_state     CHAR(1)      DEFAULT 'Y',
    CONSTRAINT pe_view_setting_pk PRIMARY KEY ( view_setting_id ),
    CONSTRAINT pe_view_setting_rslt_doc_id_fk FOREIGN KEY ( report_result_id ) REFERENCES pe_report_result( report_result_id ) ON DELETE CASCADE,
    CONSTRAINT pe_view_setting_section_id_fk  FOREIGN KEY ( section_id ) REFERENCES pe_section( section_id ) ON DELETE CASCADE,
    CONSTRAINT pe_view_setting_outpt_formt_ck CHECK ( output_format IN ( 'HTML', 'CHART' ) ),
    CONSTRAINT pe_view_setting_expanded_st_ck CHECK ( expanded_state IN ( 'Y', 'N' ) )
);

-- --------------------------------------------------------------

PROMPT CREATE UNIQUE INDEX pe_view_setting_rd_id_unq...
CREATE UNIQUE INDEX pe_view_setting_rd_id_unq ON pe_view_setting( report_result_id );
-- --------------------------------------------------------------

PROMPT CREATE UNIQUE INDEX pe_view_setting_sect_id_unq...
CREATE UNIQUE INDEX pe_view_setting_sect_id_unq ON pe_view_setting( section_id );

-- --------------------------------------------------------------

PROMPT CREATE SEQUENCE pe_view_setting_seq...
CREATE SEQUENCE pe_view_setting_seq START WITH 1000;

-- --------------------------------------------------------------
-- valnt00089658 - change type of column from VARCHAR to NVARCHAR
-- Used as part of reporting - must be able to store internationalized
-- text as entity name may now contain it.
PROMPT CREATE TABLE pe_view_setting_entity...
CREATE TABLE pe_view_setting_entity (
  view_setting_id    INTEGER,
  entity_name        NVARCHAR2(64),
    CONSTRAINT pe_view_setting_entity_pk PRIMARY KEY ( view_setting_id, entity_name ),
    CONSTRAINT pe_view_setting_entity_vs_fk FOREIGN KEY ( view_setting_id ) REFERENCES pe_view_setting( view_setting_id ) ON DELETE CASCADE
);

-- --------------------------------------------------------------

PROMPT CREATE TABLE pe_view_setting_field...
CREATE TABLE pe_view_setting_field (
  view_setting_id    INTEGER,
  field_name         VARCHAR2(64),
    CONSTRAINT pe_view_setting_field_pk PRIMARY KEY ( view_setting_id, field_name ),
    CONSTRAINT pe_view_setting_field_vs_fk FOREIGN KEY ( view_setting_id ) REFERENCES pe_view_setting( view_setting_id ) ON DELETE CASCADE
);

-- --------------------------------------------------------------

PROMPT CREATE TABLE pe_view_setting_field_sort...
CREATE TABLE pe_view_setting_field_sort (
  view_setting_id    INTEGER,
  field_name         VARCHAR2(64),
  sort               CHAR(4),
  sort_type          CHAR(5),
  ordinal            INTEGER,
    CONSTRAINT pe_view_setting_field_sort_pk PRIMARY KEY ( view_setting_id, field_name, sort_type ),
    CONSTRAINT pe_view_setting_fld_sort_vs_fk FOREIGN KEY ( view_setting_id ) REFERENCES pe_view_setting( view_setting_id ) ON DELETE CASCADE,
    CONSTRAINT pe_view_setting_fld_sort_st_ck CHECK ( sort IN ( 'ASC', 'DESC' ) ),
    CONSTRAINT pe_view_setting_fld_st_type_ck CHECK ( sort_type IN ( 'MULTI', 'CLICK' ) ),
    CONSTRAINT pe_view_setting_fld_sort_or_nn CHECK ( ordinal IS NOT NULL )
);

-- --------------------------------------------------------------

PROMPT CREATE UNIQUE INDEX pe_view_setting_field_sort_unq...
CREATE UNIQUE INDEX pe_view_setting_field_sort_unq ON pe_view_setting_field_sort( view_setting_id, ordinal, sort_type );

-- --------------------------------------------------------------

PROMPT CREATE TABLE pe_view_setting_html...
CREATE TABLE pe_view_setting_html (
  view_setting_id      INTEGER,
  show_all_columns     CHAR(1) DEFAULT 'Y',
  view_style           VARCHAR2(64),
  subselected_entities CHAR(1) DEFAULT 'N',
  sort_by_multiple     CHAR(1) DEFAULT 'N',
    CONSTRAINT pe_view_set_html_pk PRIMARY KEY ( view_setting_id ),
    CONSTRAINT pe_view_set_html_fk FOREIGN KEY ( view_setting_id ) REFERENCES pe_view_setting( view_setting_id ) ON DELETE CASCADE,
    CONSTRAINT pe_view_set_html_show_cols_ck CHECK ( show_all_columns IN ( 'Y', 'N' ) ),
    CONSTRAINT pe_view_set_html_subsl_ents_ck CHECK ( subselected_entities IN ( 'Y', 'N' ) ),
    CONSTRAINT pe_view_set_html_sort_multp_ck CHECK ( sort_by_multiple IN ( 'Y', 'N' ) )
);

-- --------------------------------------------------------------

PROMPT CREATE TABLE pe_view_setting_chart...
CREATE TABLE pe_view_setting_chart (
  view_setting_id INTEGER,
  view_style      VARCHAR2(64),
  chart_type      VARCHAR2(64),
  chart_width     INTEGER      DEFAULT 0,
  chart_height    INTEGER      DEFAULT 0,
  show_legend     CHAR(1)     DEFAULT 'N',
  show_hints      CHAR(1)     DEFAULT 'N',
  show_limits     CHAR(1)     DEFAULT 'Y',
    CONSTRAINT pe_view_set_chart_pk PRIMARY KEY ( view_setting_id ),
    CONSTRAINT pe_view_set_chart_fk FOREIGN KEY ( view_setting_id ) REFERENCES pe_view_setting( view_setting_id ) ON DELETE CASCADE,
    CONSTRAINT pe_view_set_chart_show_lgnd_ck CHECK ( show_legend IN ( 'Y', 'N' ) ),
    CONSTRAINT pe_view_set_chart_show_hint_ck CHECK ( show_hints IN ( 'Y', 'N' ) ),
    CONSTRAINT pe_view_set_chart_show_lmt_ck CHECK ( show_limits IN ( 'Y', 'N' ) )
);

-- --------------------------------------------------------------

PROMPT CREATE VIEW ViewSettingsHtml_vw...
CREATE OR REPLACE VIEW ViewSettingsHtml_vw AS
  SELECT a.view_setting_id      view_setting_id,
         a.report_result_id     report_result_id,
         a.section_id           section_id,
         a.rollup_level         rollup_level,
         a.output_format        output_format,
         a.expanded_state       expanded_state,
         b.show_all_columns     show_all_columns,
         b.view_style           view_style,
         b.subselected_entities subselected_entities,
         b.sort_by_multiple     sort_by_multiple
    FROM pe_view_setting      a,
         pe_view_setting_html b         
   WHERE a.view_setting_id = b.view_setting_id;

-- --------------------------------------------------------------

PROMPT CREATE VIEW ViewSettingsChart_vw...
CREATE OR REPLACE VIEW ViewSettingsChart_vw AS
  SELECT a.view_setting_id    view_setting_id,
         a.report_result_id   report_result_id,
         a.section_id         section_id,
         a.rollup_level       rollup_level,
         a.output_format      output_format,
         a.expanded_state     expanded_state,
         b.view_style         view_style,
         b.chart_type         chart_type,
         b.chart_width        chart_width,
         b.chart_height       chart_height,
         b.show_legend        show_legend,
         b.show_hints         show_hints,
         b.show_limits        show_limits         
    FROM pe_view_setting       a,
         pe_view_setting_chart b         
   WHERE a.view_setting_id = b.view_setting_id;

-- --------------------------------------------------------------
