
INSERT INTO pm_document_type VALUES
(seq_document_type.nextval, 
'Report Log', 'PE_REPORT_RESULT', 'REPORT_RESULT_ID', 'REPORT_NAME', 'USERID',
'com.watchmark.prospect.enterprise.api.ReportFileAccessSessionHome',
'com.watchmark.prospect.enterprise.api.ReportFileAccessSessionHome',
'ReportFileAccess');

COMMIT;

CREATE OR REPLACE VIEW 
  pe_report_log_doc_vw
AS
  SELECT d.document_id, r.report_result_id, 
         f.document_fk folder_id, d.document_type_id,
         d.name, r.focal_entity_name, r.size_in_bytes, 
         d.user_id, d.group_id, p.filename, r.task_id,
         r.datasource_id, r.remote_task_id, r.report_id, r.job_time
   FROM  pm_document d, 
         pe_report_result r,
	 pm_document f,
         pm_document_type dt,
         pm_file p
   WHERE d.document_fk = r.report_result_id
     AND p.file_id = r.file_id
     AND f.document_id = d.parent_doc_id
     AND d.document_type_id = dt.document_type_id
     AND dt.document_type_name = 'Report Log';



--
-- Use an INSTEAD OF TRIGGER to support INSERTION into this view
--
CREATE OR REPLACE TRIGGER
  -- ------------------------------------------------------------------------
  --     COPYRIGHT WatchMark Corp 2003
  -- *** @(#) pe_payload_triggers.sql 1.1.0 03/10/30 09:37:51 
  -- *** @(#) 
  -- ------------------------------------------------------------------------
pe_report_log_to_pm_doc
 INSTEAD OF INSERT OR UPDATE OR DELETE
 ON pe_report_log_doc_vw
FOR EACH ROW
DECLARE
 integrity_constraint exception;
 pragma exception_init( integrity_constraint, -2292 );

 reportResultId   INTEGER;
 lv_file_id       pm_file.file_id%TYPE;
BEGIN
   IF INSERTING 
   THEN

     INSERT INTO pm_file ( file_id, filename ) 
       VALUES ( pm_file_seq.NEXTVAL, :new.filename )
       RETURNING file_id INTO lv_file_id;

     INSERT INTO pe_report_result(report_result_id, file_id, focal_entity_name,
                 size_in_bytes, task_id, datasource_id, remote_task_id, report_id, job_time)
	VALUES (pe_seq_report_result.nextval, lv_file_id, 
                :new.focal_entity_name,	:new.size_in_bytes, 
                :new.task_id, :new.datasource_id, :new.remote_task_id, :new.report_id, :new.job_time )
	RETURNING report_result_id INTO reportResultId;
     
     pm_doc.add_document(:new.name,
                         :new.folder_id,
                         :new.user_id,
                         'Report Log',
                         reportResultId,
                         'text/plain',
                         null,
                         nvl(:new.size_in_bytes, 0));
   ELSIF DELETING
   THEN
     DELETE FROM pe_report_result WHERE report_result_id =
	(SELECT document_fk FROM pm_document WHERE document_id = :old.document_id);
     DELETE FROM pm_document WHERE document_id = :old.document_id;
     BEGIN
       DELETE FROM pm_file WHERE filename = :old.filename;
     EXCEPTION
       WHEN integrity_constraint THEN
         NULL;
     END;
   ELSIF UPDATING 
   THEN
     -- since this is update, the :old.id and :new.id should be same
     pm_doc.update_document(:new.report_result_id,
                            :new.folder_id,
                            :new.name,
                            :new.user_id,
                            'Report Log',
                            null,
                            nvl(:new.size_in_bytes, 0));
   END IF;
END pe_report_log_to_pm_doc;
/
SHOW ERRORS TRIGGER pe_report_log_to_pm_doc;

