---------------------------------------------------------------------------
--
-- Licensed Materials - Property of IBM
-- 5724-T05,5724-T06
--
-- (C) Copyright IBM Corp. 2003,2008. All Rights Reserved.
--
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
--
---------------------------------------------------------------------------
-- (#) ./pweb/vendor/EnterpriseTrafficCache/performanceMonitorSchema.sql BL_core_schema_8.0.7_8.0.7.4.02_20100413  064938
-- (#) 
--
-- Web Performance Schema Tables
--
-- ------------------------------------------------------------------------

-- ------------------------------------------------------------------------
-- Stores performance statistics of the pweb environment
-- at certain intervals marked by the tstamp column.
-- Currently the intervals are 30 minutes.
-- ------------------------------------------------------------------------
CREATE TABLE pe_perf_stats_general
(
   tstamp                        DATE NOT NULL,
   active_user_count             INTEGER NOT NULL,
   max_memory                    INTEGER NOT NULL,
   available_memory              INTEGER NOT NULL,
   report_started_count          INTEGER NOT NULL,
   report_completed_count        INTEGER NOT NULL,
   scheduled_report_queue_count  INTEGER NOT NULL,
   immediate_report_queue_count  INTEGER NOT NULL,
   CONSTRAINT pk_perf_stats_general PRIMARY KEY(tstamp)
)
 ORGANIZATION INDEX 
 PARTITION BY RANGE ( tstamp )
 (
   PARTITION p0 VALUES LESS THAN ( TO_DATE( '2000-01-01 00', 'YYYY-MM-DD HH24' ) )
 )
 PCTFREE 0
 TABLESPACE TRAFFIC_SMALL
 ;

-- ------------------------------------------------------------------------
-- Stores computed information about the report run
-- ------------------------------------------------------------------------
CREATE TABLE pe_perf_stats_report
(
   tstamp                  DATE NOT NULL,
   task_id                 INTEGER NOT NULL,
   report_id               INTEGER NOT NULL,
   datasource_id           INTEGER,
   user_id                 INTEGER,
   queue_time              DATE,
   start_time              DATE,
   end_time                DATE,
   job_type                INTEGER,
   report_attrs            INTEGER,
   status_code             INTEGER,
   table_count             INTEGER,
   column_count            INTEGER,
   CONSTRAINT pk_perf_stats_report PRIMARY KEY(tstamp, task_id)
)
 ORGANIZATION INDEX 
 PARTITION BY RANGE ( tstamp )
 (
   PARTITION p0 VALUES LESS THAN ( TO_DATE( '2000-01-01 00', 'YYYY-MM-DD HH24' ) )
 )
 PCTFREE 0
 TABLESPACE TRAFFIC_SMALL
 ;

-- ------------------------------------------------------------------------
-- Stores string information about the report run
-- ------------------------------------------------------------------------
CREATE TABLE pe_perf_stats_report_strings
(
   tstamp                  DATE NOT NULL,
   task_id				   INTEGER NOT NULL,
   report_name             VARCHAR2(256),
   status_message          VARCHAR2(4000),
   CONSTRAINT pk_perf_stats_report_strings PRIMARY KEY(tstamp, task_id)
)
 ORGANIZATION INDEX 
 PARTITION BY RANGE ( tstamp )
 (
   PARTITION p0 VALUES LESS THAN ( TO_DATE( '2000-01-01 00', 'YYYY-MM-DD HH24' ) )
 )
 PCTFREE 0
 TABLESPACE TRAFFIC_SMALL
 ;

-- ------------------------------------------------------------------------
-- Stores information about the report queue for each server
-- ------------------------------------------------------------------------
CREATE TABLE pe_perf_stats_report_queue
(
   tstamp                  DATE NOT NULL,
   agent_type_id		   INTEGER NOT NULL,
   datasource_id		   INTEGER NOT NULL,
   avg_queue_length		   FLOAT,
   max_queue_length 	   INTEGER,
   min_queue_length 	   INTEGER,
   CONSTRAINT pk_perf_stats_report_queue PRIMARY KEY(tstamp, agent_type_id, datasource_id)
)
 ORGANIZATION INDEX 
 PARTITION BY RANGE ( tstamp )
 (
   PARTITION p0 VALUES LESS THAN ( TO_DATE( '2000-01-01 00', 'YYYY-MM-DD HH24' ) )
 )
 PCTFREE 0
 TABLESPACE TRAFFIC_SMALL
 ;

-- ------------------------------------------------------------------------
-- Stores information about the unique db stat names
-- ------------------------------------------------------------------------
CREATE TABLE pe_perf_db_stat_name
(
	stat_id		           INTEGER NOT NULL,
 	stat_name		       VARCHAR2(64) NOT NULL,
   CONSTRAINT pk_perf_db_stat_name PRIMARY KEY(stat_id)
)
 PCTFREE 0
 TABLESPACE TRAFFIC_SMALL
 ;

CREATE UNIQUE INDEX pe_idx_perf_db_stat_name ON pe_perf_db_stat_name(UPPER(stat_name));
CREATE SEQUENCE pe_seq_perf_db_stat;

-- ------------------------------------------------------------------------
-- Stores information about the report db stats
-- ------------------------------------------------------------------------
CREATE TABLE pe_perf_report_db_stats
(
   tstamp                  DATE NOT NULL,
   task_id		           INTEGER NOT NULL,
   stat_id		           INTEGER NOT NULL,   
   stat_value		       NUMBER(22),
   CONSTRAINT pk_perf_report_db_stats PRIMARY KEY(tstamp, task_id, stat_id)
)
 ORGANIZATION INDEX 
 PARTITION BY RANGE ( tstamp )
 (
   PARTITION p0 VALUES LESS THAN ( TO_DATE( '2000-01-01 00', 'YYYY-MM-DD HH24' ) )
 )
 PCTFREE 0
 TABLESPACE TRAFFIC_SMALL
 ;

-- ------------------------------------------------------------------------
-- Temp table to use to store db stats
-- ------------------------------------------------------------------------
CREATE GLOBAL TEMPORARY TABLE pe_perf_report_db_stats_tmp
(  
     stat_name             VARCHAR(64),
     stat_value            NUMBER(22)
)
ON COMMIT DELETE ROWS;

