---------------------------------------------------------------------------
--
-- Licensed Materials - Property of IBM
-- 5724-T05,5724-T06
--
-- (C) Copyright IBM Corp. 2003,2008. All Rights Reserved.
--
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
--
---------------------------------------------------------------------------
-- (#) ./pweb/vendor/EnterpriseTrafficCache/performanceMonitorSchemaViews.sql BL_core_schema_8.0.7_8.0.7.4.02_20100413  064938
-- (#) 
--
-- Web Performance Schema Views
--
-- ------------------------------------------------------------------------

-- ----------------------------------------------------------------------------
-- View to resolve datasource name and user name for report detail

PROMPT
PROMPT Creating view pe_perf_stats_report_vw...

CREATE OR REPLACE VIEW pe_perf_stats_report_vw AS 
SELECT pmr.tstamp,
       pmr.task_id,
       nvl(ds.datasource_name, 'Datasourceid ' || pmr.datasource_id) datasource_Name,
       nvl(u.NAME, 'Userid ' || pmr.user_id) user_name,
       decode(r.folderid, NULL, 'Report Deleted', pe_folder.FS_LookupPathbyFolderID(r.folderid)) folder,
       pmr.report_id,
       pmrs.report_name,
       pmr.queue_time,
       pmr.start_time,
       pmr.end_time,
       (pmr.start_time - pmr.queue_time)*24*60*60 sec_in_queue,
       (pmr.end_time - pmr.start_time)*24*60*60 run_time_in_sec,
       decode(pmr.job_type, 1, 'Immediate', 10, 'Scheduled') job_type,
       pe_perf_stats.decodeReportAttrs(pmr.report_attrs) report_attrs,
       pmr.table_count,
       pmr.column_count,
       decode(pmr.status_code, sched_general.SC_Done, 'Success', 'Failed') status,
       pmrs.status_message message
  FROM pe_perf_stats_report         pmr,
       pe_perf_stats_report_strings pmrs,
       pm_user                      u,
       pe_datasource                ds,
       pm_report                    r
 WHERE pmr.task_id = pmrs.task_id
   AND pmr.datasource_id = ds.datasource_id(+)
   AND pmr.user_id = u.id(+)
   AND pmr.report_id = r.id (+);

show errors view pe_perf_stats_report_vw;

-- View to show report db stats

PROMPT
PROMPT Creating view pe_perf_report_db_stats_vw...

CREATE OR REPLACE VIEW pe_perf_report_db_stats_vw AS
SELECT s.tstamp,
       s.task_id,
       s.stat_id,
       n.stat_name,
       s.stat_value
  FROM pe_perf_db_stat_name n,
       pe_perf_report_db_stats s
 WHERE n.stat_id = s.stat_id;

show errors view pe_perf_report_db_stats_vw;

-- View to show report queue stats

PROMPT
PROMPT Creating view pe_perf_stats_report_queue_vw...

CREATE OR REPLACE VIEW pe_perf_stats_report_queue_vw AS
SELECT tstamp,
       t.agent_type_name,
       NVL(d.datasource_name, 'Datasource '||q.datasource_id) datasource_name,
       avg_queue_length,
       max_queue_length,
       min_queue_length
  FROM pe_perf_stats_report_queue q, pe_agent_types t, pe_datasource d
 WHERE q.agent_type_id = t.agent_type_id
   AND q.datasource_id = d.datasource_id(+); 

show errors view pe_perf_stats_report_queue_vw;

-- ----------------------------------------------------------------------------
--
-- Local Variables:
-- mode: pls
-- End:
