-- (#) ./pweb/vendor/EnterpriseTrafficCache/pmdocViews.sql BL_core_schema_8.0.7_8.0.7.4.02_20100413  064938
-- (#) 
--

CREATE OR REPLACE VIEW pm_doc_permissions_v
AS
  SELECT document_id doc_id, d.name doc_name, user_id, u.name user_name,
         user_read read,user_write write, 'owner' user_type
    FROM pm_document d, pm_user u
   WHERE d.user_id=u.id
UNION
  SELECT document_id doc_id, d.name doc_name, d.group_id user_id, g.group_name user_name,
         group_read read,group_write write, 'primary group' user_type
    FROM pm_document d, pm_group g
   WHERE d.group_id=g.group_id
UNION
  SELECT doc.document_id doc_id, doc.name doc_name, uacl.user_id, u.name user_name,
         read, write, 'user' user_type
    FROM pm_document doc,
         pm_user_acl uacl,
         pm_user u
   WHERE doc.document_id = uacl.doc_id
     AND uacl.user_id=u.id
UNION
  SELECT doc.document_id doc_id, doc.name doc_name, gacl.group_id user_id, g.group_name user_name,
         read, write, 'group' user_type
    FROM pm_document doc,
         pm_group_acl gacl,
         pm_group g
   WHERE doc.document_id = gacl.doc_id
     AND gacl.group_id=g.group_id
;

CREATE OR REPLACE VIEW pm_doc_user_acl_v
AS
SELECT doc.DOCUMENT_ID,
       doc.parent_doc_id,
       doc.document_type_id,
       doc.name,
       doc.document_fk,
       doc.user_id doc_userId,
       doc.group_id doc_groupid,
       PM_doc_acl.CanIreadThisDoc(doc.DOCUMENT_ID, u.id) read,
       PM_doc_acl.CanIWriteThisDoc(doc.DOCUMENT_ID, u.id) Write,
       substr(PM_doc_acl.CanIChangePermission(doc.DOCUMENT_ID, u.id),1,1) change_permission,
       u.id readerID,
       u.group_id readergroupID,
       u.name reader
  FROM pm_document doc, pm_user u
;

CREATE OR REPLACE VIEW pm_browse_document_vw
AS
SELECT pd.DOCUMENT_ID             doc_id,
       pd.PARENT_DOC_ID           parent_doc_id,
       pd.DOCUMENT_TYPE_ID        doc_type_id,
       pd.NAME                    doc_name,
       pd.DOCUMENT_FK             doc_fk,
       pd.USER_ID                 doc_user_id,
       pu.name                    doc_owner,
       pdt.document_type_name     type_name,
       pd.description             description,
       pd.created                 created,
       pd.changed                 changed,
       pd.mime_type               mime_type,
       pd.size_bytes              size_bytes
  FROM pm_document pd,
       pm_document_type pdt,
       pm_user pu
 WHERE pdt.document_type_id = pd.document_type_id
   AND pu.id = pd.user_id;
   
-- folder docs for import/export tool
CREATE OR REPLACE VIEW pm_folder_vw
AS
SELECT pe_folder.fs_lookuppathbyfolderid(nvl(f.folderid,  1)) folder_path,
       f.name, 
       u.name user_name, 
       f.description,
       f.id,
       f.retain,
       f.retainDays,
       f.inheritRetention
FROM   pm_folder f, pm_user u
WHERE  f.userid = u.id
AND u.name != 'system'
;

-- default permissions for all documents
CREATE OR REPLACE VIEW pm_default_permission_vw
AS
SELECT d.document_id,
       d.document_fk,
       t.document_type_name, 
       d.name,
       u.name default_user_name, 
       g.group_name default_group_name, 
       d.user_read default_user_read, 
       d.user_write default_user_write, 
       d.group_read default_group_read, 
       d.group_write default_group_write
FROM pm_document_type t, 
     pm_document d, 
     pm_group g, 
     pm_user u
WHERE t.document_type_id = d.document_type_id
AND g.group_id = d.group_id
AND d.user_id = u.id
AND u.name != 'system'
;

-- group ACL permissions for all documents
CREATE OR REPLACE VIEW pm_group_acl_vw
AS
SELECT g.doc_id document_id, 
       g.read group_read, 
       g.write group_write, 
       pg.group_name,
       t.document_type_name,
       d.document_fk
FROM   pm_group_acl g, 
       pm_group pg,
       pm_document_type t,
       pm_document d
WHERE g.group_id = pg.group_id
AND   t.document_type_id = d.document_type_id
AND d.document_id = g.doc_id
;

-- user ACL permission for all documents
CREATE OR REPLACE VIEW pm_user_acl_vw
AS
SELECT u.doc_id document_id, 
       pu.name user_name, 
       u.read user_read, 
       u.write user_write,
        t.document_type_name,
       d.document_fk
FROM  pm_user_acl u, 
      pm_user pu,
      pm_document_type t,
       pm_document d
WHERE u.user_id = pu.id
AND   t.document_type_id = d.document_type_id
AND d.document_id = u.doc_id
;

-- report results and default permissions 
CREATE OR REPLACE VIEW PE_REPORT_RESULTS_VW
AS
SELECT f.document_fk result_folderid,
       pe_folder.fs_lookuppathbyfolderid( nvl ( f.document_fk , 1 ) ) result_folder,
       d.name result_name,
       r.focal_entity_name,
       r.size_in_bytes,
       u.name user_name,
       p.filename,
       ds.datasource_name,
       r.job_time,
       rp.name local_report_name,
       pe_folder.fs_lookuppathbyfolderid( nvl ( rp.folderid, 1 ) ) local_report_folder,
       r.report_result_id,
       r.report_id
FROM   pm_document d,
       pe_report_result r,
       pm_document f,
       pm_document_type dt,
       pm_file p,
       pm_user u,
       pe_datasource ds,
       pm_report rp
WHERE d.document_fk = r.report_result_id
AND f.document_id = d.parent_doc_id
AND d.document_type_id = dt.document_type_id
AND r.file_id = p.file_id
AND UPPER(dt.document_type_name) = 'REPORT RESULT'
AND d.user_id = u.ID
AND r.datasource_id = ds.datasource_id
AND r.report_id = rp.ID (+)
;

CREATE OR REPLACE VIEW pm_browse_roots_vw AS 
SELECT 'Y' is_admin_root,
       d.document_id,
       pe_folder.FS_LookupPathByFolderId(f.folderid) document_path,
       d.name document_name,
       g1.group_id default_group_id,
       g1.group_name default_group_name,                     
       f.changed,
       u.id owner_id,
       u.name owner_name,
       g2.group_id owner_group_id,
       g2.group_name owner_group_name,
       d.user_read,
       d.user_write,
       d.group_read,
       d.group_write
  FROM pm_document d,
       pm_folder f,
       pm_document_type t,
       pm_user u,
       pm_group g1,
       pm_group g2
 WHERE f.id = pe_folder.FS_LookupFolderByPath('/Users')
   AND d.document_fk = f.id
   AND d.user_id = u.id  
   AND u.group_id = g2.group_id
   AND d.document_type_id = t.document_type_id
   AND UPPER(t.document_type_name) = 'FOLDER'
   AND d.user_id = u.id
   AND d.group_id = g1.group_id
UNION ALL
SELECT 'N' is_admin,
       d.document_id,
       pe_folder.FS_LookupPathByFolderId(f.folderid) document_path,
       d.name document_name,
       g1.group_id default_group_id,
       g1.group_name default_group_name,                     
       f.changed,
       u.id owner_id,
       u.name owner_name,
       g2.group_id owner_group_id,
       g2.group_name owner_group_name,
       d.user_read,
       d.user_write,
       d.group_read,
       d.group_write
  FROM pm_document d, 
       pm_folder f,
       pm_document_type t,
       pm_user u,
       pm_group g1,
       pm_group g2
 WHERE u.folderid = d.document_fk 
   AND u.group_id = g2.group_id
   AND d.document_fk = f.id 
   AND d.document_type_id = t.document_type_id
   AND UPPER(t.document_type_name) = 'FOLDER'
   AND d.user_id = u.id
   AND d.group_id = g1.group_id;
/
