---------------------------------------------------------------------------
--
-- Licensed Materials - Property of IBM
-- 5724-T05,5724-T06
--
-- (C) Copyright IBM Corp. 2003,2010. All Rights Reserved.
--
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
--
---------------------------------------------------------------------------
-- (#) ./pweb/vendor/EnterpriseTrafficCache/reportSchema.sql BL_core_schema_8.0.7_8.0.7.4.02_20100413  064938
-- (#) 
--
-- ------------------------------------------------------------------------
--
-- Schema for WatchMark Prospect Enterprise.
--
-- Robin Arnold, 2003-06-26.
--
-- ------------------------------------------------------------------------


-- ------------------------------------------------------------------------
-- This series of expression tables are used to represent a logical expression
-- used to filter traffic cache queries.
-- ------------------------------------------------------------------------
CREATE TABLE pe_expression
(
  expression_id        INTEGER NOT NULL,
  top_node_id          INTEGER,
  CONSTRAINT pk_expression PRIMARY KEY (expression_id)
);

CREATE SEQUENCE pe_seq_expression;

--
-- Note that NULL is valid for the literal. We always store the value as a string
-- which is why we also have a literal_type so we know whether or not to quote 
-- it.
-- SEAde5808 change size of literal_value from 256 to 4000
-- valnt00089658: literal to NVARCHAR to store UTF-8 filter text i.e. Japanese
--
CREATE TABLE pe_expression_literal
(
  literal_id              INTEGER NOT NULL,
  literal_type            CHAR(1) NOT NULL,
  literal_value           NCLOB,
  CONSTRAINT pk_expression_literal PRIMARY KEY (literal_id),
  CONSTRAINT ck_expression_literal_type CHECK (literal_type IN ('I', 'F', 'S'))
) tablespace WM_FLEXPM;

CREATE SEQUENCE pe_seq_expression_literal;

CREATE TABLE pe_expression_node
(
  node_id              INTEGER NOT NULL,
  expression_id        INTEGER NOT NULL,
  operator             VARCHAR2(16),
  left_node_id         INTEGER,
  right_node_id        INTEGER,
  literal_id           INTEGER, -- this
  pe_field_id          INTEGER, -- this
  mv_field_id          INTEGER, -- or this, but only one of them
  CONSTRAINT pk_expression_node PRIMARY KEY (node_id),
  CONSTRAINT fk_expression_node_expid FOREIGN KEY (expression_id) REFERENCES pe_expression(expression_id)
  ON DELETE CASCADE,
  CONSTRAINT fk_expression_node_left FOREIGN KEY (left_node_id) REFERENCES pe_expression_node(node_id),
  CONSTRAINT fk_expression_node_right FOREIGN KEY (right_node_id) REFERENCES pe_expression_node(node_id),
  CONSTRAINT fk_expression_node_pfid FOREIGN KEY (pe_field_id) REFERENCES pe_field(field_id),
  CONSTRAINT fk_expression_node_mvfid FOREIGN KEY (mv_field_id) REFERENCES pe_mv_field(mv_field_id)
);

CREATE SEQUENCE pe_seq_expression_node;
CREATE INDEX pe_expression_node_idx ON pe_expression_node(expression_id);


-- ------------------------------------------------------------------------
-- Central definition of an Enterprise report definition. Referenced by
-- PM_REPORT.
--
-- This reportspec supports either an enterprise report definition (where
-- entity_id IS NOT NULL) or a remote report definition (where entity_id
-- IS NULL AND remote_reportspec_id IS NOT NULL).
-- ------------------------------------------------------------------------
CREATE TABLE pe_reportspec
(
  reportspec_id           INTEGER NOT NULL,
  resultName              VARCHAR2(128),
  entity_id               INTEGER, -- null for remote reports
  frequency_id            INTEGER NOT NULL,
  filter_expression_id    INTEGER, -- expressions
  report_type             VARCHAR2(10) DEFAULT 'Standard' not NULL,
  tf_filter_expression_id INTEGER,
  bh_filter_expression_id INTEGER,
  time_first              CHAR(1) DEFAULT 'N' NOT NULL,
  groupby_year            CHAR(1) DEFAULT 'N' NOT NULL,
  groupby_quarter         CHAR(1) DEFAULT 'N' NOT NULL,
  groupby_month           CHAR(1) DEFAULT 'N' NOT NULL,
  groupby_week            CHAR(1) DEFAULT 'N' NOT NULL,
  groupby_day             CHAR(1) DEFAULT 'N' NOT NULL,
  groupby_hour            CHAR(1) DEFAULT 'N' NOT NULL,
  groupby_30              CHAR(1) DEFAULT 'N' NOT NULL,
  groupby_15              CHAR(1) DEFAULT 'N' NOT NULL,
  groupby_10              CHAR(1) DEFAULT 'N' NOT NULL,
  groupby_5               CHAR(1) DEFAULT 'N' NOT NULL,
  CONSTRAINT pk_reportspec PRIMARY KEY (reportspec_id),
  CONSTRAINT fk_reportspec_filter FOREIGN KEY (filter_expression_id) REFERENCES pe_expression (expression_id),
  CONSTRAINT fk_reportspec_tf_filter FOREIGN KEY (tf_filter_expression_id) REFERENCES pe_expression (expression_id),
  CONSTRAINT fk_reportspec_bh_filter FOREIGN KEY (bh_filter_expression_id) REFERENCES pe_expression (expression_id),
  CONSTRAINT ck_groupby_year    CHECK (groupby_year    IN ('Y', 'N')),
  CONSTRAINT ck_groupby_quarter CHECK (groupby_quarter IN ('Y', 'N')),
  CONSTRAINT ck_groupby_month   CHECK (groupby_month   IN ('Y', 'N')),
  CONSTRAINT ck_groupby_week    CHECK (groupby_week    IN ('Y', 'N')),
  CONSTRAINT ck_groupby_day     CHECK (groupby_day     IN ('Y', 'N')),
  CONSTRAINT ck_groupby_hour    CHECK (groupby_hour    IN ('Y', 'N')),
  CONSTRAINT ck_groupby_30      CHECK (groupby_30      IN ('Y', 'N')),
  CONSTRAINT ck_groupby_15      CHECK (groupby_15      IN ('Y', 'N')),
  CONSTRAINT ck_groupby_10      CHECK (groupby_10      IN ('Y', 'N')),
  CONSTRAINT ck_groupby_5       CHECK (groupby_5       IN ('Y', 'N')),
  CONSTRAINT ck_rs_time_first   CHECK (time_first      IN ('Y', 'N'))
);

CREATE SEQUENCE pe_seq_reportspec;

-- Delete enterprise reportspec when the client deletes pm_report.
CREATE OR REPLACE TRIGGER pm_report_del_enterprise BEFORE DELETE ON pm_report FOR EACH ROW
BEGIN
  DELETE FROM pe_reportspec WHERE reportspec_id = :OLD.pe_reportspecid;
END;
/
SHOW ERRORS TRIGGER pm_report_del_enterprise

-- ------------------------------------------------------------------------
-- pe_ranking.
-- ------------------------------------------------------------------------
CREATE TABLE pe_ranking
(
  reportspec_id          INTEGER NOT NULL,  
  frequency_id           INTEGER,
  range_min              INTEGER, -- DEFAULT 0
  range_max              INTEGER,
  ordering               VARCHAR2(4),
  rank_field_id          INTEGER, -- EITHER field_id
  rank_mv_field_id       INTEGER, -- OR mv_field_id
  dim_field_id           INTEGER, -- EITHER field_id
  dim_mv_field_id        INTEGER, -- OR mv_field_id
  CONSTRAINT pk_ranking PRIMARY KEY( reportspec_id ),
  CONSTRAINT fk_ranking_rsid FOREIGN KEY (reportspec_id) REFERENCES pe_reportspec(reportspec_id) ON DELETE CASCADE,
  CONSTRAINT fk_ranking_rkfid  FOREIGN KEY (rank_field_id) REFERENCES pe_field (field_id), 
  CONSTRAINT fk_ranking_rkmvfid FOREIGN KEY (rank_mv_field_id) REFERENCES pe_mv_field (mv_field_id),
  CONSTRAINT fk_ranking_dmfid  FOREIGN KEY (dim_field_id) REFERENCES pe_field (field_id),  
  CONSTRAINT fk_ranking_dmmvfid FOREIGN KEY (dim_mv_field_id) REFERENCES pe_mv_field (mv_field_id),
  CONSTRAINT ck_ordering        CHECK (ordering        IN ('ASC', 'DESC')),
  CONSTRAINT ck_min             CHECK (range_min >=0 ),
  CONSTRAINT ck_max             CHECK (range_max >0  )
);

-- ------------------------------------------------------------------------
-- pe_busyhour
-- ------------------------------------------------------------------------
CREATE TABLE pe_busyhour
(
  reportspec_id          INTEGER NOT NULL,  
  frequency_id           INTEGER, -- DEFAULT 0
  percentile             INTEGER, -- DEFAULT 100
  entity_id              INTEGER, -- EITHER entity_id, field_id  
  field_id               INTEGER,   
  mv_entity_id           INTEGER, -- OR mv_entity_id, mv_field_id 
  mv_field_id            INTEGER, 
  mv_stored_id           INTEGER,
  mv_stored_name         VARCHAR2(128),  
  bh_type                VARCHAR2(10) DEFAULT 'BusyHour' NOT NULL,
  CONSTRAINT pk_busyhour PRIMARY KEY( reportspec_id ),
  CONSTRAINT fk_busyhour_rsid FOREIGN KEY (reportspec_id) REFERENCES pe_reportspec(reportspec_id) ON DELETE CASCADE,
  CONSTRAINT fk_busyour_fid  FOREIGN KEY (field_id) REFERENCES pe_field (field_id),
  CONSTRAINT fk_busyhour_eid  FOREIGN KEY (entity_id) REFERENCES pe_entity (entity_id),  
  CONSTRAINT fk_busyhour_mvfid FOREIGN KEY (mv_field_id) REFERENCES pe_mv_field (mv_field_id),
  CONSTRAINT fk_busyhour_mveid FOREIGN KEY (mv_entity_id) REFERENCES pe_mv_entity (mv_entity_id)
);

-- ------------------------------------------------------------------------
-- pe_filternhigh.
-- ------------------------------------------------------------------------
CREATE TABLE pe_filternhigh
(
  reportspec_id          INTEGER NOT NULL,  
  frequency_id           INTEGER,
  maximum                INTEGER,
  filter_count           INTEGER,
  factor                 FLOAT,
  field_id               INTEGER, -- EITHER field_id
  mv_field_id            INTEGER, -- OR mv_field_id
  CONSTRAINT pk_filternhigh PRIMARY KEY( reportspec_id ),
  CONSTRAINT fk_filternhigh_rsid FOREIGN KEY (reportspec_id) REFERENCES pe_reportspec(reportspec_id) ON DELETE CASCADE,
  CONSTRAINT fk_filternhigh_fid  FOREIGN KEY (field_id) REFERENCES pe_field (field_id),  
  CONSTRAINT fk_filternhigh_mvfid FOREIGN KEY (mv_field_id) REFERENCES pe_mv_field (mv_field_id)
);

-- ------------------------------------------------------------------------
-- pe_reportfield. What fields do we want to see in the report?
-- ------------------------------------------------------------------------
CREATE TABLE pe_reportfield
(
  reportspec_id          INTEGER NOT NULL,
  ordinal                INTEGER NOT NULL,
  pe_field_id            INTEGER NOT NULL,
  CONSTRAINT pk_reportfield PRIMARY KEY (reportspec_id, ordinal),
  CONSTRAINT fk_reportfield_rsid FOREIGN KEY (reportspec_id) REFERENCES pe_reportspec(reportspec_id) ON DELETE CASCADE,
  CONSTRAINT fk_reportfield_fid FOREIGN KEY (pe_field_id) REFERENCES pe_field(field_id)
);


-- ------------------------------------------------------------------------
-- Filters are used to restrict the set of instances returned by the query
-- for instance: WHERE ... region = '1' and market = '2'
-- DEPRECATED. Filters are implemented using the expression series tables
-- above.
-- ------------------------------------------------------------------------
CREATE TABLE pe_reportfilter
(
  reportfilter_id        INTEGER NOT NULL,
  reportspec_id          INTEGER NOT NULL,
  pe_field_id            INTEGER,
  CONSTRAINT pk_reportfilter PRIMARY KEY (reportfilter_id),
  CONSTRAINT fk_reportfilter_rsid FOREIGN KEY (reportspec_id) REFERENCES pe_reportspec(reportspec_id) ON DELETE CASCADE,
  CONSTRAINT fk_reportfilter_fid FOREIGN KEY (pe_field_id) REFERENCES pe_field(field_id)
);

CREATE SEQUENCE pe_seq_reportfilter;


-- ------------------------------------------------------------------------
-- Define an order by clause for the report
-- ------------------------------------------------------------------------
CREATE TABLE pe_reportordering
(
  reportspec_id          INTEGER NOT NULL,
  ordinal                INTEGER NOT NULL,
  pe_field_id            INTEGER NOT NULL,
  direction              CHAR(1) NOT NULL,
  CONSTRAINT pk_reportordering PRIMARY KEY (reportspec_id, ordinal),
  CONSTRAINT fk_reportordering_rsid FOREIGN KEY (reportspec_id) REFERENCES pe_reportspec(reportspec_id) ON DELETE CASCADE,
  CONSTRAINT fk_reportordering_fid FOREIGN KEY (pe_field_id) REFERENCES pe_field(field_id),
  CONSTRAINT ck_reportordering_dir CHECK (direction IN ('A', 'D'))
);


-- ------------------------------------------------------------------------
-- pe_reportgroup. What should we group by? Is a field_id appropriate here?
-- What about time? How do we identify time groupings?
-- ------------------------------------------------------------------------
CREATE TABLE pe_reportgrouping
(
  reportspec_id          INTEGER NOT NULL,
  ordinal                INTEGER NOT NULL,
  pe_field_id            INTEGER,
  CONSTRAINT pk_reportgrouping PRIMARY KEY (reportspec_id, ordinal),
  CONSTRAINT fk_reportgrouping_rsid FOREIGN KEY (reportspec_id) REFERENCES pe_reportspec(reportspec_id) ON DELETE CASCADE,
  CONSTRAINT fk_reportgrouping_fid FOREIGN KEY (pe_field_id) REFERENCES pe_field(field_id)
);


-- ------------------------------------------------------------------------
-- pe_report_result. When a report is complete, the file is removed from
-- task_filename and an entry made here. The status set to COMPLETE 
-- (from DONE). Note that records in this table are also pm_documents,
-- so there's a trigger on the table to keep pe_document in sync.
-- ------------------------------------------------------------------------
CREATE TABLE pe_report_result
(
  report_result_id       INTEGER NOT NULL,
  report_id              INTEGER NOT NULL, -- SEAde44871
  job_time               DATE,
  file_id                INTEGER,
  focal_entity_name      VARCHAR2(100), -- snap some useful info about the report
  size_in_bytes          INTEGER,
  task_id                INTEGER,       -- this result record could outlive the task
  datasource_id          INTEGER NOT NULL, -- SEAde44871
  remote_task_id         INTEGER, 
  row_count              INTEGER DEFAULT 0, 
  CONSTRAINT pk_report_result PRIMARY KEY (report_result_id),
  CONSTRAINT fk_report_result_file_id FOREIGN KEY ( file_id ) REFERENCES pm_file( file_id ),
  CONSTRAINT fk_report_result_datasrce_id FOREIGN KEY ( datasource_id ) REFERENCES  pe_datasource( datasource_id ) ON DELETE CASCADE,
  CONSTRAINT nn_report_result_datasrce_id CHECK ( datasource_id IS NOT NULL )
);

CREATE SEQUENCE pe_seq_report_result;

-- SEAde44871
CREATE INDEX pe_report_result_idx ON pe_report_result( datasource_id, report_id );

--SEAde51509
CREATE INDEX pe_report_result_file_idx ON pe_report_result( file_id );

-- ------------------------------------------------------------------------
-- Support for remote reports. Remote reportspecs have a record in this
-- table as well as a record in pe_reportspec (consider this a subclass).
-- Doing it this way means we can support remote report specs for different
-- types of remote system in the future, just using additional reportspec
-- tables like this.
-- I guess technically, we should have pe_reportspec and pe_enterprise_reportspec
-- tables, but that seems a little excessive when we can just allow a null
-- entity_id on pe_reportspec to signal that that particular record is 
-- non-enterprise.
-- We need some way to clean up stuff related to a datasource. Perhaps
-- some triggers?
-- ------------------------------------------------------------------------
CREATE TABLE pe_remote_reportspec
(
  reportspec_id          INTEGER NOT NULL,
  datasource_id          INTEGER NOT NULL,
  mv_entity_id           INTEGER NOT NULL,
  system_id              VARCHAR2(50) NOT NULL, -- report runs for one system only  
  CONSTRAINT pk_remote_reportspec PRIMARY KEY (reportspec_id),
  CONSTRAINT fk_remote_reportspec_rsid FOREIGN KEY (reportspec_id) REFERENCES pe_reportspec(reportspec_id) ON DELETE CASCADE,
  CONSTRAINT fk_remote_reportspec_dsid FOREIGN KEY (datasource_id) REFERENCES pe_datasource(datasource_id),
  CONSTRAINT fk_remote_reportspec_mveid FOREIGN KEY (mv_entity_id) REFERENCES pe_mv_entity (mv_entity_id)
);

CREATE TABLE pe_remote_reportfield
(
  reportspec_id          INTEGER NOT NULL,
  ordinal                INTEGER NOT NULL,
  mv_field_id            INTEGER NOT NULL,
  CONSTRAINT pk_remote_reportfield PRIMARY KEY (reportspec_id, ordinal),
  CONSTRAINT fk_remote_reportfield_rsid FOREIGN KEY (reportspec_id) REFERENCES pe_reportspec(reportspec_id) ON DELETE CASCADE,
  CONSTRAINT fk_remote_reportfield_mvfid FOREIGN KEY (mv_field_id) REFERENCES pe_mv_field (mv_field_id) ON DELETE CASCADE
);

CREATE TABLE pe_remote_reportgrouping
(
  reportspec_id          INTEGER NOT NULL,
  ordinal                INTEGER NOT NULL,
  mv_field_id            INTEGER NOT NULL,
  CONSTRAINT pk_remote_reportgrouping PRIMARY KEY (reportspec_id, ordinal),
  CONSTRAINT fk_remote_reportgrouping_rsid FOREIGN KEY (reportspec_id) REFERENCES pe_reportspec(reportspec_id) ON DELETE CASCADE,
  CONSTRAINT fk_remote_reportgrouping_mvfid FOREIGN KEY (mv_field_id) REFERENCES pe_mv_field (mv_field_id) ON DELETE CASCADE
);

-- stores files of a temporary nature
CREATE TABLE pe_remote_file
(
  file_id      VARCHAR2(150) NOT NULL,
  file_type    VARCHAR2(3)   NOT NULL, 
  file_name    VARCHAR2(255) NOT NULL,
  cleanup_time DATE,
  CONSTRAINT pk_pe_remote_file PRIMARY KEY(file_id, file_type),
  CONSTRAINT ck_pe_remote_file_type CHECK (file_type IN ('LOG', 'CSV', 'TMP', 'XLS')),
  CONSTRAINT uq_pe_remote_file_name UNIQUE (file_name)
);

-- stores tasks that have been auto-downloaded. Tasks get purged out of
-- this table as they go away from the remote report_status_v, so this is
-- not a large table.
CREATE TABLE pe_auto_downloaded_tasks 
(
   datasource_id  INTEGER NOT NULL,
   remote_task_id INTEGER NOT NULL,
   remote_job_id  INTEGER NOT NULL,
   was_downloaded CHAR(1) DEFAULT 'N',
   was_marked     CHAR(1) DEFAULT 'N',
   CONSTRAINT pk_auto_downloaded_tasks PRIMARY KEY (datasource_id, remote_task_id),
   CONSTRAINT ck_auto_downloaded_wasd CHECK (was_downloaded IN ('Y', 'N')),
   CONSTRAINT ck_auto_downloaded_wasm CHECK (was_marked IN ('Y', 'N')),
   CONSTRAINT fk_auto_downloaded_dsid FOREIGN KEY (datasource_id) REFERENCES pe_datasource(datasource_id) ON DELETE CASCADE
);

CREATE TABLE pe_auto_downloaded_settings
(
  datasource_id      INTEGER,
  remote_schedule_id INTEGER,
  result_folder_id   INTEGER,
  auto_organize_str  VARCHAR2(255),
  backload           CHAR(1)         DEFAULT 'N',
    CONSTRAINT pk_pe_auto_dnld_setngs PRIMARY KEY ( datasource_id, remote_schedule_id ),
    CONSTRAINT fk_pe_auto_dnld_setngs_ds_id FOREIGN KEY ( datasource_id ) REFERENCES pe_datasource( datasource_id ) ON DELETE CASCADE,
    CONSTRAINT fk_pe_auto_dnld_setngs_fldr_id FOREIGN KEY ( result_folder_id ) REFERENCES pm_document( document_id ),
    CONSTRAINT nn_pe_auto_dnld_setngs_fldr_id CHECK ( result_folder_id IS NOT NULL ),
    CONSTRAINT ck_pe_auto_dnld_setngs_bckload CHECK ( backload IN ( 'Y', 'N' ) )
);

CREATE INDEX pe_idx_auto_dl_set_folder_id ON pe_auto_downloaded_settings(result_folder_id);

-- -----------------------------------------------------------------------
-- The following tables are used for emailing/saving result to disk in
-- a friendly format.
-- -----------------------------------------------------------------------
CREATE TABLE pe_result_export
(
  report_result_id       INTEGER NOT NULL,
  email_addr             VARCHAR2(64), 
  destination            VARCHAR2(4000),
  format_type            VARCHAR2(23),
  status                 VARCHAR2(20),
  email_enabled          CHAR(1) NOT NULL,
  auto_down_enabled      CHAR(1) NOT NULL,
  CONSTRAINT pk_result_export PRIMARY KEY (report_result_id),
  CONSTRAINT ck_result_export_status CHECK (status IN ('processed', 'not processed', 'email failure', 'download failure')),
  CONSTRAINT fk_result_export_result_id FOREIGN KEY ( report_result_id ) 
              REFERENCES pe_report_result( report_result_id ) ON DELETE CASCADE  
);

CREATE TABLE PE_EXPORTED_RESULT_FILES
(
  filename                VARCHAR2(4000)
);

-- -----------------------------------------------------------------------
-- Additional custom info for a schedule related to emailing/exporting
-- a result to disk
-- -----------------------------------------------------------------------
CREATE TABLE pe_schedule_extension
(
  rg_schedule_id       INTEGER   NOT NULL,
  user_mail_address    VARCHAR2(64),
  file_format          VARCHAR2(23),
  email_notif_enabled  CHAR(1)   NOT NULL,
  autodownload_enabled CHAR(1)   NOT NULL,
  destination_path     VARCHAR2(256),  
  CONSTRAINT pk_pe_schedule_extension PRIMARY KEY (rg_schedule_id),  
  CONSTRAINT ck_schedule_ext_email CHECK (email_notif_enabled IN ('Y', 'N')),
  CONSTRAINT ck_schedule_ext_download CHECK (autodownload_enabled IN ('Y', 'N')), 
  CONSTRAINT ck_schedule_ext_format CHECK (file_format IN ('CSV (with rollups)', 'CSV (without rollups)', 'Excel (with rollups)', 'Excel (without rollups)', 'XML')),
  CONSTRAINT fk_pe_schedule_ext_schedule_id FOREIGN KEY ( rg_schedule_id )
   REFERENCES schedule ( schedule_id ) ON DELETE CASCADE  
);

-- ----------------------------------------------------------------------------
--
-- Local Variables:
-- mode: pls
-- End:
