---------------------------------------------------------------------------
--
-- Licensed Materials - Property of IBM
-- 5724-T05,5724-T06
--
-- (C) Copyright IBM Corp. 2003,2009. All Rights Reserved.
--
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
--
---------------------------------------------------------------------------
-- (#) ./pweb/vendor/EnterpriseTrafficCache/reportSchemaViews.sql BL_core_schema_8.0.7_8.0.7.4.02_20100413  064938
-- (#) 
--

-- ------------------------------------------------------------------------
-- pe_remote_report_bh_vw
-- ------------------------------------------------------------------------
PROMPT
PROMPT Creating view pe_remote_report_bh_vw...

CREATE OR REPLACE VIEW pe_remote_report_bh_vw AS
SELECT 
      rp.ID                 REPORT_ID,
      bh.MV_STORED_ID       STORED_ID,
      bh.MV_STORED_NAME     STORED_NAME,
      cl.ENTITY_NAME        ENTITY_NAME,
      fe.entity_name        FIELD_ENTITY_NAME,
      f.FIELD_NAME          FIELD_NAME,
      bh.frequency_id       frequency_id,
      bh.percentile         percentile,
      bh.bh_type            bh_type
 FROM 
      pe_busyhour bh,
      pe_mv_field f, 
      pm_report rp, 
      pe_mv_entity cl,
      pe_mv_entity fe
 WHERE bh.MV_FIELD_ID = f.MV_FIELD_ID(+)
   AND bh.MV_ENTITY_ID = cl.MV_ENTITY_ID
   AND bh.REPORTSPEC_ID = rp.PE_REPORTSPECID
   AND f.mv_entity_id = fe.mv_entity_id(+)
   AND NOT ( bh.MV_STORED_ID IS NULL AND bh.MV_FIELD_ID IS NULL );

show errors view pe_remote_report_bh_vw;

-- ------------------------------------------------------------------------
-- pe_remote_ranking_vw
-- ------------------------------------------------------------------------
PROMPT
PROMPT Creating view pe_remote_ranking_vw...

CREATE OR REPLACE VIEW pe_remote_ranking_vw AS
SELECT pr.id report_id,
       pf1.field_name dimensionfieldname,
       pe1.entity_name dimensionEntityName,
       pf2.field_name rankfieldname,
       pe2.entity_name rankEntityName,
       prs.ordering,
       prs.range_min,
       prs.range_max,
       prs.frequency_id
  FROM pm_report pr,
       pe_ranking prs,
       pe_mv_field pf1,
       pe_mv_entity pe1,
       pe_mv_field pf2,
       pe_mv_entity pe2
 WHERE pr.pe_reportspecid = prs.reportspec_id
   AND prs.dim_mv_field_id = pf1.mv_field_id(+)
   AND pf1.mv_entity_id = pe1.mv_entity_id(+)
   AND prs.rank_mv_field_id = pf2.mv_field_id
   AND pf2.Mv_entity_id = pe2.mv_entity_id
   AND NOT ( prs.rank_mv_field_id IS NULL AND prs.dim_mv_field_id IS NULL );

show errors view pe_remote_ranking_vw;

-- ------------------------------------------
-- pe_remote_report_fnh_vw
-- -----------------------------------------------
PROMPT
PROMPT Creating view pe_remote_report_fnh_vw...

CREATE OR REPLACE VIEW pe_remote_report_fnh_vw AS
  SELECT rp.ID REPORT_ID,
          f.FIELD_NAME,
         fe.ENTITY_NAME,
         fnh.frequency_id,
         fnh.maximum,
         fnh.filter_count,
         fnh.factor
    FROM pm_report rp,
         pe_filternhigh fnh,
         pe_mv_field f,
         pe_mv_entity fe
    WHERE fnh.reportspec_id = rp.pe_reportspecid
      AND fnh.mv_field_id = f.mv_field_id
      AND f.mv_entity_id = fe.mv_entity_id
      AND fnh.mv_field_id IS NOT NULL;
  
show errors view pe_remote_report_fnh_vw;

-- -------------------------------------------------------
-- -------------------------------------------------------
PROMPT
PROMPT Creating view pe_remote_exp_vw...

CREATE OR REPLACE VIEW pe_remote_exp_vw AS
SELECT n.expression_id,
       n.node_id,
       n.OPERATOR,
       l.literal_value,
       l.literal_type,
       mvf.field_name,
       mve.entity_name,
       c.type_name field_type_name
  FROM pe_expression_node n,
       pe_expression_literal l,
       pe_mv_field mvf ,
       PE_MV_ENTITY mve,
       pe_column_type c
 WHERE mvf.mv_field_id ( + ) = n.mv_field_id
   AND mve.mv_entity_id (+) = mvf.mv_entity_id
   AND l.literal_id ( + ) = n.literal_id
   AND c.column_type_id (+)= mvf.column_type_id
 ORDER BY node_id;

show errors view pe_remote_exp_vw;

-- -------------------------------------------------------
-- -------------------------------------------------------
PROMPT
PROMPT Creating view pe_remote_field_grouping_vw...

CREATE OR REPLACE VIEW pe_remote_field_grouping_vw AS
SELECT pr.ID report_id,
       pr.folderID,
       pr.name report_name,
       pf.field_name mv_field_name,
       pe.entity_name mv_entity_name,
       pf.heading1,
       pf.heading2,
       pf.description,
       pf.is_dimension,
       grp.field_group_name,
       ct.type_name field_type,
       a.aggr_name,
       prg.ordinal
  FROM pm_report pr,
       pe_mv_field pf,
       pe_mv_entity pe,
       pe_remote_reportgrouping prg,
       pe_mv_field_group grp,
       pe_column_type ct,
       wmd_aggregator_base a
 WHERE pr.pe_reportspecid = prg.reportspec_id
   AND pf.mv_field_id = prg.mv_field_id
   AND pe.mv_entity_id = pf.mv_entity_id
   AND pf.aggr = a.aggr_id
   AND pf.column_type_id  = ct.column_type_id
   AND pf.field_group_id = grp.field_group_id ( + );

show errors view pe_remote_field_grouping_vw;

-- -------------------------------------------------------
-- -------------------------------------------------------
PROMPT
PROMPT Creating view pe_remote_reportspec_field_vw...

CREATE OR REPLACE VIEW pe_remote_reportspec_field_vw AS
SELECT pr.ID report_id,
       pr.folderID,
       pr.name report_name,
       pf.field_name mv_field_name,
       pe.entity_name mv_entity_name,
       NVL2(pu.datasource_id, pu.heading1, pf.heading1) heading1,
       NVL2(pu.datasource_id, pu.heading2, pf.heading2) heading2,
       NVL2(pu.datasource_id, pu.description, pf.description) description,
       pf.is_dimension,
       grp.field_group_name,
       ct.type_name field_type,
       a.aggr_name,
       pu.datasource_id,
       prf.ordinal
  FROM pm_report pr,
       pe_mv_field pf,
       pe_mv_entity pe,
       pe_mv_udc_field pu,
       pe_remote_reportfield prf,
       pe_remote_reportspec prs,
       pe_mv_field_group grp,
       pe_column_type ct,
       wmd_aggregator_base a
 WHERE pr.pe_reportspecid = prf.reportspec_id
   AND prs.reportspec_id = pr.pe_reportspecid
   AND pf.mv_field_id = prf.mv_field_id
   AND pe.mv_entity_id = pf.mv_entity_id
   AND NVL2(pu.datasource_id, pu.aggr, pf.aggr) = a.aggr_id
   AND NVL2(pu.datasource_id, pu.column_type_id, pf.column_type_id) = ct.column_type_id
   AND pf.field_group_id = grp.field_group_id ( + )
   AND pf.mv_field_id = pu.mv_field_id ( + )
   AND NVL(pu.datasource_id, prs.datasource_id) = prs.datasource_id;

show errors view pe_remote_reportspec_field_vw;

-- ------------------------------------------------------------------------
-- Collate a bunch of useful information needed to build a report into one 
-- view.
-- ------------------------------------------------------------------------
PROMPT
PROMPT Creating view pe_report_field_vw...

CREATE OR REPLACE VIEW pe_report_field_vw AS
SELECT tl.id task_id, f.entity_id, f.field_name, f.aggr, rf.ordinal, 
       mf.module_version_id, mf.numerator, mf.denominator, tbl.table_name,
       f.heading1,
       f.heading2,
       f.description
  FROM rg_tasklist tl, pe_reportfield rf, pe_field f, pe_mv_field_map mf,
       pe_table tbl
 WHERE rf.reportspec_id   = tl.pe_reportspecid
   AND f.field_id         = rf.pe_field_id
   AND mf.field_id        = rf.pe_field_id
   AND tbl.table_id       = mf.table_id
 ORDER BY rf.ordinal;

show errors view pe_report_field_vw;

-- ------------------------------------------------------------------------
-- This view provides the fields used for grouping
-- ------------------------------------------------------------------------
PROMPT
PROMPT Creating view pe_reportgrouping_vw...

CREATE OR REPLACE VIEW pe_reportgrouping_vw AS
SELECT tl.id task_id, f.entity_id, f.field_name, rg.ordinal, tbl.table_name,
       f.heading1, f.heading2
  FROM rg_tasklist tl, pe_reportgrouping rg, pe_dimension_field df,
       pe_field f, pe_table tbl
 WHERE rg.reportspec_id   = tl.pe_reportspecid
   AND  f.field_id        = rg.pe_field_id
   AND df.field_id        = rg.pe_field_id
   AND tbl.table_id       = df.table_id
 ORDER BY rg.ordinal;
  
show errors view pe_reportgrouping_vw;

-- ------------------------------------------------------------------------
-- This view provides the column numbers used for final ordering
-- ------------------------------------------------------------------------
PROMPT
PROMPT Creating view pe_reportordering_vw...

CREATE OR REPLACE VIEW pe_reportordering_vw AS
SELECT tl.id task_id, ro.pe_field_id field_id, ro.ordinal
  FROM rg_tasklist tl, pe_reportordering ro
 WHERE ro.reportspec_id   = tl.pe_reportspecid
 ORDER BY ro.ordinal;
  
show errors view pe_reportordering_vw;

-- ------------------------------------------------------------------------
-- This view allows us to determine the set of overlapping keys from two
-- entities. It therefore tells us how to join two entity tables together.
-- ------------------------------------------------------------------------
PROMPT
PROMPT Creating view pe_entity_key_overlap_vw...

CREATE OR REPLACE VIEW pe_entity_key_overlap_vw AS
SELECT DISTINCT af.entity_id a_entity_id, bf.entity_id b_entity_id, af.field_name
  FROM pe_dimension_field a,
       pe_dimension_field b,
       pe_field af,
       pe_field bf
 WHERE a.key_ordinal IS NOT NULL
   AND b.key_ordinal IS NOT NULL
   AND af.field_id = a.field_id
   AND bf.field_id = b.field_id
   AND af.field_name = bf.field_name
   AND af.entity_id != bf.entity_id;

show errors view pe_entity_key_overlap_vw;

-- ------------------------------------------------------------------------
-- Get the keys for all the entity tables involved in each report
-- ------------------------------------------------------------------------
PROMPT
PROMPT Creating view pe_reporttablekeys_vw...

CREATE OR REPLACE VIEW pe_reporttablekeys_vw AS
SELECT DISTINCT tl.id task_id, t.table_name, keyfield.field_name column_name, dimkey.key_ordinal
  FROM rg_tasklist tl, pe_reportgrouping rg,
       pe_dimension_field df, pe_table t,
       pe_dimension_field dimkey,
       pe_field keyfield
 WHERE tl.pe_reportspecid = rg.reportspec_id
   AND df.field_id = rg.pe_field_id
   AND  t.table_id = df.table_id
   AND dimkey.table_id = df.table_id
   AND keyfield.field_id = dimkey.field_id
UNION
SELECT DISTINCT tl.id task_id, t.table_name, keyfield.field_name column_name, dimkey.key_ordinal
  FROM rg_tasklist tl, pe_reportspec rs,
       pe_dimension_field df, pe_table t,
       pe_dimension_field dimkey,
       pe_field keyfield
 WHERE tl.pe_reportspecid = rs.reportspec_id
   AND keyfield.entity_id = rs.entity_id
   AND t.table_id = df.table_id
   AND dimkey.table_id = df.table_id
   AND keyfield.field_id = dimkey.field_id;
  
show errors view pe_reporttablekeys_vw;  

-- ------------------------------------------------------------------------
-- ------------------------------------------------------------------------
PROMPT
PROMPT Creating view pe_reportfiles_vw...

CREATE OR REPLACE VIEW pe_reportfiles_vw AS
SELECT tl.id task_id, j.job_id, rpt.id report_id, j.schedule_id, tf.filename, rpt.name report_name
  FROM rg_tasklist tl,
       active_job j,
       active_task t,
       task_filename tf,
       pm_report rpt
 WHERE t.task_id = tl.id
   AND tf.taskid = t.task_id
   AND t.job_id = j.job_id
   AND t.sched_task_fk = rpt.id;
    
show errors view pe_reportfiles_vw;

-- ------------------------------------------------------------------------
-- ------------------------------------------------------------------------
PROMPT
PROMPT Creating view pe_latestreport_vw...

CREATE OR REPLACE VIEW pe_latestreport_vw AS
SELECT task_id, schedule_id, filename, report_name 
  FROM (SELECT task_id, schedule_id, filename, report_name,
               RANK() OVER (PARTITION BY report_id ORDER BY task_id DESC) rank1
          FROM pe_reportfiles_vw) 
 WHERE rank1 < 2;

show errors view pe_latestreport_vw;

-- ------------------------------------------
-- pe_report_bh_vw
-- -----------------------------------------------
PROMPT
PROMPT Creating view pe_report_bh_vw...

CREATE OR REPLACE VIEW pe_report_bh_vw AS
SELECT rp.ID REPORT_ID,
       e.ENTITY_NAME,
       f.FIELD_NAME,
       fe.ENTITY_NAME field_entity_name,
       bh.frequency_id frequency_id,
       bh.percentile   percentile
  FROM pe_busyhour bh,
       pe_field f,
       pm_report rp,
       pe_entity e,
       pe_entity fe
 WHERE bh.FIELD_ID = f.FIELD_ID (+)
   AND bh.ENTITY_ID = e.ENTITY_ID
   AND bh.REPORTSPEC_ID = rp.PE_REPORTSPECID
   AND f.entity_id = fe.entity_id(+)
   AND bh.entity_id IS NOT NULL;

show errors view pe_report_bh_vw;

-- ------------------------------------------
-- pe_report_fnh_vw
-- -----------------------------------------------
PROMPT
PROMPT Creating view pe_report_fnh_vw...

CREATE OR REPLACE VIEW pe_report_fnh_vw AS
SELECT rp.ID REPORT_ID,
       f.FIELD_NAME,
       fe.ENTITY_NAME,
       fnh.frequency_id,
       fnh.maximum,
       fnh.filter_count,
       fnh.factor
  FROM pm_report rp,
       pe_filternhigh fnh,
       pe_field f,
       pe_entity fe
 WHERE fnh.reportspec_id = rp.pe_reportspecid
   AND fnh.field_id = f.field_id
   AND f.entity_id = fe.entity_id
   AND fnh.field_id IS NOT NULL;
  
show errors view pe_report_fnh_vw;

-- ---------------------------------------
-- pe_ranking_vw
-- ----------------------------------------
PROMPT
PROMPT Creating view pe_ranking_vw...

CREATE OR REPLACE VIEW pe_ranking_vw AS
SELECT pr.id report_id,
       pf1.field_name dimensionfieldname,
       pe1.entity_name dimensionEntityName,
       pf2.field_name rankfieldname,
       pe2.entity_name rankEntityName,
       prs.ordering,
       prs.range_max,
       prs.range_min,
       prs.frequency_id
  FROM pm_report pr,
       pe_ranking prs,
       pe_field pf1,
       pe_entity pe1,
       pe_field pf2,
       pe_entity pe2
 WHERE pr.pe_reportspecid = prs.reportspec_id
   AND prs.dim_field_id = pf1.field_id(+)
   AND pf1.entity_id = pe1.entity_id(+)
   AND prs.rank_field_id = pf2.field_id
   AND pf2.entity_id = pe2.entity_id
   AND NOT ( prs.rank_field_id IS NULL AND prs.dim_field_id IS NULL )
;
show errors view pe_ranking_vw;

-- ----------------------------------------------------------------
-- combines all fields and literals (remote and enterprise) for expression
-- ------------------------------------------------------------------
PROMPT
PROMPT Creating view pe_ent_remote_exp_vw...

CREATE OR REPLACE VIEW pe_ent_remote_exp_vw AS
SELECT   n.expression_id expression_id,
         n.node_id node_id,
         n.OPERATOR OPERATOR,
         l.literal_value literal_value,
         l.literal_type literal_type,
         NVL ( f.field_name,
               m.field_name ) field_name,
         NVL ( e.entity_name,
               v.entity_name ) entity_name,
         NVL ( c1.type_name,
               c2.type_name ) field_type_name
    FROM pe_expression_node n,
         pe_expression_literal l,
         pe_field f,
         pe_mv_field m,
         pe_entity e,
         pe_mv_entity v,
         pe_column_type c1,
         pe_column_type c2
   WHERE n.literal_id = l.literal_id ( + )
     AND n.pe_field_id = f.field_id ( + )
     AND n.mv_field_id = m.mv_field_id ( + )
     AND f.entity_id = e.entity_id ( + )
     AND m.mv_entity_id = v.mv_entity_id ( + )
     AND f.column_type_id = c1.column_type_id ( + )
     AND m.column_type_id = c2.column_type_id ( + )
;

show errors view pe_ent_remote_exp_vw;

-- ---------------------------------------
-- enterprise and remote expression by filter type(bh, traffic ...)
-- ------------------------------------------
PROMPT
PROMPT Creating view pe_ent_remote_exp_node_vw...

CREATE OR REPLACE VIEW pe_ent_remote_exp_node_vw AS
SELECT r.ID report_id,
       s.filter_expression_id,
       x1.node_id node_id,
       x1.OPERATOR OPERATOR,
       x1.literal_value literal_value,
       x1.literal_type literal_type,
       x1.field_name field_name,
       x1.entity_name entity_name,
       x1.field_type_name field_type_name,
       s.tf_filter_expression_id,
       x2.node_id tf_node_id,
       x2.OPERATOR tf_operator,
       x2.literal_value tf_literal_value,
       x2.literal_type tf_literal_type,
       x2.field_name tf_field_name,
       x2.entity_name tf_entity_name,
       x2.field_type_name tf_field_type_name,
       s.bh_filter_expression_id,
       x3.node_id bh_node_id,
       x3.OPERATOR bh_operator,
       x3.literal_value bh_literal_value,
       x3.literal_type bh_literal_type,
       x3.field_name bh_field_name,
       x3.entity_name bh_entity_name,
       x3.field_type_name bh_field_type_name
  FROM pm_report r,
       ( SELECT REPORTSPEC_ID,
                FILTER_EXPRESSION_ID FILTER_EXPRESSION_ID,
                NULL TF_FILTER_EXPRESSION_ID,
                NULL BH_FILTER_EXPRESSION_ID
           FROM pe_reportspec
          WHERE FILTER_EXPRESSION_ID IS NOT NULL
         UNION ALL 
         SELECT REPORTSPEC_ID,
                NULL FILTER_EXPRESSION_ID,
                TF_FILTER_EXPRESSION_ID TF_FILTER_EXPRESSION_ID,
                NULL BH_FILTER_EXPRESSION_ID
           FROM pe_reportspec
          WHERE TF_FILTER_EXPRESSION_ID IS NOT NULL
        UNION ALL 
        SELECT REPORTSPEC_ID,
               NULL FILTER_EXPRESSION_ID,
               NULL TF_FILTER_EXPRESSION_ID,
               BH_FILTER_EXPRESSION_ID BH_FILTER_EXPRESSION_ID
          FROM pe_reportspec
         WHERE BH_FILTER_EXPRESSION_ID IS NOT NULL ) s,
       pe_ent_remote_exp_vw x1,
       pe_ent_remote_exp_vw x2,
       pe_ent_remote_exp_vw x3
 WHERE r.PE_REPORTSPECID = s.REPORTSPEC_ID
   AND s.FILTER_EXPRESSION_ID = x1.EXPRESSION_ID ( + )
   AND s.TF_FILTER_EXPRESSION_ID = x2.EXPRESSION_ID ( + )
   AND s.BH_FILTER_EXPRESSION_ID = x3.EXPRESSION_ID ( + )
 ORDER BY r.ID,
          x1.node_id,
          x2.node_id,
          x3.node_id
;

show errors view pe_ent_remote_exp_node_vw;

-- --------------------------------------------
-- pe expression
-- ---------------------------------------------
PROMPT
PROMPT Creating view pe_exp_vw...

CREATE OR REPLACE VIEW pe_exp_vw AS  
SELECT n.expression_id,
       n.node_id,
       n.OPERATOR,
       l.literal_value,
       l.literal_type,
       f.field_name,
       e.entity_name,
       c.type_name field_type_name
  FROM pe_expression_node n,
       pe_expression_literal l,
       pe_field f,
       PE_ENTITY e,
       pe_column_type c
 WHERE f.field_id ( + ) = n.pe_field_id
   AND e.entity_id ( + ) = f.entity_id
   AND l.literal_id ( + ) = n.literal_id
   AND c.column_type_id (+)= f.column_type_id
 ORDER BY node_id
;

show errors view pe_exp_vw;

-- --------------------------------------------------------------------------
-- reportspec attributes for both web and enterprise report defs
-- this view also filters immediate snap shots of the report def, name='TMP-%'
-- --------------------------------------------------------------------------
PROMPT
PROMPT Creating view pe_ent_remote_reportspec_vw...

CREATE OR REPLACE VIEW pe_ent_remote_reportspec_vw AS
SELECT pr.id report_id,
       pr.folderId,
       pe_folder.fs_lookuppathbyfolderid ( nvl ( pr.folderId, 1 ) ) report_folder_path,
       pr.name report_name,
       pr.description,
       prs.report_type type,
       pu.name user_name,
       DECODE((SELECT value FROM wm_system_values_v WHERE name = 'UseFirstBHWhenEqual'), '1', 'Y', 'N') first_bh_equal,
       pd.delimiter,
       prrs.system_id,
       ds.datasource_name,
       pmve.entity_name mv_entity_name,
       pe.entity_name,
       pr.scenarioid
  FROM pm_report pr,
       pm_user pu,
       pm_destination pd,
       pe_remote_reportspec prrs,
       pe_reportspec prs,
       pe_datasource ds,
       pe_mv_entity pmve,
       pe_entity pe
 WHERE pu.id = pr.userid
   AND pr.destinationid = pd.id
   AND prrs.reportspec_id(+)=pr.pe_reportspecid
   AND prrs.datasource_id=ds.datasource_id(+)
   AND prrs.mv_entity_id=pmve.mv_entity_id(+)
   AND prs.reportspec_id(+)=pr.pe_reportspecid
   AND prs.entity_id=pe.entity_id(+)
   AND pr.name not like 'TMP-%';

show errors view pe_ent_remote_reportspec_vw;

--------------------------------------------------------
--  Pe report with reportspec info
--------------------------------------------------------
PROMPT
PROMPT Creating view pe_reportspec_vw...

CREATE OR REPLACE VIEW pe_reportspec_vw AS
SELECT pr.id report_id,
       pr.folderID,
       pr.name report_name,
       prs.reportspec_id,
       pr.dtscopeid,
       prs.filter_expression_id,
       pe.entity_name,
       wf.tag frequency_tag,
       pr.description,
       prs.report_type type,
       pd.FormatId,
       pd.toDisplay,
       pd.toprinter,
       pd.tofile,
       pd.toemail,
       pd.delimiter,
       pd.directory,
       pu.name user_name,
       DECODE((SELECT value FROM wm_system_values_v WHERE name = 'UseFirstBHWhenEqual'), '1', 'Y', 'N') first_bh_equal,
       prs.RESULTNAME report_result
  FROM pm_report pr,
       pe_entity pe,
       pe_reportspec prs,
       wm_frequency wf,
       pm_destination pd,
       pm_user pu,
       pe_remote_reportspec prrs
 WHERE pr.pe_reportspecid=prs.reportspec_id
   AND pr.userid=pu.id
   AND prs.entity_id=pe.entity_id(+)
   AND prs.frequency_id=wf.frequency_id
   AND pr.destinationid=pd.id
   AND prs.reportspec_id=prrs.reportspec_id(+)
   AND prrs.reportspec_id is NULL;

show errors view pe_reportspec_vw;

--------------------------------------------------------
--  Pe report with reportspec fields info
--------------------------------------------------------
PROMPT
PROMPT Creating view pe_reportspec_fields_vw...

CREATE OR REPLACE VIEW pe_reportspec_fields_vw AS
SELECT pr.id report_id,
       pr.folderID, 
       pr.name report_name,
       pf.field_name, 
       pe.entity_name,
       pf.heading1,
       pf.heading2,
       pf.description,
       DECODE ( df.local_data,
                NULL,
                'N',
                'Y' ) is_dimension,
       nvl2(pu.udc_source, 'UDC', 'Peg Count') field_group_name,
       ct.type_name field_type,
       a.aggr_name,
       prf.ordinal
  FROM pm_report pr, 
       pe_reportfield prf,
       pe_field pf,
       pe_entity pe,
       pe_udc_field pu,
       pe_dimension_field df,
       pe_column_type ct,
       wmd_aggregator_base a
 WHERE pr.pe_reportspecid = prf.reportspec_id
   AND pf.field_id = prf.pe_field_id
   AND pf.entity_id = pe.entity_id
   AND pf.column_type_id = ct.column_type_id
   AND pf.aggr = a.aggr_id
   AND pf.field_id = df.field_id ( + )
   AND pf.field_id = pu.field_id ( + );

show errors view pe_reportspec_fields_vw;

--------------------------------------------------------
--  Pe report with reportspec groupby info
--------------------------------------------------------
-- if all the groupby times are N, then no groupby time is set
PROMPT
PROMPT Creating view pe_groupby_period_vw...

-- Core Merge, BLavin 23/3/2009
-- A new column for 10min Group By has been added to the pe_reportSpec table
-- Need to update the view to return it
  
CREATE OR REPLACE VIEW pe_groupby_period_vw AS
SELECT pr.id report_id,pr.folderID, pr.name report_name,
       prs.time_first timefirst, prs.groupby_year year,
       prs.groupby_month month, prs.groupby_quarter quarter,
       prs.groupby_week week, prs.groupby_day day,
       prs.groupby_hour hour,
       prs.groupby_30 thirty, 
       prs.groupby_15 fifteen,
       prs.groupby_10 ten,
       prs.groupby_5 five
  FROM pm_report pr,pe_reportspec prs
 WHERE pr.pe_reportspecid=prs.reportspec_id
   AND NOT (prs.groupby_year = 'N' AND prs.groupby_month = 'N' 
            AND prs.groupby_quarter = 'N' AND prs.groupby_week = 'N' 
            AND prs.groupby_day = 'N' AND prs.groupby_hour = 'N'
            AND prs.groupby_30 = 'N'  AND prs.groupby_15 = 'N'
            AND prs.groupby_10 = 'N' AND prs.groupby_5 = 'N') 
;
-- Core Merge - end change 

show errors view pe_groupby_period_vw;


--------------------------------------------------------
--  Pe report with reportspec grouping fields info
--------------------------------------------------------
PROMPT
PROMPT Creating view pe_groupby_field_vw...

CREATE OR REPLACE VIEW pe_groupby_field_vw AS
SELECT pr.id report_id, pr.folderID, pr.name report_name,
       pf.field_name fieldname, 
       pf.entity_name entityname,
       pf.heading1,
       pf.heading2,
       pf.description,
       pf.is_dimension,
       pf.field_group_name,
       pf.field_type,
       pf.aggr_name,
       prg.ordinal
  FROM pm_report pr, 
       pe_reportgrouping prg,
       pe_field_vw pf
 WHERE pr.pe_reportspecid=prg.reportspec_id
   AND prg.pe_field_id=pf.field_id;

show errors view pe_groupby_field_vw;

--------------------------------------------------------
--  Pe report with reportspec ordering fields info
--------------------------------------------------------
PROMPT
PROMPT Creating view pe_orderby_vw...

CREATE OR REPLACE VIEW pe_orderby_vw AS
SELECT pr.id report_id, pr.folderID, pr.name report_name,
       pf.field_name fieldname, 
       pe.entity_name entityname, 
       pro.ordinal, pro.direction
  FROM pm_report pr, 
       pe_entity pe,
       pe_reportordering pro,
       pe_reportspec prs, pe_field pf
 WHERE pr.pe_reportspecid=pro.reportspec_id
   AND pr.pe_reportspecid=prs.reportspec_id
   AND pf.entity_id = pe.entity_id (+) 
   AND pro.pe_field_id=pf.field_id ;

show errors view pe_orderby_vw;

--------------------------------------------------------
--  Pe dtscope info for reports/schedules
--------------------------------------------------------
PROMPT
PROMPT Creating view pe_dtscope_vw...

CREATE OR REPLACE VIEW pe_dtscope_vw AS
SELECT pr.id report_id, s.id schedule_id,
       pdts.id, pdts.scopetype, pdts.startofweek, pdts.timeunit, pdts.dtperiod,
       pdts.howmanyunits, pdts.extendrange,
       pdts.quickrange, pdts.includecurrent,
       pdts.samehourseachday, pdts.includeholidays,
       pdts.weekendsonly, pdts.sundays, pdts.mondays,
       pdts.tuesdays, pdts.wednesdays, pdts.thursdays,
       pdts.fridays, pdts.saturdays, pdts.includeweekends,
       pdts.holidaysonly
  FROM pm_report pr,
       pm_dtscope pdts,
       rg_schedule_view s
 WHERE pdts.id = pr.dtscopeid (+)
   AND pdts.id = s.ovrdtscopeid (+) 
;
show errors view pe_dtscope_vw;

--------------------------------------------------------
--  Pe calendar info for reports/schedules
--------------------------------------------------------
PROMPT
PROMPT Creating view pe_calendar_vw...

CREATE OR REPLACE VIEW pe_calendar_vw AS
SELECT pr.id report_id, s.id schedule_id,
       pc.calendardate, pc.firsthour, pc.lasthour,
       pc.firstseconds, pc.lastseconds
  FROM pm_report pr,
       pm_calendar pc,
       rg_schedule_view s
 WHERE pc.DTSCOPEID = pr.dtscopeid (+)
   AND pc.DTSCOPEID = s.ovrdtscopeid (+)
;
show errors view pe_calendar_vw;

--------------------------------------------------------
--  Pe report schedule info
--------------------------------------------------------
PROMPT
PROMPT Creating view pe_report_schedule_vw...

CREATE OR REPLACE VIEW pe_report_schedule_vw AS
SELECT pr.ID report_id,
       pr.name report_name,
       pe_folder.fs_lookuppathbyfolderid( nvl ( pr.folderid, 1 ) ) report_folder_path,
       rgsv.folderID,
       pe_folder.fs_lookuppathbyfolderid( rgsv.folderID ) schedule_folder_path,
       rgsv.ID schedule_id,
       rgsv.name schedule_name,
       rgsv.periodicity,
       rgsv.frequency,
       pu.name userName
  FROM rg_schedule_view rgsv,
       job_group_item jgi,
       pm_report pr,
       pm_user pu,
       pe_reportspec rs
 WHERE rgsv.rptgrpid = jgi.group_id
   AND document_id = pr.ID
   AND pu.ID = rgsv.userid
   AND pr.pe_reportspecid = rs.reportspec_id(+)
   AND (rgsv.CLEANUP_TIME > sysdate
   OR   rgsv.CLEANUP_TIME is null);

show errors view pe_report_schedule_vw;

--------------------------------------------------------
--  Pe schedule info
--------------------------------------------------------
PROMPT
PROMPT Creating view pe_schedule_vw...

CREATE OR REPLACE VIEW pe_schedule_vw AS
SELECT rgsv.folderID,
       pe_folder.fs_lookuppathbyfolderid( rgsv.folderID ) schedule_folder_path,
       rgsv.ID schedule_id,
       rgsv.firstdatetime,
       nvl(rgsv.finaldatetime, sysdate + 365 * 19) finaldatetime,
       rgsv.scheduledtime,
       rgsv.tzregion,
       rgsv.whichmonthdate,
       rgsv.whichweek,
       rgsv.whichweekday,
       rgsv.periodicity,
       rgsv.frequency,
       rgsv.scheduleactive,
       rgsv.includemondays,
       rgsv.includetuesdays,
       rgsv.includewednesdays,
       rgsv.includethursdays,
       rgsv.includefridays,
       rgsv.includesaturdays,
       rgsv.includesundays,
       rgsv.includeholidays,
       rgsv.includedayafterhol,
       pu.name userName,
       rgsv.name schedule_name,
       rgsv.description,
       rgsv.runmode,
       rgsv.retrievemode,
       rgsv.auto_organize,
       rgsv.rptgrpid,
       rgsv.ovrdtscopeid,
       rgsv.pe_resultfolder result_folderid,
       pe_folder.fs_lookuppathbyfolderid( rgsv.pe_resultfolder ) result_path,
       se.user_mail_address, 
       se.file_format, 
       se.email_notif_enabled, 
       se.autodownload_enabled, 
       se.destination_path
  FROM rg_schedule_view rgsv,
       pm_user pu,
       pe_schedule_extension se
 WHERE pu.ID = rgsv.userid
   AND rgsv.ID = se.rg_schedule_id (+)
   AND (rgsv.CLEANUP_TIME > sysdate
   OR   rgsv.CLEANUP_TIME is null);

show errors view pe_schedule_vw;

--------------------------------------------------------
-- Remote report spec view
--------------------------------------------------------
PROMPT
PROMPT Creating view pe_remote_reportspec_vw...

CREATE OR REPLACE VIEW pe_remote_reportspec_vw AS
 SELECT pr.id report_id,pr.folderID, pr.name report_name,
        prs.reportspec_id,
        rrs.system_id,
        ds.datasource_name,
        prs.filter_expression_id,
        pe.entity_name,
        wf.tag frequency_tag, pr.description,
        prs.report_type type, pd.FormatId,
        pd.toDisplay, pd.toprinter, pd.tofile,
        pd.toemail, pd.delimiter, pd.directory,
        pu.name user_name,
        (SELECT value FROM wm_system_values_v WHERE name = 'UseFirstBHWhenEqual') first_bh_equal,
        prs.RESULTNAME report_result,
        pr.scenarioid
   FROM pm_report pr,
        pe_mv_entity pe,
        pe_reportspec prs,
        wm_frequency wf,
        pm_destination pd,
        pm_user pu,
        pe_remote_reportspec rrs,
        pe_datasource ds
  WHERE pr.pe_reportspecid=rrs.reportspec_id
    AND ds.datasource_id = rrs.datasource_id
    AND pr.pe_reportspecid=prs.reportspec_id
    AND pr.userid=pu.id
    AND rrs.mv_entity_id = pe.mv_entity_id
    AND prs.frequency_id=wf.frequency_id
    AND pr.destinationid=pd.id ;

show errors view pe_remote_reportspec_vw;

--------------------------------------------------------
-- The PWEB status monitor code should select from this view rather than
-- try to do the join itself.
PROMPT
PROMPT Creating view pe_task_status_v...

CREATE OR REPLACE VIEW pe_task_status_v AS
SELECT v.task_Id,
       v.job_Id,
       v.report_Name,
       nvl2(ds.datasource_name, 'Web', 'Enterprise') report_Type,
       v.owner,
       v.job_Scheduled_Start,
       v.task_started,
       v.task_ended,
       v.status_Word,
       v.status_Message,
       nvl(ds.datasource_name, 'Enterprise') datasource_name
  FROM report_status_v v,
       rg_tasklist tl,
       pe_remote_reportspec rs,
       pe_datasource ds
 WHERE tl.id = v.task_id
   AND rs.reportspec_id (+)= tl.pe_reportspecid
   AND ds.datasource_id (+)= rs.datasource_id
   AND tl.PE_REPORTSPECID IS NOT NULL
 ORDER BY v.task_id;

show errors view pe_task_status_v;

--------------------------------------------------------
-- when importing docs check if doc already exist on system and its depencies are
-- there
PROMPT
PROMPT Creating view pe_import_doc_depend_vw...

CREATE OR REPLACE VIEW pe_import_doc_depend_vw AS
SELECT d.name document_name,
       d.document_fk, 
       t.document_type_name,
       pe_folder.FS_LOOKUPFOLDERPATH(
           DECODE( t.document_type_name,
                   'Folder',   f.folderid,
                   'Schedule', s.folderid,
                   'Report',   r.folderid,
                   'Report Group', g.folderid,
                   NULL )
                                     ) folder_name
  FROM pm_document      d,
       pm_document_type t,
       pm_folder        f,
       rg_schedule_view s,
       pm_report        r,
       job_group        g
 WHERE d.document_type_id = t.document_type_id
   AND t.document_type_name IN ( 'Folder', 'Report', 'Schedule', 'Report Group' )
   AND d.document_fk = f.id(+)
   AND d.document_fk = s.id(+)
   AND d.document_fk = r.id(+)
   AND d.document_fk = g.id(+)
;
show errors view pe_import_doc_depend_vw;

--------------------------------------------------------
--  Pe reportgroup view
--------------------------------------------------------
PROMPT
PROMPT Creating view pe_reportgroup_vw...

CREATE OR REPLACE VIEW pe_reportgroup_vw AS
SELECT g.id,
       pe_folder.fs_lookupPathByFolderId(g.folderid) path,
       g.folderid,
       g.name,
       u.name user_name,
       g.description,
       g.changed,
       g.group_type
  FROM job_group g, pm_user u
 WHERE g.userid = u.id;

show errors view pe_reportgroup_vw;

--------------------------------------------------------
-- PE reportgroup report view
--------------------------------------------------------
PROMPT
PROMPT Creating view pe_reportgroup_report_vw...

CREATE OR REPLACE VIEW pe_reportgroup_report_vw AS
SELECT i.group_id,
       i.ordinal,
       r.id,
       pe_folder.FS_LookupPathbyFolderID(r.folderid) path,
       r.name,
       u.name user_name,
       r.description,
       r.changed
  FROM job_group_item i, pm_report r, pm_user u
 WHERE i.document_id = r.id
   AND r.userid = u.id;
  
show errors view pe_reportgroup_report_vw;

-- ----------------------------------------------------------------------------
--
-- Local Variables:
-- mode: pls
-- End:
