-- ------------------------------------------------------------------------
--     COPYRIGHT WatchMark Corp 2003
-- *** (#) ./pweb/vendor/EnterpriseTrafficCache/upgradeViewsPatch.sql BL_core_schema_8.0.7_8.0.7.4.02_20100413  064938
-- *** (#) 
-- ------------------------------------------------------------------------


-- default permissions for all documents
CREATE OR REPLACE VIEW pm_default_permission_vw
AS
SELECT d.document_id,
       t.document_type_name, 
       d.name, 
       g.group_name default_group_name, 
       d.user_read default_user_read, 
       d.user_write default_user_write, 
       d.group_read default_group_read, 
       d.group_write default_group_write
FROM pm_document_type t, 
     pm_document d, 
     pm_group g
WHERE t.document_type_id = d.document_type_id
AND g.group_id = d.group_id
;

-- group ACL permissions for all documents
CREATE OR REPLACE VIEW pm_group_acl_vw
AS
SELECT g.doc_id document_id, 
       g.read group_read, 
       g.write group_write, 
       pg.group_name
FROM   pm_group_acl g, 
       pm_group pg
WHERE g.group_id = pg.group_id
;

-- user ACL permission for all documents
CREATE OR REPLACE VIEW pm_user_acl_vw
AS
SELECT u.doc_id document_id, 
       pu.name user_name, 
       u.read user_read, 
       u.write user_write 
FROM  pm_user_acl u, 
      pm_user pu
WHERE u.user_id = pu.id
;


-- report results and default permissions 
CREATE OR REPLACE VIEW pe_report_results_vw
AS
SELECT wm_client.get_folder_path ( nvl ( f.document_fk , 1 ) ) result_folder,
       d.name result_name,
       r.focal_entity_name,
       r.size_in_bytes,
       u.name user_name,
       p.filename,
       ds.datasource_name,
       r.job_time,
       rp.name local_report_name,
       wm_client.get_folder_path ( nvl ( rp.folderid, 1 ) ) local_report_folder
FROM   pm_document d,
       pe_report_result r,
       pm_document f,
       pm_document_type dt,
       pm_file p,
       pm_user u,
       pe_datasource ds,
       pm_report rp
WHERE d.document_fk = r.report_result_id
AND f.document_id = d.parent_doc_id
AND d.document_type_id = dt.document_type_id
AND r.file_id = p.file_id
AND dt.document_type_name = 'Report Result'
AND d.user_id = u.ID
AND r.datasource_id = ds.datasource_id
AND rp.ID = r.report_id
;

-- folder docs for import/export tool
CREATE OR REPLACE VIEW pm_folder_vw
AS
SELECT wm_client.get_folder_path(nvl(f.id,  1)) folder_path,
       f.name, 
       u.name user_name, 
       f.description
FROM   pm_folder f, pm_user u
WHERE  f.userid = u.id
AND u.name != 'system'
;


CREATE OR REPLACE VIEW pe_report_schedule_vw AS
SELECT pr.ID report_id,
       pr.name report_name,
       wm_client.get_folder_path ( nvl ( pr.folderid, 1 ) ) report_folder_path,
       rgsv.folderID,
       wm_client.get_folder_path ( nvl ( rgsv.folderID, 1 ) ) schedule_folder_path,
       rgsv.ID schedule_id,
       rs.FOLDER_ID result_folder_id,
       rs.RESULTNAME,
       rgsv.firstdatetime,
       rgsv.finaldatetime,
       rgsv.whichmonthdate,
       rgsv.whichweek,
       rgsv.whichweekday,
       rgsv.periodicity,
       rgsv.frequency,
       rgsv.includemondays,
       rgsv.includetuesdays,
       rgsv.includewednesdays,
       rgsv.includethursdays,
       rgsv.includefridays,
       rgsv.includesaturdays,
       rgsv.includesundays,
       rgsv.includeholidays,
       rgsv.includedayafterhol,
       pu.name userName,
       rgsv.name schedule_name,
       rgsv.description,
       rgsv.runmode,
       rgsv.retrievemode
  FROM rg_schedule_view rgsv,
       job_group jg,
       job_group_item jgi,
       pm_report pr,
       pm_user pu,
       pe_reportspec rs
 WHERE rgsv.rptgrpid = jg.ID
   AND jg.ID = jgi.group_id
   AND document_id = pr.ID
   AND pu.ID = pr.userid
   AND pr.pe_reportspecid = rs.reportspec_id(+)
   AND (rgsv.CLEANUP_TIME > sysdate
   OR   rgsv.CLEANUP_TIME is null)
;
