-- ------------------------------------------------------------------------
-- @(#) wb_preferencesSchema.sql 1.13.0 04/04/09 14:00:40
-- @(#) 
--
-- Web Preferences Schema
--
-- Jimmy Ren, 04/04/09
--
-- ------------------------------------------------------------------------


CREATE TABLE WB_PREFERENCES 
(
  User_Id                         INTEGER NOT NULL,     -- Enterprise or LDAP user Id assigend when user logged in
  Def_Page_4General               VARCHAR2(15),         -- Default page for General
  Def_Page_4MyProspect            VARCHAR2(20),         -- Default page for MyProspect
  Show_MyProspect                 CHAR(1),              -- 'Y/N' value only
  Refresh_Frenquency              VARCHAR2(10),         -- 'never/15/30/45' minutes
  Def_Save_Loc_4MyProspect        VARCHAR2(10),         -- Default page save location for MyProspect
  Favorite_Folder                 VARCHAR2(10),         -- Favorite page folder for MyProspect
  Favorite_DocId                  VARCHAR2(10),         -- Favorite page doc id for MyProspect
  Def_Page_4Reporting             VARCHAR2(20),         -- Default page for Reporting
  Enable_Dynamic_Charting         CHAR(1),              -- 'Y/N' value only
  Output_ViewType                 VARCHAR2(8) NOT NULL, -- 'Raw Data/Charting' value only
  Output_DataType                 VARCHAR2(5) NOT NULL, -- 'HTML/ASCII/XML' value only
  Def_Rep_Def_Save_Loc            VARCHAR2(10),         -- Default Report definition save location
  Def_Report_Save_Loc             VARCHAR2(10),         -- Default Report save location
  Def_Sch_Def_Save_Loc            VARCHAR2(10),         -- Default Schedule definition save location
  Def_Schedule_Save_Loc           VARCHAR2(10),         -- Default Schedule save location
  Auto_Organize_Rpt_Dest          VARCHAR2(255),        -- Auto-organize reporting destination
  Def_Page_4Browse                VARCHAR2(20),         -- Default page for Browse
  File_Read_Priviledge_4Group     CHAR(1),              -- 'Y/N' value only
  File_Write_Priviledge_4Group    CHAR(1),              -- 'Y/N' value only
  File_Execute_Priviledge_4Group  CHAR(1),              -- 'Y/N' value only
  File_Read_Priviledge_4World     CHAR(1),              -- 'Y/N' value only
  File_Write_Priviledge_4World    CHAR(1),              -- 'Y/N' value only
  File_Execute_Priviledge_4World  CHAR(1),              -- 'Y/N' value only
  Def_Page_4Monitor               VARCHAR2(15),         -- Default page for Monitor
  Max_Number_Per_Page             INTEGER,              -- Number of records diplayed on one page
  Report_Name_CaseSensitive       CHAR(1),              -- 'Y/N' value only
  Sorting_CaseSensitive           CHAR(1),              -- 'Y/N' value only
  sched_auto_organize             VARCHAR2(256),        -- scheduled report result auto-organize string
  immed_auto_organize             VARCHAR2(256),        -- immediate report result auto-organize string
  RAD_Folder                      VARCHAR2(20),
  RAD_Backload                    CHAR(1) DEFAULT 'N',
  RAD_Auto_Organize               VARCHAR2(256),
  Default_Rollup_Level            VARCHAR2(6) DEFAULT 'Bottom', -- Initialize rollup level: Top/Bottom
  Chart_Background_Color          VARCHAR2(10),         -- Chart background color
  Max_Number_Per_Page4RV          INTEGER DEFAULT 24,   -- Number of lines displayed on one page
  Number_Of_Decimals              INTEGER DEFAULT 2,    -- Number of decimals
  DA_Max_Per_Page                 INTEGER DEFAULT 20,   -- Data Availability max rows per page
  Default_Language                 VARCHAR2(40),        -- Menu and Report Langauge
  Attribute_Preference             VARCHAR2(100),
  Attribute_Preference_Language    VARCHAR2(40),
 --
  -- primary key
  --
    CONSTRAINT PK_WB_PREFERENCES PRIMARY KEY (User_Id),
  --
  -- Constraint ensures that only these values are allowed.
  --
    CONSTRAINT WB_yes_no_value_ck
      CHECK ( ( Show_MyProspect IN ( 'Y', 'N') ) AND
              ( Enable_Dynamic_Charting IN ( 'Y', 'N') ) AND
              ( File_Read_Priviledge_4Group IN ( 'Y', 'N') ) AND
              ( File_Write_Priviledge_4Group IN ( 'Y', 'N') ) AND
              ( File_Execute_Priviledge_4Group IN ( 'Y', 'N') ) AND
              ( File_Read_Priviledge_4World IN ( 'Y', 'N') ) AND
              ( File_Write_Priviledge_4World IN ( 'Y', 'N') ) AND
              ( File_Execute_Priviledge_4World IN ( 'Y', 'N') ) AND
              ( Report_Name_CaseSensitive IN ( 'Y', 'N') ) AND
              ( Sorting_CaseSensitive IN ( 'Y', 'N') ) AND
              ( RAD_Backload IN ( 'Y', 'N') ) ),
  --
  -- Constraint ensures that only these values are allowed for Output_ViewType.
  --
    CONSTRAINT WB_Output_ViewType_ck
      CHECK (  Output_ViewType IN ( 'Raw Data', 'Charting' ) ),
  --
  -- Constraint ensures that only these values are allowed for Output_DataType.
  --
    CONSTRAINT WB_Output_DataType_ck
      CHECK ( Output_DataType IN ( 'HTML', 'ASCII', 'XML' ) )
)
TABLESPACE wm_client;



CREATE TABLE WB_MON_DEFAULT 
(
  Id                     INTEGER NOT NULL,     -- Primary key
  User_Id                INTEGER NOT NULL,     -- Enterprise or LDAP user Id assigend when user logged in
  Monitor_Type           VARCHAR2(8) NOT NULL, -- 'jobs/tasks/treeview' value only
  Report_Name_Match_Str  VARCHAR2(30),         -- Report name match string, for filtering
  Remote_UserId          INTEGER,              -- UserId on remote server or enterprise server, for filtering
  Remote_ServerId        INTEGER,              -- Remote server or enterprise server id, for filtering
  Status_Id              INTEGER,              -- Report status id, for filtering
  Type_Id                INTEGER,              -- Report or Job type id, for filtering
  Date_Range_Prefix      VARCHAR2(10) NOT NULL,-- 'older than/in last' value only
  Date_Range_Num         INTEGER,              -- Number used to calculate a specific date
  Date_Unit_Type         VARCHAR2(8) NOT NULL, -- 'Time/hour(s)/day(s)/week(s)/month(s)' value only
  Advanced_Search	 CHAR(1),              -- 'Y/N' value only
  Set_As_Default	 CHAR(1),              -- 'Y/N' value only
  Sorting_Field          VARCHAR2(20),         -- Sorting Field
  Ascending_Sorting	 CHAR(1),              -- 'Y/N' value only
  --  
  -- Primary key
  --
    CONSTRAINT PK_WB_MON_DEFAULT PRIMARY KEY (Id),
  --
  -- Constraints required to prevent removing folder or user
  --
    CONSTRAINT FK_WB_MON_DEFAULT_UserId
		FOREIGN KEY(User_Id)            REFERENCES WB_PREFERENCES(User_Id),
  --
  -- Constraint ensures that only these values are allowed.
  --
    CONSTRAINT WB_Set_As_Default_ck
      CHECK ( ( Set_As_Default IN ( 'Y', 'N') ) AND
              ( Advanced_Search IN ( 'Y', 'N') ) AND 
              ( Ascending_Sorting IN ( 'Y', 'N') ) ),
  --
  -- Constraint ensures that only these values are allowed for Monitor_Type.
  --
    CONSTRAINT WB_Monitor_Type_ck
      CHECK ( ( Monitor_Type IN ( 'jobs', 'tasks', 'treeview' ) ) ),
  --
  -- Constraint ensures that only these values are allowed for Date_Range_Prefix.
  --
    CONSTRAINT WB_Date_Range_Prefix_ck
      CHECK ( ( Date_Range_Prefix IN ( 'older than', 'in last' ) ) ),
  --
  -- Constraint ensures that only these values are allowed for Date_Unit_Type.
  --
    CONSTRAINT WB_Date_Unit_Type_ck
      CHECK ( ( Date_Unit_Type IN ( 'Time', 'hour(s)', 'day(s)', 'week(s)', 'month(s)' ) ) )
) 
TABLESPACE wm_client;

--
-- sequence for WB_MON_DEFAULT.Id
--
CREATE SEQUENCE SQ_WB_MON_DEFAULT
    START WITH 1
    INCREMENT BY 1
    NOMAXVALUE
    NOCYCLE
;

-- ----------------------------------------------------------------------------
--
-- Local Variables:
-- mode: pls
-- End:
