#!/bin/ksh
#-----------------------------------------------------------------------
# (#) ./base/tools/wm_consumer/scripts/load_archive.sh BL_core_schema_8.0.7_8.0.7.4.02_20100413  064938
# (#) 
# Copyright 2003 WatchMark Corp.
#-----------------------------------------------------------------------
#

MYNAME=$(basename $0)
MYDIR=$(pwd)
MYTSTAMP=`date "+%Y\
%m\
%d\
%H\
%M\
%S"`


INDIR="in"
OKDIR="ok"
FAILDIR="fail"
PRCDIR="processed"

#----------------------------------------------------------------------
error_out()
#----------------------------------------------------------------------
{
   echo "$MYNAME: (ERROR): $1" >&2
   exit ${2:-9}
}

#----------------------------------------------------------------------
warn()
#----------------------------------------------------------------------
{
   echo "$MYNAME: (Warning): $1" >&2
}

#----------------------------------------------------------------------
check_dir()
#----------------------------------------------------------------------
{
   if [ ! -d $1 ]
   then
      mkdir $1
      if [ $? -ne 0 ]
      then
         error_out "Cannot create $1"
      fi
   fi
}

#----------------------------------------------------------------------
check_script()
#----------------------------------------------------------------------
{
   if [ ! -f $1 ]
   then
      error_out "Cannot find $1"
   elif [ ! -x $1 ]
   then
      error_out "Cannot execute $1"
   fi
}

#----------------------------------------------------------------------
get_fullpath()
#----------------------------------------------------------------------
{
   CURDIR=`pwd`
   cd $1
   FP=`pwd`
   cd $CURDIR
   echo $FP
}

#----------------------------------------------------------------------
update_archive()
#----------------------------------------------------------------------
# $1 = archive; $2 = set-list file
{

   if [ -f $2 ]
   then

      if [ -f $1 ]
      then
         unzipped=$(echo $1|sed "s/\.gz$//g")
         gunzip $1
         [ $? -eq 0 ] && gtar uf $unzipped $(cat $2)
         [ $? -eq 0 ] && gzip $unzipped
      else
         gtar cfz $1 $(cat $2)
      fi
   
      if [ $? -eq 0 ]
      then
         rm $(cat $2)
         rm $2
      fi

   fi

}



#===========================================================================
# M A I N
#===========================================================================
#

#----------------------------------------------------------------------
# Test tarball
#----------------------------------------------------------------------
if [ $# -lt 1 ]
then
   error_out "Usage: $MYNAME <log-archive>"
fi

ARCNAME=$(basename $1);
ARCDIR=`get_fullpath $(dirname $1)`

if [ ! -f $ARCDIR/$ARCNAME ]
then
   error_out "Cannot find archive $ARCDIR/$ARCNAME"
fi

#----------------------------------------------------------------------
# get SET TSTAMP
#----------------------------------------------------------------------
SETTSTAMP=$(echo $ARCNAME| cut -f1 -d"." | sed "s/logs-//g")
### ADD CHECK HERE!

#----------------------------------------------------------------------
# Test scripts
#----------------------------------------------------------------------
SCRIPTDIR=`get_fullpath $(dirname $0)`

SET_LOADER="$SCRIPTDIR/load_set.sh"
ENV_TESTER="$SCRIPTDIR/test_env.pl"

check_script $SET_LOADER
check_script $ENV_TESTER

#----------------------------------------------------------------------
# Test Environment
#----------------------------------------------------------------------
eval $ENV_TESTER
if [ $? -ne 0 ]
then
   error_out "The environment is not properly set."
fi

#----------------------------------------------------------------------
# Test if the gnu tools are available
#----------------------------------------------------------------------
gtar --version > /dev/null 2>&1
[ $? -eq 0 ] && gzip   --version > /dev/null 2>&1
[ $? -eq 0 ] && gunzip --version > /dev/null 2>&1
if [ $? -ne 0 ]
then
   echo "$MYNAME: Cannot find the gtar/gzip/gunzip utilities"
   exit 2
fi

#----------------------------------------------------------------------
# test required files and driectories
#----------------------------------------------------------------------
SITEDIR=`get_fullpath $ARCDIR/..`

INDIR=$SITEDIR/$INDIR
OKDIR=$SITEDIR/$OKDIR
FAILDIR=$SITEDIR/$FAILDIR

check_dir $INDIR
check_dir $OKDIR
check_dir $FAILDIR

PRCDIR=$SITEDIR/$PRCDIR
check_dir $PRCDIR

#----------------------------------------------------------------------
# Extract to "in"
#----------------------------------------------------------------------
cd $INDIR

gtar xfvz $ARCDIR/$ARCNAME > set.${SETTSTAMP}
if [ $? -ne 0 ]
then
   error_out "Failed to extract $ARCNAME"
fi

#----------------------------------------------------------------------
# Process List
#----------------------------------------------------------------------
eval $SET_LOADER set.${SETTSTAMP}

#----------------------------------------------------------------------
# Move to "processed"
#----------------------------------------------------------------------
FIRSTNAME=$(echo $ARCNAME | sed "s/\.tar\.gz$//g")
if [ -f ${PRCDIR}/${FIRSTNAME}.tar.gz ]
then
   mv ${ARCDIR}/${ARCNAME} ${PRCDIR}/${FIRSTNAME}.${$}.tar.gz
else
   mv ${ARCDIR}/${ARCNAME} ${PRCDIR}/${FIRSTNAME}.tar.gz
fi
rm $INDIR/set.${SETTSTAMP}

#----------------------------------------------------------------------
# Archive results
#----------------------------------------------------------------------
cd $OKDIR
update_archive logs-${SETTSTAMP}.ok.tar.gz set.${SETTSTAMP}.ok

cd $FAILDIR
update_archive logs-${SETTSTAMP}.fail.tar.gz set.${SETTSTAMP}.fail

