#---------------------------------------------------------
# (#) ./base/tools/wm_consumer/scripts/modules/wmc_loginfo.pm BL_core_schema_8.0.7_8.0.7.4.02_20100413  064938
# (#) 
# COPYRIGHT 2003 WatchMark Corp.
#---------------------------------------------------------
#
package wmc_loginfo;

use wmc_general;
use DBI;

my $NOTFOUND_STRING = '***NOT FOUND***';

#---------------------------------------------------------------------------
sub find_info($$$$$)
#---------------------------------------------------------------------------
{
   my $dbc        = shift;
   my $set_id     = shift;
   my $log_name   = shift;
   my $log_tstamp = shift;
   my $info_name  = shift;
   my $info_value;

   my $info_cursor = $dbc->prepare( "select info_value from WMON_LOG_INFO"
                                  . " where set_id = ?"
                                  .   " and log_name = ?"
                                  .   " and log_tstamp = to_date(?, 'YYYYMMDD:HH24:MI:SS')"
                                  .   " and info_name = ?"
                                  );

   $info_cursor->bind_param(1, $set_id);
   $info_cursor->bind_param(2, $log_name);
   $info_cursor->bind_param(3, $log_tstamp);
   $info_cursor->bind_param(4, $info_name);
   $info_cursor->bind_columns(undef, \$info_value);

   $info_cursor->execute;
   if ( ! $info_cursor->fetch() )
   { 
      $info_value = $NOTFOUND_STRING;
   }
   $info_cursor->finish;

   return $info_value;
}

#---------------------------------------------------------------------------
sub register_info($$$$$$)
#---------------------------------------------------------------------------
{

   my $dbc        = shift;
   my $set_id     = shift;
   my $log_name   = shift;
   my $log_tstamp = shift;
   my $info_name  = shift;
   my $info_value = shift;

   my $x_info = find_info($dbc, $set_id, $log_name, $log_tstamp, $info_name);
   if ( $x_info eq $NOTFOUND_STRING )
   {

      my $insert_row = $dbc->prepare(
           "insert into WMON_LOG_INFO (set_id, log_name, log_tstamp, info_name, info_value) "
         .                    "values (?, ?, to_date(?, 'YYYYMMDD:HH24:MI:SS'), ?, ?)");

      $insert_row->bind_param(1, $set_id);
      $insert_row->bind_param(2, $log_name);
      $insert_row->bind_param(3, $log_tstamp);
      $insert_row->bind_param(4, $info_name);
      $insert_row->bind_param(5, $info_value);
   
      $insert_row->execute;
      $insert_row->finish;
      
   }

}

#---------------------------------------------------------------------------
sub register_logheader
#---------------------------------------------------------------------------
{
   my ($dbc, $set_id, %hinfo) = @_;

   error_out("'Name' not found in Log Header")
      if (not defined $hinfo{'Name'});

   error_out("'Date' not found in Log Header")
      if (not defined $hinfo{'Date'});

   error_out("Invalid 'Date' or date format in Log Header")
      if (not verify_tstamp($hinfo{'Date'}));

   foreach $key (keys %hinfo)
   {

      if ( $key ne 'Date' && $key ne 'Name' )
      {
         register_info( $dbc
                      , $set_id
                      , $hinfo{'Name'}
                      , $hinfo{'Date'}
                      , $key
                      , $hinfo{$key}
                      );
      }

   }

}


#---------------------------------------------------------------------------
sub verify_tstamp($)
#---------------------------------------------------------------------------
{
   my $rawTStamp = shift;
   my $mystatus = 0;

   $rawTStamp =~ s/://g;

   if ( length($rawTStamp) == 14 )
   {
      my $year    = substr($rawTStamp,  0, 4);
      my $month   = substr($rawTStamp,  4, 2);
      my $day     = substr($rawTStamp,  6, 2);
      my $hour    = substr($rawTStamp,  8, 2);
      my $minute  = substr($rawTStamp, 10, 2);
      my $seconds = substr($rawTStamp, 12, 2);

      if ( $year    =~ /[1-9][0-9][0-9][0-9]/ &&
           ($month  =~ /0[1-9]/     || $month =~ /1[0-2]/) &&
           ($day    =~ /[0-2][0-9]/ || $day   =~ /3[0-1]/) &&
           ($hour   =~ /[0-1][0-9]/ || $hour  =~ /2[0-3]/) &&
           $minute  =~ /[0-5][0-9]/ &&
           $seconds =~ /[0-5][0-9]/
         )
      {
         $mystatus = 1;
      }
   }

   return $mystatus;
}

1;
