package wmc_set;
#---------------------------------------------------------
# (#) ./base/tools/wm_consumer/scripts/modules/wmc_set.pm BL_core_schema_8.0.7_8.0.7.4.02_20100413  064938
# (#) 
# COPYRIGHT 2003 WatchMark Corp.
#---------------------------------------------------------
#

use wmc_general;
use DBI;

my $LOG_PREFIX = "logs-";

#---------------------------------------------------------------------------
sub getSetID($$$)
#---------------------------------------------------------------------------
{

   my $dbc        = shift;
   my $site_id    = shift;
   my $set_tstamp = shift;
   my $set_id;

   my $set_cursor = $dbc->prepare( "select set_id from WMON_SITE_SET"
                                 . " where site_id = ?"
                                 .   " and set_tstamp = to_date(?, 'YYYYMMDDHH24MISS')"
                                 );

   $set_cursor->bind_param(1, $site_id);
   $set_cursor->bind_param(2, $set_tstamp);
   $set_cursor->bind_columns(undef, \$set_id);

   $set_cursor->execute;
   if ( ! $set_cursor->fetch() )
   { 
      $set_id = 0;
   }
   $set_cursor->finish;

   return $set_id;
}

#---------------------------------------------------------------------------
sub createNewSet
#---------------------------------------------------------------------------
{
   my ($dbc, $site_id, $set_tstamp) = @_;

   my $insert_row = $dbc->prepare( "insert into WMON_SITE_SET (site_id, set_tstamp) "
                                 . "values (?, to_date(?, 'YYYYMMDDHH24MISS'))"
                                 );
   $insert_row->bind_param(1, $site_id);
   $insert_row->bind_param(2, $set_tstamp);

   $insert_row->execute;
   $insert_row->finish;

   my $set_id = getSetID($dbc, $site_id, $set_tstamp);
   return $set_id;

}

#---------------------------------------------------------------------------
sub getSetInfo
#---------------------------------------------------------------------------
{
   my ($dbc, $site_id, $set_tstamp) = @_;

   my %SetInfo;
   $SetInfo{"TSTAMP"} = $set_tstamp;
   $SetInfo{"ID"} = getSetID($dbc, $site_id, $set_tstamp);

   if ( $SetInfo{"ID"} == 0 )
   {
      $SetInfo{"ID"} = createNewSet($dbc, $site_id
                                        , $SetInfo{"TSTAMP"}
                                   );
   }

   return %SetInfo;
}

#---------------------------------------------------------------------------
sub verify_tstamp($)
#---------------------------------------------------------------------------
{
   my $rawTStamp = shift;
   my $mystatus = 0;

   if ( length($rawTStamp) == 14 )
   {
      my $year    = substr($rawTStamp,  0, 4);
      my $month   = substr($rawTStamp,  4, 2);
      my $day     = substr($rawTStamp,  6, 2);
      my $hour    = substr($rawTStamp,  8, 2);
      my $minute  = substr($rawTStamp, 10, 2);
      my $seconds = substr($rawTStamp, 12, 2);

      if ( $year    =~ /[1-9][0-9][0-9][0-9]/ &&
           ($month  =~ /0[1-9]/     || $month =~ /1[0-2]/) &&
           ($day    =~ /[0-2][0-9]/ || $day   =~ /3[0-1]/) &&
           ($hour   =~ /[0-1][0-9]/ || $hour  =~ /2[0-3]/) &&
           $minute  =~ /[0-5][0-9]/ &&
           $seconds =~ /[0-5][0-9]/
         )
      {
         $mystatus = 1;
      }
   }

   return $mystatus;
}

1;
