#!/usr/bin/env perl -w
#---------------------------------------------------------
# (#) ./base/tools/wm_consumer/scripts/wmc_mps.pl BL_core_schema_8.0.7_8.0.7.4.02_20100413  064938
# (#) 
# COPYRIGHT 2003 WatchMark Corp.
#---------------------------------------------------------
#

BEGIN {
  use File::Basename;
  unshift @INC, dirname($0) . "/modules";
}

use wmc_general;
use wmc_oracle;
use wmc_site;
use wmc_set;
use wmc_file;
use wmc_loginfo;

use Env;

my $SCRIPT_ID     = basename($0);
my $FLEXPM_HOME   = $ENV{"FLEXPM_HOME"} || '';
my $DELIMITER     = '|';
my $ESC_DELIMITER = '\|';

my $SET_FP = F_SET;
my $LOG_FP = F_LOG;

#---------------------------------------------------------------------------
sub process_logfile($$$$)
#---------------------------------------------------------------------------
{
   my $dbc     = shift;
   my $logfile = shift;
   my $site_id = shift;
   my $set_id  = shift;
   my $line;
   my $line_no = 0;
   my $status  = 1;
   my $insert_ok;

   my $cpu;
   my $rest_of_line;
   my $prv_cpu = 999999999;

   my $DATE_FORMAT = "to_date(?, 'YYYYMMDD:HH24:MI:SS')";

   my $log_fp = wmc_file::open_file($LOG_FP, $logfile);
   my %HeaderInfo = wmc_file::read_header($log_fp);

   wmc_loginfo::register_logheader($dbc, $set_id, %HeaderInfo);

   my ($sample_interval, $sample_count) = split(' ', $HeaderInfo{'Options'},2);

   my $InsertStatement =
         "insert into WMON_MPS ( set_id, log_tstamp, sample_tstamp,"
      .                        " cpu, minf, mjf, xcal, intr,"
      .                        " ithr, csw, icsw, migr, smtx,"
      .                        " srw, syscl, usr, sys, wt, idl )"
      .               " values (?,$DATE_FORMAT,$DATE_FORMAT+?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?)";
   my $ParamCount = 20;

   my $db_insert = wmc_oracle::prepareInsert($dbc, $InsertStatement);

   while (<$log_fp>)
   {
      chomp;
      if ( $_ !~ /^[ 	]*#/ && $_ !~ /^[ 	]$/ )
      {
         ($cpu, $rest_of_line) = split($ESC_DELIMITER, $_, 2);

         $line_no ++ if ($cpu <= $prv_cpu );
         $prv_cpu = $cpu;

         $line = $set_id                             . $DELIMITER
               . $HeaderInfo{'Date'}                 . $DELIMITER
               . $HeaderInfo{'Date'}                 . $DELIMITER
               . $line_no * ($sample_interval/86400) . $DELIMITER
               . $_;

          $insert_ok = wmc_oracle::insertRecord($db_insert, $line, $ParamCount);

          if ( ! $insert_ok )
          {
             $status = 0;
             last;
          }
      }
   }

   wmc_file::close_file($log_fp); 
   return $status;
}

#---------------------------------------------------------------------------
sub main()
#---------------------------------------------------------------------------
{
   wmc_general::error_out("FLEXPM_HOME is not set.")
      if ( $FLEXPM_HOME eq '' );

   wmc_general::error_out("$FLEXPM_HOME does not exist.")
      if ( ! -d $FLEXPM_HOME );

   my %options = wmc_general::process_CommandLine;

   if ( $options{'MODE'} eq 'USAGE' )
   {
      wmc_general::show_usage;
   }
   else
   {

      if ( not wmc_set::verify_tstamp($options{'SETTSTAMP'}) )
      {
         wmc_general::error_out( "Invalid SET TStamp ($options{'SETTSTAMP'}). "
                                  . "Use --help to see format." );
      }
   
      my $db = wmc_oracle::dbConnect;
    
      my %SiteInfo = wmc_site::getSiteInfo($db, $options{'SITEDIR'});
      my %SetInfo  = wmc_set::getSetInfo($db, $SiteInfo{"ID"}
                                            , $options{'SETTSTAMP'});
      $process_ok = process_logfile( $db
                                   , $options{'LOGFILE'}
                                   , $SiteInfo{'ID'}
                                   , $SetInfo{'ID'}
                                   );

      if ( $process_ok )
      {
         wmc_oracle::finish($db, 'COMMIT')
      }
      else
      {
         wmc_oracle::finish($db, 'ROLLBACK')
      }
 
      my $dbclose = wmc_oracle::dbDisconnect($db);

      wmc_general::error_out("Errors encountered when loading $options{'LOGFILE'}")
         if (!$process_ok);

   }

   return 0;
}

exit main;
