#!/usr/bin/env perl -w
#---------------------------------------------------------
# (#) ./base/tools/wm_consumer/scripts/wmc_report_defs.pl BL_core_schema_8.0.7_8.0.7.4.02_20100413  064938
# (#) 
# COPYRIGHT 2003 WatchMark Corp.
#---------------------------------------------------------
#

BEGIN {
  use File::Basename;
  unshift @INC, dirname($0) . "/modules";
}

use wmc_general;
use wmc_oracle;
use wmc_site;
use wmc_set;
use wmc_file;
use wmc_loginfo;

use Env;

my $SCRIPT_ID   = basename($0);
my $FLEXPM_HOME = $ENV{"FLEXPM_HOME"} || '';
my $DELIMITER   = '|';

my $SET_FP = F_SET;
my $LOG_FP = F_LOG;

#---------------------------------------------------------------------------
sub process_logfile($$$$)
#---------------------------------------------------------------------------
{
   my $dbc     = shift;
   my $logfile = shift;
   my $site_id = shift;
   my $set_id  = shift;
   my $line;
   my $line_no = 0;
   my $status  = 1;
   my $insert_ok;

   my $DATE_FORMAT  = "to_date(?, 'YYYYMMDD:HH24:MI:SS')";
   my $DATE_FORMAT2 = "to_date(?, 'YYYY/MM/DD HH24:MI:SS')";

   my $log_fp = wmc_file::open_file($LOG_FP, $logfile);
   my %HeaderInfo = wmc_file::read_header($log_fp);

   wmc_loginfo::register_logheader($dbc, $set_id, %HeaderInfo);

   my ($sample_interval, $sample_count) = split(' ', $HeaderInfo{'Options'},2);

   my $InsertStatement =
         "insert into WMON_REPORT_DEFS "
      .              "( set_id, log_tstamp, line_no,"
      .               " report_name, scenario_name, template_name, entity_level,"
      .               " entity_name, field_name, dostored, bh_entity_name,"
      .               " bh_field_name, bh_name, field_type, run_time, task_id )"
      .      " values ( ?, $DATE_FORMAT, ?,"
      .               " ?, ?, ?, ?,"
      .               " ?, ?, ?, ?,"
      .               " ?, ?, ?, $DATE_FORMAT2, ? )";
   my $ParamCount = 16;

   my $db_insert = wmc_oracle::prepareInsert($dbc, $InsertStatement);

   while (<$log_fp>)
   {
      chomp;
      if ( $_ !~ /^[ 	]*#/ && $_ !~ /^[ 	]$/ )
      {
         $line_no++;
         $line = $set_id                             . $DELIMITER
               . $HeaderInfo{'Date'}                 . $DELIMITER
               . $line_no                            . $DELIMITER
               . $_;

         $insert_ok = wmc_oracle::insertRecord($db_insert, $line, $ParamCount);

         if ( ! $insert_ok )
         {
            $status = 0;
            last;
         }
      }
   }

   wmc_file::close_file($log_fp); 
   return $status;
}

#---------------------------------------------------------------------------
sub main()
#---------------------------------------------------------------------------
{
   wmc_general::error_out("FLEXPM_HOME is not set.")
      if ( $FLEXPM_HOME eq '' );

   wmc_general::error_out("$FLEXPM_HOME does not exist.")
      if ( ! -d $FLEXPM_HOME );

   my %options = wmc_general::process_CommandLine;

   if ( $options{'MODE'} eq 'USAGE' )
   {
      wmc_general::show_usage;
   }
   else
   {

      if ( not wmc_set::verify_tstamp($options{'SETTSTAMP'}) )
      {
         wmc_general::error_out( "Invalid SET TStamp ($options{'SETTSTAMP'}). "
                                  . "Use --help to see format." );
      }
   
      my $db = wmc_oracle::dbConnect;
    
      my %SiteInfo = wmc_site::getSiteInfo($db, $options{'SITEDIR'});
      my %SetInfo  = wmc_set::getSetInfo($db, $SiteInfo{"ID"}
                                            , $options{'SETTSTAMP'});
      $process_ok = process_logfile( $db
                                   , $options{'LOGFILE'}
                                   , $SiteInfo{'ID'}
                                   , $SetInfo{'ID'}
                                   );

      if ( $process_ok )
      {
         wmc_oracle::finish($db, 'COMMIT')
      }
      else
      {
         wmc_oracle::finish($db, 'ROLLBACK')
      }
 
      my $dbclose = wmc_oracle::dbDisconnect($db);

      wmc_general::error_out("Errors encountered when loading $options{'LOGFILE'}")
         if (!$process_ok);

   }

   return 0;
}

exit main;
